Coverage for /root/GitHubProjects/impacket/impacket/system_errors.py: 100%

# Coverage for /root/GitHubProjects/impacket/impacket/system_errors.py : 100%

## 2752 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1# SECUREAUTH LABS. Copyright 2018 SecureAuth Corporation. All rights reserved.

2#

3# This software is provided under under a slightly modified version

4# of the Apache Software License. See the accompanying LICENSE file

5# for more information.

6#

7# Author: Alberto Solino (@agsolino)

8#

9# Description:

10# SYSTEM Errors from [MS-ERREF]. Ideally all the files

11# should grab the error codes from here

12#

13

14 ERROR_MESSAGES = {

15 0x00000000: ("ERROR_SUCCESS", "The operation completed successfully."),

16 0x00000001: ("ERROR_INVALID_FUNCTION", "Incorrect function."),

17 0x00000002: ("ERROR_FILE_NOT_FOUND", "The system cannot find the file specified."),

18 0x00000003: ("ERROR_PATH_NOT_FOUND", "The system cannot find the path specified."),

19 0x00000004: ("ERROR_TOO_MANY_OPEN_FILES", "The system cannot open the file."),

20 0x00000005: ("ERROR_ACCESS_DENIED", "Access is denied."),

21 0x00000006: ("ERROR_INVALID_HANDLE", "The handle is invalid."),

22 0x00000007: ("ERROR_ARENA_TRASHED", "The storage control blocks were destroyed."),

23 0x00000008: ("ERROR_NOT_ENOUGH_MEMORY", "Not enough storage is available to process this command."),

24 0x00000009: ("ERROR_INVALID_BLOCK", "The storage control block address is invalid."),

25 0x0000000a: ("ERROR_BAD_ENVIRONMENT", "The environment is incorrect."),

26 0x0000000b: ("ERROR_BAD_FORMAT", "An attempt was made to load a program with an incorrect format."),

27 0x0000000c: ("ERROR_INVALID_ACCESS", "The access code is invalid."),

28 0x0000000d: ("ERROR_INVALID_DATA", "The data is invalid."),

29 0x0000000e: ("ERROR_OUTOFMEMORY", "Not enough storage is available to complete this operation."),

30 0x0000000f: ("ERROR_INVALID_DRIVE", "The system cannot find the drive specified."),

31 0x00000010: ("ERROR_CURRENT_DIRECTORY", "The directory cannot be removed."),

32 0x00000011: ("ERROR_NOT_SAME_DEVICE", "The system cannot move the file to a different disk drive."),

33 0x00000012: ("ERROR_NO_MORE_FILES", "There are no more files."),

34 0x00000013: ("ERROR_WRITE_PROTECT", "The media is write protected."),

35 0x00000014: ("ERROR_BAD_UNIT", "The system cannot find the device specified."),

36 0x00000015: ("ERROR_NOT_READY", "The device is not ready."),

37 0x00000016: ("ERROR_BAD_COMMAND", "The device does not recognize the command."),

38 0x00000017: ("ERROR_CRC", "Data error (cyclic redundancy check)."),

39 0x00000018: ("ERROR_BAD_LENGTH", "The program issued a command but the command length is incorrect."),

40 0x00000019: ("ERROR_SEEK", "The drive cannot locate a specific area or track on the disk."),

41 0x0000001a: ("ERROR_NOT_DOS_DISK", "The specified disk or diskette cannot be accessed."),

42 0x0000001b: ("ERROR_SECTOR_NOT_FOUND", "The drive cannot find the sector requested."),

43 0x0000001c: ("ERROR_OUT_OF_PAPER", "The printer is out of paper."),

44 0x0000001d: ("ERROR_WRITE_FAULT", "The system cannot write to the specified device."),

45 0x0000001e: ("ERROR_READ_FAULT", "The system cannot read from the specified device."),

46 0x0000001f: ("ERROR_GEN_FAILURE", "A device attached to the system is not functioning."),

47 0x00000020: ("ERROR_SHARING_VIOLATION", "The process cannot access the file because it is being used by another process."),

48 0x00000021: ("ERROR_LOCK_VIOLATION", "The process cannot access the file because another process has locked a portion of the file."),

49 0x00000022: ("ERROR_WRONG_DISK", "The wrong diskette is in the drive."),

50 0x00000024: ("ERROR_SHARING_BUFFER_EXCEEDED", "Too many files opened for sharing."),

51 0x00000026: ("ERROR_HANDLE_EOF", "Reached the end of the file."),

52 0x00000027: ("ERROR_HANDLE_DISK_FULL", "The disk is full."),

53 0x00000032: ("ERROR_NOT_SUPPORTED", "The request is not supported."),

54 0x00000033: ("ERROR_REM_NOT_LIST", "Windows cannot find the network path. Verify that the network path is correct and the destination computer is not busy or turned off. If Windows still cannot find the network path, contact your network administrator."),

55 0x00000034: ("ERROR_DUP_NAME", "You were not connected because a duplicate name exists on the network. If joining a domain, go to System in Control Panel to change the computer name and try again. If joining a workgroup, choose another workgroup name."),

56 0x00000035: ("ERROR_BAD_NETPATH", "The network path was not found."),

57 0x00000036: ("ERROR_NETWORK_BUSY", "The network is busy."),

58 0x00000037: ("ERROR_DEV_NOT_EXIST", "The specified network resource or device is no longer available."),

59 0x00000038: ("ERROR_TOO_MANY_CMDS", "The network BIOS command limit has been reached."),

60 0x00000039: ("ERROR_ADAP_HDW_ERR", "A network adapter hardware error occurred."),

61 0x0000003a: ("ERROR_BAD_NET_RESP", "The specified server cannot perform the requested operation."),

62 0x0000003b: ("ERROR_UNEXP_NET_ERR", "An unexpected network error occurred."),

63 0x0000003c: ("ERROR_BAD_REM_ADAP", "The remote adapter is not compatible."),

64 0x0000003d: ("ERROR_PRINTQ_FULL", "The printer queue is full."),

65 0x0000003e: ("ERROR_NO_SPOOL_SPACE", "Space to store the file waiting to be printed is not available on the server."),

66 0x0000003f: ("ERROR_PRINT_CANCELLED", "Your file waiting to be printed was deleted."),

67 0x00000040: ("ERROR_NETNAME_DELETED", "The specified network name is no longer available."),

68 0x00000041: ("ERROR_NETWORK_ACCESS_DENIED", "Network access is denied."),

69 0x00000042: ("ERROR_BAD_DEV_TYPE", "The network resource type is not correct."),

70 0x00000043: ("ERROR_BAD_NET_NAME", "The network name cannot be found."),

71 0x00000044: ("ERROR_TOO_MANY_NAMES", "The name limit for the local computer network adapter card was exceeded."),

72 0x00000045: ("ERROR_TOO_MANY_SESS", "The network BIOS session limit was exceeded."),

73 0x00000046: ("ERROR_SHARING_PAUSED", "The remote server has been paused or is in the process of being started."),

74 0x00000047: ("ERROR_REQ_NOT_ACCEP", "No more connections can be made to this remote computer at this time because there are already as many connections as the computer can accept."),

75 0x00000048: ("ERROR_REDIR_PAUSED", "The specified printer or disk device has been paused."),

76 0x00000050: ("ERROR_FILE_EXISTS", "The file exists."),

77 0x00000052: ("ERROR_CANNOT_MAKE", "The directory or file cannot be created."),

78 0x00000053: ("ERROR_FAIL_I24", "Fail on INT 24."),

79 0x00000054: ("ERROR_OUT_OF_STRUCTURES", "Storage to process this request is not available."),

80 0x00000055: ("ERROR_ALREADY_ASSIGNED", "The local device name is already in use."),

81 0x00000056: ("ERROR_INVALID_PASSWORD", "The specified network password is not correct."),

82 0x00000057: ("ERROR_INVALID_PARAMETER", "The parameter is incorrect."),

83 0x00000058: ("ERROR_NET_WRITE_FAULT", "A write fault occurred on the network."),

84 0x00000059: ("ERROR_NO_PROC_SLOTS", "The system cannot start another process at this time."),

85 0x00000064: ("ERROR_TOO_MANY_SEMAPHORES", "Cannot create another system semaphore."),

86 0x00000065: ("ERROR_EXCL_SEM_ALREADY_OWNED", "The exclusive semaphore is owned by another process."),

87 0x00000066: ("ERROR_SEM_IS_SET", "The semaphore is set and cannot be closed."),

88 0x00000067: ("ERROR_TOO_MANY_SEM_REQUESTS", "The semaphore cannot be set again."),

89 0x00000068: ("ERROR_INVALID_AT_INTERRUPT_TIME", "Cannot request exclusive semaphores at interrupt time."),

90 0x00000069: ("ERROR_SEM_OWNER_DIED", "The previous ownership of this semaphore has ended."),

91 0x0000006a: ("ERROR_SEM_USER_LIMIT", "Insert the diskette for drive %1."),

92 0x0000006b: ("ERROR_DISK_CHANGE", "The program stopped because an alternate diskette was not inserted."),

93 0x0000006c: ("ERROR_DRIVE_LOCKED", "The disk is in use or locked by another process."),

94 0x0000006d: ("ERROR_BROKEN_PIPE", "The pipe has been ended."),

95 0x0000006e: ("ERROR_OPEN_FAILED", "The system cannot open the device or file specified."),

96 0x0000006f: ("ERROR_BUFFER_OVERFLOW", "The file name is too long."),

97 0x00000070: ("ERROR_DISK_FULL", "There is not enough space on the disk."),

98 0x00000071: ("ERROR_NO_MORE_SEARCH_HANDLES", "No more internal file identifiers available."),

99 0x00000072: ("ERROR_INVALID_TARGET_HANDLE", "The target internal file identifier is incorrect."),

100 0x00000075: ("ERROR_INVALID_CATEGORY", "The IOCTL call made by the application program is not correct."),

101 0x00000076: ("ERROR_INVALID_VERIFY_SWITCH", "The verify-on-write switch parameter value is not correct."),

102 0x00000077: ("ERROR_BAD_DRIVER_LEVEL", "The system does not support the command requested."),

103 0x00000078: ("ERROR_CALL_NOT_IMPLEMENTED", "This function is not supported on this system."),

104 0x00000079: ("ERROR_SEM_TIMEOUT", "The semaphore timeout period has expired."),

105 0x0000007a: ("ERROR_INSUFFICIENT_BUFFER", "The data area passed to a system call is too small."),

106 0x0000007b: ("ERROR_INVALID_NAME", "The filename, directory name, or volume label syntax is incorrect."),

107 0x0000007c: ("ERROR_INVALID_LEVEL", "The system call level is not correct."),

108 0x0000007d: ("ERROR_NO_VOLUME_LABEL", "The disk has no volume label."),

109 0x0000007e: ("ERROR_MOD_NOT_FOUND", "The specified module could not be found."),

110 0x0000007f: ("ERROR_PROC_NOT_FOUND", "The specified procedure could not be found."),

111 0x00000080: ("ERROR_WAIT_NO_CHILDREN", "There are no child processes to wait for."),

112 0x00000081: ("ERROR_CHILD_NOT_COMPLETE", "The %1 application cannot be run in Win32 mode."),

113 0x00000082: ("ERROR_DIRECT_ACCESS_HANDLE", "Attempt to use a file handle to an open disk partition for an operation other than raw disk I/O."),

114 0x00000083: ("ERROR_NEGATIVE_SEEK", "An attempt was made to move the file pointer before the beginning of the file."),

115 0x00000084: ("ERROR_SEEK_ON_DEVICE", "The file pointer cannot be set on the specified device or file."),

116 0x00000085: ("ERROR_IS_JOIN_TARGET", "A JOIN or SUBST command cannot be used for a drive that contains previously joined drives."),

117 0x00000086: ("ERROR_IS_JOINED", "An attempt was made to use a JOIN or SUBST command on a drive that has already been joined."),

118 0x00000087: ("ERROR_IS_SUBSTED", "An attempt was made to use a JOIN or SUBST command on a drive that has already been substituted."),

119 0x00000088: ("ERROR_NOT_JOINED", "The system tried to delete the JOIN of a drive that is not joined."),

120 0x00000089: ("ERROR_NOT_SUBSTED", "The system tried to delete the substitution of a drive that is not substituted."),

121 0x0000008a: ("ERROR_JOIN_TO_JOIN", "The system tried to join a drive to a directory on a joined drive."),

122 0x0000008b: ("ERROR_SUBST_TO_SUBST", "The system tried to substitute a drive to a directory on a substituted drive."),

123 0x0000008c: ("ERROR_JOIN_TO_SUBST", "The system tried to join a drive to a directory on a substituted drive."),

124 0x0000008d: ("ERROR_SUBST_TO_JOIN", "The system tried to SUBST a drive to a directory on a joined drive."),

125 0x0000008e: ("ERROR_BUSY_DRIVE", "The system cannot perform a JOIN or SUBST at this time."),

126 0x0000008f: ("ERROR_SAME_DRIVE", "The system cannot join or substitute a drive to or for a directory on the same drive."),

127 0x00000090: ("ERROR_DIR_NOT_ROOT", "The directory is not a subdirectory of the root directory."),

128 0x00000091: ("ERROR_DIR_NOT_EMPTY", "The directory is not empty."),

129 0x00000092: ("ERROR_IS_SUBST_PATH", "The path specified is being used in a substitute."),

130 0x00000093: ("ERROR_IS_JOIN_PATH", "Not enough resources are available to process this command."),

131 0x00000094: ("ERROR_PATH_BUSY", "The path specified cannot be used at this time."),

132 0x00000095: ("ERROR_IS_SUBST_TARGET", "An attempt was made to join or substitute a drive for which a directory on the drive is the target of a previous substitute."),

133 0x00000096: ("ERROR_SYSTEM_TRACE", "System trace information was not specified in your CONFIG.SYS file, or tracing is disallowed."),

134 0x00000097: ("ERROR_INVALID_EVENT_COUNT", "The number of specified semaphore events for DosMuxSemWait is not correct."),

135 0x00000098: ("ERROR_TOO_MANY_MUXWAITERS", "DosMuxSemWait did not execute; too many semaphores are already set."),

136 0x00000099: ("ERROR_INVALID_LIST_FORMAT", "The DosMuxSemWait list is not correct."),

137 0x0000009a: ("ERROR_LABEL_TOO_LONG", "The volume label you entered exceeds the label character limit of the target file system."),

138 0x0000009b: ("ERROR_TOO_MANY_TCBS", "Cannot create another thread."),

139 0x0000009c: ("ERROR_SIGNAL_REFUSED", "The recipient process has refused the signal."),

140 0x0000009d: ("ERROR_DISCARDED", "The segment is already discarded and cannot be locked."),

141 0x0000009e: ("ERROR_NOT_LOCKED", "The segment is already unlocked."),

142 0x0000009f: ("ERROR_BAD_THREADID_ADDR", "The address for the thread ID is not correct."),

143 0x000000a0: ("ERROR_BAD_ARGUMENTS", "One or more arguments are not correct."),

144 0x000000a1: ("ERROR_BAD_PATHNAME", "The specified path is invalid."),

145 0x000000a2: ("ERROR_SIGNAL_PENDING", "A signal is already pending."),

146 0x000000a4: ("ERROR_MAX_THRDS_REACHED", "No more threads can be created in the system."),

147 0x000000a7: ("ERROR_LOCK_FAILED", "Unable to lock a region of a file."),

148 0x000000aa: ("ERROR_BUSY", "The requested resource is in use."),

149 0x000000ab: ("ERROR_DEVICE_SUPPORT_IN_PROGRESS", "Device's command support detection is in progress."),

150 0x000000ad: ("ERROR_CANCEL_VIOLATION", "A lock request was not outstanding for the supplied cancel region."),

151 0x000000ae: ("ERROR_ATOMIC_LOCKS_NOT_SUPPORTED", "The file system does not support atomic changes to the lock type."),

152 0x000000b4: ("ERROR_INVALID_SEGMENT_NUMBER", "The system detected a segment number that was not correct."),

153 0x000000b6: ("ERROR_INVALID_ORDINAL", "The operating system cannot run %1."),

154 0x000000b7: ("ERROR_ALREADY_EXISTS", "Cannot create a file when that file already exists."),

155 0x000000ba: ("ERROR_INVALID_FLAG_NUMBER", "The flag passed is not correct."),

156 0x000000bb: ("ERROR_SEM_NOT_FOUND", "The specified system semaphore name was not found."),

157 0x000000bc: ("ERROR_INVALID_STARTING_CODESEG", "The operating system cannot run %1."),

158 0x000000bd: ("ERROR_INVALID_STACKSEG", "The operating system cannot run %1."),

159 0x000000be: ("ERROR_INVALID_MODULETYPE", "The operating system cannot run %1."),

160 0x000000bf: ("ERROR_INVALID_EXE_SIGNATURE", "Cannot run %1 in Win32 mode."),

161 0x000000c0: ("ERROR_EXE_MARKED_INVALID", "The operating system cannot run %1."),

162 0x000000c1: ("ERROR_BAD_EXE_FORMAT", "%1 is not a valid Win32 application."),

163 0x000000c2: ("ERROR_ITERATED_DATA_EXCEEDS_64k", "The operating system cannot run %1."),

164 0x000000c3: ("ERROR_INVALID_MINALLOCSIZE", "The operating system cannot run %1."),

165 0x000000c4: ("ERROR_DYNLINK_FROM_INVALID_RING", "The operating system cannot run this application program."),

166 0x000000c5: ("ERROR_IOPL_NOT_ENABLED", "The operating system is not presently configured to run this application."),

167 0x000000c6: ("ERROR_INVALID_SEGDPL", "The operating system cannot run %1."),

168 0x000000c7: ("ERROR_AUTODATASEG_EXCEEDS_64k", "The operating system cannot run this application program."),

169 0x000000c8: ("ERROR_RING2SEG_MUST_BE_MOVABLE", "The code segment cannot be greater than or equal to 64K."),

170 0x000000c9: ("ERROR_RELOC_CHAIN_XEEDS_SEGLIM", "The operating system cannot run %1."),

171 0x000000ca: ("ERROR_INFLOOP_IN_RELOC_CHAIN", "The operating system cannot run %1."),

172 0x000000cb: ("ERROR_ENVVAR_NOT_FOUND", "The system could not find the environment option that was entered."),

173 0x000000cd: ("ERROR_NO_SIGNAL_SENT", "No process in the command subtree has a signal handler."),

174 0x000000ce: ("ERROR_FILENAME_EXCED_RANGE", "The filename or extension is too long."),

175 0x000000cf: ("ERROR_RING2_STACK_IN_USE", "The ring 2 stack is in use."),

176 0x000000d0: ("ERROR_META_EXPANSION_TOO_LONG", "The global filename characters, * or ?, are entered incorrectly or too many global filename characters are specified."),

177 0x000000d1: ("ERROR_INVALID_SIGNAL_NUMBER", "The signal being posted is not correct."),

178 0x000000d2: ("ERROR_THREAD_1_INACTIVE", "The signal handler cannot be set."),

179 0x000000d4: ("ERROR_LOCKED", "The segment is locked and cannot be reallocated."),

180 0x000000d6: ("ERROR_TOO_MANY_MODULES", "Too many dynamic-link modules are attached to this program or dynamic-link module."),

181 0x000000d7: ("ERROR_NESTING_NOT_ALLOWED", "Cannot nest calls to LoadModule."),

182 0x000000d8: ("ERROR_EXE_MACHINE_TYPE_MISMATCH", "This version of %1 is not compatible with the version of Windows you're running. Check your computer's system information and then contact the software publisher."),

183 0x000000d9: ("ERROR_EXE_CANNOT_MODIFY_SIGNED_BINARY", "The image file %1 is signed, unable to modify."),

184 0x000000da: ("ERROR_EXE_CANNOT_MODIFY_STRONG_SIGNED_BINARY", "The image file %1 is strong signed, unable to modify."),

185 0x000000dc: ("ERROR_FILE_CHECKED_OUT", "This file is checked out or locked for editing by another user."),

186 0x000000dd: ("ERROR_CHECKOUT_REQUIRED", "The file must be checked out before saving changes."),

187 0x000000de: ("ERROR_BAD_FILE_TYPE", "The file type being saved or retrieved has been blocked."),

188 0x000000df: ("ERROR_FILE_TOO_LARGE", "The file size exceeds the limit allowed and cannot be saved."),

189 0x000000e0: ("ERROR_FORMS_AUTH_REQUIRED", "Access Denied. Before opening files in this location, you must first add the web site to your trusted sites list, browse to the web site, and select the option to login automatically."),

190 0x000000e1: ("ERROR_VIRUS_INFECTED", "Operation did not complete successfully because the file contains a virus or potentially unwanted software."),

191 0x000000e2: ("ERROR_VIRUS_DELETED", "This file contains a virus or potentially unwanted software and cannot be opened. Due to the nature of this virus or potentially unwanted software, the file has been removed from this location."),

192 0x000000e5: ("ERROR_PIPE_LOCAL", "The pipe is local."),

193 0x000000e6: ("ERROR_BAD_PIPE", "The pipe state is invalid."),

194 0x000000e7: ("ERROR_PIPE_BUSY", "All pipe instances are busy."),

195 0x000000e8: ("ERROR_NO_DATA", "The pipe is being closed."),

196 0x000000e9: ("ERROR_PIPE_NOT_CONNECTED", "No process is on the other end of the pipe."),

197 0x000000ea: ("ERROR_MORE_DATA", "More data is available."),

198 0x000000f0: ("ERROR_VC_DISCONNECTED", "The session was canceled."),

199 0x000000fe: ("ERROR_INVALID_EA_NAME", "The specified extended attribute name was invalid."),

200 0x000000ff: ("ERROR_EA_LIST_INCONSISTENT", "The extended attributes are inconsistent."),

201 0x00000102: ("WAIT_TIMEOUT", "The wait operation timed out."),

202 0x00000103: ("ERROR_NO_MORE_ITEMS", "No more data is available."),

203 0x0000010a: ("ERROR_CANNOT_COPY", "The copy functions cannot be used."),

204 0x0000010b: ("ERROR_DIRECTORY", "The directory name is invalid."),

205 0x00000113: ("ERROR_EAS_DIDNT_FIT", "The extended attributes did not fit in the buffer."),

206 0x00000114: ("ERROR_EA_FILE_CORRUPT", "The extended attribute file on the mounted file system is corrupt."),

207 0x00000115: ("ERROR_EA_TABLE_FULL", "The extended attribute table file is full."),

208 0x00000116: ("ERROR_INVALID_EA_HANDLE", "The specified extended attribute handle is invalid."),

209 0x0000011a: ("ERROR_EAS_NOT_SUPPORTED", "The mounted file system does not support extended attributes."),

210 0x00000120: ("ERROR_NOT_OWNER", "Attempt to release mutex not owned by caller."),

211 0x0000012a: ("ERROR_TOO_MANY_POSTS", "Too many posts were made to a semaphore."),

212 0x0000012b: ("ERROR_PARTIAL_COPY", "Only part of a ReadProcessMemory or WriteProcessMemory request was completed."),

213 0x0000012c: ("ERROR_OPLOCK_NOT_GRANTED", "The oplock request is denied."),

214 0x0000012d: ("ERROR_INVALID_OPLOCK_PROTOCOL", "An invalid oplock acknowledgment was received by the system."),

215 0x0000012e: ("ERROR_DISK_TOO_FRAGMENTED", "The volume is too fragmented to complete this operation."),

216 0x0000012f: ("ERROR_DELETE_PENDING", "The file cannot be opened because it is in the process of being deleted."),

217 0x00000130: ("ERROR_INCOMPATIBLE_WITH_GLOBAL_SHORT_NAME_REGISTRY_SETTING", "Short name settings may not be changed on this volume due to the global registry setting."),

218 0x00000131: ("ERROR_SHORT_NAMES_NOT_ENABLED_ON_VOLUME", "Short names are not enabled on this volume."),

219 0x00000132: ("ERROR_SECURITY_STREAM_IS_INCONSISTENT", "The security stream for the given volume is in an inconsistent state."),

220 0x00000133: ("ERROR_INVALID_LOCK_RANGE", "A requested file lock operation cannot be processed due to an invalid byte range."),

221 0x00000134: ("ERROR_IMAGE_SUBSYSTEM_NOT_PRESENT", "The subsystem needed to support the image type is not present."),

222 0x00000135: ("ERROR_NOTIFICATION_GUID_ALREADY_DEFINED", "The specified file already has a notification GUID associated with it."),

223 0x00000136: ("ERROR_INVALID_EXCEPTION_HANDLER", "An invalid exception handler routine has been detected."),

224 0x00000137: ("ERROR_DUPLICATE_PRIVILEGES", "Duplicate privileges were specified for the token."),

225 0x00000138: ("ERROR_NO_RANGES_PROCESSED", "No ranges for the specified operation were able to be processed."),

226 0x00000139: ("ERROR_NOT_ALLOWED_ON_SYSTEM_FILE", "Operation is not allowed on a file system internal file."),

227 0x0000013a: ("ERROR_DISK_RESOURCES_EXHAUSTED", "The physical resources of this disk have been exhausted."),

228 0x0000013b: ("ERROR_INVALID_TOKEN", "The token representing the data is invalid."),

229 0x0000013c: ("ERROR_DEVICE_FEATURE_NOT_SUPPORTED", "The device does not support the command feature."),

230 0x0000013d: ("ERROR_MR_MID_NOT_FOUND", "The system cannot find message text for message number 0x%1 in the message file for %2."),

231 0x0000013e: ("ERROR_SCOPE_NOT_FOUND", "The scope specified was not found."),

232 0x0000013f: ("ERROR_UNDEFINED_SCOPE", "The Central Access Policy specified is not defined on the target machine."),

233 0x00000140: ("ERROR_INVALID_CAP", "The Central Access Policy obtained from Active Directory is invalid."),

234 0x00000141: ("ERROR_DEVICE_UNREACHABLE", "The device is unreachable."),

235 0x00000142: ("ERROR_DEVICE_NO_RESOURCES", "The target device has insufficient resources to complete the operation."),

236 0x00000143: ("ERROR_DATA_CHECKSUM_ERROR", "A data integrity checksum error occurred. Data in the file stream is corrupt."),

237 0x00000144: ("ERROR_INTERMIXED_KERNEL_EA_OPERATION", "An attempt was made to modify both a KERNEL and normal Extended Attribute (EA) in the same operation."),

238 0x00000146: ("ERROR_FILE_LEVEL_TRIM_NOT_SUPPORTED", "Device does not support file-level TRIM."),

239 0x00000147: ("ERROR_OFFSET_ALIGNMENT_VIOLATION", "The command specified a data offset that does not align to the device's granularity/alignment."),

240 0x00000148: ("ERROR_INVALID_FIELD_IN_PARAMETER_LIST", "The command specified an invalid field in its parameter list."),

241 0x00000149: ("ERROR_OPERATION_IN_PROGRESS", "An operation is currently in progress with the device."),

242 0x0000014a: ("ERROR_BAD_DEVICE_PATH", "An attempt was made to send down the command via an invalid path to the target device."),

243 0x0000014b: ("ERROR_TOO_MANY_DESCRIPTORS", "The command specified a number of descriptors that exceeded the maximum supported by the device."),

244 0x0000014c: ("ERROR_SCRUB_DATA_DISABLED", "Scrub is disabled on the specified file."),

245 0x0000014d: ("ERROR_NOT_REDUNDANT_STORAGE", "The storage device does not provide redundancy."),

246 0x0000014e: ("ERROR_RESIDENT_FILE_NOT_SUPPORTED", "An operation is not supported on a resident file."),

247 0x0000014f: ("ERROR_COMPRESSED_FILE_NOT_SUPPORTED", "An operation is not supported on a compressed file."),

248 0x00000150: ("ERROR_DIRECTORY_NOT_SUPPORTED", "An operation is not supported on a directory."),

249 0x00000151: ("ERROR_NOT_READ_FROM_COPY", "The specified copy of the requested data could not be read."),

250 0x00000152: ("ERROR_FT_WRITE_FAILURE", "The specified data could not be written to any of the copies."),

251 0x00000153: ("ERROR_FT_DI_SCAN_REQUIRED", "One or more copies of data on this device may be out of sync. No writes may be performed until a data integrity scan is completed."),

252 0x00000154: ("ERROR_INVALID_KERNEL_INFO_VERSION", "The supplied kernel information version is invalid."),

253 0x00000155: ("ERROR_INVALID_PEP_INFO_VERSION", "The supplied PEP information version is invalid."),

254 0x0000015e: ("ERROR_FAIL_NOACTION_REBOOT", "No action was taken as a system reboot is required."),

255 0x0000015f: ("ERROR_FAIL_SHUTDOWN", "The shutdown operation failed."),

256 0x00000160: ("ERROR_FAIL_RESTART", "The restart operation failed."),

257 0x00000161: ("ERROR_MAX_SESSIONS_REACHED", "The maximum number of sessions has been reached."),

258 0x00000190: ("ERROR_THREAD_MODE_ALREADY_BACKGROUND", "The thread is already in background processing mode."),

259 0x00000191: ("ERROR_THREAD_MODE_NOT_BACKGROUND", "The thread is not in background processing mode."),

260 0x00000192: ("ERROR_PROCESS_MODE_ALREADY_BACKGROUND", "The process is already in background processing mode."),

261 0x00000193: ("ERROR_PROCESS_MODE_NOT_BACKGROUND", "The process is not in background processing mode."),

262 0x000001e7: ("ERROR_INVALID_ADDRESS", "Attempt to access invalid address."),

263 0x000001f4: ("ERROR_USER_PROFILE_LOAD", "User profile cannot be loaded."),

264 0x00000216: ("ERROR_ARITHMETIC_OVERFLOW", "Arithmetic result exceeded 32 bits."),

265 0x00000217: ("ERROR_PIPE_CONNECTED", "There is a process on other end of the pipe."),

266 0x00000218: ("ERROR_PIPE_LISTENING", "Waiting for a process to open the other end of the pipe."),

267 0x00000219: ("ERROR_VERIFIER_STOP", "Application verifier has found an error in the current process."),

268 0x0000021a: ("ERROR_ABIOS_ERROR", "An error occurred in the ABIOS subsystem."),

269 0x0000021b: ("ERROR_WX86_WARNING", "A warning occurred in the WX86 subsystem."),

270 0x0000021c: ("ERROR_WX86_ERROR", "An error occurred in the WX86 subsystem."),

271 0x0000021d: ("ERROR_TIMER_NOT_CANCELED", "An attempt was made to cancel or set a timer that has an associated APC and the subject thread is not the thread that originally set the timer with an associated APC routine."),

272 0x0000021e: ("ERROR_UNWIND", "Unwind exception code."),

273 0x0000021f: ("ERROR_BAD_STACK", "An invalid or unaligned stack was encountered during an unwind operation."),

274 0x00000220: ("ERROR_INVALID_UNWIND_TARGET", "An invalid unwind target was encountered during an unwind operation."),

275 0x00000221: ("ERROR_INVALID_PORT_ATTRIBUTES", "Invalid Object Attributes specified to NtCreatePort or invalid Port Attributes specified to NtConnectPort"),

276 0x00000222: ("ERROR_PORT_MESSAGE_TOO_LONG", "Length of message passed to NtRequestPort or NtRequestWaitReplyPort was longer than the maximum message allowed by the port."),

277 0x00000223: ("ERROR_INVALID_QUOTA_LOWER", "An attempt was made to lower a quota limit below the current usage."),

278 0x00000224: ("ERROR_DEVICE_ALREADY_ATTACHED", "An attempt was made to attach to a device that was already attached to another device."),

279 0x00000225: ("ERROR_INSTRUCTION_MISALIGNMENT", "An attempt was made to execute an instruction at an unaligned address and the host system does not support unaligned instruction references."),

280 0x00000226: ("ERROR_PROFILING_NOT_STARTED", "Profiling not started."),

281 0x00000227: ("ERROR_PROFILING_NOT_STOPPED", "Profiling not stopped."),

282 0x00000228: ("ERROR_COULD_NOT_INTERPRET", "The passed ACL did not contain the minimum required information."),

283 0x00000229: ("ERROR_PROFILING_AT_LIMIT", "The number of active profiling objects is at the maximum and no more may be started."),

284 0x0000022a: ("ERROR_CANT_WAIT", "Used to indicate that an operation cannot continue without blocking for I/O."),

285 0x0000022b: ("ERROR_CANT_TERMINATE_SELF", "Indicates that a thread attempted to terminate itself by default (called NtTerminateThread with NULL) and it was the last thread in the current process."),

286 0x0000022c: ("ERROR_UNEXPECTED_MM_CREATE_ERR", "If an MM error is returned which is not defined in the standard FsRtl filter, it is converted to one of the following errors which is guaranteed to be in the filter."),

287 0x0000022d: ("ERROR_UNEXPECTED_MM_MAP_ERROR", "If an MM error is returned which is not defined in the standard FsRtl filter, it is converted to one of the following errors which is guaranteed to be in the filter."),

288 0x0000022e: ("ERROR_UNEXPECTED_MM_EXTEND_ERR", "If an MM error is returned which is not defined in the standard FsRtl filter, it is converted to one of the following errors which is guaranteed to be in the filter."),

289 0x0000022f: ("ERROR_BAD_FUNCTION_TABLE", "A malformed function table was encountered during an unwind operation."),

290 0x00000230: ("ERROR_NO_GUID_TRANSLATION", "Indicates that an attempt was made to assign protection to a file system file or directory and one of the SIDs in the security descriptor could not be translated into a GUID that could be stored by the file system."),

291 0x00000231: ("ERROR_INVALID_LDT_SIZE", "Indicates that an attempt was made to grow an LDT by setting its size, or that the size was not an even number of selectors."),

292 0x00000233: ("ERROR_INVALID_LDT_OFFSET", "Indicates that the starting value for the LDT information was not an integral multiple of the selector size."),

293 0x00000234: ("ERROR_INVALID_LDT_DESCRIPTOR", "Indicates that the user supplied an invalid descriptor when trying to set up Ldt descriptors."),

294 0x00000235: ("ERROR_TOO_MANY_THREADS", "Indicates a process has too many threads to perform the requested action. For example, assignment of a primary token may only be performed when a process has zero or one threads."),

295 0x00000236: ("ERROR_THREAD_NOT_IN_PROCESS", "An attempt was made to operate on a thread within a specific process, but the thread specified is not in the process specified."),

296 0x00000237: ("ERROR_PAGEFILE_QUOTA_EXCEEDED", "Page file quota was exceeded."),

297 0x00000238: ("ERROR_LOGON_SERVER_CONFLICT", "The Netlogon service cannot start because another Netlogon service running in the domain conflicts with the specified role."),

298 0x00000239: ("ERROR_SYNCHRONIZATION_REQUIRED", "The SAM database on a Windows Server is significantly out of synchronization with the copy on the Domain Controller. A complete synchronization is required."),

299 0x0000023a: ("ERROR_NET_OPEN_FAILED", "The NtCreateFile API failed. This error should never be returned to an application, it is a place holder for the Windows Lan Manager Redirector to use in its internal error mapping routines."),

300 0x0000023b: ("ERROR_IO_PRIVILEGE_FAILED", "{Privilege Failed}"),

301 0x0000023c: ("ERROR_CONTROL_C_EXIT", "{Application Exit by CTRL+C}"),

302 0x0000023d: ("ERROR_MISSING_SYSTEMFILE", "{Missing System File}"),

303 0x0000023e: ("ERROR_UNHANDLED_EXCEPTION", "{Application Error}"),

304 0x0000023f: ("ERROR_APP_INIT_FAILURE", "{Application Error}"),

305 0x00000240: ("ERROR_PAGEFILE_CREATE_FAILED", "{Unable to Create Paging File}"),

306 0x00000241: ("ERROR_INVALID_IMAGE_HASH", "Windows cannot verify the digital signature for this file. A recent hardware or software change might have installed a file that is signed incorrectly or damaged, or that might be malicious software from an unknown source."),

307 0x00000242: ("ERROR_NO_PAGEFILE", "{No Paging File Specified}"),

308 0x00000243: ("ERROR_ILLEGAL_FLOAT_CONTEXT", "{EXCEPTION}"),

309 0x00000244: ("ERROR_NO_EVENT_PAIR", "An event pair synchronization operation was performed using the thread specific client/server event pair object, but no event pair object was associated with the thread."),

310 0x00000245: ("ERROR_DOMAIN_CTRLR_CONFIG_ERROR", "A Windows Server has an incorrect configuration."),

311 0x00000246: ("ERROR_ILLEGAL_CHARACTER", "An illegal character was encountered. For a multi-byte character set this includes a lead byte without a succeeding trail byte. For the Unicode character set this includes the characters 0xFFFF and 0xFFFE."),

312 0x00000247: ("ERROR_UNDEFINED_CHARACTER", "The Unicode character is not defined in the Unicode character set installed on the system."),

313 0x00000248: ("ERROR_FLOPPY_VOLUME", "The paging file cannot be created on a floppy diskette."),

314 0x00000249: ("ERROR_BIOS_FAILED_TO_CONNECT_INTERRUPT", "The system BIOS failed to connect a system interrupt to the device or bus for which the device is connected."),

315 0x0000024a: ("ERROR_BACKUP_CONTROLLER", "This operation is only allowed for the Primary Domain Controller of the domain."),

316 0x0000024b: ("ERROR_MUTANT_LIMIT_EXCEEDED", "An attempt was made to acquire a mutant such that its maximum count would have been exceeded."),

317 0x0000024c: ("ERROR_FS_DRIVER_REQUIRED", "A volume has been accessed for which a file system driver is required that has not yet been loaded."),

318 0x0000024d: ("ERROR_CANNOT_LOAD_REGISTRY_FILE", "{Registry File Failure}"),

319 0x0000024e: ("ERROR_DEBUG_ATTACH_FAILED", "{Unexpected Failure in DebugActiveProcess}"),

320 0x0000024f: ("ERROR_SYSTEM_PROCESS_TERMINATED", "{Fatal System Error}"),

321 0x00000250: ("ERROR_DATA_NOT_ACCEPTED", "{Data Not Accepted}"),

322 0x00000251: ("ERROR_VDM_HARD_ERROR", "NTVDM encountered a hard error."),

323 0x00000252: ("ERROR_DRIVER_CANCEL_TIMEOUT", "{Cancel Timeout}"),

324 0x00000253: ("ERROR_REPLY_MESSAGE_MISMATCH", "{Reply Message Mismatch}"),

325 0x00000254: ("ERROR_LOST_WRITEBEHIND_DATA", "{Delayed Write Failed}"),

326 0x00000255: ("ERROR_CLIENT_SERVER_PARAMETERS_INVALID", "The parameter(s) passed to the server in the client/server shared memory window were invalid. Too much data may have been put in the shared memory window."),

327 0x00000256: ("ERROR_NOT_TINY_STREAM", "The stream is not a tiny stream."),

328 0x00000257: ("ERROR_STACK_OVERFLOW_READ", "The request must be handled by the stack overflow code."),

329 0x00000258: ("ERROR_CONVERT_TO_LARGE", "Internal OFS status codes indicating how an allocation operation is handled. Either it is retried after the containing onode is moved or the extent stream is converted to a large stream."),

330 0x00000259: ("ERROR_FOUND_OUT_OF_SCOPE", "The attempt to find the object found an object matching by ID on the volume but it is out of the scope of the handle used for the operation."),

331 0x0000025a: ("ERROR_ALLOCATE_BUCKET", "The bucket array must be grown. Retry transaction after doing so."),

332 0x0000025b: ("ERROR_MARSHALL_OVERFLOW", "The user/kernel marshalling buffer has overflowed."),

333 0x0000025c: ("ERROR_INVALID_VARIANT", "The supplied variant structure contains invalid data."),

334 0x0000025d: ("ERROR_BAD_COMPRESSION_BUFFER", "The specified buffer contains ill-formed data."),

335 0x0000025e: ("ERROR_AUDIT_FAILED", "{Audit Failed}"),

336 0x0000025f: ("ERROR_TIMER_RESOLUTION_NOT_SET", "The timer resolution was not previously set by the current process."),

337 0x00000260: ("ERROR_INSUFFICIENT_LOGON_INFO", "There is insufficient account information to log you on."),

338 0x00000261: ("ERROR_BAD_DLL_ENTRYPOINT", "{Invalid DLL Entrypoint}"),

339 0x00000262: ("ERROR_BAD_SERVICE_ENTRYPOINT", "{Invalid Service Callback Entrypoint}"),

340 0x00000263: ("ERROR_IP_ADDRESS_CONFLICT1", "There is an IP address conflict with another system on the network"),

341 0x00000264: ("ERROR_IP_ADDRESS_CONFLICT2", "There is an IP address conflict with another system on the network"),

342 0x00000265: ("ERROR_REGISTRY_QUOTA_LIMIT", "{Low On Registry Space}"),

343 0x00000266: ("ERROR_NO_CALLBACK_ACTIVE", "A callback return system service cannot be executed when no callback is active."),

344 0x00000267: ("ERROR_PWD_TOO_SHORT", "The password provided is too short to meet the policy of your user account."),

345 0x00000268: ("ERROR_PWD_TOO_RECENT", "The policy of your user account does not allow you to change passwords too frequently."),

346 0x00000269: ("ERROR_PWD_HISTORY_CONFLICT", "You have attempted to change your password to one that you have used in the past."),

347 0x0000026a: ("ERROR_UNSUPPORTED_COMPRESSION", "The specified compression format is unsupported."),

348 0x0000026b: ("ERROR_INVALID_HW_PROFILE", "The specified hardware profile configuration is invalid."),

349 0x0000026c: ("ERROR_INVALID_PLUGPLAY_DEVICE_PATH", "The specified Plug and Play registry device path is invalid."),

350 0x0000026d: ("ERROR_QUOTA_LIST_INCONSISTENT", "The specified quota list is internally inconsistent with its descriptor."),

351 0x0000026e: ("ERROR_EVALUATION_EXPIRATION", "{Windows Evaluation Notification}"),

352 0x0000026f: ("ERROR_ILLEGAL_DLL_RELOCATION", "{Illegal System DLL Relocation}"),

353 0x00000270: ("ERROR_DLL_INIT_FAILED_LOGOFF", "{DLL Initialization Failed}"),

354 0x00000271: ("ERROR_VALIDATE_CONTINUE", "The validation process needs to continue on to the next step."),

355 0x00000272: ("ERROR_NO_MORE_MATCHES", "There are no more matches for the current index enumeration."),

356 0x00000273: ("ERROR_RANGE_LIST_CONFLICT", "The range could not be added to the range list because of a conflict."),

357 0x00000274: ("ERROR_SERVER_SID_MISMATCH", "The server process is running under a SID different than that required by client."),

358 0x00000275: ("ERROR_CANT_ENABLE_DENY_ONLY", "A group marked use for deny only cannot be enabled."),

359 0x00000276: ("ERROR_FLOAT_MULTIPLE_FAULTS", "{EXCEPTION}"),

360 0x00000277: ("ERROR_FLOAT_MULTIPLE_TRAPS", "{EXCEPTION}"),

361 0x00000278: ("ERROR_NOINTERFACE", "The requested interface is not supported."),

362 0x00000279: ("ERROR_DRIVER_FAILED_SLEEP", "{System Standby Failed}"),

363 0x0000027a: ("ERROR_CORRUPT_SYSTEM_FILE", "The system file %1 has become corrupt and has been replaced."),

364 0x0000027b: ("ERROR_COMMITMENT_MINIMUM", "{Virtual Memory Minimum Too Low}"),

365 0x0000027c: ("ERROR_PNP_RESTART_ENUMERATION", "A device was removed so enumeration must be restarted."),

366 0x0000027d: ("ERROR_SYSTEM_IMAGE_BAD_SIGNATURE", "{Fatal System Error}"),

367 0x0000027e: ("ERROR_PNP_REBOOT_REQUIRED", "Device will not start without a reboot."),

368 0x0000027f: ("ERROR_INSUFFICIENT_POWER", "There is not enough power to complete the requested operation."),

369 0x00000280: ("ERROR_MULTIPLE_FAULT_VIOLATION", " ERROR_MULTIPLE_FAULT_VIOLATION"),

370 0x00000281: ("ERROR_SYSTEM_SHUTDOWN", "The system is in the process of shutting down."),

371 0x00000282: ("ERROR_PORT_NOT_SET", "An attempt to remove a processes DebugPort was made, but a port was not already associated with the process."),

372 0x00000283: ("ERROR_DS_VERSION_CHECK_FAILURE", "This version of Windows is not compatible with the behavior version of directory forest, domain or domain controller."),

373 0x00000284: ("ERROR_RANGE_NOT_FOUND", "The specified range could not be found in the range list."),

374 0x00000286: ("ERROR_NOT_SAFE_MODE_DRIVER", "The driver was not loaded because the system is booting into safe mode."),

375 0x00000287: ("ERROR_FAILED_DRIVER_ENTRY", "The driver was not loaded because it failed its initialization call."),

376 0x00000288: ("ERROR_DEVICE_ENUMERATION_ERROR", "The '%hs' encountered an error while applying power or reading the device configuration."),

377 0x00000289: ("ERROR_MOUNT_POINT_NOT_RESOLVED", "The create operation failed because the name contained at least one mount point which resolves to a volume to which the specified device object is not attached."),

378 0x0000028a: ("ERROR_INVALID_DEVICE_OBJECT_PARAMETER", "The device object parameter is either not a valid device object or is not attached to the volume specified by the file name."),

379 0x0000028b: ("ERROR_MCA_OCCURED", "A Machine Check Error has occurred. Please check the system eventlog for additional information."),

380 0x0000028c: ("ERROR_DRIVER_DATABASE_ERROR", "There was error [%2] processing the driver database."),

381 0x0000028d: ("ERROR_SYSTEM_HIVE_TOO_LARGE", "System hive size has exceeded its limit."),

382 0x0000028e: ("ERROR_DRIVER_FAILED_PRIOR_UNLOAD", "The driver could not be loaded because a previous version of the driver is still in memory."),

383 0x0000028f: ("ERROR_VOLSNAP_PREPARE_HIBERNATE", "{Volume Shadow Copy Service}"),

384 0x00000290: ("ERROR_HIBERNATION_FAILURE", "The system has failed to hibernate (The error code is %hs). Hibernation will be disabled until the system is restarted."),

385 0x00000291: ("ERROR_PWD_TOO_LONG", "The password provided is too long to meet the policy of your user account."),

386 0x00000299: ("ERROR_FILE_SYSTEM_LIMITATION", "The requested operation could not be completed due to a file system limitation"),

387 0x0000029c: ("ERROR_ASSERTION_FAILURE", "An assertion failure has occurred."),

388 0x0000029d: ("ERROR_ACPI_ERROR", "An error occurred in the ACPI subsystem."),

389 0x0000029e: ("ERROR_WOW_ASSERTION", "WOW Assertion Error."),

390 0x0000029f: ("ERROR_PNP_BAD_MPS_TABLE", "A device is missing in the system BIOS MPS table. This device will not be used."),

391 0x000002a0: ("ERROR_PNP_TRANSLATION_FAILED", "A translator failed to translate resources."),

392 0x000002a1: ("ERROR_PNP_IRQ_TRANSLATION_FAILED", "A IRQ translator failed to translate resources."),

393 0x000002a2: ("ERROR_PNP_INVALID_ID", "Driver %2 returned invalid ID for a child device (%3)."),

394 0x000002a3: ("ERROR_WAKE_SYSTEM_DEBUGGER", "{Kernel Debugger Awakened}"),

395 0x000002a4: ("ERROR_HANDLES_CLOSED", "{Handles Closed}"),

396 0x000002a5: ("ERROR_EXTRANEOUS_INFORMATION", "{Too Much Information}"),

397 0x000002a6: ("ERROR_RXACT_COMMIT_NECESSARY", "This warning level status indicates that the transaction state already exists for the registry sub-tree, but that a transaction commit was previously aborted."),

398 0x000002a7: ("ERROR_MEDIA_CHECK", "{Media Changed}"),

399 0x000002a8: ("ERROR_GUID_SUBSTITUTION_MADE", "{GUID Substitution}"),

400 0x000002a9: ("ERROR_STOPPED_ON_SYMLINK", "The create operation stopped after reaching a symbolic link"),

401 0x000002aa: ("ERROR_LONGJUMP", "A long jump has been executed."),

402 0x000002ab: ("ERROR_PLUGPLAY_QUERY_VETOED", "The Plug and Play query operation was not successful."),

403 0x000002ac: ("ERROR_UNWIND_CONSOLIDATE", "A frame consolidation has been executed."),

404 0x000002ad: ("ERROR_REGISTRY_HIVE_RECOVERED", "{Registry Hive Recovered}"),

405 0x000002ae: ("ERROR_DLL_MIGHT_BE_INSECURE", "The application is attempting to run executable code from the module %hs. This may be insecure. An alternative, %hs, is available. Should the application use the secure module %hs?"),

406 0x000002af: ("ERROR_DLL_MIGHT_BE_INCOMPATIBLE", "The application is loading executable code from the module %hs. This is secure, but may be incompatible with previous releases of the operating system. An alternative, %hs, is available. Should the application use the secure module %hs?"),

407 0x000002b0: ("ERROR_DBG_EXCEPTION_NOT_HANDLED", "Debugger did not handle the exception."),

408 0x000002b1: ("ERROR_DBG_REPLY_LATER", "Debugger will reply later."),

409 0x000002b2: ("ERROR_DBG_UNABLE_TO_PROVIDE_HANDLE", "Debugger cannot provide handle."),

410 0x000002b3: ("ERROR_DBG_TERMINATE_THREAD", "Debugger terminated thread."),

411 0x000002b4: ("ERROR_DBG_TERMINATE_PROCESS", "Debugger terminated process."),

412 0x000002b5: ("ERROR_DBG_CONTROL_C", "Debugger got control C."),

413 0x000002b6: ("ERROR_DBG_PRINTEXCEPTION_C", "Debugger printed exception on control C."),

414 0x000002b7: ("ERROR_DBG_RIPEXCEPTION", "Debugger received RIP exception."),

415 0x000002b8: ("ERROR_DBG_CONTROL_BREAK", "Debugger received control break."),

416 0x000002b9: ("ERROR_DBG_COMMAND_EXCEPTION", "Debugger command communication exception."),

417 0x000002ba: ("ERROR_OBJECT_NAME_EXISTS", "{Object Exists}"),

418 0x000002bb: ("ERROR_THREAD_WAS_SUSPENDED", "{Thread Suspended}"),

419 0x000002bc: ("ERROR_IMAGE_NOT_AT_BASE", "{Image Relocated}"),

420 0x000002bd: ("ERROR_RXACT_STATE_CREATED", "This informational level status indicates that a specified registry sub-tree transaction state did not yet exist and had to be created."),

421 0x000002be: ("ERROR_SEGMENT_NOTIFICATION", "{Segment Load}"),

422 0x000002bf: ("ERROR_BAD_CURRENT_DIRECTORY", "{Invalid Current Directory}"),

423 0x000002c0: ("ERROR_FT_READ_RECOVERY_FROM_BACKUP", "{Redundant Read}"),

424 0x000002c1: ("ERROR_FT_WRITE_RECOVERY", "{Redundant Write}"),

425 0x000002c2: ("ERROR_IMAGE_MACHINE_TYPE_MISMATCH", "{Machine Type Mismatch}"),

426 0x000002c3: ("ERROR_RECEIVE_PARTIAL", "{Partial Data Received}"),

427 0x000002c4: ("ERROR_RECEIVE_EXPEDITED", "{Expedited Data Received}"),

428 0x000002c5: ("ERROR_RECEIVE_PARTIAL_EXPEDITED", "{Partial Expedited Data Received}"),

429 0x000002c6: ("ERROR_EVENT_DONE", "{TDI Event Done}"),

430 0x000002c7: ("ERROR_EVENT_PENDING", "{TDI Event Pending}"),

431 0x000002c8: ("ERROR_CHECKING_FILE_SYSTEM", "Checking file system on %wZ"),

432 0x000002c9: ("ERROR_FATAL_APP_EXIT", "{Fatal Application Exit}"),

433 0x000002ca: ("ERROR_PREDEFINED_HANDLE", "The specified registry key is referenced by a predefined handle."),

434 0x000002cb: ("ERROR_WAS_UNLOCKED", "{Page Unlocked}"),

435 0x000002cc: ("ERROR_SERVICE_NOTIFICATION", "%hs"),

436 0x000002cd: ("ERROR_WAS_LOCKED", "{Page Locked}"),

437 0x000002ce: ("ERROR_LOG_HARD_ERROR", "Application popup: %1 : %2"),

438 0x000002cf: ("ERROR_ALREADY_WIN32", " ERROR_ALREADY_WIN32"),

439 0x000002d0: ("ERROR_IMAGE_MACHINE_TYPE_MISMATCH_EXE", "{Machine Type Mismatch}"),

440 0x000002d1: ("ERROR_NO_YIELD_PERFORMED", "A yield execution was performed and no thread was available to run."),

441 0x000002d2: ("ERROR_TIMER_RESUME_IGNORED", "The resumable flag to a timer API was ignored."),

442 0x000002d3: ("ERROR_ARBITRATION_UNHANDLED", "The arbiter has deferred arbitration of these resources to its parent"),

443 0x000002d4: ("ERROR_CARDBUS_NOT_SUPPORTED", "The inserted CardBus device cannot be started because of a configuration error on '%hs'."),

444 0x000002d5: ("ERROR_MP_PROCESSOR_MISMATCH", "The CPUs in this multiprocessor system are not all the same revision level. To use all processors the operating system restricts itself to the features of the least capable processor in the system. Should problems occur with this system, contact the CPU manufacturer to see if this mix of processors is supported."),

445 0x000002d6: ("ERROR_HIBERNATED", "The system was put into hibernation."),

446 0x000002d7: ("ERROR_RESUME_HIBERNATION", "The system was resumed from hibernation."),

447 0x000002d8: ("ERROR_FIRMWARE_UPDATED", "Windows has detected that the system firmware (BIOS) was updated [previous firmware date = %2, current firmware date %3]."),

448 0x000002d9: ("ERROR_DRIVERS_LEAKING_LOCKED_PAGES", "A device driver is leaking locked I/O pages causing system degradation. The system has automatically enabled tracking code in order to try and catch the culprit."),

449 0x000002da: ("ERROR_WAKE_SYSTEM", "The system has awoken"),

450 0x000002db: ("ERROR_WAIT_1", " ERROR_WAIT_1"),

451 0x000002dc: ("ERROR_WAIT_2", " ERROR_WAIT_2"),

452 0x000002dd: ("ERROR_WAIT_3", " ERROR_WAIT_3"),

453 0x000002de: ("ERROR_WAIT_63", " ERROR_WAIT_63"),

454 0x000002df: ("ERROR_ABANDONED_WAIT_0", " ERROR_ABANDONED_WAIT_0"),

455 0x000002e0: ("ERROR_ABANDONED_WAIT_63", " ERROR_ABANDONED_WAIT_63"),

456 0x000002e1: ("ERROR_USER_APC", " ERROR_USER_APC"),

457 0x000002e2: ("ERROR_KERNEL_APC", " ERROR_KERNEL_APC"),

458 0x000002e3: ("ERROR_ALERTED", " ERROR_ALERTED"),

459 0x000002e4: ("ERROR_ELEVATION_REQUIRED", "The requested operation requires elevation."),

460 0x000002e5: ("ERROR_REPARSE", "A reparse should be performed by the Object Manager since the name of the file resulted in a symbolic link."),

461 0x000002e6: ("ERROR_OPLOCK_BREAK_IN_PROGRESS", "An open/create operation completed while an oplock break is underway."),

462 0x000002e7: ("ERROR_VOLUME_MOUNTED", "A new volume has been mounted by a file system."),

463 0x000002e8: ("ERROR_RXACT_COMMITTED", "This success level status indicates that the transaction state already exists for the registry sub-tree, but that a transaction commit was previously aborted."),

464 0x000002e9: ("ERROR_NOTIFY_CLEANUP", "This indicates that a notify change request has been completed due to closing the handle which made the notify change request."),

465 0x000002ea: ("ERROR_PRIMARY_TRANSPORT_CONNECT_FAILED", "{Connect Failure on Primary Transport}"),

466 0x000002eb: ("ERROR_PAGE_FAULT_TRANSITION", "Page fault was a transition fault."),

467 0x000002ec: ("ERROR_PAGE_FAULT_DEMAND_ZERO", "Page fault was a demand zero fault."),

468 0x000002ed: ("ERROR_PAGE_FAULT_COPY_ON_WRITE", "Page fault was a demand zero fault."),

469 0x000002ee: ("ERROR_PAGE_FAULT_GUARD_PAGE", "Page fault was a demand zero fault."),

470 0x000002ef: ("ERROR_PAGE_FAULT_PAGING_FILE", "Page fault was satisfied by reading from a secondary storage device."),

471 0x000002f0: ("ERROR_CACHE_PAGE_LOCKED", "Cached page was locked during operation."),

472 0x000002f1: ("ERROR_CRASH_DUMP", "Crash dump exists in paging file."),

473 0x000002f2: ("ERROR_BUFFER_ALL_ZEROS", "Specified buffer contains all zeros."),

474 0x000002f3: ("ERROR_REPARSE_OBJECT", "A reparse should be performed by the Object Manager since the name of the file resulted in a symbolic link."),

475 0x000002f4: ("ERROR_RESOURCE_REQUIREMENTS_CHANGED", "The device has succeeded a query-stop and its resource requirements have changed."),

476 0x000002f5: ("ERROR_TRANSLATION_COMPLETE", "The translator has translated these resources into the global space and no further translations should be performed."),

477 0x000002f6: ("ERROR_NOTHING_TO_TERMINATE", "A process being terminated has no threads to terminate."),

478 0x000002f7: ("ERROR_PROCESS_NOT_IN_JOB", "The specified process is not part of a job."),

479 0x000002f8: ("ERROR_PROCESS_IN_JOB", "The specified process is part of a job."),

480 0x000002f9: ("ERROR_VOLSNAP_HIBERNATE_READY", "{Volume Shadow Copy Service}"),

481 0x000002fa: ("ERROR_FSFILTER_OP_COMPLETED_SUCCESSFULLY", "A file system or file system filter driver has successfully completed an FsFilter operation."),

482 0x000002fb: ("ERROR_INTERRUPT_VECTOR_ALREADY_CONNECTED", "The specified interrupt vector was already connected."),

483 0x000002fc: ("ERROR_INTERRUPT_STILL_CONNECTED", "The specified interrupt vector is still connected."),

484 0x000002fd: ("ERROR_WAIT_FOR_OPLOCK", "An operation is blocked waiting for an oplock."),

485 0x000002fe: ("ERROR_DBG_EXCEPTION_HANDLED", "Debugger handled exception"),

486 0x000002ff: ("ERROR_DBG_CONTINUE", "Debugger continued"),

487 0x00000300: ("ERROR_CALLBACK_POP_STACK", "An exception occurred in a user mode callback and the kernel callback frame should be removed."),

488 0x00000301: ("ERROR_COMPRESSION_DISABLED", "Compression is disabled for this volume."),

489 0x00000302: ("ERROR_CANTFETCHBACKWARDS", "The data provider cannot fetch backwards through a result set."),

490 0x00000303: ("ERROR_CANTSCROLLBACKWARDS", "The data provider cannot scroll backwards through a result set."),

491 0x00000304: ("ERROR_ROWSNOTRELEASED", "The data provider requires that previously fetched data is released before asking for more data."),

492 0x00000305: ("ERROR_BAD_ACCESSOR_FLAGS", "The data provider was not able to interpret the flags set for a column binding in an accessor."),

493 0x00000306: ("ERROR_ERRORS_ENCOUNTERED", "One or more errors occurred while processing the request."),

494 0x00000307: ("ERROR_NOT_CAPABLE", "The implementation is not capable of performing the request."),

495 0x00000308: ("ERROR_REQUEST_OUT_OF_SEQUENCE", "The client of a component requested an operation which is not valid given the state of the component instance."),

496 0x00000309: ("ERROR_VERSION_PARSE_ERROR", "A version number could not be parsed."),

497 0x0000030a: ("ERROR_BADSTARTPOSITION", "The iterator's start position is invalid."),

498 0x0000030b: ("ERROR_MEMORY_HARDWARE", "The hardware has reported an uncorrectable memory error."),

499 0x0000030c: ("ERROR_DISK_REPAIR_DISABLED", "The attempted operation required self healing to be enabled."),

500 0x0000030d: ("ERROR_INSUFFICIENT_RESOURCE_FOR_SPECIFIED_SHARED_SECTION_SIZE", "The Desktop heap encountered an error while allocating session memory. There is more information in the system event log."),

501 0x0000030e: ("ERROR_SYSTEM_POWERSTATE_TRANSITION", "The system power state is transitioning from %2 to %3."),

502 0x0000030f: ("ERROR_SYSTEM_POWERSTATE_COMPLEX_TRANSITION", "The system power state is transitioning from %2 to %3 but could enter %4."),

503 0x00000310: ("ERROR_MCA_EXCEPTION", "A thread is getting dispatched with MCA EXCEPTION because of MCA."),

504 0x00000311: ("ERROR_ACCESS_AUDIT_BY_POLICY", "Access to %1 is monitored by policy rule %2."),

505 0x00000312: ("ERROR_ACCESS_DISABLED_NO_SAFER_UI_BY_POLICY", "Access to %1 has been restricted by your Administrator by policy rule %2."),

506 0x00000313: ("ERROR_ABANDON_HIBERFILE", "A valid hibernation file has been invalidated and should be abandoned."),

507 0x00000314: ("ERROR_LOST_WRITEBEHIND_DATA_NETWORK_DISCONNECTED", "{Delayed Write Failed}"),

508 0x00000315: ("ERROR_LOST_WRITEBEHIND_DATA_NETWORK_SERVER_ERROR", "{Delayed Write Failed}"),

509 0x00000316: ("ERROR_LOST_WRITEBEHIND_DATA_LOCAL_DISK_ERROR", "{Delayed Write Failed}"),

510 0x00000317: ("ERROR_BAD_MCFG_TABLE", "The resources required for this device conflict with the MCFG table."),

511 0x00000318: ("ERROR_DISK_REPAIR_REDIRECTED", "The volume repair could not be performed while it is online."),

512 0x00000319: ("ERROR_DISK_REPAIR_UNSUCCESSFUL", "The volume repair was not successful."),

513 0x0000031a: ("ERROR_CORRUPT_LOG_OVERFULL", "One of the volume corruption logs is full. Further corruptions that may be detected won't be logged."),

514 0x0000031b: ("ERROR_CORRUPT_LOG_CORRUPTED", "One of the volume corruption logs is internally corrupted and needs to be recreated. The volume may contain undetected corruptions and must be scanned."),

515 0x0000031c: ("ERROR_CORRUPT_LOG_UNAVAILABLE", "One of the volume corruption logs is unavailable for being operated on."),

516 0x0000031d: ("ERROR_CORRUPT_LOG_DELETED_FULL", "One of the volume corruption logs was deleted while still having corruption records in them. The volume contains detected corruptions and must be scanned."),

517 0x0000031e: ("ERROR_CORRUPT_LOG_CLEARED", "One of the volume corruption logs was cleared by chkdsk and no longer contains real corruptions."),

518 0x0000031f: ("ERROR_ORPHAN_NAME_EXHAUSTED", "Orphaned files exist on the volume but could not be recovered because no more new names could be created in the recovery directory. Files must be moved from the recovery directory."),

519 0x00000320: ("ERROR_OPLOCK_SWITCHED_TO_NEW_HANDLE", "The oplock that was associated with this handle is now associated with a different handle."),

520 0x00000321: ("ERROR_CANNOT_GRANT_REQUESTED_OPLOCK", "An oplock of the requested level cannot be granted. An oplock of a lower level may be available."),

521 0x00000322: ("ERROR_CANNOT_BREAK_OPLOCK", "The operation did not complete successfully because it would cause an oplock to be broken. The caller has requested that existing oplocks not be broken."),

522 0x00000323: ("ERROR_OPLOCK_HANDLE_CLOSED", "The handle with which this oplock was associated has been closed. The oplock is now broken."),

523 0x00000324: ("ERROR_NO_ACE_CONDITION", "The specified access control entry (ACE) does not contain a condition."),

524 0x00000325: ("ERROR_INVALID_ACE_CONDITION", "The specified access control entry (ACE) contains an invalid condition."),

525 0x00000326: ("ERROR_FILE_HANDLE_REVOKED", "Access to the specified file handle has been revoked."),

526 0x00000327: ("ERROR_IMAGE_AT_DIFFERENT_BASE", "{Image Relocated}"),

527 0x000003e2: ("ERROR_EA_ACCESS_DENIED", "Access to the extended attribute was denied."),

528 0x000003e3: ("ERROR_OPERATION_ABORTED", "The I/O operation has been aborted because of either a thread exit or an application request."),

529 0x000003e4: ("ERROR_IO_INCOMPLETE", "Overlapped I/O event is not in a signaled state."),

530 0x000003e5: ("ERROR_IO_PENDING", "Overlapped I/O operation is in progress."),

531 0x000003e6: ("ERROR_NOACCESS", "Invalid access to memory location."),

532 0x000003e7: ("ERROR_SWAPERROR", "Error performing inpage operation."),

533 0x000003e9: ("ERROR_STACK_OVERFLOW", "Recursion too deep; the stack overflowed."),

534 0x000003ea: ("ERROR_INVALID_MESSAGE", "The window cannot act on the sent message."),

535 0x000003eb: ("ERROR_CAN_NOT_COMPLETE", "Cannot complete this function."),

536 0x000003ec: ("ERROR_INVALID_FLAGS", "Invalid flags."),

537 0x000003ed: ("ERROR_UNRECOGNIZED_VOLUME", "The volume does not contain a recognized file system."),

538 0x000003ee: ("ERROR_FILE_INVALID", "The volume for a file has been externally altered so that the opened file is no longer valid."),

539 0x000003ef: ("ERROR_FULLSCREEN_MODE", "The requested operation cannot be performed in full-screen mode."),

540 0x000003f0: ("ERROR_NO_TOKEN", "An attempt was made to reference a token that does not exist."),

541 0x000003f1: ("ERROR_BADDB", "The configuration registry database is corrupt."),

542 0x000003f2: ("ERROR_BADKEY", "The configuration registry key is invalid."),

543 0x000003f3: ("ERROR_CANTOPEN", "The configuration registry key could not be opened."),

544 0x000003f4: ("ERROR_CANTREAD", "The configuration registry key could not be read."),

545 0x000003f5: ("ERROR_CANTWRITE", "The configuration registry key could not be written."),

546 0x000003f6: ("ERROR_REGISTRY_RECOVERED", "One of the files in the registry database had to be recovered by use of a log or alternate copy. The recovery was successful."),

547 0x000003f7: ("ERROR_REGISTRY_CORRUPT", "The registry is corrupted. The structure of one of the files containing registry data is corrupted, or the system's memory image of the file is corrupted, or the file could not be recovered because the alternate copy or log was absent or corrupted."),

548 0x000003f8: ("ERROR_REGISTRY_IO_FAILED", "An I/O operation initiated by the registry failed unrecoverably. The registry could not read in, or write out, or flush, one of the files that contain the system's image of the registry."),

549 0x000003f9: ("ERROR_NOT_REGISTRY_FILE", "The system has attempted to load or restore a file into the registry, but the specified file is not in a registry file format."),

550 0x000003fa: ("ERROR_KEY_DELETED", "Illegal operation attempted on a registry key that has been marked for deletion."),

551 0x000003fb: ("ERROR_NO_LOG_SPACE", "System could not allocate the required space in a registry log."),

552 0x000003fc: ("ERROR_KEY_HAS_CHILDREN", "Cannot create a symbolic link in a registry key that already has subkeys or values."),

553 0x000003fd: ("ERROR_CHILD_MUST_BE_VOLATILE", "Cannot create a stable subkey under a volatile parent key."),

554 0x000003fe: ("ERROR_NOTIFY_ENUM_DIR", "A notify change request is being completed and the information is not being returned in the caller's buffer. The caller now needs to enumerate the files to find the changes."),

555 0x0000041b: ("ERROR_DEPENDENT_SERVICES_RUNNING", "A stop control has been sent to a service that other running services are dependent on."),

556 0x0000041c: ("ERROR_INVALID_SERVICE_CONTROL", "The requested control is not valid for this service."),

557 0x0000041d: ("ERROR_SERVICE_REQUEST_TIMEOUT", "The service did not respond to the start or control request in a timely fashion."),

558 0x0000041e: ("ERROR_SERVICE_NO_THREAD", "A thread could not be created for the service."),

559 0x0000041f: ("ERROR_SERVICE_DATABASE_LOCKED", "The service database is locked."),

560 0x00000420: ("ERROR_SERVICE_ALREADY_RUNNING", "An instance of the service is already running."),

561 0x00000421: ("ERROR_INVALID_SERVICE_ACCOUNT", "The account name is invalid or does not exist, or the password is invalid for the account name specified."),

562 0x00000422: ("ERROR_SERVICE_DISABLED", "The service cannot be started, either because it is disabled or because it has no enabled devices associated with it."),

563 0x00000423: ("ERROR_CIRCULAR_DEPENDENCY", "Circular service dependency was specified."),

564 0x00000424: ("ERROR_SERVICE_DOES_NOT_EXIST", "The specified service does not exist as an installed service."),

565 0x00000425: ("ERROR_SERVICE_CANNOT_ACCEPT_CTRL", "The service cannot accept control messages at this time."),

566 0x00000426: ("ERROR_SERVICE_NOT_ACTIVE", "The service has not been started."),

567 0x00000427: ("ERROR_FAILED_SERVICE_CONTROLLER_CONNECT", "The service process could not connect to the service controller."),

568 0x00000428: ("ERROR_EXCEPTION_IN_SERVICE", "An exception occurred in the service when handling the control request."),

569 0x00000429: ("ERROR_DATABASE_DOES_NOT_EXIST", "The database specified does not exist."),

570 0x0000042a: ("ERROR_SERVICE_SPECIFIC_ERROR", "The service has returned a service-specific error code."),

571 0x0000042b: ("ERROR_PROCESS_ABORTED", "The process terminated unexpectedly."),

572 0x0000042c: ("ERROR_SERVICE_DEPENDENCY_FAIL", "The dependency service or group failed to start."),

573 0x0000042d: ("ERROR_SERVICE_LOGON_FAILED", "The service did not start due to a logon failure."),

574 0x0000042e: ("ERROR_SERVICE_START_HANG", "After starting, the service hung in a start-pending state."),

575 0x0000042f: ("ERROR_INVALID_SERVICE_LOCK", "The specified service database lock is invalid."),

576 0x00000430: ("ERROR_SERVICE_MARKED_FOR_DELETE", "The specified service has been marked for deletion."),

577 0x00000431: ("ERROR_SERVICE_EXISTS", "The specified service already exists."),

578 0x00000432: ("ERROR_ALREADY_RUNNING_LKG", "The system is currently running with the last-known-good configuration."),

579 0x00000433: ("ERROR_SERVICE_DEPENDENCY_DELETED", "The dependency service does not exist or has been marked for deletion."),

580 0x00000434: ("ERROR_BOOT_ALREADY_ACCEPTED", "The current boot has already been accepted for use as the last-known-good control set."),

581 0x00000435: ("ERROR_SERVICE_NEVER_STARTED", "No attempts to start the service have been made since the last boot."),

582 0x00000436: ("ERROR_DUPLICATE_SERVICE_NAME", "The name is already in use as either a service name or a service display name."),

583 0x00000437: ("ERROR_DIFFERENT_SERVICE_ACCOUNT", "The account specified for this service is different from the account specified for other services running in the same process."),

584 0x00000438: ("ERROR_CANNOT_DETECT_DRIVER_FAILURE", "Failure actions can only be set for Win32 services, not for drivers."),

585 0x00000439: ("ERROR_CANNOT_DETECT_PROCESS_ABORT", "This service runs in the same process as the service control manager."),

586 0x0000043a: ("ERROR_NO_RECOVERY_PROGRAM", "No recovery program has been configured for this service."),

587 0x0000043b: ("ERROR_SERVICE_NOT_IN_EXE", "The executable program that this service is configured to run in does not implement the service."),

588 0x0000043c: ("ERROR_NOT_SAFEBOOT_SERVICE", "This service cannot be started in Safe Mode"),

589 0x0000044c: ("ERROR_END_OF_MEDIA", "The physical end of the tape has been reached."),

590 0x0000044d: ("ERROR_FILEMARK_DETECTED", "A tape access reached a filemark."),

591 0x0000044e: ("ERROR_BEGINNING_OF_MEDIA", "The beginning of the tape or a partition was encountered."),

592 0x0000044f: ("ERROR_SETMARK_DETECTED", "A tape access reached the end of a set of files."),

593 0x00000450: ("ERROR_NO_DATA_DETECTED", "No more data is on the tape."),

594 0x00000451: ("ERROR_PARTITION_FAILURE", "Tape could not be partitioned."),

595 0x00000452: ("ERROR_INVALID_BLOCK_LENGTH", "When accessing a new tape of a multivolume partition, the current block size is incorrect."),

596 0x00000453: ("ERROR_DEVICE_NOT_PARTITIONED", "Tape partition information could not be found when loading a tape."),

597 0x00000454: ("ERROR_UNABLE_TO_LOCK_MEDIA", "Unable to lock the media eject mechanism."),

598 0x00000455: ("ERROR_UNABLE_TO_UNLOAD_MEDIA", "Unable to unload the media."),

599 0x00000456: ("ERROR_MEDIA_CHANGED", "The media in the drive may have changed."),

600 0x00000457: ("ERROR_BUS_RESET", "The I/O bus was reset."),

601 0x00000458: ("ERROR_NO_MEDIA_IN_DRIVE", "No media in drive."),

602 0x00000459: ("ERROR_NO_UNICODE_TRANSLATION", "No mapping for the Unicode character exists in the target multi-byte code page."),

603 0x0000045a: ("ERROR_DLL_INIT_FAILED", "A dynamic link library (DLL) initialization routine failed."),

604 0x0000045b: ("ERROR_SHUTDOWN_IN_PROGRESS", "A system shutdown is in progress."),

605 0x0000045c: ("ERROR_NO_SHUTDOWN_IN_PROGRESS", "Unable to abort the system shutdown because no shutdown was in progress."),

606 0x0000045d: ("ERROR_IO_DEVICE", "The request could not be performed because of an I/O device error."),

607 0x0000045e: ("ERROR_SERIAL_NO_DEVICE", "No serial device was successfully initialized. The serial driver will unload."),

608 0x0000045f: ("ERROR_IRQ_BUSY", "Unable to open a device that was sharing an interrupt request (IRQ) with other devices. At least one other device that uses that IRQ was already opened."),

609 0x00000460: ("ERROR_MORE_WRITES", "A serial I/O operation was completed by another write to the serial port."),

610 0x00000461: ("ERROR_COUNTER_TIMEOUT", "A serial I/O operation completed because the timeout period expired."),

611 0x00000462: ("ERROR_FLOPPY_ID_MARK_NOT_FOUND", "No ID address mark was found on the floppy disk."),

612 0x00000463: ("ERROR_FLOPPY_WRONG_CYLINDER", "Mismatch between the floppy disk sector ID field and the floppy disk controller track address."),

613 0x00000464: ("ERROR_FLOPPY_UNKNOWN_ERROR", "The floppy disk controller reported an error that is not recognized by the floppy disk driver."),

614 0x00000465: ("ERROR_FLOPPY_BAD_REGISTERS", "The floppy disk controller returned inconsistent results in its registers."),

615 0x00000466: ("ERROR_DISK_RECALIBRATE_FAILED", "While accessing the hard disk, a recalibrate operation failed, even after retries."),

616 0x00000467: ("ERROR_DISK_OPERATION_FAILED", "While accessing the hard disk, a disk operation failed even after retries."),

617 0x00000468: ("ERROR_DISK_RESET_FAILED", "While accessing the hard disk, a disk controller reset was needed, but even that failed."),

618 0x00000469: ("ERROR_EOM_OVERFLOW", "Physical end of tape encountered."),

619 0x0000046a: ("ERROR_NOT_ENOUGH_SERVER_MEMORY", "Not enough server storage is available to process this command."),

620 0x0000046b: ("ERROR_POSSIBLE_DEADLOCK", "A potential deadlock condition has been detected."),

621 0x0000046c: ("ERROR_MAPPED_ALIGNMENT", "The base address or the file offset specified does not have the proper alignment."),

622 0x00000474: ("ERROR_SET_POWER_STATE_VETOED", "An attempt to change the system power state was vetoed by another application or driver."),

623 0x00000475: ("ERROR_SET_POWER_STATE_FAILED", "The system BIOS failed an attempt to change the system power state."),

624 0x00000476: ("ERROR_TOO_MANY_LINKS", "An attempt was made to create more links on a file than the file system supports."),

625 0x0000047e: ("ERROR_OLD_WIN_VERSION", "The specified program requires a newer version of Windows."),

626 0x0000047f: ("ERROR_APP_WRONG_OS", "The specified program is not a Windows or MS-DOS program."),

627 0x00000480: ("ERROR_SINGLE_INSTANCE_APP", "Cannot start more than one instance of the specified program."),

628 0x00000481: ("ERROR_RMODE_APP", "The specified program was written for an earlier version of Windows."),

629 0x00000482: ("ERROR_INVALID_DLL", "One of the library files needed to run this application is damaged."),

630 0x00000483: ("ERROR_NO_ASSOCIATION", "No application is associated with the specified file for this operation."),

631 0x00000484: ("ERROR_DDE_FAIL", "An error occurred in sending the command to the application."),

632 0x00000485: ("ERROR_DLL_NOT_FOUND", "One of the library files needed to run this application cannot be found."),

633 0x00000486: ("ERROR_NO_MORE_USER_HANDLES", "The current process has used all of its system allowance of handles for Window Manager objects."),

634 0x00000487: ("ERROR_MESSAGE_SYNC_ONLY", "The message can be used only with synchronous operations."),

635 0x00000488: ("ERROR_SOURCE_ELEMENT_EMPTY", "The indicated source element has no media."),

636 0x00000489: ("ERROR_DESTINATION_ELEMENT_FULL", "The indicated destination element already contains media."),

637 0x0000048a: ("ERROR_ILLEGAL_ELEMENT_ADDRESS", "The indicated element does not exist."),

638 0x0000048b: ("ERROR_MAGAZINE_NOT_PRESENT", "The indicated element is part of a magazine that is not present."),

639 0x0000048c: ("ERROR_DEVICE_REINITIALIZATION_NEEDED", "The indicated device requires reinitialization due to hardware errors."),

640 0x0000048d: ("ERROR_DEVICE_REQUIRES_CLEANING", "The device has indicated that cleaning is required before further operations are attempted."),

641 0x0000048e: ("ERROR_DEVICE_DOOR_OPEN", "The device has indicated that its door is open."),

642 0x0000048f: ("ERROR_DEVICE_NOT_CONNECTED", "The device is not connected."),

643 0x00000490: ("ERROR_NOT_FOUND", "Element not found."),

644 0x00000491: ("ERROR_NO_MATCH", "There was no match for the specified key in the index."),

645 0x00000492: ("ERROR_SET_NOT_FOUND", "The property set specified does not exist on the object."),

646 0x00000493: ("ERROR_POINT_NOT_FOUND", "The point passed to GetMouseMovePoints is not in the buffer."),

647 0x00000494: ("ERROR_NO_TRACKING_SERVICE", "The tracking (workstation) service is not running."),

648 0x00000495: ("ERROR_NO_VOLUME_ID", "The Volume ID could not be found."),

649 0x00000497: ("ERROR_UNABLE_TO_REMOVE_REPLACED", "Unable to remove the file to be replaced."),

650 0x00000498: ("ERROR_UNABLE_TO_MOVE_REPLACEMENT", "Unable to move the replacement file to the file to be replaced. The file to be replaced has retained its original name."),

651 0x00000499: ("ERROR_UNABLE_TO_MOVE_REPLACEMENT_2", "Unable to move the replacement file to the file to be replaced. The file to be replaced has been renamed using the backup name."),

652 0x0000049a: ("ERROR_JOURNAL_DELETE_IN_PROGRESS", "The volume change journal is being deleted."),

653 0x0000049b: ("ERROR_JOURNAL_NOT_ACTIVE", "The volume change journal is not active."),

654 0x0000049c: ("ERROR_POTENTIAL_FILE_FOUND", "A file was found, but it may not be the correct file."),

655 0x0000049d: ("ERROR_JOURNAL_ENTRY_DELETED", "The journal entry has been deleted from the journal."),

656 0x000004a6: ("ERROR_SHUTDOWN_IS_SCHEDULED", "A system shutdown has already been scheduled."),

657 0x000004a7: ("ERROR_SHUTDOWN_USERS_LOGGED_ON", "The system shutdown cannot be initiated because there are other users logged on to the computer."),

658 0x000004b0: ("ERROR_BAD_DEVICE", "The specified device name is invalid."),

659 0x000004b1: ("ERROR_CONNECTION_UNAVAIL", "The device is not currently connected but it is a remembered connection."),

660 0x000004b2: ("ERROR_DEVICE_ALREADY_REMEMBERED", "The local device name has a remembered connection to another network resource."),

661 0x000004b3: ("ERROR_NO_NET_OR_BAD_PATH", "The network path was either typed incorrectly, does not exist, or the network provider is not currently available. Please try retyping the path or contact your network administrator."),

662 0x000004b4: ("ERROR_BAD_PROVIDER", "The specified network provider name is invalid."),

663 0x000004b5: ("ERROR_CANNOT_OPEN_PROFILE", "Unable to open the network connection profile."),

664 0x000004b6: ("ERROR_BAD_PROFILE", "The network connection profile is corrupted."),

665 0x000004b7: ("ERROR_NOT_CONTAINER", "Cannot enumerate a noncontainer."),

666 0x000004b8: ("ERROR_EXTENDED_ERROR", "An extended error has occurred."),

667 0x000004b9: ("ERROR_INVALID_GROUPNAME", "The format of the specified group name is invalid."),

668 0x000004ba: ("ERROR_INVALID_COMPUTERNAME", "The format of the specified computer name is invalid."),

669 0x000004bb: ("ERROR_INVALID_EVENTNAME", "The format of the specified event name is invalid."),

670 0x000004bc: ("ERROR_INVALID_DOMAINNAME", "The format of the specified domain name is invalid."),

671 0x000004bd: ("ERROR_INVALID_SERVICENAME", "The format of the specified service name is invalid."),

672 0x000004be: ("ERROR_INVALID_NETNAME", "The format of the specified network name is invalid."),

673 0x000004bf: ("ERROR_INVALID_SHARENAME", "The format of the specified share name is invalid."),

674 0x000004c0: ("ERROR_INVALID_PASSWORDNAME", "The format of the specified password is invalid."),

675 0x000004c1: ("ERROR_INVALID_MESSAGENAME", "The format of the specified message name is invalid."),

676 0x000004c2: ("ERROR_INVALID_MESSAGEDEST", "The format of the specified message destination is invalid."),

677 0x000004c3: ("ERROR_SESSION_CREDENTIAL_CONFLICT", "Multiple connections to a server or shared resource by the same user, using more than one user name, are not allowed. Disconnect all previous connections to the server or shared resource and try again."),

678 0x000004c4: ("ERROR_REMOTE_SESSION_LIMIT_EXCEEDED", "An attempt was made to establish a session to a network server, but there are already too many sessions established to that server."),

679 0x000004c5: ("ERROR_DUP_DOMAINNAME", "The workgroup or domain name is already in use by another computer on the network."),

680 0x000004c6: ("ERROR_NO_NETWORK", "The network is not present or not started."),

681 0x000004c7: ("ERROR_CANCELLED", "The operation was canceled by the user."),

682 0x000004c8: ("ERROR_USER_MAPPED_FILE", "The requested operation cannot be performed on a file with a user-mapped section open."),

683 0x000004c9: ("ERROR_CONNECTION_REFUSED", "The remote computer refused the network connection."),

684 0x000004ca: ("ERROR_GRACEFUL_DISCONNECT", "The network connection was gracefully closed."),

685 0x000004cb: ("ERROR_ADDRESS_ALREADY_ASSOCIATED", "The network transport endpoint already has an address associated with it."),

686 0x000004cc: ("ERROR_ADDRESS_NOT_ASSOCIATED", "An address has not yet been associated with the network endpoint."),

687 0x000004cd: ("ERROR_CONNECTION_INVALID", "An operation was attempted on a nonexistent network connection."),

688 0x000004ce: ("ERROR_CONNECTION_ACTIVE", "An invalid operation was attempted on an active network connection."),

689 0x000004cf: ("ERROR_NETWORK_UNREACHABLE", "The network location cannot be reached. For information about network troubleshooting, see Windows Help."),

690 0x000004d0: ("ERROR_HOST_UNREACHABLE", "The network location cannot be reached. For information about network troubleshooting, see Windows Help."),

691 0x000004d1: ("ERROR_PROTOCOL_UNREACHABLE", "The network location cannot be reached. For information about network troubleshooting, see Windows Help."),

692 0x000004d2: ("ERROR_PORT_UNREACHABLE", "No service is operating at the destination network endpoint on the remote system."),

693 0x000004d3: ("ERROR_REQUEST_ABORTED", "The request was aborted."),

694 0x000004d4: ("ERROR_CONNECTION_ABORTED", "The network connection was aborted by the local system."),

695 0x000004d5: ("ERROR_RETRY", "The operation could not be completed. A retry should be performed."),

696 0x000004d6: ("ERROR_CONNECTION_COUNT_LIMIT", "A connection to the server could not be made because the limit on the number of concurrent connections for this account has been reached."),

697 0x000004d7: ("ERROR_LOGIN_TIME_RESTRICTION", "Attempting to log in during an unauthorized time of day for this account."),

698 0x000004d8: ("ERROR_LOGIN_WKSTA_RESTRICTION", "The account is not authorized to log in from this station."),

699 0x000004d9: ("ERROR_INCORRECT_ADDRESS", "The network address could not be used for the operation requested."),

700 0x000004da: ("ERROR_ALREADY_REGISTERED", "The service is already registered."),

701 0x000004db: ("ERROR_SERVICE_NOT_FOUND", "The specified service does not exist."),

702 0x000004dc: ("ERROR_NOT_AUTHENTICATED", "The operation being requested was not performed because the user has not been authenticated."),

703 0x000004dd: ("ERROR_NOT_LOGGED_ON", "The operation being requested was not performed because the user has not logged on to the network. The specified service does not exist."),

704 0x000004de: ("ERROR_CONTINUE", "Continue with work in progress."),

705 0x000004df: ("ERROR_ALREADY_INITIALIZED", "An attempt was made to perform an initialization operation when initialization has already been completed."),

706 0x000004e0: ("ERROR_NO_MORE_DEVICES", "No more local devices."),

707 0x000004e1: ("ERROR_NO_SUCH_SITE", "The specified site does not exist."),

708 0x000004e2: ("ERROR_DOMAIN_CONTROLLER_EXISTS", "A domain controller with the specified name already exists."),

709 0x000004e3: ("ERROR_ONLY_IF_CONNECTED", "This operation is supported only when you are connected to the server."),

710 0x000004e4: ("ERROR_OVERRIDE_NOCHANGES", "The group policy framework should call the extension even if there are no changes."),

711 0x000004e5: ("ERROR_BAD_USER_PROFILE", "The specified user does not have a valid profile."),

712 0x000004e6: ("ERROR_NOT_SUPPORTED_ON_SBS", "This operation is not supported on a computer running Windows Server 2003 for Small Business Server"),

713 0x000004e7: ("ERROR_SERVER_SHUTDOWN_IN_PROGRESS", "The server machine is shutting down."),

714 0x000004e8: ("ERROR_HOST_DOWN", "The remote system is not available. For information about network troubleshooting, see Windows Help."),

715 0x000004e9: ("ERROR_NON_ACCOUNT_SID", "The security identifier provided is not from an account domain."),

716 0x000004ea: ("ERROR_NON_DOMAIN_SID", "The security identifier provided does not have a domain component."),

717 0x000004eb: ("ERROR_APPHELP_BLOCK", "AppHelp dialog canceled thus preventing the application from starting."),

718 0x000004ec: ("ERROR_ACCESS_DISABLED_BY_POLICY", "This program is blocked by group policy. For more information, contact your system administrator."),

719 0x000004ed: ("ERROR_REG_NAT_CONSUMPTION", "A program attempt to use an invalid register value. Normally caused by an uninitialized register. This error is Itanium specific."),

720 0x000004ee: ("ERROR_CSCSHARE_OFFLINE", "The share is currently offline or does not exist."),

721 0x000004ef: ("ERROR_PKINIT_FAILURE", "The Kerberos protocol encountered an error while validating the KDC certificate during smartcard logon. There is more information in the system event log."),

722 0x000004f0: ("ERROR_SMARTCARD_SUBSYSTEM_FAILURE", "The Kerberos protocol encountered an error while attempting to utilize the smartcard subsystem."),

723 0x000004f1: ("ERROR_DOWNGRADE_DETECTED", "The system cannot contact a domain controller to service the authentication request. Please try again later."),

724 0x000004f7: ("ERROR_MACHINE_LOCKED", "The machine is locked and cannot be shut down without the force option."),

725 0x000004f9: ("ERROR_CALLBACK_SUPPLIED_INVALID_DATA", "An application-defined callback gave invalid data when called."),

726 0x000004fa: ("ERROR_SYNC_FOREGROUND_REFRESH_REQUIRED", "The group policy framework should call the extension in the synchronous foreground policy refresh."),

727 0x000004fb: ("ERROR_DRIVER_BLOCKED", "This driver has been blocked from loading"),

728 0x000004fc: ("ERROR_INVALID_IMPORT_OF_NON_DLL", "A dynamic link library (DLL) referenced a module that was neither a DLL nor the process's executable image."),

729 0x000004fd: ("ERROR_ACCESS_DISABLED_WEBBLADE", "Windows cannot open this program since it has been disabled."),

730 0x000004fe: ("ERROR_ACCESS_DISABLED_WEBBLADE_TAMPER", "Windows cannot open this program because the license enforcement system has been tampered with or become corrupted."),

731 0x000004ff: ("ERROR_RECOVERY_FAILURE", "A transaction recover failed."),

732 0x00000500: ("ERROR_ALREADY_FIBER", "The current thread has already been converted to a fiber."),

733 0x00000501: ("ERROR_ALREADY_THREAD", "The current thread has already been converted from a fiber."),

734 0x00000502: ("ERROR_STACK_BUFFER_OVERRUN", "The system detected an overrun of a stack-based buffer in this application. This overrun could potentially allow a malicious user to gain control of this application."),

735 0x00000503: ("ERROR_PARAMETER_QUOTA_EXCEEDED", "Data present in one of the parameters is more than the function can operate on."),

736 0x00000504: ("ERROR_DEBUGGER_INACTIVE", "An attempt to do an operation on a debug object failed because the object is in the process of being deleted."),

737 0x00000505: ("ERROR_DELAY_LOAD_FAILED", "An attempt to delay-load a .dll or get a function address in a delay-loaded .dll failed."),

738 0x00000506: ("ERROR_VDM_DISALLOWED", "%1 is a 16-bit application. You do not have permissions to execute 16-bit applications. Check your permissions with your system administrator."),

739 0x00000507: ("ERROR_UNIDENTIFIED_ERROR", "Insufficient information exists to identify the cause of failure."),

740 0x00000508: ("ERROR_INVALID_CRUNTIME_PARAMETER", "The parameter passed to a C runtime function is incorrect."),

741 0x00000509: ("ERROR_BEYOND_VDL", "The operation occurred beyond the valid data length of the file."),

742 0x0000050a: ("ERROR_INCOMPATIBLE_SERVICE_SID_TYPE", "The service start failed since one or more services in the same process have an incompatible service SID type setting. A service with restricted service SID type can only coexist in the same process with other services with a restricted SID type. If the service SID type for this service was just configured, the hosting process must be restarted in order to start this service."),

743 0x0000050b: ("ERROR_DRIVER_PROCESS_TERMINATED", "The process hosting the driver for this device has been terminated."),

744 0x0000050c: ("ERROR_IMPLEMENTATION_LIMIT", "An operation attempted to exceed an implementation-defined limit."),

745 0x0000050d: ("ERROR_PROCESS_IS_PROTECTED", "Either the target process, or the target thread's containing process, is a protected process."),

746 0x0000050e: ("ERROR_SERVICE_NOTIFY_CLIENT_LAGGING", "The service notification client is lagging too far behind the current state of services in the machine."),

747 0x0000050f: ("ERROR_DISK_QUOTA_EXCEEDED", "The requested file operation failed because the storage quota was exceeded."),

748 0x00000510: ("ERROR_CONTENT_BLOCKED", "The requested file operation failed because the storage policy blocks that type of file. For more information, contact your system administrator."),

749 0x00000511: ("ERROR_INCOMPATIBLE_SERVICE_PRIVILEGE", "A privilege that the service requires to function properly does not exist in the service account configuration."),

750 0x00000512: ("ERROR_APP_HANG", "A thread involved in this operation appears to be unresponsive."),

751 0x00000513: ("ERROR_INVALID_LABEL", "Indicates a particular Security ID may not be assigned as the label of an object."),

752 0x00000514: ("ERROR_NOT_ALL_ASSIGNED", "Not all privileges or groups referenced are assigned to the caller."),

753 0x00000515: ("ERROR_SOME_NOT_MAPPED", "Some mapping between account names and security IDs was not done."),

754 0x00000516: ("ERROR_NO_QUOTAS_FOR_ACCOUNT", "No system quota limits are specifically set for this account."),

755 0x00000517: ("ERROR_LOCAL_USER_SESSION_KEY", "No encryption key is available. A well-known encryption key was returned."),

756 0x00000518: ("ERROR_NULL_LM_PASSWORD", "The password is too complex to be converted to a LAN Manager password. The LAN Manager password returned is a NULL string."),

757 0x00000519: ("ERROR_UNKNOWN_REVISION", "The revision level is unknown."),

758 0x0000051a: ("ERROR_REVISION_MISMATCH", "Indicates two revision levels are incompatible."),

759 0x0000051b: ("ERROR_INVALID_OWNER", "This security ID may not be assigned as the owner of this object."),

760 0x0000051c: ("ERROR_INVALID_PRIMARY_GROUP", "This security ID may not be assigned as the primary group of an object."),

761 0x0000051d: ("ERROR_NO_IMPERSONATION_TOKEN", "An attempt has been made to operate on an impersonation token by a thread that is not currently impersonating a client."),

762 0x0000051e: ("ERROR_CANT_DISABLE_MANDATORY", "The group may not be disabled."),

763 0x0000051f: ("ERROR_NO_LOGON_SERVERS", "There are currently no logon servers available to service the logon request."),

764 0x00000520: ("ERROR_NO_SUCH_LOGON_SESSION", "A specified logon session does not exist. It may already have been terminated."),

765 0x00000521: ("ERROR_NO_SUCH_PRIVILEGE", "A specified privilege does not exist."),

766 0x00000522: ("ERROR_PRIVILEGE_NOT_HELD", "A required privilege is not held by the client."),

767 0x00000523: ("ERROR_INVALID_ACCOUNT_NAME", "The name provided is not a properly formed account name."),

768 0x00000524: ("ERROR_USER_EXISTS", "The specified account already exists."),

769 0x00000525: ("ERROR_NO_SUCH_USER", "The specified account does not exist."),

770 0x00000526: ("ERROR_GROUP_EXISTS", "The specified group already exists."),

771 0x00000527: ("ERROR_NO_SUCH_GROUP", "The specified group does not exist."),

772 0x00000528: ("ERROR_MEMBER_IN_GROUP", "Either the specified user account is already a member of the specified group, or the specified group cannot be deleted because it contains a member."),

773 0x00000529: ("ERROR_MEMBER_NOT_IN_GROUP", "The specified user account is not a member of the specified group account."),

774 0x0000052a: ("ERROR_LAST_ADMIN", "This operation is disallowed as it could result in an administration account being disabled, deleted or unable to logon."),

775 0x0000052b: ("ERROR_WRONG_PASSWORD", "Unable to update the password. The value provided as the current password is incorrect."),

776 0x0000052c: ("ERROR_ILL_FORMED_PASSWORD", "Unable to update the password. The value provided for the new password contains values that are not allowed in passwords."),

777 0x0000052d: ("ERROR_PASSWORD_RESTRICTION", "Unable to update the password. The value provided for the new password does not meet the length, complexity, or history requirements of the domain."),

778 0x0000052e: ("ERROR_LOGON_FAILURE", "The user name or password is incorrect."),

779 0x0000052f: ("ERROR_ACCOUNT_RESTRICTION", "Account restrictions are preventing this user from signing in. For example: blank passwords aren't allowed, sign-in times are limited, or a policy restriction has been enforced."),

780 0x00000530: ("ERROR_INVALID_LOGON_HOURS", "Your account has time restrictions that keep you from signing in right now."),

781 0x00000531: ("ERROR_INVALID_WORKSTATION", "This user isn't allowed to sign in to this computer."),

782 0x00000532: ("ERROR_PASSWORD_EXPIRED", "The password for this account has expired."),

783 0x00000533: ("ERROR_ACCOUNT_DISABLED", "This user can't sign in because this account is currently disabled."),

784 0x00000534: ("ERROR_NONE_MAPPED", "No mapping between account names and security IDs was done."),

785 0x00000535: ("ERROR_TOO_MANY_LUIDS_REQUESTED", "Too many local user identifiers (LUIDs) were requested at one time."),

786 0x00000536: ("ERROR_LUIDS_EXHAUSTED", "No more local user identifiers (LUIDs) are available."),

787 0x00000537: ("ERROR_INVALID_SUB_AUTHORITY", "The subauthority part of a security ID is invalid for this particular use."),

788 0x00000538: ("ERROR_INVALID_ACL", "The access control list (ACL) structure is invalid."),

789 0x00000539: ("ERROR_INVALID_SID", "The security ID structure is invalid."),

790 0x0000053a: ("ERROR_INVALID_SECURITY_DESCR", "The security descriptor structure is invalid."),

791 0x0000053c: ("ERROR_BAD_INHERITANCE_ACL", "The inherited access control list (ACL) or access control entry (ACE) could not be built."),

792 0x0000053d: ("ERROR_SERVER_DISABLED", "The server is currently disabled."),

793 0x0000053e: ("ERROR_SERVER_NOT_DISABLED", "The server is currently enabled."),

794 0x0000053f: ("ERROR_INVALID_ID_AUTHORITY", "The value provided was an invalid value for an identifier authority."),

795 0x00000540: ("ERROR_ALLOTTED_SPACE_EXCEEDED", "No more memory is available for security information updates."),

796 0x00000541: ("ERROR_INVALID_GROUP_ATTRIBUTES", "The specified attributes are invalid, or incompatible with the attributes for the group as a whole."),

797 0x00000542: ("ERROR_BAD_IMPERSONATION_LEVEL", "Either a required impersonation level was not provided, or the provided impersonation level is invalid."),

798 0x00000543: ("ERROR_CANT_OPEN_ANONYMOUS", "Cannot open an anonymous level security token."),

799 0x00000544: ("ERROR_BAD_VALIDATION_CLASS", "The validation information class requested was invalid."),

800 0x00000545: ("ERROR_BAD_TOKEN_TYPE", "The type of the token is inappropriate for its attempted use."),

801 0x00000546: ("ERROR_NO_SECURITY_ON_OBJECT", "Unable to perform a security operation on an object that has no associated security."),

802 0x00000547: ("ERROR_CANT_ACCESS_DOMAIN_INFO", "Configuration information could not be read from the domain controller, either because the machine is unavailable, or access has been denied."),

803 0x00000548: ("ERROR_INVALID_SERVER_STATE", "The security account manager (SAM) or local security authority (LSA) server was in the wrong state to perform the security operation."),

804 0x00000549: ("ERROR_INVALID_DOMAIN_STATE", "The domain was in the wrong state to perform the security operation."),

805 0x0000054a: ("ERROR_INVALID_DOMAIN_ROLE", "This operation is only allowed for the Primary Domain Controller of the domain."),

806 0x0000054b: ("ERROR_NO_SUCH_DOMAIN", "The specified domain either does not exist or could not be contacted."),

807 0x0000054c: ("ERROR_DOMAIN_EXISTS", "The specified domain already exists."),

808 0x0000054d: ("ERROR_DOMAIN_LIMIT_EXCEEDED", "An attempt was made to exceed the limit on the number of domains per server."),

809 0x0000054e: ("ERROR_INTERNAL_DB_CORRUPTION", "Unable to complete the requested operation because of either a catastrophic media failure or a data structure corruption on the disk."),

810 0x0000054f: ("ERROR_INTERNAL_ERROR", "An internal error occurred."),

811 0x00000550: ("ERROR_GENERIC_NOT_MAPPED", "Generic access types were contained in an access mask which should already be mapped to nongeneric types."),

812 0x00000551: ("ERROR_BAD_DESCRIPTOR_FORMAT", "A security descriptor is not in the right format (absolute or self-relative)."),

813 0x00000552: ("ERROR_NOT_LOGON_PROCESS", "The requested action is restricted for use by logon processes only. The calling process has not registered as a logon process."),

814 0x00000553: ("ERROR_LOGON_SESSION_EXISTS", "Cannot start a new logon session with an ID that is already in use."),

815 0x00000554: ("ERROR_NO_SUCH_PACKAGE", "A specified authentication package is unknown."),

816 0x00000555: ("ERROR_BAD_LOGON_SESSION_STATE", "The logon session is not in a state that is consistent with the requested operation."),

817 0x00000556: ("ERROR_LOGON_SESSION_COLLISION", "The logon session ID is already in use."),

818 0x00000557: ("ERROR_INVALID_LOGON_TYPE", "A logon request contained an invalid logon type value."),

819 0x00000558: ("ERROR_CANNOT_IMPERSONATE", "Unable to impersonate using a named pipe until data has been read from that pipe."),

820 0x00000559: ("ERROR_RXACT_INVALID_STATE", "The transaction state of a registry subtree is incompatible with the requested operation."),

821 0x0000055a: ("ERROR_RXACT_COMMIT_FAILURE", "An internal security database corruption has been encountered."),

822 0x0000055b: ("ERROR_SPECIAL_ACCOUNT", "Cannot perform this operation on built-in accounts."),

823 0x0000055c: ("ERROR_SPECIAL_GROUP", "Cannot perform this operation on this built-in special group."),

824 0x0000055d: ("ERROR_SPECIAL_USER", "Cannot perform this operation on this built-in special user."),

825 0x0000055e: ("ERROR_MEMBERS_PRIMARY_GROUP", "The user cannot be removed from a group because the group is currently the user's primary group."),

826 0x0000055f: ("ERROR_TOKEN_ALREADY_IN_USE", "The token is already in use as a primary token."),

827 0x00000560: ("ERROR_NO_SUCH_ALIAS", "The specified local group does not exist."),

828 0x00000561: ("ERROR_MEMBER_NOT_IN_ALIAS", "The specified account name is not a member of the group."),

829 0x00000562: ("ERROR_MEMBER_IN_ALIAS", "The specified account name is already a member of the group."),

830 0x00000563: ("ERROR_ALIAS_EXISTS", "The specified local group already exists."),

831 0x00000564: ("ERROR_LOGON_NOT_GRANTED", "Logon failure: the user has not been granted the requested logon type at this computer."),

832 0x00000565: ("ERROR_TOO_MANY_SECRETS", "The maximum number of secrets that may be stored in a single system has been exceeded."),

833 0x00000566: ("ERROR_SECRET_TOO_LONG", "The length of a secret exceeds the maximum length allowed."),

834 0x00000567: ("ERROR_INTERNAL_DB_ERROR", "The local security authority database contains an internal inconsistency."),

835 0x00000568: ("ERROR_TOO_MANY_CONTEXT_IDS", "During a logon attempt, the user's security context accumulated too many security IDs."),

836 0x00000569: ("ERROR_LOGON_TYPE_NOT_GRANTED", "Logon failure: the user has not been granted the requested logon type at this computer."),

837 0x0000056a: ("ERROR_NT_CROSS_ENCRYPTION_REQUIRED", "A cross-encrypted password is necessary to change a user password."),

838 0x0000056b: ("ERROR_NO_SUCH_MEMBER", "A member could not be added to or removed from the local group because the member does not exist."),

839 0x0000056c: ("ERROR_INVALID_MEMBER", "A new member could not be added to a local group because the member has the wrong account type."),

840 0x0000056d: ("ERROR_TOO_MANY_SIDS", "Too many security IDs have been specified."),

841 0x0000056e: ("ERROR_LM_CROSS_ENCRYPTION_REQUIRED", "A cross-encrypted password is necessary to change this user password."),

842 0x0000056f: ("ERROR_NO_INHERITANCE", "Indicates an ACL contains no inheritable components."),

843 0x00000570: ("ERROR_FILE_CORRUPT", "The file or directory is corrupted and unreadable."),

844 0x00000571: ("ERROR_DISK_CORRUPT", "The disk structure is corrupted and unreadable."),

845 0x00000572: ("ERROR_NO_USER_SESSION_KEY", "There is no user session key for the specified logon session."),

846 0x00000573: ("ERROR_LICENSE_QUOTA_EXCEEDED", "The service being accessed is licensed for a particular number of connections. No more connections can be made to the service at this time because there are already as many connections as the service can accept."),

847 0x00000574: ("ERROR_WRONG_TARGET_NAME", "The target account name is incorrect."),

848 0x00000575: ("ERROR_MUTUAL_AUTH_FAILED", "Mutual Authentication failed. The server's password is out of date at the domain controller."),

849 0x00000576: ("ERROR_TIME_SKEW", "There is a time and/or date difference between the client and server."),

850 0x00000577: ("ERROR_CURRENT_DOMAIN_NOT_ALLOWED", "This operation cannot be performed on the current domain."),

851 0x00000578: ("ERROR_INVALID_WINDOW_HANDLE", "Invalid window handle."),

852 0x00000579: ("ERROR_INVALID_MENU_HANDLE", "Invalid menu handle."),

853 0x0000057a: ("ERROR_INVALID_CURSOR_HANDLE", "Invalid cursor handle."),

854 0x0000057b: ("ERROR_INVALID_ACCEL_HANDLE", "Invalid accelerator table handle."),

855 0x0000057c: ("ERROR_INVALID_HOOK_HANDLE", "Invalid hook handle."),

856 0x0000057d: ("ERROR_INVALID_DWP_HANDLE", "Invalid handle to a multiple-window position structure."),

857 0x0000057e: ("ERROR_TLW_WITH_WSCHILD", "Cannot create a top-level child window."),

858 0x0000057f: ("ERROR_CANNOT_FIND_WND_CLASS", "Cannot find window class."),

859 0x00000580: ("ERROR_WINDOW_OF_OTHER_THREAD", "Invalid window; it belongs to other thread."),

860 0x00000581: ("ERROR_HOTKEY_ALREADY_REGISTERED", "Hot key is already registered."),

861 0x00000582: ("ERROR_CLASS_ALREADY_EXISTS", "Class already exists."),

862 0x00000583: ("ERROR_CLASS_DOES_NOT_EXIST", "Class does not exist."),

863 0x00000584: ("ERROR_CLASS_HAS_WINDOWS", "Class still has open windows."),

864 0x00000585: ("ERROR_INVALID_INDEX", "Invalid index."),

865 0x00000586: ("ERROR_INVALID_ICON_HANDLE", "Invalid icon handle."),

866 0x00000587: ("ERROR_PRIVATE_DIALOG_INDEX", "Using private DIALOG window words."),

867 0x00000588: ("ERROR_LISTBOX_ID_NOT_FOUND", "The list box identifier was not found."),

868 0x00000589: ("ERROR_NO_WILDCARD_CHARACTERS", "No wildcards were found."),

869 0x0000058a: ("ERROR_CLIPBOARD_NOT_OPEN", "Thread does not have a clipboard open."),

870 0x0000058b: ("ERROR_HOTKEY_NOT_REGISTERED", "Hot key is not registered."),

871 0x0000058c: ("ERROR_WINDOW_NOT_DIALOG", "The window is not a valid dialog window."),

872 0x0000058d: ("ERROR_CONTROL_ID_NOT_FOUND", "Control ID not found."),

873 0x0000058e: ("ERROR_INVALID_COMBOBOX_MESSAGE", "Invalid message for a combo box because it does not have an edit control."),

874 0x0000058f: ("ERROR_WINDOW_NOT_COMBOBOX", "The window is not a combo box."),

875 0x00000590: ("ERROR_INVALID_EDIT_HEIGHT", "Height must be less than 256."),

876 0x00000591: ("ERROR_DC_NOT_FOUND", "Invalid device context (DC) handle."),

877 0x00000592: ("ERROR_INVALID_HOOK_FILTER", "Invalid hook procedure type."),

878 0x00000593: ("ERROR_INVALID_FILTER_PROC", "Invalid hook procedure."),

879 0x00000594: ("ERROR_HOOK_NEEDS_HMOD", "Cannot set nonlocal hook without a module handle."),

880 0x00000595: ("ERROR_GLOBAL_ONLY_HOOK", "This hook procedure can only be set globally."),

881 0x00000596: ("ERROR_JOURNAL_HOOK_SET", "The journal hook procedure is already installed."),

882 0x00000597: ("ERROR_HOOK_NOT_INSTALLED", "The hook procedure is not installed."),

883 0x00000598: ("ERROR_INVALID_LB_MESSAGE", "Invalid message for single-selection list box."),

884 0x00000599: ("ERROR_SETCOUNT_ON_BAD_LB", "LB_SETCOUNT sent to non-lazy list box."),

885 0x0000059a: ("ERROR_LB_WITHOUT_TABSTOPS", "This list box does not support tab stops."),

886 0x0000059b: ("ERROR_DESTROY_OBJECT_OF_OTHER_THREAD", "Cannot destroy object created by another thread."),

887 0x0000059c: ("ERROR_CHILD_WINDOW_MENU", "Child windows cannot have menus."),

888 0x0000059d: ("ERROR_NO_SYSTEM_MENU", "The window does not have a system menu."),

889 0x0000059e: ("ERROR_INVALID_MSGBOX_STYLE", "Invalid message box style."),

890 0x0000059f: ("ERROR_INVALID_SPI_VALUE", "Invalid system-wide (SPI_*) parameter."),

891 0x000005a0: ("ERROR_SCREEN_ALREADY_LOCKED", "Screen already locked."),

892 0x000005a1: ("ERROR_HWNDS_HAVE_DIFF_PARENT", "All handles to windows in a multiple-window position structure must have the same parent."),

893 0x000005a2: ("ERROR_NOT_CHILD_WINDOW", "The window is not a child window."),

894 0x000005a3: ("ERROR_INVALID_GW_COMMAND", "Invalid GW_* command."),

895 0x000005a4: ("ERROR_INVALID_THREAD_ID", "Invalid thread identifier."),

896 0x000005a5: ("ERROR_NON_MDICHILD_WINDOW", "Cannot process a message from a window that is not a multiple document interface (MDI) window."),

897 0x000005a6: ("ERROR_POPUP_ALREADY_ACTIVE", "Popup menu already active."),

898 0x000005a7: ("ERROR_NO_SCROLLBARS", "The window does not have scroll bars."),

899 0x000005a8: ("ERROR_INVALID_SCROLLBAR_RANGE", "Scroll bar range cannot be greater than MAXLONG."),

900 0x000005a9: ("ERROR_INVALID_SHOWWIN_COMMAND", "Cannot show or remove the window in the way specified."),

901 0x000005aa: ("ERROR_NO_SYSTEM_RESOURCES", "Insufficient system resources exist to complete the requested service."),

902 0x000005ab: ("ERROR_NONPAGED_SYSTEM_RESOURCES", "Insufficient system resources exist to complete the requested service."),

903 0x000005ac: ("ERROR_PAGED_SYSTEM_RESOURCES", "Insufficient system resources exist to complete the requested service."),

904 0x000005ad: ("ERROR_WORKING_SET_QUOTA", "Insufficient quota to complete the requested service."),

905 0x000005ae: ("ERROR_PAGEFILE_QUOTA", "Insufficient quota to complete the requested service."),

906 0x000005af: ("ERROR_COMMITMENT_LIMIT", "The paging file is too small for this operation to complete."),

907 0x000005b0: ("ERROR_MENU_ITEM_NOT_FOUND", "A menu item was not found."),

908 0x000005b1: ("ERROR_INVALID_KEYBOARD_HANDLE", "Invalid keyboard layout handle."),

909 0x000005b2: ("ERROR_HOOK_TYPE_NOT_ALLOWED", "Hook type not allowed."),

910 0x000005b3: ("ERROR_REQUIRES_INTERACTIVE_WINDOWSTATION", "This operation requires an interactive window station."),

911 0x000005b4: ("ERROR_TIMEOUT", "This operation returned because the timeout period expired."),

912 0x000005b5: ("ERROR_INVALID_MONITOR_HANDLE", "Invalid monitor handle."),

913 0x000005b6: ("ERROR_INCORRECT_SIZE", "Incorrect size argument."),

914 0x000005b7: ("ERROR_SYMLINK_CLASS_DISABLED", "The symbolic link cannot be followed because its type is disabled."),

915 0x000005b8: ("ERROR_SYMLINK_NOT_SUPPORTED", "This application does not support the current operation on symbolic links."),

916 0x000005b9: ("ERROR_XML_PARSE_ERROR", "Windows was unable to parse the requested XML data."),

917 0x000005ba: ("ERROR_XMLDSIG_ERROR", "An error was encountered while processing an XML digital signature."),

918 0x000005bb: ("ERROR_RESTART_APPLICATION", "This application must be restarted."),

919 0x000005bc: ("ERROR_WRONG_COMPARTMENT", "The caller made the connection request in the wrong routing compartment."),

920 0x000005bd: ("ERROR_AUTHIP_FAILURE", "There was an AuthIP failure when attempting to connect to the remote host."),

921 0x000005be: ("ERROR_NO_NVRAM_RESOURCES", "Insufficient NVRAM resources exist to complete the requested service. A reboot might be required."),

922 0x000005bf: ("ERROR_NOT_GUI_PROCESS", "Unable to finish the requested operation because the specified process is not a GUI process."),

923 0x000005dc: ("ERROR_EVENTLOG_FILE_CORRUPT", "The event log file is corrupted."),

924 0x000005dd: ("ERROR_EVENTLOG_CANT_START", "No event log file could be opened, so the event logging service did not start."),

925 0x000005de: ("ERROR_LOG_FILE_FULL", "The event log file is full."),

926 0x000005df: ("ERROR_EVENTLOG_FILE_CHANGED", "The event log file has changed between read operations."),

927 0x0000060e: ("ERROR_INVALID_TASK_NAME", "The specified task name is invalid."),

928 0x0000060f: ("ERROR_INVALID_TASK_INDEX", "The specified task index is invalid."),

929 0x00000610: ("ERROR_THREAD_ALREADY_IN_TASK", "The specified thread is already joining a task."),

930 0x00000641: ("ERROR_INSTALL_SERVICE_FAILURE", "The Windows Installer Service could not be accessed. This can occur if the Windows Installer is not correctly installed. Contact your support personnel for assistance."),

931 0x00000642: ("ERROR_INSTALL_USEREXIT", "User cancelled installation."),

932 0x00000643: ("ERROR_INSTALL_FAILURE", "Fatal error during installation."),

933 0x00000644: ("ERROR_INSTALL_SUSPEND", "Installation suspended, incomplete."),

934 0x00000645: ("ERROR_UNKNOWN_PRODUCT", "This action is only valid for products that are currently installed."),

935 0x00000646: ("ERROR_UNKNOWN_FEATURE", "Feature ID not registered."),

936 0x00000647: ("ERROR_UNKNOWN_COMPONENT", "Component ID not registered."),

937 0x00000648: ("ERROR_UNKNOWN_PROPERTY", "Unknown property."),

938 0x00000649: ("ERROR_INVALID_HANDLE_STATE", "Handle is in an invalid state."),

939 0x0000064a: ("ERROR_BAD_CONFIGURATION", "The configuration data for this product is corrupt. Contact your support personnel."),

940 0x0000064b: ("ERROR_INDEX_ABSENT", "Component qualifier not present."),

941 0x0000064c: ("ERROR_INSTALL_SOURCE_ABSENT", "The installation source for this product is not available. Verify that the source exists and that you can access it."),

942 0x0000064d: ("ERROR_INSTALL_PACKAGE_VERSION", "This installation package cannot be installed by the Windows Installer service. You must install a Windows service pack that contains a newer version of the Windows Installer service."),

943 0x0000064e: ("ERROR_PRODUCT_UNINSTALLED", "Product is uninstalled."),

944 0x0000064f: ("ERROR_BAD_QUERY_SYNTAX", "SQL query syntax invalid or unsupported."),

945 0x00000650: ("ERROR_INVALID_FIELD", "Record field does not exist."),

946 0x00000651: ("ERROR_DEVICE_REMOVED", "The device has been removed."),

947 0x00000652: ("ERROR_INSTALL_ALREADY_RUNNING", "Another installation is already in progress. Complete that installation before proceeding with this install."),

948 0x00000653: ("ERROR_INSTALL_PACKAGE_OPEN_FAILED", "This installation package could not be opened. Verify that the package exists and that you can access it, or contact the application vendor to verify that this is a valid Windows Installer package."),

949 0x00000654: ("ERROR_INSTALL_PACKAGE_INVALID", "This installation package could not be opened. Contact the application vendor to verify that this is a valid Windows Installer package."),

950 0x00000655: ("ERROR_INSTALL_UI_FAILURE", "There was an error starting the Windows Installer service user interface. Contact your support personnel."),

951 0x00000656: ("ERROR_INSTALL_LOG_FAILURE", "Error opening installation log file. Verify that the specified log file location exists and that you can write to it."),

952 0x00000657: ("ERROR_INSTALL_LANGUAGE_UNSUPPORTED", "The language of this installation package is not supported by your system."),

953 0x00000658: ("ERROR_INSTALL_TRANSFORM_FAILURE", "Error applying transforms. Verify that the specified transform paths are valid."),

954 0x00000659: ("ERROR_INSTALL_PACKAGE_REJECTED", "This installation is forbidden by system policy. Contact your system administrator."),

955 0x0000065a: ("ERROR_FUNCTION_NOT_CALLED", "Function could not be executed."),

956 0x0000065b: ("ERROR_FUNCTION_FAILED", "Function failed during execution."),

957 0x0000065c: ("ERROR_INVALID_TABLE", "Invalid or unknown table specified."),

958 0x0000065d: ("ERROR_DATATYPE_MISMATCH", "Data supplied is of wrong type."),

959 0x0000065e: ("ERROR_UNSUPPORTED_TYPE", "Data of this type is not supported."),

960 0x0000065f: ("ERROR_CREATE_FAILED", "The Windows Installer service failed to start. Contact your support personnel."),

961 0x00000660: ("ERROR_INSTALL_TEMP_UNWRITABLE", "The Temp folder is on a drive that is full or is inaccessible. Free up space on the drive or verify that you have write permission on the Temp folder."),

962 0x00000661: ("ERROR_INSTALL_PLATFORM_UNSUPPORTED", "This installation package is not supported by this processor type. Contact your product vendor."),

963 0x00000662: ("ERROR_INSTALL_NOTUSED", "Component not used on this computer."),

964 0x00000663: ("ERROR_PATCH_PACKAGE_OPEN_FAILED", "This update package could not be opened. Verify that the update package exists and that you can access it, or contact the application vendor to verify that this is a valid Windows Installer update package."),

965 0x00000664: ("ERROR_PATCH_PACKAGE_INVALID", "This update package could not be opened. Contact the application vendor to verify that this is a valid Windows Installer update package."),

966 0x00000665: ("ERROR_PATCH_PACKAGE_UNSUPPORTED", "This update package cannot be processed by the Windows Installer service. You must install a Windows service pack that contains a newer version of the Windows Installer service."),

967 0x00000666: ("ERROR_PRODUCT_VERSION", "Another version of this product is already installed. Installation of this version cannot continue. To configure or remove the existing version of this product, use Add/Remove Programs on the Control Panel."),

968 0x00000667: ("ERROR_INVALID_COMMAND_LINE", "Invalid command line argument. Consult the Windows Installer SDK for detailed command line help."),

969 0x00000668: ("ERROR_INSTALL_REMOTE_DISALLOWED", "Only administrators have permission to add, remove, or configure server software during a Terminal services remote session. If you want to install or configure software on the server, contact your network administrator."),

970 0x00000669: ("ERROR_SUCCESS_REBOOT_INITIATED", "The requested operation completed successfully. The system will be restarted so the changes can take effect."),

971 0x0000066a: ("ERROR_PATCH_TARGET_NOT_FOUND", "The upgrade cannot be installed by the Windows Installer service because the program to be upgraded may be missing, or the upgrade may update a different version of the program. Verify that the program to be upgraded exists on your computer and that you have the correct upgrade."),

972 0x0000066b: ("ERROR_PATCH_PACKAGE_REJECTED", "The update package is not permitted by software restriction policy."),

973 0x0000066c: ("ERROR_INSTALL_TRANSFORM_REJECTED", "One or more customizations are not permitted by software restriction policy."),

974 0x0000066d: ("ERROR_INSTALL_REMOTE_PROHIBITED", "The Windows Installer does not permit installation from a Remote Desktop Connection."),

975 0x0000066e: ("ERROR_PATCH_REMOVAL_UNSUPPORTED", "Uninstallation of the update package is not supported."),

976 0x0000066f: ("ERROR_UNKNOWN_PATCH", "The update is not applied to this product."),

977 0x00000670: ("ERROR_PATCH_NO_SEQUENCE", "No valid sequence could be found for the set of updates."),

978 0x00000671: ("ERROR_PATCH_REMOVAL_DISALLOWED", "Update removal was disallowed by policy."),

979 0x00000672: ("ERROR_INVALID_PATCH_XML", "The XML update data is invalid."),

980 0x00000673: ("ERROR_PATCH_MANAGED_ADVERTISED_PRODUCT", "Windows Installer does not permit updating of managed advertised products. At least one feature of the product must be installed before applying the update."),

981 0x00000674: ("ERROR_INSTALL_SERVICE_SAFEBOOT", "The Windows Installer service is not accessible in Safe Mode. Please try again when your computer is not in Safe Mode or you can use System Restore to return your machine to a previous good state."),

982 0x00000675: ("ERROR_FAIL_FAST_EXCEPTION", "A fail fast exception occurred. Exception handlers will not be invoked and the process will be terminated immediately."),

983 0x00000676: ("ERROR_INSTALL_REJECTED", "The app that you are trying to run is not supported on this version of Windows."),

984 0x000006a4: ("RPC_S_INVALID_STRING_BINDING", "The string binding is invalid."),

985 0x000006a5: ("RPC_S_WRONG_KIND_OF_BINDING", "The binding handle is not the correct type."),

986 0x000006a6: ("RPC_S_INVALID_BINDING", "The binding handle is invalid."),

987 0x000006a7: ("RPC_S_PROTSEQ_NOT_SUPPORTED", "The RPC protocol sequence is not supported."),

988 0x000006a8: ("RPC_S_INVALID_RPC_PROTSEQ", "The RPC protocol sequence is invalid."),

989 0x000006a9: ("RPC_S_INVALID_STRING_UUID", "The string universal unique identifier (UUID) is invalid."),

990 0x000006aa: ("RPC_S_INVALID_ENDPOINT_FORMAT", "The endpoint format is invalid."),

991 0x000006ab: ("RPC_S_INVALID_NET_ADDR", "The network address is invalid."),

992 0x000006ac: ("RPC_S_NO_ENDPOINT_FOUND", "No endpoint was found."),

993 0x000006ad: ("RPC_S_INVALID_TIMEOUT", "The timeout value is invalid."),

994 0x000006ae: ("RPC_S_OBJECT_NOT_FOUND", "The object universal unique identifier (UUID) was not found."),

995 0x000006af: ("RPC_S_ALREADY_REGISTERED", "The object universal unique identifier (UUID) has already been registered."),

996 0x000006b0: ("RPC_S_TYPE_ALREADY_REGISTERED", "The type universal unique identifier (UUID) has already been registered."),

997 0x000006b1: ("RPC_S_ALREADY_LISTENING", "The RPC server is already listening."),

998 0x000006b2: ("RPC_S_NO_PROTSEQS_REGISTERED", "No protocol sequences have been registered."),

999 0x000006b3: ("RPC_S_NOT_LISTENING", "The RPC server is not listening."),

1000 0x000006b4: ("RPC_S_UNKNOWN_MGR_TYPE", "The manager type is unknown."),

1001 0x000006b5: ("RPC_S_UNKNOWN_IF", "The interface is unknown."),

1002 0x000006b6: ("RPC_S_NO_BINDINGS", "There are no bindings."),

1003 0x000006b7: ("RPC_S_NO_PROTSEQS", "There are no protocol sequences."),

1004 0x000006b8: ("RPC_S_CANT_CREATE_ENDPOINT", "The endpoint cannot be created."),

1005 0x000006b9: ("RPC_S_OUT_OF_RESOURCES", "Not enough resources are available to complete this operation."),

1006 0x000006ba: ("RPC_S_SERVER_UNAVAILABLE", "The RPC server is unavailable."),

1007 0x000006bb: ("RPC_S_SERVER_TOO_BUSY", "The RPC server is too busy to complete this operation."),

1008 0x000006bc: ("RPC_S_INVALID_NETWORK_OPTIONS", "The network options are invalid."),

1009 0x000006bd: ("RPC_S_NO_CALL_ACTIVE", "There are no remote procedure calls active on this thread."),

1010 0x000006be: ("RPC_S_CALL_FAILED", "The remote procedure call failed."),

1011 0x000006bf: ("RPC_S_CALL_FAILED_DNE", "The remote procedure call failed and did not execute."),

1012 0x000006c0: ("RPC_S_PROTOCOL_ERROR", "A remote procedure call (RPC) protocol error occurred."),

1013 0x000006c1: ("RPC_S_PROXY_ACCESS_DENIED", "Access to the HTTP proxy is denied."),

1014 0x000006c2: ("RPC_S_UNSUPPORTED_TRANS_SYN", "The transfer syntax is not supported by the RPC server."),

1015 0x000006c4: ("RPC_S_UNSUPPORTED_TYPE", "The universal unique identifier (UUID) type is not supported."),

1016 0x000006c5: ("RPC_S_INVALID_TAG", "The tag is invalid."),

1017 0x000006c6: ("RPC_S_INVALID_BOUND", "The array bounds are invalid."),

1018 0x000006c7: ("RPC_S_NO_ENTRY_NAME", "The binding does not contain an entry name."),

1019 0x000006c8: ("RPC_S_INVALID_NAME_SYNTAX", "The name syntax is invalid."),

1020 0x000006c9: ("RPC_S_UNSUPPORTED_NAME_SYNTAX", "The name syntax is not supported."),

1021 0x000006cb: ("RPC_S_UUID_NO_ADDRESS", "No network address is available to use to construct a universal unique identifier (UUID)."),

1022 0x000006cc: ("RPC_S_DUPLICATE_ENDPOINT", "The endpoint is a duplicate."),

1023 0x000006cd: ("RPC_S_UNKNOWN_AUTHN_TYPE", "The authentication type is unknown."),

1024 0x000006ce: ("RPC_S_MAX_CALLS_TOO_SMALL", "The maximum number of calls is too small."),

1025 0x000006cf: ("RPC_S_STRING_TOO_LONG", "The string is too long."),

1026 0x000006d0: ("RPC_S_PROTSEQ_NOT_FOUND", "The RPC protocol sequence was not found."),

1027 0x000006d1: ("RPC_S_PROCNUM_OUT_OF_RANGE", "The procedure number is out of range."),

1028 0x000006d2: ("RPC_S_BINDING_HAS_NO_AUTH", "The binding does not contain any authentication information."),

1029 0x000006d3: ("RPC_S_UNKNOWN_AUTHN_SERVICE", "The authentication service is unknown."),

1030 0x000006d4: ("RPC_S_UNKNOWN_AUTHN_LEVEL", "The authentication level is unknown."),

1031 0x000006d5: ("RPC_S_INVALID_AUTH_IDENTITY", "The security context is invalid."),

1032 0x000006d6: ("RPC_S_UNKNOWN_AUTHZ_SERVICE", "The authorization service is unknown."),

1033 0x000006d7: ("EPT_S_INVALID_ENTRY", "The entry is invalid."),

1034 0x000006d8: ("EPT_S_CANT_PERFORM_OP", "The server endpoint cannot perform the operation."),

1035 0x000006d9: ("EPT_S_NOT_REGISTERED", "There are no more endpoints available from the endpoint mapper."),

1036 0x000006da: ("RPC_S_NOTHING_TO_EXPORT", "No interfaces have been exported."),

1037 0x000006db: ("RPC_S_INCOMPLETE_NAME", "The entry name is incomplete."),

1038 0x000006dc: ("RPC_S_INVALID_VERS_OPTION", "The version option is invalid."),

1039 0x000006dd: ("RPC_S_NO_MORE_MEMBERS", "There are no more members."),

1040 0x000006de: ("RPC_S_NOT_ALL_OBJS_UNEXPORTED", "There is nothing to unexport."),

1041 0x000006df: ("RPC_S_INTERFACE_NOT_FOUND", "The interface was not found."),

1042 0x000006e0: ("RPC_S_ENTRY_ALREADY_EXISTS", "The entry already exists."),

1043 0x000006e1: ("RPC_S_ENTRY_NOT_FOUND", "The entry is not found."),

1044 0x000006e2: ("RPC_S_NAME_SERVICE_UNAVAILABLE", "The name service is unavailable."),

1045 0x000006e3: ("RPC_S_INVALID_NAF_ID", "The network address family is invalid."),

1046 0x000006e4: ("RPC_S_CANNOT_SUPPORT", "The requested operation is not supported."),

1047 0x000006e5: ("RPC_S_NO_CONTEXT_AVAILABLE", "No security context is available to allow impersonation."),

1048 0x000006e6: ("RPC_S_INTERNAL_ERROR", "An internal error occurred in a remote procedure call (RPC)."),

1049 0x000006e7: ("RPC_S_ZERO_DIVIDE", "The RPC server attempted an integer division by zero."),

1050 0x000006e8: ("RPC_S_ADDRESS_ERROR", "An addressing error occurred in the RPC server."),

1051 0x000006e9: ("RPC_S_FP_DIV_ZERO", "A floating-point operation at the RPC server caused a division by zero."),

1052 0x000006ea: ("RPC_S_FP_UNDERFLOW", "A floating-point underflow occurred at the RPC server."),

1053 0x000006eb: ("RPC_S_FP_OVERFLOW", "A floating-point overflow occurred at the RPC server."),

1054 0x000006ec: ("RPC_X_NO_MORE_ENTRIES", "The list of RPC servers available for the binding of auto handles has been exhausted."),

1055 0x000006ed: ("RPC_X_SS_CHAR_TRANS_OPEN_FAIL", "Unable to open the character translation table file."),

1056 0x000006ee: ("RPC_X_SS_CHAR_TRANS_SHORT_FILE", "The file containing the character translation table has fewer than 512 bytes."),

1057 0x000006ef: ("RPC_X_SS_IN_NULL_CONTEXT", "A null context handle was passed from the client to the host during a remote procedure call."),

1058 0x000006f1: ("RPC_X_SS_CONTEXT_DAMAGED", "The context handle changed during a remote procedure call."),

1059 0x000006f2: ("RPC_X_SS_HANDLES_MISMATCH", "The binding handles passed to a remote procedure call do not match."),

1060 0x000006f3: ("RPC_X_SS_CANNOT_GET_CALL_HANDLE", "The stub is unable to get the remote procedure call handle."),

1061 0x000006f4: ("RPC_X_NULL_REF_POINTER", "A null reference pointer was passed to the stub."),

1062 0x000006f5: ("RPC_X_ENUM_VALUE_OUT_OF_RANGE", "The enumeration value is out of range."),

1063 0x000006f6: ("RPC_X_BYTE_COUNT_TOO_SMALL", "The byte count is too small."),

1064 0x000006f7: ("RPC_X_BAD_STUB_DATA", "The stub received bad data."),

1065 0x000006f8: ("ERROR_INVALID_USER_BUFFER", "The supplied user buffer is not valid for the requested operation."),

1066 0x000006f9: ("ERROR_UNRECOGNIZED_MEDIA", "The disk media is not recognized. It may not be formatted."),

1067 0x000006fa: ("ERROR_NO_TRUST_LSA_SECRET", "The workstation does not have a trust secret."),

1068 0x000006fb: ("ERROR_NO_TRUST_SAM_ACCOUNT", "The security database on the server does not have a computer account for this workstation trust relationship."),

1069 0x000006fc: ("ERROR_TRUSTED_DOMAIN_FAILURE", "The trust relationship between the primary domain and the trusted domain failed."),

1070 0x000006fd: ("ERROR_TRUSTED_RELATIONSHIP_FAILURE", "The trust relationship between this workstation and the primary domain failed."),

1071 0x000006fe: ("ERROR_TRUST_FAILURE", "The network logon failed."),

1072 0x000006ff: ("RPC_S_CALL_IN_PROGRESS", "A remote procedure call is already in progress for this thread."),

1073 0x00000700: ("ERROR_NETLOGON_NOT_STARTED", "An attempt was made to logon, but the network logon service was not started."),

1074 0x00000701: ("ERROR_ACCOUNT_EXPIRED", "The user's account has expired."),

1075 0x00000702: ("ERROR_REDIRECTOR_HAS_OPEN_HANDLES", "The redirector is in use and cannot be unloaded."),

1076 0x00000703: ("ERROR_PRINTER_DRIVER_ALREADY_INSTALLED", "The specified printer driver is already installed."),

1077 0x00000704: ("ERROR_UNKNOWN_PORT", "The specified port is unknown."),

1078 0x00000705: ("ERROR_UNKNOWN_PRINTER_DRIVER", "The printer driver is unknown."),

1079 0x00000706: ("ERROR_UNKNOWN_PRINTPROCESSOR", "The print processor is unknown."),

1080 0x00000707: ("ERROR_INVALID_SEPARATOR_FILE", "The specified separator file is invalid."),

1081 0x00000708: ("ERROR_INVALID_PRIORITY", "The specified priority is invalid."),

1082 0x00000709: ("ERROR_INVALID_PRINTER_NAME", "The printer name is invalid."),

1083 0x0000070a: ("ERROR_PRINTER_ALREADY_EXISTS", "The printer already exists."),

1084 0x0000070b: ("ERROR_INVALID_PRINTER_COMMAND", "The printer command is invalid."),

1085 0x0000070c: ("ERROR_INVALID_DATATYPE", "The specified datatype is invalid."),

1086 0x0000070d: ("ERROR_INVALID_ENVIRONMENT", "The environment specified is invalid."),

1087 0x0000070e: ("RPC_S_NO_MORE_BINDINGS", "There are no more bindings."),

1088 0x0000070f: ("ERROR_NOLOGON_INTERDOMAIN_TRUST_ACCOUNT", "The account used is an interdomain trust account. Use your global user account or local user account to access this server."),

1089 0x00000710: ("ERROR_NOLOGON_WORKSTATION_TRUST_ACCOUNT", "The account used is a computer account. Use your global user account or local user account to access this server."),

1090 0x00000711: ("ERROR_NOLOGON_SERVER_TRUST_ACCOUNT", "The account used is a server trust account. Use your global user account or local user account to access this server."),

1091 0x00000712: ("ERROR_DOMAIN_TRUST_INCONSISTENT", "The name or security ID (SID) of the domain specified is inconsistent with the trust information for that domain."),

1092 0x00000713: ("ERROR_SERVER_HAS_OPEN_HANDLES", "The server is in use and cannot be unloaded."),

1093 0x00000714: ("ERROR_RESOURCE_DATA_NOT_FOUND", "The specified image file did not contain a resource section."),

1094 0x00000715: ("ERROR_RESOURCE_TYPE_NOT_FOUND", "The specified resource type cannot be found in the image file."),

1095 0x00000716: ("ERROR_RESOURCE_NAME_NOT_FOUND", "The specified resource name cannot be found in the image file."),

1096 0x00000717: ("ERROR_RESOURCE_LANG_NOT_FOUND", "The specified resource language ID cannot be found in the image file."),

1097 0x00000718: ("ERROR_NOT_ENOUGH_QUOTA", "Not enough quota is available to process this command."),

1098 0x00000719: ("RPC_S_NO_INTERFACES", "No interfaces have been registered."),

1099 0x0000071a: ("RPC_S_CALL_CANCELLED", "The remote procedure call was cancelled."),

1100 0x0000071b: ("RPC_S_BINDING_INCOMPLETE", "The binding handle does not contain all required information."),

1101 0x0000071c: ("RPC_S_COMM_FAILURE", "A communications failure occurred during a remote procedure call."),

1102 0x0000071d: ("RPC_S_UNSUPPORTED_AUTHN_LEVEL", "The requested authentication level is not supported."),

1103 0x0000071e: ("RPC_S_NO_PRINC_NAME", "No principal name registered."),

1104 0x0000071f: ("RPC_S_NOT_RPC_ERROR", "The error specified is not a valid Windows RPC error code."),

1105 0x00000720: ("RPC_S_UUID_LOCAL_ONLY", "A UUID that is valid only on this computer has been allocated."),

1106 0x00000721: ("RPC_S_SEC_PKG_ERROR", "A security package specific error occurred."),

1107 0x00000722: ("RPC_S_NOT_CANCELLED", "Thread is not canceled."),

1108 0x00000723: ("RPC_X_INVALID_ES_ACTION", "Invalid operation on the encoding/decoding handle."),

1109 0x00000724: ("RPC_X_WRONG_ES_VERSION", "Incompatible version of the serializing package."),

1110 0x00000725: ("RPC_X_WRONG_STUB_VERSION", "Incompatible version of the RPC stub."),

1111 0x00000726: ("RPC_X_INVALID_PIPE_OBJECT", "The RPC pipe object is invalid or corrupted."),

1112 0x00000727: ("RPC_X_WRONG_PIPE_ORDER", "An invalid operation was attempted on an RPC pipe object."),

1113 0x00000728: ("RPC_X_WRONG_PIPE_VERSION", "Unsupported RPC pipe version."),

1114 0x00000729: ("RPC_S_COOKIE_AUTH_FAILED", "HTTP proxy server rejected the connection because the cookie authentication failed."),

1115 0x0000076a: ("RPC_S_GROUP_MEMBER_NOT_FOUND", "The group member was not found."),

1116 0x0000076b: ("EPT_S_CANT_CREATE", "The endpoint mapper database entry could not be created."),

1117 0x0000076c: ("RPC_S_INVALID_OBJECT", "The object universal unique identifier (UUID) is the nil UUID."),

1118 0x0000076d: ("ERROR_INVALID_TIME", "The specified time is invalid."),

1119 0x0000076e: ("ERROR_INVALID_FORM_NAME", "The specified form name is invalid."),

1120 0x0000076f: ("ERROR_INVALID_FORM_SIZE", "The specified form size is invalid."),

1121 0x00000770: ("ERROR_ALREADY_WAITING", "The specified printer handle is already being waited on"),

1122 0x00000771: ("ERROR_PRINTER_DELETED", "The specified printer has been deleted."),

1123 0x00000772: ("ERROR_INVALID_PRINTER_STATE", "The state of the printer is invalid."),

1124 0x00000773: ("ERROR_PASSWORD_MUST_CHANGE", "The user's password must be changed before signing in."),

1125 0x00000774: ("ERROR_DOMAIN_CONTROLLER_NOT_FOUND", "Could not find the domain controller for this domain."),

1126 0x00000775: ("ERROR_ACCOUNT_LOCKED_OUT", "The referenced account is currently locked out and may not be logged on to."),

1127 0x00000776: ("OR_INVALID_OXID", "The object exporter specified was not found."),

1128 0x00000777: ("OR_INVALID_OID", "The object specified was not found."),

1129 0x00000778: ("OR_INVALID_SET", "The object resolver set specified was not found."),

1130 0x00000779: ("RPC_S_SEND_INCOMPLETE", "Some data remains to be sent in the request buffer."),

1131 0x0000077a: ("RPC_S_INVALID_ASYNC_HANDLE", "Invalid asynchronous remote procedure call handle."),

1132 0x0000077b: ("RPC_S_INVALID_ASYNC_CALL", "Invalid asynchronous RPC call handle for this operation."),

1133 0x0000077c: ("RPC_X_PIPE_CLOSED", "The RPC pipe object has already been closed."),

1134 0x0000077d: ("RPC_X_PIPE_DISCIPLINE_ERROR", "The RPC call completed before all pipes were processed."),

1135 0x0000077e: ("RPC_X_PIPE_EMPTY", "No more data is available from the RPC pipe."),

1136 0x0000077f: ("ERROR_NO_SITENAME", "No site name is available for this machine."),

1137 0x00000780: ("ERROR_CANT_ACCESS_FILE", "The file cannot be accessed by the system."),

1138 0x00000781: ("ERROR_CANT_RESOLVE_FILENAME", "The name of the file cannot be resolved by the system."),

1139 0x00000782: ("RPC_S_ENTRY_TYPE_MISMATCH", "The entry is not of the expected type."),

1140 0x00000783: ("RPC_S_NOT_ALL_OBJS_EXPORTED", "Not all object UUIDs could be exported to the specified entry."),

1141 0x00000784: ("RPC_S_INTERFACE_NOT_EXPORTED", "Interface could not be exported to the specified entry."),

1142 0x00000785: ("RPC_S_PROFILE_NOT_ADDED", "The specified profile entry could not be added."),

1143 0x00000786: ("RPC_S_PRF_ELT_NOT_ADDED", "The specified profile element could not be added."),

1144 0x00000787: ("RPC_S_PRF_ELT_NOT_REMOVED", "The specified profile element could not be removed."),

1145 0x00000788: ("RPC_S_GRP_ELT_NOT_ADDED", "The group element could not be added."),

1146 0x00000789: ("RPC_S_GRP_ELT_NOT_REMOVED", "The group element could not be removed."),

1147 0x0000078a: ("ERROR_KM_DRIVER_BLOCKED", "The printer driver is not compatible with a policy enabled on your computer that blocks NT 4.0 drivers."),

1148 0x0000078b: ("ERROR_CONTEXT_EXPIRED", "The context has expired and can no longer be used."),

1149 0x0000078c: ("ERROR_PER_USER_TRUST_QUOTA_EXCEEDED", "The current user's delegated trust creation quota has been exceeded."),

1150 0x0000078d: ("ERROR_ALL_USER_TRUST_QUOTA_EXCEEDED", "The total delegated trust creation quota has been exceeded."),

1151 0x0000078e: ("ERROR_USER_DELETE_TRUST_QUOTA_EXCEEDED", "The current user's delegated trust deletion quota has been exceeded."),

1152 0x0000078f: ("ERROR_AUTHENTICATION_FIREWALL_FAILED", "The computer you are signing into is protected by an authentication firewall. The specified account is not allowed to authenticate to the computer."),

1153 0x00000790: ("ERROR_REMOTE_PRINT_CONNECTIONS_BLOCKED", "Remote connections to the Print Spooler are blocked by a policy set on your machine."),

1154 0x00000791: ("ERROR_NTLM_BLOCKED", "Authentication failed because NTLM authentication has been disabled."),

1155 0x00000792: ("ERROR_PASSWORD_CHANGE_REQUIRED", "Logon Failure: EAS policy requires that the user change their password before this operation can be performed."),

1156 0x000007d0: ("ERROR_INVALID_PIXEL_FORMAT", "The pixel format is invalid."),

1157 0x000007d1: ("ERROR_BAD_DRIVER", "The specified driver is invalid."),

1158 0x000007d2: ("ERROR_INVALID_WINDOW_STYLE", "The window style or class attribute is invalid for this operation."),

1159 0x000007d3: ("ERROR_METAFILE_NOT_SUPPORTED", "The requested metafile operation is not supported."),

1160 0x000007d4: ("ERROR_TRANSFORM_NOT_SUPPORTED", "The requested transformation operation is not supported."),

1161 0x000007d5: ("ERROR_CLIPPING_NOT_SUPPORTED", "The requested clipping operation is not supported."),

1162 0x000007da: ("ERROR_INVALID_CMM", "The specified color management module is invalid."),

1163 0x000007db: ("ERROR_INVALID_PROFILE", "The specified color profile is invalid."),

1164 0x000007dc: ("ERROR_TAG_NOT_FOUND", "The specified tag was not found."),

1165 0x000007dd: ("ERROR_TAG_NOT_PRESENT", "A required tag is not present."),

1166 0x000007de: ("ERROR_DUPLICATE_TAG", "The specified tag is already present."),

1167 0x000007df: ("ERROR_PROFILE_NOT_ASSOCIATED_WITH_DEVICE", "The specified color profile is not associated with the specified device."),

1168 0x000007e0: ("ERROR_PROFILE_NOT_FOUND", "The specified color profile was not found."),

1169 0x000007e1: ("ERROR_INVALID_COLORSPACE", "The specified color space is invalid."),

1170 0x000007e2: ("ERROR_ICM_NOT_ENABLED", "Image Color Management is not enabled."),

1171 0x000007e3: ("ERROR_DELETING_ICM_XFORM", "There was an error while deleting the color transform."),

1172 0x000007e4: ("ERROR_INVALID_TRANSFORM", "The specified color transform is invalid."),

1173 0x000007e5: ("ERROR_COLORSPACE_MISMATCH", "The specified transform does not match the bitmap's color space."),

1174 0x000007e6: ("ERROR_INVALID_COLORINDEX", "The specified named color index is not present in the profile."),

1175 0x000007e7: ("ERROR_PROFILE_DOES_NOT_MATCH_DEVICE", "The specified profile is intended for a device of a different type than the specified device."),

1176 0x0000083c: ("ERROR_CONNECTED_OTHER_PASSWORD", "The network connection was made successfully, but the user had to be prompted for a password other than the one originally specified."),

1177 0x0000083d: ("ERROR_CONNECTED_OTHER_PASSWORD_DEFAULT", "The network connection was made successfully using default credentials."),

1178 0x0000089a: ("ERROR_BAD_USERNAME", "The specified username is invalid."),

1179 0x000008ca: ("ERROR_NOT_CONNECTED", "This network connection does not exist."),

1180 0x00000961: ("ERROR_OPEN_FILES", "This network connection has files open or requests pending."),

1181 0x00000962: ("ERROR_ACTIVE_CONNECTIONS", "Active connections still exist."),

1182 0x00000964: ("ERROR_DEVICE_IN_USE", "The device is in use by an active process and cannot be disconnected."),

1183 0x00000bb8: ("ERROR_UNKNOWN_PRINT_MONITOR", "The specified print monitor is unknown."),

1184 0x00000bb9: ("ERROR_PRINTER_DRIVER_IN_USE", "The specified printer driver is currently in use."),

1185 0x00000bba: ("ERROR_SPOOL_FILE_NOT_FOUND", "The spool file was not found."),

1186 0x00000bbb: ("ERROR_SPL_NO_STARTDOC", "A StartDocPrinter call was not issued."),

1187 0x00000bbc: ("ERROR_SPL_NO_ADDJOB", "An AddJob call was not issued."),

1188 0x00000bbd: ("ERROR_PRINT_PROCESSOR_ALREADY_INSTALLED", "The specified print processor has already been installed."),

1189 0x00000bbe: ("ERROR_PRINT_MONITOR_ALREADY_INSTALLED", "The specified print monitor has already been installed."),

1190 0x00000bbf: ("ERROR_INVALID_PRINT_MONITOR", "The specified print monitor does not have the required functions."),

1191 0x00000bc0: ("ERROR_PRINT_MONITOR_IN_USE", "The specified print monitor is currently in use."),

1192 0x00000bc1: ("ERROR_PRINTER_HAS_JOBS_QUEUED", "The requested operation is not allowed when there are jobs queued to the printer."),

1193 0x00000bc2: ("ERROR_SUCCESS_REBOOT_REQUIRED", "The requested operation is successful. Changes will not be effective until the system is rebooted."),

1194 0x00000bc3: ("ERROR_SUCCESS_RESTART_REQUIRED", "The requested operation is successful. Changes will not be effective until the service is restarted."),

1195 0x00000bc4: ("ERROR_PRINTER_NOT_FOUND", "No printers were found."),

1196 0x00000bc5: ("ERROR_PRINTER_DRIVER_WARNED", "The printer driver is known to be unreliable."),

1197 0x00000bc6: ("ERROR_PRINTER_DRIVER_BLOCKED", "The printer driver is known to harm the system."),

1198 0x00000bc7: ("ERROR_PRINTER_DRIVER_PACKAGE_IN_USE", "The specified printer driver package is currently in use."),

1199 0x00000bc8: ("ERROR_CORE_DRIVER_PACKAGE_NOT_FOUND", "Unable to find a core driver package that is required by the printer driver package."),

1200 0x00000bc9: ("ERROR_FAIL_REBOOT_REQUIRED", "The requested operation failed. A system reboot is required to roll back changes made."),

1201 0x00000bca: ("ERROR_FAIL_REBOOT_INITIATED", "The requested operation failed. A system reboot has been initiated to roll back changes made."),

1202 0x00000bcb: ("ERROR_PRINTER_DRIVER_DOWNLOAD_NEEDED", "The specified printer driver was not found on the system and needs to be downloaded."),

1203 0x00000bcc: ("ERROR_PRINT_JOB_RESTART_REQUIRED", "The requested print job has failed to print. A print system update requires the job to be resubmitted."),

1204 0x00000bcd: ("ERROR_INVALID_PRINTER_DRIVER_MANIFEST", "The printer driver does not contain a valid manifest, or contains too many manifests."),

1205 0x00000bce: ("ERROR_PRINTER_NOT_SHAREABLE", "The specified printer cannot be shared."),

1206 0x00000bea: ("ERROR_REQUEST_PAUSED", "The operation was paused."),

1207 0x00000f6e: ("ERROR_IO_REISSUE_AS_CACHED", "Reissue the given operation as a cached IO operation"),

1208 0x00000fa0: ("ERROR_WINS_INTERNAL", "WINS encountered an error while processing the command."),

1209 0x00000fa1: ("ERROR_CAN_NOT_DEL_LOCAL_WINS", "The local WINS cannot be deleted."),

1210 0x00000fa2: ("ERROR_STATIC_INIT", "The importation from the file failed."),

1211 0x00000fa3: ("ERROR_INC_BACKUP", "The backup failed. Was a full backup done before?"),

1212 0x00000fa4: ("ERROR_FULL_BACKUP", "The backup failed. Check the directory to which you are backing the database."),

1213 0x00000fa5: ("ERROR_REC_NON_EXISTENT", "The name does not exist in the WINS database."),

1214 0x00000fa6: ("ERROR_RPL_NOT_ALLOWED", "Replication with a nonconfigured partner is not allowed."),

1215 0x00000fd2: ("PEERDIST_ERROR_CONTENTINFO_VERSION_UNSUPPORTED", "The version of the supplied content information is not supported."),

1216 0x00000fd3: ("PEERDIST_ERROR_CANNOT_PARSE_CONTENTINFO", "The supplied content information is malformed."),

1217 0x00000fd4: ("PEERDIST_ERROR_MISSING_DATA", "The requested data cannot be found in local or peer caches."),

1218 0x00000fd5: ("PEERDIST_ERROR_NO_MORE", "No more data is available or required."),

1219 0x00000fd6: ("PEERDIST_ERROR_NOT_INITIALIZED", "The supplied object has not been initialized."),

1220 0x00000fd7: ("PEERDIST_ERROR_ALREADY_INITIALIZED", "The supplied object has already been initialized."),

1221 0x00000fd8: ("PEERDIST_ERROR_SHUTDOWN_IN_PROGRESS", "A shutdown operation is already in progress."),

1222 0x00000fd9: ("PEERDIST_ERROR_INVALIDATED", "The supplied object has already been invalidated."),

1223 0x00000fda: ("PEERDIST_ERROR_ALREADY_EXISTS", "An element already exists and was not replaced."),

1224 0x00000fdb: ("PEERDIST_ERROR_OPERATION_NOTFOUND", "Can not cancel the requested operation as it has already been completed."),

1225 0x00000fdc: ("PEERDIST_ERROR_ALREADY_COMPLETED", "Can not perform the reqested operation because it has already been carried out."),

1226 0x00000fdd: ("PEERDIST_ERROR_OUT_OF_BOUNDS", "An operation accessed data beyond the bounds of valid data."),

1227 0x00000fde: ("PEERDIST_ERROR_VERSION_UNSUPPORTED", "The requested version is not supported."),

1228 0x00000fdf: ("PEERDIST_ERROR_INVALID_CONFIGURATION", "A configuration value is invalid."),

1229 0x00000fe0: ("PEERDIST_ERROR_NOT_LICENSED", "The SKU is not licensed."),

1230 0x00000fe1: ("PEERDIST_ERROR_SERVICE_UNAVAILABLE", "PeerDist Service is still initializing and will be available shortly."),

1231 0x00000fe2: ("PEERDIST_ERROR_TRUST_FAILURE", "Communication with one or more computers will be temporarily blocked due to recent errors."),

1232 0x00001004: ("ERROR_DHCP_ADDRESS_CONFLICT", "The DHCP client has obtained an IP address that is already in use on the network. The local interface will be disabled until the DHCP client can obtain a new address."),

1233 0x00001068: ("ERROR_WMI_GUID_NOT_FOUND", "The GUID passed was not recognized as valid by a WMI data provider."),

1234 0x00001069: ("ERROR_WMI_INSTANCE_NOT_FOUND", "The instance name passed was not recognized as valid by a WMI data provider."),

1235 0x0000106a: ("ERROR_WMI_ITEMID_NOT_FOUND", "The data item ID passed was not recognized as valid by a WMI data provider."),

1236 0x0000106b: ("ERROR_WMI_TRY_AGAIN", "The WMI request could not be completed and should be retried."),

1237 0x0000106c: ("ERROR_WMI_DP_NOT_FOUND", "The WMI data provider could not be located."),

1238 0x0000106d: ("ERROR_WMI_UNRESOLVED_INSTANCE_REF", "The WMI data provider references an instance set that has not been registered."),

1239 0x0000106e: ("ERROR_WMI_ALREADY_ENABLED", "The WMI data block or event notification has already been enabled."),

1240 0x0000106f: ("ERROR_WMI_GUID_DISCONNECTED", "The WMI data block is no longer available."),

1241 0x00001070: ("ERROR_WMI_SERVER_UNAVAILABLE", "The WMI data service is not available."),

1242 0x00001071: ("ERROR_WMI_DP_FAILED", "The WMI data provider failed to carry out the request."),

1243 0x00001072: ("ERROR_WMI_INVALID_MOF", "The WMI MOF information is not valid."),

1244 0x00001073: ("ERROR_WMI_INVALID_REGINFO", "The WMI registration information is not valid."),

1245 0x00001074: ("ERROR_WMI_ALREADY_DISABLED", "The WMI data block or event notification has already been disabled."),

1246 0x00001075: ("ERROR_WMI_READ_ONLY", "The WMI data item or data block is read only."),

1247 0x00001076: ("ERROR_WMI_SET_FAILURE", "The WMI data item or data block could not be changed."),

1248 0x0000109a: ("ERROR_NOT_APPCONTAINER", "This operation is only valid in the context of an app container."),

1249 0x0000109b: ("ERROR_APPCONTAINER_REQUIRED", "This application can only run in the context of an app container."),

1250 0x0000109c: ("ERROR_NOT_SUPPORTED_IN_APPCONTAINER", "This functionality is not supported in the context of an app container."),

1251 0x0000109d: ("ERROR_INVALID_PACKAGE_SID_LENGTH", "The length of the SID supplied is not a valid length for app container SIDs."),

1252 0x000010cc: ("ERROR_INVALID_MEDIA", "The media identifier does not represent a valid medium."),

1253 0x000010cd: ("ERROR_INVALID_LIBRARY", "The library identifier does not represent a valid library."),

1254 0x000010ce: ("ERROR_INVALID_MEDIA_POOL", "The media pool identifier does not represent a valid media pool."),

1255 0x000010cf: ("ERROR_DRIVE_MEDIA_MISMATCH", "The drive and medium are not compatible or exist in different libraries."),

1256 0x000010d0: ("ERROR_MEDIA_OFFLINE", "The medium currently exists in an offline library and must be online to perform this operation."),

1257 0x000010d1: ("ERROR_LIBRARY_OFFLINE", "The operation cannot be performed on an offline library."),

1258 0x000010d2: ("ERROR_EMPTY", "The library, drive, or media pool is empty."),

1259 0x000010d3: ("ERROR_NOT_EMPTY", "The library, drive, or media pool must be empty to perform this operation."),

1260 0x000010d4: ("ERROR_MEDIA_UNAVAILABLE", "No media is currently available in this media pool or library."),

1261 0x000010d5: ("ERROR_RESOURCE_DISABLED", "A resource required for this operation is disabled."),

1262 0x000010d6: ("ERROR_INVALID_CLEANER", "The media identifier does not represent a valid cleaner."),

1263 0x000010d7: ("ERROR_UNABLE_TO_CLEAN", "The drive cannot be cleaned or does not support cleaning."),

1264 0x000010d8: ("ERROR_OBJECT_NOT_FOUND", "The object identifier does not represent a valid object."),

1265 0x000010d9: ("ERROR_DATABASE_FAILURE", "Unable to read from or write to the database."),

1266 0x000010da: ("ERROR_DATABASE_FULL", "The database is full."),

1267 0x000010db: ("ERROR_MEDIA_INCOMPATIBLE", "The medium is not compatible with the device or media pool."),

1268 0x000010dc: ("ERROR_RESOURCE_NOT_PRESENT", "The resource required for this operation does not exist."),

1269 0x000010dd: ("ERROR_INVALID_OPERATION", "The operation identifier is not valid."),

1270 0x000010de: ("ERROR_MEDIA_NOT_AVAILABLE", "The media is not mounted or ready for use."),

1271 0x000010df: ("ERROR_DEVICE_NOT_AVAILABLE", "The device is not ready for use."),

1272 0x000010e0: ("ERROR_REQUEST_REFUSED", "The operator or administrator has refused the request."),

1273 0x000010e1: ("ERROR_INVALID_DRIVE_OBJECT", "The drive identifier does not represent a valid drive."),

1274 0x000010e2: ("ERROR_LIBRARY_FULL", "Library is full. No slot is available for use."),

1275 0x000010e3: ("ERROR_MEDIUM_NOT_ACCESSIBLE", "The transport cannot access the medium."),

1276 0x000010e4: ("ERROR_UNABLE_TO_LOAD_MEDIUM", "Unable to load the medium into the drive."),

1277 0x000010e5: ("ERROR_UNABLE_TO_INVENTORY_DRIVE", "Unable to retrieve the drive status."),

1278 0x000010e6: ("ERROR_UNABLE_TO_INVENTORY_SLOT", "Unable to retrieve the slot status."),

1279 0x000010e7: ("ERROR_UNABLE_TO_INVENTORY_TRANSPORT", "Unable to retrieve status about the transport."),

1280 0x000010e8: ("ERROR_TRANSPORT_FULL", "Cannot use the transport because it is already in use."),

1281 0x000010e9: ("ERROR_CONTROLLING_IEPORT", "Unable to open or close the inject/eject port."),

1282 0x000010ea: ("ERROR_UNABLE_TO_EJECT_MOUNTED_MEDIA", "Unable to eject the medium because it is in a drive."),

1283 0x000010eb: ("ERROR_CLEANER_SLOT_SET", "A cleaner slot is already reserved."),

1284 0x000010ec: ("ERROR_CLEANER_SLOT_NOT_SET", "A cleaner slot is not reserved."),

1285 0x000010ed: ("ERROR_CLEANER_CARTRIDGE_SPENT", "The cleaner cartridge has performed the maximum number of drive cleanings."),

1286 0x000010ee: ("ERROR_UNEXPECTED_OMID", "Unexpected on-medium identifier."),

1287 0x000010ef: ("ERROR_CANT_DELETE_LAST_ITEM", "The last remaining item in this group or resource cannot be deleted."),

1288 0x000010f0: ("ERROR_MESSAGE_EXCEEDS_MAX_SIZE", "The message provided exceeds the maximum size allowed for this parameter."),

1289 0x000010f1: ("ERROR_VOLUME_CONTAINS_SYS_FILES", "The volume contains system or paging files."),

1290 0x000010f2: ("ERROR_INDIGENOUS_TYPE", "The media type cannot be removed from this library since at least one drive in the library reports it can support this media type."),

1291 0x000010f3: ("ERROR_NO_SUPPORTING_DRIVES", "This offline media cannot be mounted on this system since no enabled drives are present which can be used."),

1292 0x000010f4: ("ERROR_CLEANER_CARTRIDGE_INSTALLED", "A cleaner cartridge is present in the tape library."),

1293 0x000010f5: ("ERROR_IEPORT_FULL", "Cannot use the inject/eject port because it is not empty."),

1294 0x000010fe: ("ERROR_FILE_OFFLINE", "This file is currently not available for use on this computer."),

1295 0x000010ff: ("ERROR_REMOTE_STORAGE_NOT_ACTIVE", "The remote storage service is not operational at this time."),

1296 0x00001100: ("ERROR_REMOTE_STORAGE_MEDIA_ERROR", "The remote storage service encountered a media error."),

1297 0x00001126: ("ERROR_NOT_A_REPARSE_POINT", "The file or directory is not a reparse point."),

1298 0x00001127: ("ERROR_REPARSE_ATTRIBUTE_CONFLICT", "The reparse point attribute cannot be set because it conflicts with an existing attribute."),

1299 0x00001128: ("ERROR_INVALID_REPARSE_DATA", "The data present in the reparse point buffer is invalid."),

1300 0x00001129: ("ERROR_REPARSE_TAG_INVALID", "The tag present in the reparse point buffer is invalid."),

1301 0x0000112a: ("ERROR_REPARSE_TAG_MISMATCH", "There is a mismatch between the tag specified in the request and the tag present in the reparse point."),

1302 0x00001130: ("ERROR_APP_DATA_NOT_FOUND", "Fast Cache data not found."),

1303 0x00001131: ("ERROR_APP_DATA_EXPIRED", "Fast Cache data expired."),

1304 0x00001132: ("ERROR_APP_DATA_CORRUPT", "Fast Cache data corrupt."),

1305 0x00001133: ("ERROR_APP_DATA_LIMIT_EXCEEDED", "Fast Cache data has exceeded its max size and cannot be updated."),

1306 0x00001134: ("ERROR_APP_DATA_REBOOT_REQUIRED", "Fast Cache has been ReArmed and requires a reboot until it can be updated."),

1307 0x00001144: ("ERROR_SECUREBOOT_ROLLBACK_DETECTED", "Secure Boot detected that rollback of protected data has been attempted."),

1308 0x00001145: ("ERROR_SECUREBOOT_POLICY_VIOLATION", "The value is protected by Secure Boot policy and cannot be modified or deleted."),

1309 0x00001146: ("ERROR_SECUREBOOT_INVALID_POLICY", "The Secure Boot policy is invalid."),

1310 0x00001147: ("ERROR_SECUREBOOT_POLICY_PUBLISHER_NOT_FOUND", "A new Secure Boot policy did not contain the current publisher on its update list."),

1311 0x00001148: ("ERROR_SECUREBOOT_POLICY_NOT_SIGNED", "The Secure Boot policy is either not signed or is signed by a non-trusted signer."),

1312 0x00001149: ("ERROR_SECUREBOOT_NOT_ENABLED", "Secure Boot is not enabled on this machine."),

1313 0x0000114a: ("ERROR_SECUREBOOT_FILE_REPLACED", "Secure Boot requires that certain files and drivers are not replaced by other files or drivers."),

1314 0x00001158: ("ERROR_OFFLOAD_READ_FLT_NOT_SUPPORTED", "The copy offload read operation is not supported by a filter."),

1315 0x00001159: ("ERROR_OFFLOAD_WRITE_FLT_NOT_SUPPORTED", "The copy offload write operation is not supported by a filter."),

1316 0x0000115a: ("ERROR_OFFLOAD_READ_FILE_NOT_SUPPORTED", "The copy offload read operation is not supported for the file."),

1317 0x0000115b: ("ERROR_OFFLOAD_WRITE_FILE_NOT_SUPPORTED", "The copy offload write operation is not supported for the file."),

1318 0x00001194: ("ERROR_VOLUME_NOT_SIS_ENABLED", "Single Instance Storage is not available on this volume."),

1319 0x00001389: ("ERROR_DEPENDENT_RESOURCE_EXISTS", "The operation cannot be completed because other resources are dependent on this resource."),

1320 0x0000138a: ("ERROR_DEPENDENCY_NOT_FOUND", "The cluster resource dependency cannot be found."),

1321 0x0000138b: ("ERROR_DEPENDENCY_ALREADY_EXISTS", "The cluster resource cannot be made dependent on the specified resource because it is already dependent."),

1322 0x0000138c: ("ERROR_RESOURCE_NOT_ONLINE", "The cluster resource is not online."),

1323 0x0000138d: ("ERROR_HOST_NODE_NOT_AVAILABLE", "A cluster node is not available for this operation."),

1324 0x0000138e: ("ERROR_RESOURCE_NOT_AVAILABLE", "The cluster resource is not available."),

1325 0x0000138f: ("ERROR_RESOURCE_NOT_FOUND", "The cluster resource could not be found."),

1326 0x00001390: ("ERROR_SHUTDOWN_CLUSTER", "The cluster is being shut down."),

1327 0x00001391: ("ERROR_CANT_EVICT_ACTIVE_NODE", "A cluster node cannot be evicted from the cluster unless the node is down or it is the last node."),

1328 0x00001392: ("ERROR_OBJECT_ALREADY_EXISTS", "The object already exists."),

1329 0x00001393: ("ERROR_OBJECT_IN_LIST", "The object is already in the list."),

1330 0x00001394: ("ERROR_GROUP_NOT_AVAILABLE", "The cluster group is not available for any new requests."),

1331 0x00001395: ("ERROR_GROUP_NOT_FOUND", "The cluster group could not be found."),

1332 0x00001396: ("ERROR_GROUP_NOT_ONLINE", "The operation could not be completed because the cluster group is not online."),

1333 0x00001397: ("ERROR_HOST_NODE_NOT_RESOURCE_OWNER", "The operation failed because either the specified cluster node is not the owner of the resource, or the node is not a possible owner of the resource."),

1334 0x00001398: ("ERROR_HOST_NODE_NOT_GROUP_OWNER", "The operation failed because either the specified cluster node is not the owner of the group, or the node is not a possible owner of the group."),

1335 0x00001399: ("ERROR_RESMON_CREATE_FAILED", "The cluster resource could not be created in the specified resource monitor."),

1336 0x0000139a: ("ERROR_RESMON_ONLINE_FAILED", "The cluster resource could not be brought online by the resource monitor."),

1337 0x0000139b: ("ERROR_RESOURCE_ONLINE", "The operation could not be completed because the cluster resource is online."),

1338 0x0000139c: ("ERROR_QUORUM_RESOURCE", "The cluster resource could not be deleted or brought offline because it is the quorum resource."),

1339 0x0000139d: ("ERROR_NOT_QUORUM_CAPABLE", "The cluster could not make the specified resource a quorum resource because it is not capable of being a quorum resource."),

1340 0x0000139e: ("ERROR_CLUSTER_SHUTTING_DOWN", "The cluster software is shutting down."),

1341 0x0000139f: ("ERROR_INVALID_STATE", "The group or resource is not in the correct state to perform the requested operation."),

1342 0x000013a0: ("ERROR_RESOURCE_PROPERTIES_STORED", "The properties were stored but not all changes will take effect until the next time the resource is brought online."),

1343 0x000013a1: ("ERROR_NOT_QUORUM_CLASS", "The cluster could not make the specified resource a quorum resource because it does not belong to a shared storage class."),

1344 0x000013a2: ("ERROR_CORE_RESOURCE", "The cluster resource could not be deleted since it is a core resource."),

1345 0x000013a3: ("ERROR_QUORUM_RESOURCE_ONLINE_FAILED", "The quorum resource failed to come online."),

1346 0x000013a4: ("ERROR_QUORUMLOG_OPEN_FAILED", "The quorum log could not be created or mounted successfully."),

1347 0x000013a5: ("ERROR_CLUSTERLOG_CORRUPT", "The cluster log is corrupt."),

1348 0x000013a6: ("ERROR_CLUSTERLOG_RECORD_EXCEEDS_MAXSIZE", "The record could not be written to the cluster log since it exceeds the maximum size."),

1349 0x000013a7: ("ERROR_CLUSTERLOG_EXCEEDS_MAXSIZE", "The cluster log exceeds its maximum size."),

1350 0x000013a8: ("ERROR_CLUSTERLOG_CHKPOINT_NOT_FOUND", "No checkpoint record was found in the cluster log."),

1351 0x000013a9: ("ERROR_CLUSTERLOG_NOT_ENOUGH_SPACE", "The minimum required disk space needed for logging is not available."),

1352 0x000013aa: ("ERROR_QUORUM_OWNER_ALIVE", "The cluster node failed to take control of the quorum resource because the resource is owned by another active node."),

1353 0x000013ab: ("ERROR_NETWORK_NOT_AVAILABLE", "A cluster network is not available for this operation."),

1354 0x000013ac: ("ERROR_NODE_NOT_AVAILABLE", "A cluster node is not available for this operation."),

1355 0x000013ad: ("ERROR_ALL_NODES_NOT_AVAILABLE", "All cluster nodes must be running to perform this operation."),

1356 0x000013ae: ("ERROR_RESOURCE_FAILED", "A cluster resource failed."),

1357 0x000013af: ("ERROR_CLUSTER_INVALID_NODE", "The cluster node is not valid."),

1358 0x000013b0: ("ERROR_CLUSTER_NODE_EXISTS", "The cluster node already exists."),

1359 0x000013b1: ("ERROR_CLUSTER_JOIN_IN_PROGRESS", "A node is in the process of joining the cluster."),

1360 0x000013b2: ("ERROR_CLUSTER_NODE_NOT_FOUND", "The cluster node was not found."),

1361 0x000013b3: ("ERROR_CLUSTER_LOCAL_NODE_NOT_FOUND", "The cluster local node information was not found."),

1362 0x000013b4: ("ERROR_CLUSTER_NETWORK_EXISTS", "The cluster network already exists."),

1363 0x000013b5: ("ERROR_CLUSTER_NETWORK_NOT_FOUND", "The cluster network was not found."),

1364 0x000013b6: ("ERROR_CLUSTER_NETINTERFACE_EXISTS", "The cluster network interface already exists."),

1365 0x000013b7: ("ERROR_CLUSTER_NETINTERFACE_NOT_FOUND", "The cluster network interface was not found."),

1366 0x000013b8: ("ERROR_CLUSTER_INVALID_REQUEST", "The cluster request is not valid for this object."),

1367 0x000013b9: ("ERROR_CLUSTER_INVALID_NETWORK_PROVIDER", "The cluster network provider is not valid."),

1368 0x000013ba: ("ERROR_CLUSTER_NODE_DOWN", "The cluster node is down."),

1369 0x000013bb: ("ERROR_CLUSTER_NODE_UNREACHABLE", "The cluster node is not reachable."),

1370 0x000013bc: ("ERROR_CLUSTER_NODE_NOT_MEMBER", "The cluster node is not a member of the cluster."),

1371 0x000013bd: ("ERROR_CLUSTER_JOIN_NOT_IN_PROGRESS", "A cluster join operation is not in progress."),

1372 0x000013be: ("ERROR_CLUSTER_INVALID_NETWORK", "The cluster network is not valid."),

1373 0x000013c0: ("ERROR_CLUSTER_NODE_UP", "The cluster node is up."),

1374 0x000013c1: ("ERROR_CLUSTER_IPADDR_IN_USE", "The cluster IP address is already in use."),

1375 0x000013c2: ("ERROR_CLUSTER_NODE_NOT_PAUSED", "The cluster node is not paused."),

1376 0x000013c3: ("ERROR_CLUSTER_NO_SECURITY_CONTEXT", "No cluster security context is available."),

1377 0x000013c4: ("ERROR_CLUSTER_NETWORK_NOT_INTERNAL", "The cluster network is not configured for internal cluster communication."),

1378 0x000013c5: ("ERROR_CLUSTER_NODE_ALREADY_UP", "The cluster node is already up."),

1379 0x000013c6: ("ERROR_CLUSTER_NODE_ALREADY_DOWN", "The cluster node is already down."),

1380 0x000013c7: ("ERROR_CLUSTER_NETWORK_ALREADY_ONLINE", "The cluster network is already online."),

1381 0x000013c8: ("ERROR_CLUSTER_NETWORK_ALREADY_OFFLINE", "The cluster network is already offline."),

1382 0x000013c9: ("ERROR_CLUSTER_NODE_ALREADY_MEMBER", "The cluster node is already a member of the cluster."),

1383 0x000013ca: ("ERROR_CLUSTER_LAST_INTERNAL_NETWORK", "The cluster network is the only one configured for internal cluster communication between two or more active cluster nodes. The internal communication capability cannot be removed from the network."),

1384 0x000013cb: ("ERROR_CLUSTER_NETWORK_HAS_DEPENDENTS", "One or more cluster resources depend on the network to provide service to clients. The client access capability cannot be removed from the network."),

1385 0x000013cc: ("ERROR_INVALID_OPERATION_ON_QUORUM", "This operation cannot be performed on the cluster resource as it the quorum resource. You may not bring the quorum resource offline or modify its possible owners list."),

1386 0x000013cd: ("ERROR_DEPENDENCY_NOT_ALLOWED", "The cluster quorum resource is not allowed to have any dependencies."),

1387 0x000013ce: ("ERROR_CLUSTER_NODE_PAUSED", "The cluster node is paused."),

1388 0x000013cf: ("ERROR_NODE_CANT_HOST_RESOURCE", "The cluster resource cannot be brought online. The owner node cannot run this resource."),

1389 0x000013d0: ("ERROR_CLUSTER_NODE_NOT_READY", "The cluster node is not ready to perform the requested operation."),

1390 0x000013d1: ("ERROR_CLUSTER_NODE_SHUTTING_DOWN", "The cluster node is shutting down."),

1391 0x000013d2: ("ERROR_CLUSTER_JOIN_ABORTED", "The cluster join operation was aborted."),

1392 0x000013d3: ("ERROR_CLUSTER_INCOMPATIBLE_VERSIONS", "The cluster join operation failed due to incompatible software versions between the joining node and its sponsor."),

1393 0x000013d4: ("ERROR_CLUSTER_MAXNUM_OF_RESOURCES_EXCEEDED", "This resource cannot be created because the cluster has reached the limit on the number of resources it can monitor."),

1394 0x000013d5: ("ERROR_CLUSTER_SYSTEM_CONFIG_CHANGED", "The system configuration changed during the cluster join or form operation. The join or form operation was aborted."),

1395 0x000013d6: ("ERROR_CLUSTER_RESOURCE_TYPE_NOT_FOUND", "The specified resource type was not found."),

1396 0x000013d7: ("ERROR_CLUSTER_RESTYPE_NOT_SUPPORTED", "The specified node does not support a resource of this type. This may be due to version inconsistencies or due to the absence of the resource DLL on this node."),

1397 0x000013d8: ("ERROR_CLUSTER_RESNAME_NOT_FOUND", "The specified resource name is not supported by this resource DLL. This may be due to a bad (or changed) name supplied to the resource DLL."),

1398 0x000013d9: ("ERROR_CLUSTER_NO_RPC_PACKAGES_REGISTERED", "No authentication package could be registered with the RPC server."),

1399 0x000013da: ("ERROR_CLUSTER_OWNER_NOT_IN_PREFLIST", "You cannot bring the group online because the owner of the group is not in the preferred list for the group. To change the owner node for the group, move the group."),

1400 0x000013db: ("ERROR_CLUSTER_DATABASE_SEQMISMATCH", "The join operation failed because the cluster database sequence number has changed or is incompatible with the locker node. This may happen during a join operation if the cluster database was changing during the join."),

1401 0x000013dc: ("ERROR_RESMON_INVALID_STATE", "The resource monitor will not allow the fail operation to be performed while the resource is in its current state. This may happen if the resource is in a pending state."),

1402 0x000013dd: ("ERROR_CLUSTER_GUM_NOT_LOCKER", "A non locker code got a request to reserve the lock for making global updates."),

1403 0x000013de: ("ERROR_QUORUM_DISK_NOT_FOUND", "The quorum disk could not be located by the cluster service."),

1404 0x000013df: ("ERROR_DATABASE_BACKUP_CORRUPT", "The backed up cluster database is possibly corrupt."),

1405 0x000013e0: ("ERROR_CLUSTER_NODE_ALREADY_HAS_DFS_ROOT", "A DFS root already exists in this cluster node."),

1406 0x000013e1: ("ERROR_RESOURCE_PROPERTY_UNCHANGEABLE", "An attempt to modify a resource property failed because it conflicts with another existing property."),

1407 0x00001702: ("ERROR_CLUSTER_MEMBERSHIP_INVALID_STATE", "An operation was attempted that is incompatible with the current membership state of the node."),

1408 0x00001703: ("ERROR_CLUSTER_QUORUMLOG_NOT_FOUND", "The quorum resource does not contain the quorum log."),

1409 0x00001704: ("ERROR_CLUSTER_MEMBERSHIP_HALT", "The membership engine requested shutdown of the cluster service on this node."),

1410 0x00001705: ("ERROR_CLUSTER_INSTANCE_ID_MISMATCH", "The join operation failed because the cluster instance ID of the joining node does not match the cluster instance ID of the sponsor node."),

1411 0x00001706: ("ERROR_CLUSTER_NETWORK_NOT_FOUND_FOR_IP", "A matching cluster network for the specified IP address could not be found."),

1412 0x00001707: ("ERROR_CLUSTER_PROPERTY_DATA_TYPE_MISMATCH", "The actual data type of the property did not match the expected data type of the property."),

1413 0x00001708: ("ERROR_CLUSTER_EVICT_WITHOUT_CLEANUP", "The cluster node was evicted from the cluster successfully, but the node was not cleaned up. To determine what cleanup steps failed and how to recover, see the Failover Clustering application event log using Event Viewer."),

1414 0x00001709: ("ERROR_CLUSTER_PARAMETER_MISMATCH", "Two or more parameter values specified for a resource's properties are in conflict."),

1415 0x0000170a: ("ERROR_NODE_CANNOT_BE_CLUSTERED", "This computer cannot be made a member of a cluster."),

1416 0x0000170b: ("ERROR_CLUSTER_WRONG_OS_VERSION", "This computer cannot be made a member of a cluster because it does not have the correct version of Windows installed."),

1417 0x0000170c: ("ERROR_CLUSTER_CANT_CREATE_DUP_CLUSTER_NAME", "A cluster cannot be created with the specified cluster name because that cluster name is already in use. Specify a different name for the cluster."),

1418 0x0000170d: ("ERROR_CLUSCFG_ALREADY_COMMITTED", "The cluster configuration action has already been committed."),

1419 0x0000170e: ("ERROR_CLUSCFG_ROLLBACK_FAILED", "The cluster configuration action could not be rolled back."),

1420 0x0000170f: ("ERROR_CLUSCFG_SYSTEM_DISK_DRIVE_LETTER_CONFLICT", "The drive letter assigned to a system disk on one node conflicted with the drive letter assigned to a disk on another node."),

1421 0x00001710: ("ERROR_CLUSTER_OLD_VERSION", "One or more nodes in the cluster are running a version of Windows that does not support this operation."),

1422 0x00001711: ("ERROR_CLUSTER_MISMATCHED_COMPUTER_ACCT_NAME", "The name of the corresponding computer account doesn't match the Network Name for this resource."),

1423 0x00001712: ("ERROR_CLUSTER_NO_NET_ADAPTERS", "No network adapters are available."),

1424 0x00001713: ("ERROR_CLUSTER_POISONED", "The cluster node has been poisoned."),

1425 0x00001714: ("ERROR_CLUSTER_GROUP_MOVING", "The group is unable to accept the request since it is moving to another node."),

1426 0x00001715: ("ERROR_CLUSTER_RESOURCE_TYPE_BUSY", "The resource type cannot accept the request since is too busy performing another operation."),

1427 0x00001716: ("ERROR_RESOURCE_CALL_TIMED_OUT", "The call to the cluster resource DLL timed out."),

1428 0x00001717: ("ERROR_INVALID_CLUSTER_IPV6_ADDRESS", "The address is not valid for an IPv6 Address resource. A global IPv6 address is required, and it must match a cluster network. Compatibility addresses are not permitted."),

1429 0x00001718: ("ERROR_CLUSTER_INTERNAL_INVALID_FUNCTION", "An internal cluster error occurred. A call to an invalid function was attempted."),

1430 0x00001719: ("ERROR_CLUSTER_PARAMETER_OUT_OF_BOUNDS", "A parameter value is out of acceptable range."),

1431 0x0000171a: ("ERROR_CLUSTER_PARTIAL_SEND", "A network error occurred while sending data to another node in the cluster. The number of bytes transmitted was less than required."),

1432 0x0000171b: ("ERROR_CLUSTER_REGISTRY_INVALID_FUNCTION", "An invalid cluster registry operation was attempted."),

1433 0x0000171c: ("ERROR_CLUSTER_INVALID_STRING_TERMINATION", "An input string of characters is not properly terminated."),

1434 0x0000171d: ("ERROR_CLUSTER_INVALID_STRING_FORMAT", "An input string of characters is not in a valid format for the data it represents."),

1435 0x0000171e: ("ERROR_CLUSTER_DATABASE_TRANSACTION_IN_PROGRESS", "An internal cluster error occurred. A cluster database transaction was attempted while a transaction was already in progress."),

1436 0x0000171f: ("ERROR_CLUSTER_DATABASE_TRANSACTION_NOT_IN_PROGRESS", "An internal cluster error occurred. There was an attempt to commit a cluster database transaction while no transaction was in progress."),

1437 0x00001720: ("ERROR_CLUSTER_NULL_DATA", "An internal cluster error occurred. Data was not properly initialized."),

1438 0x00001721: ("ERROR_CLUSTER_PARTIAL_READ", "An error occurred while reading from a stream of data. An unexpected number of bytes was returned."),

1439 0x00001722: ("ERROR_CLUSTER_PARTIAL_WRITE", "An error occurred while writing to a stream of data. The required number of bytes could not be written."),

1440 0x00001723: ("ERROR_CLUSTER_CANT_DESERIALIZE_DATA", "An error occurred while deserializing a stream of cluster data."),

1441 0x00001724: ("ERROR_DEPENDENT_RESOURCE_PROPERTY_CONFLICT", "One or more property values for this resource are in conflict with one or more property values associated with its dependent resource(s)."),

1442 0x00001725: ("ERROR_CLUSTER_NO_QUORUM", "A quorum of cluster nodes was not present to form a cluster."),

1443 0x00001726: ("ERROR_CLUSTER_INVALID_IPV6_NETWORK", "The cluster network is not valid for an IPv6 Address resource, or it does not match the configured address."),

1444 0x00001727: ("ERROR_CLUSTER_INVALID_IPV6_TUNNEL_NETWORK", "The cluster network is not valid for an IPv6 Tunnel resource. Check the configuration of the IP Address resource on which the IPv6 Tunnel resource depends."),

1445 0x00001728: ("ERROR_QUORUM_NOT_ALLOWED_IN_THIS_GROUP", "Quorum resource cannot reside in the Available Storage group."),

1446 0x00001729: ("ERROR_DEPENDENCY_TREE_TOO_COMPLEX", "The dependencies for this resource are nested too deeply."),

1447 0x0000172a: ("ERROR_EXCEPTION_IN_RESOURCE_CALL", "The call into the resource DLL raised an unhandled exception."),

1448 0x0000172b: ("ERROR_CLUSTER_RHS_FAILED_INITIALIZATION", "The RHS process failed to initialize."),

1449 0x0000172c: ("ERROR_CLUSTER_NOT_INSTALLED", "The Failover Clustering feature is not installed on this node."),

1450 0x0000172d: ("ERROR_CLUSTER_RESOURCES_MUST_BE_ONLINE_ON_THE_SAME_NODE", "The resources must be online on the same node for this operation"),

1451 0x0000172e: ("ERROR_CLUSTER_MAX_NODES_IN_CLUSTER", "A new node can not be added since this cluster is already at its maximum number of nodes."),

1452 0x0000172f: ("ERROR_CLUSTER_TOO_MANY_NODES", "This cluster can not be created since the specified number of nodes exceeds the maximum allowed limit."),

1453 0x00001730: ("ERROR_CLUSTER_OBJECT_ALREADY_USED", "An attempt to use the specified cluster name failed because an enabled computer object with the given name already exists in the domain."),

1454 0x00001731: ("ERROR_NONCORE_GROUPS_FOUND", "This cluster cannot be destroyed. It has non-core application groups which must be deleted before the cluster can be destroyed."),

1455 0x00001732: ("ERROR_FILE_SHARE_RESOURCE_CONFLICT", "File share associated with file share witness resource cannot be hosted by this cluster or any of its nodes."),

1456 0x00001733: ("ERROR_CLUSTER_EVICT_INVALID_REQUEST", "Eviction of this node is invalid at this time. Due to quorum requirements node eviction will result in cluster shutdown."),

1457 0x00001734: ("ERROR_CLUSTER_SINGLETON_RESOURCE", "Only one instance of this resource type is allowed in the cluster."),

1458 0x00001735: ("ERROR_CLUSTER_GROUP_SINGLETON_RESOURCE", "Only one instance of this resource type is allowed per resource group."),

1459 0x00001736: ("ERROR_CLUSTER_RESOURCE_PROVIDER_FAILED", "The resource failed to come online due to the failure of one or more provider resources."),

1460 0x00001737: ("ERROR_CLUSTER_RESOURCE_CONFIGURATION_ERROR", "The resource has indicated that it cannot come online on any node."),

1461 0x00001738: ("ERROR_CLUSTER_GROUP_BUSY", "The current operation cannot be performed on this group at this time."),

1462 0x00001739: ("ERROR_CLUSTER_NOT_SHARED_VOLUME", "The directory or file is not located on a cluster shared volume."),

1463 0x0000173a: ("ERROR_CLUSTER_INVALID_SECURITY_DESCRIPTOR", "The Security Descriptor does not meet the requirements for a cluster."),

1464 0x0000173b: ("ERROR_CLUSTER_SHARED_VOLUMES_IN_USE", "There is one or more shared volumes resources configured in the cluster."),

1465 0x0000173c: ("ERROR_CLUSTER_USE_SHARED_VOLUMES_API", "This group or resource cannot be directly manipulated."),

1466 0x0000173d: ("ERROR_CLUSTER_BACKUP_IN_PROGRESS", "Back up is in progress. Please wait for backup completion before trying this operation again."),

1467 0x0000173e: ("ERROR_NON_CSV_PATH", "The path does not belong to a cluster shared volume."),

1468 0x0000173f: ("ERROR_CSV_VOLUME_NOT_LOCAL", "The cluster shared volume is not locally mounted on this node."),

1469 0x00001740: ("ERROR_CLUSTER_WATCHDOG_TERMINATING", "The cluster watchdog is terminating."),

1470 0x00001741: ("ERROR_CLUSTER_RESOURCE_VETOED_MOVE_INCOMPATIBLE_NODES", "A resource vetoed a move between two nodes because they are incompatible."),

1471 0x00001742: ("ERROR_CLUSTER_INVALID_NODE_WEIGHT", "The request is invalid either because node weight cannot be changed while the cluster is in disk-only quorum mode, or because changing the node weight would violate the minimum cluster quorum requirements."),

1472 0x00001743: ("ERROR_CLUSTER_RESOURCE_VETOED_CALL", "The resource vetoed the call."),

1473 0x00001744: ("ERROR_RESMON_SYSTEM_RESOURCES_LACKING", "Resource could not start or run because it could not reserve sufficient system resources."),

1474 0x00001745: ("ERROR_CLUSTER_RESOURCE_VETOED_MOVE_NOT_ENOUGH_RESOURCES_ON_DESTINATION", "A resource vetoed a move between two nodes because the destination currently does not have enough resources to complete the operation."),

1475 0x00001746: ("ERROR_CLUSTER_RESOURCE_VETOED_MOVE_NOT_ENOUGH_RESOURCES_ON_SOURCE", ""),

1476 0x00001747: ("ERROR_CLUSTER_GROUP_QUEUED", ""),

1477 0x00001748: ("ERROR_CLUSTER_RESOURCE_LOCKED_STATUS", ""),

1478 0x00001749: ("ERROR_CLUSTER_SHARED_VOLUME_FAILOVER_NOT_ALLOWED", ""),

1479 0x0000174a: ("ERROR_CLUSTER_NODE_DRAIN_IN_PROGRESS", ""),

1480 0x0000174b: ("ERROR_CLUSTER_DISK_NOT_CONNECTED", ""),

1481 0x0000174c: ("ERROR_DISK_NOT_CSV_CAPABLE", ""),

1482 0x0000174d: ("ERROR_RESOURCE_NOT_IN_AVAILABLE_STORAGE", ""),

1483 0x0000174e: ("ERROR_CLUSTER_SHARED_VOLUME_REDIRECTED", ""),

1484 0x0000174f: ("ERROR_CLUSTER_SHARED_VOLUME_NOT_REDIRECTED", ""),

1485 0x00001750: ("ERROR_CLUSTER_CANNOT_RETURN_PROPERTIES", ""),

1486 0x00001751: ("ERROR_CLUSTER_RESOURCE_CONTAINS_UNSUPPORTED_DIFF_AREA_FOR_SHARED_VOLUMES", ""),

1487 0x00001752: ("ERROR_CLUSTER_RESOURCE_IS_IN_MAINTENANCE_MODE", ""),

1488 0x00001753: ("ERROR_CLUSTER_AFFINITY_CONFLICT", ""),

1489 0x00001754: ("ERROR_CLUSTER_RESOURCE_IS_REPLICA_VIRTUAL_MACHINE", ""),

1490 0x00001770: ("ERROR_ENCRYPTION_FAILED", "The specified file could not be encrypted."),

1491 0x00001771: ("ERROR_DECRYPTION_FAILED", "The specified file could not be decrypted."),

1492 0x00001772: ("ERROR_FILE_ENCRYPTED", "The specified file is encrypted and the user does not have the ability to decrypt it."),

1493 0x00001773: ("ERROR_NO_RECOVERY_POLICY", "There is no valid encryption recovery policy configured for this system."),

1494 0x00001774: ("ERROR_NO_EFS", "The required encryption driver is not loaded for this system."),

1495 0x00001775: ("ERROR_WRONG_EFS", "The file was encrypted with a different encryption driver than is currently loaded."),

1496 0x00001776: ("ERROR_NO_USER_KEYS", "There are no EFS keys defined for the user."),

1497 0x00001777: ("ERROR_FILE_NOT_ENCRYPTED", "The specified file is not encrypted."),

1498 0x00001778: ("ERROR_NOT_EXPORT_FORMAT", "The specified file is not in the defined EFS export format."),

1499 0x00001779: ("ERROR_FILE_READ_ONLY", "The specified file is read only."),

1500 0x0000177a: ("ERROR_DIR_EFS_DISALLOWED", "The directory has been disabled for encryption."),

1501 0x0000177b: ("ERROR_EFS_SERVER_NOT_TRUSTED", "The server is not trusted for remote encryption operation."),

1502 0x0000177c: ("ERROR_BAD_RECOVERY_POLICY", "Recovery policy configured for this system contains invalid recovery certificate."),

1503 0x0000177d: ("ERROR_EFS_ALG_BLOB_TOO_BIG", "The encryption algorithm used on the source file needs a bigger key buffer than the one on the destination file."),

1504 0x0000177e: ("ERROR_VOLUME_NOT_SUPPORT_EFS", "The disk partition does not support file encryption."),

1505 0x0000177f: ("ERROR_EFS_DISABLED", "This machine is disabled for file encryption."),

1506 0x00001780: ("ERROR_EFS_VERSION_NOT_SUPPORT", "A newer system is required to decrypt this encrypted file."),

1507 0x00001781: ("ERROR_CS_ENCRYPTION_INVALID_SERVER_RESPONSE", "The remote server sent an invalid response for a file being opened with Client Side Encryption."),

1508 0x00001782: ("ERROR_CS_ENCRYPTION_UNSUPPORTED_SERVER", "Client Side Encryption is not supported by the remote server even though it claims to support it."),

1509 0x00001783: ("ERROR_CS_ENCRYPTION_EXISTING_ENCRYPTED_FILE", "File is encrypted and should be opened in Client Side Encryption mode."),

1510 0x00001784: ("ERROR_CS_ENCRYPTION_NEW_ENCRYPTED_FILE", "A new encrypted file is being created and a $EFS needs to be provided."),

1511 0x00001785: ("ERROR_CS_ENCRYPTION_FILE_NOT_CSE", "The SMB client requested a CSE FSCTL on a non-CSE file."),

1512 0x00001786: ("ERROR_ENCRYPTION_POLICY_DENIES_OPERATION", "The requested operation was blocked by policy. For more information, contact your system administrator."),

1513 0x000017e6: ("ERROR_NO_BROWSER_SERVERS_FOUND", "The list of servers for this workgroup is not currently available"),

1514 0x00001838: ("SCHED_E_SERVICE_NOT_LOCALSYSTEM", "The Task Scheduler service must be configured to run in the System account to function properly. Individual tasks may be configured to run in other accounts."),

1515 0x000019c8: ("ERROR_LOG_SECTOR_INVALID", "Log service encountered an invalid log sector."),

1516 0x000019c9: ("ERROR_LOG_SECTOR_PARITY_INVALID", "Log service encountered a log sector with invalid block parity."),

1517 0x000019ca: ("ERROR_LOG_SECTOR_REMAPPED", "Log service encountered a remapped log sector."),

1518 0x000019cb: ("ERROR_LOG_BLOCK_INCOMPLETE", "Log service encountered a partial or incomplete log block."),

1519 0x000019cc: ("ERROR_LOG_INVALID_RANGE", "Log service encountered an attempt access data outside the active log range."),

1520 0x000019cd: ("ERROR_LOG_BLOCKS_EXHAUSTED", "Log service user marshalling buffers are exhausted."),

1521 0x000019ce: ("ERROR_LOG_READ_CONTEXT_INVALID", "Log service encountered an attempt read from a marshalling area with an invalid read context."),

1522 0x000019cf: ("ERROR_LOG_RESTART_INVALID", "Log service encountered an invalid log restart area."),

1523 0x000019d0: ("ERROR_LOG_BLOCK_VERSION", "Log service encountered an invalid log block version."),

1524 0x000019d1: ("ERROR_LOG_BLOCK_INVALID", "Log service encountered an invalid log block."),

1525 0x000019d2: ("ERROR_LOG_READ_MODE_INVALID", "Log service encountered an attempt to read the log with an invalid read mode."),

1526 0x000019d3: ("ERROR_LOG_NO_RESTART", "Log service encountered a log stream with no restart area."),

1527 0x000019d4: ("ERROR_LOG_METADATA_CORRUPT", "Log service encountered a corrupted metadata file."),

1528 0x000019d5: ("ERROR_LOG_METADATA_INVALID", "Log service encountered a metadata file that could not be created by the log file system."),

1529 0x000019d6: ("ERROR_LOG_METADATA_INCONSISTENT", "Log service encountered a metadata file with inconsistent data."),

1530 0x000019d7: ("ERROR_LOG_RESERVATION_INVALID", "Log service encountered an attempt to erroneous allocate or dispose reservation space."),

1531 0x000019d8: ("ERROR_LOG_CANT_DELETE", "Log service cannot delete log file or file system container."),

1532 0x000019d9: ("ERROR_LOG_CONTAINER_LIMIT_EXCEEDED", "Log service has reached the maximum allowable containers allocated to a log file."),

1533 0x000019da: ("ERROR_LOG_START_OF_LOG", "Log service has attempted to read or write backward past the start of the log."),

1534 0x000019db: ("ERROR_LOG_POLICY_ALREADY_INSTALLED", "Log policy could not be installed because a policy of the same type is already present."),

1535 0x000019dc: ("ERROR_LOG_POLICY_NOT_INSTALLED", "Log policy in question was not installed at the time of the request."),

1536 0x000019dd: ("ERROR_LOG_POLICY_INVALID", "The installed set of policies on the log is invalid."),

1537 0x000019de: ("ERROR_LOG_POLICY_CONFLICT", "A policy on the log in question prevented the operation from completing."),

1538 0x000019df: ("ERROR_LOG_PINNED_ARCHIVE_TAIL", "Log space cannot be reclaimed because the log is pinned by the archive tail."),

1539 0x000019e0: ("ERROR_LOG_RECORD_NONEXISTENT", "Log record is not a record in the log file."),

1540 0x000019e1: ("ERROR_LOG_RECORDS_RESERVED_INVALID", "Number of reserved log records or the adjustment of the number of reserved log records is invalid."),

1541 0x000019e2: ("ERROR_LOG_SPACE_RESERVED_INVALID", "Reserved log space or the adjustment of the log space is invalid."),

1542 0x000019e3: ("ERROR_LOG_TAIL_INVALID", "An new or existing archive tail or base of the active log is invalid."),

1543 0x000019e4: ("ERROR_LOG_FULL", "Log space is exhausted."),

1544 0x000019e5: ("ERROR_COULD_NOT_RESIZE_LOG", "The log could not be set to the requested size."),

1545 0x000019e6: ("ERROR_LOG_MULTIPLEXED", "Log is multiplexed, no direct writes to the physical log is allowed."),

1546 0x000019e7: ("ERROR_LOG_DEDICATED", "The operation failed because the log is a dedicated log."),

1547 0x000019e8: ("ERROR_LOG_ARCHIVE_NOT_IN_PROGRESS", "The operation requires an archive context."),

1548 0x000019e9: ("ERROR_LOG_ARCHIVE_IN_PROGRESS", "Log archival is in progress."),

1549 0x000019ea: ("ERROR_LOG_EPHEMERAL", "The operation requires a non-ephemeral log, but the log is ephemeral."),

1550 0x000019eb: ("ERROR_LOG_NOT_ENOUGH_CONTAINERS", "The log must have at least two containers before it can be read from or written to."),

1551 0x000019ec: ("ERROR_LOG_CLIENT_ALREADY_REGISTERED", "A log client has already registered on the stream."),

1552 0x000019ed: ("ERROR_LOG_CLIENT_NOT_REGISTERED", "A log client has not been registered on the stream."),

1553 0x000019ee: ("ERROR_LOG_FULL_HANDLER_IN_PROGRESS", "A request has already been made to handle the log full condition."),

1554 0x000019ef: ("ERROR_LOG_CONTAINER_READ_FAILED", "Log service encountered an error when attempting to read from a log container."),

1555 0x000019f0: ("ERROR_LOG_CONTAINER_WRITE_FAILED", "Log service encountered an error when attempting to write to a log container."),

1556 0x000019f1: ("ERROR_LOG_CONTAINER_OPEN_FAILED", "Log service encountered an error when attempting open a log container."),

1557 0x000019f2: ("ERROR_LOG_CONTAINER_STATE_INVALID", "Log service encountered an invalid container state when attempting a requested action."),

1558 0x000019f3: ("ERROR_LOG_STATE_INVALID", "Log service is not in the correct state to perform a requested action."),

1559 0x000019f4: ("ERROR_LOG_PINNED", "Log space cannot be reclaimed because the log is pinned."),

1560 0x000019f5: ("ERROR_LOG_METADATA_FLUSH_FAILED", "Log metadata flush failed."),

1561 0x000019f6: ("ERROR_LOG_INCONSISTENT_SECURITY", "Security on the log and its containers is inconsistent."),

1562 0x000019f7: ("ERROR_LOG_APPENDED_FLUSH_FAILED", "Records were appended to the log or reservation changes were made, but the log could not be flushed."),

1563 0x000019f8: ("ERROR_LOG_PINNED_RESERVATION", "The log is pinned due to reservation consuming most of the log space. Free some reserved records to make space available."),

1564 0x00001a2c: ("ERROR_INVALID_TRANSACTION", "The transaction handle associated with this operation is not valid."),

1565 0x00001a2d: ("ERROR_TRANSACTION_NOT_ACTIVE", "The requested operation was made in the context of a transaction that is no longer active."),

1566 0x00001a2e: ("ERROR_TRANSACTION_REQUEST_NOT_VALID", "The requested operation is not valid on the Transaction object in its current state."),

1567 0x00001a2f: ("ERROR_TRANSACTION_NOT_REQUESTED", "The caller has called a response API, but the response is not expected because the TM did not issue the corresponding request to the caller."),

1568 0x00001a30: ("ERROR_TRANSACTION_ALREADY_ABORTED", "It is too late to perform the requested operation, since the Transaction has already been aborted."),

1569 0x00001a31: ("ERROR_TRANSACTION_ALREADY_COMMITTED", "It is too late to perform the requested operation, since the Transaction has already been committed."),

1570 0x00001a32: ("ERROR_TM_INITIALIZATION_FAILED", "The Transaction Manager was unable to be successfully initialized. Transacted operations are not supported."),

1571 0x00001a33: ("ERROR_RESOURCEMANAGER_READ_ONLY", "The specified ResourceManager made no changes or updates to the resource under this transaction."),

1572 0x00001a34: ("ERROR_TRANSACTION_NOT_JOINED", "The resource manager has attempted to prepare a transaction that it has not successfully joined."),

1573 0x00001a35: ("ERROR_TRANSACTION_SUPERIOR_EXISTS", "The Transaction object already has a superior enlistment, and the caller attempted an operation that would have created a new superior. Only a single superior enlistment is allow."),

1574 0x00001a36: ("ERROR_CRM_PROTOCOL_ALREADY_EXISTS", "The RM tried to register a protocol that already exists."),

1575 0x00001a37: ("ERROR_TRANSACTION_PROPAGATION_FAILED", "The attempt to propagate the Transaction failed."),

1576 0x00001a38: ("ERROR_CRM_PROTOCOL_NOT_FOUND", "The requested propagation protocol was not registered as a CRM."),

1577 0x00001a39: ("ERROR_TRANSACTION_INVALID_MARSHALL_BUFFER", "The buffer passed in to PushTransaction or PullTransaction is not in a valid format."),

1578 0x00001a3a: ("ERROR_CURRENT_TRANSACTION_NOT_VALID", "The current transaction context associated with the thread is not a valid handle to a transaction object."),

1579 0x00001a3b: ("ERROR_TRANSACTION_NOT_FOUND", "The specified Transaction object could not be opened, because it was not found."),

1580 0x00001a3c: ("ERROR_RESOURCEMANAGER_NOT_FOUND", "The specified ResourceManager object could not be opened, because it was not found."),

1581 0x00001a3d: ("ERROR_ENLISTMENT_NOT_FOUND", "The specified Enlistment object could not be opened, because it was not found."),

1582 0x00001a3e: ("ERROR_TRANSACTIONMANAGER_NOT_FOUND", "The specified TransactionManager object could not be opened, because it was not found."),

1583 0x00001a3f: ("ERROR_TRANSACTIONMANAGER_NOT_ONLINE", "The object specified could not be created or opened, because its associated TransactionManager is not online. The TransactionManager must be brought fully Online by calling RecoverTransactionManager to recover to the end of its LogFile before objects in its Transaction or ResourceManager namespaces can be opened. In addition, errors in writing records to its LogFile can cause a TransactionManager to go offline."),

1584 0x00001a40: ("ERROR_TRANSACTIONMANAGER_RECOVERY_NAME_COLLISION", "The specified TransactionManager was unable to create the objects contained in its logfile in the Ob namespace. Therefore, the TransactionManager was unable to recover."),

1585 0x00001a41: ("ERROR_TRANSACTION_NOT_ROOT", "The call to create a superior Enlistment on this Transaction object could not be completed, because the Transaction object specified for the enlistment is a subordinate branch of the Transaction. Only the root of the Transaction can be enlisted on as a superior."),

1586 0x00001a42: ("ERROR_TRANSACTION_OBJECT_EXPIRED", "Because the associated transaction manager or resource manager has been closed, the handle is no longer valid."),

1587 0x00001a43: ("ERROR_TRANSACTION_RESPONSE_NOT_ENLISTED", "The specified operation could not be performed on this Superior enlistment, because the enlistment was not created with the corresponding completion response in the NotificationMask."),

1588 0x00001a44: ("ERROR_TRANSACTION_RECORD_TOO_LONG", "The specified operation could not be performed, because the record that would be logged was too long. This can occur because of two conditions: either there are too many Enlistments on this Transaction, or the combined RecoveryInformation being logged on behalf of those Enlistments is too long."),

1589 0x00001a45: ("ERROR_IMPLICIT_TRANSACTION_NOT_SUPPORTED", "Implicit transaction are not supported."),

1590 0x00001a46: ("ERROR_TRANSACTION_INTEGRITY_VIOLATED", "The kernel transaction manager had to abort or forget the transaction because it blocked forward progress."),

1591 0x00001a47: ("ERROR_TRANSACTIONMANAGER_IDENTITY_MISMATCH", "The TransactionManager identity that was supplied did not match the one recorded in the TransactionManager's log file."),

1592 0x00001a48: ("ERROR_RM_CANNOT_BE_FROZEN_FOR_SNAPSHOT", "This snapshot operation cannot continue because a transactional resource manager cannot be frozen in its current state. Please try again."),

1593 0x00001a49: ("ERROR_TRANSACTION_MUST_WRITETHROUGH", "The transaction cannot be enlisted on with the specified EnlistmentMask, because the transaction has already completed the PrePrepare phase. In order to ensure correctness, the ResourceManager must switch to a write-through mode and cease caching data within this transaction. Enlisting for only subsequent transaction phases may still succeed."),

1594 0x00001a4a: ("ERROR_TRANSACTION_NO_SUPERIOR", "The transaction does not have a superior enlistment."),

1595 0x00001a4b: ("ERROR_HEURISTIC_DAMAGE_POSSIBLE", "The attempt to commit the Transaction completed, but it is possible that some portion of the transaction tree did not commit successfully due to heuristics. Therefore it is possible that some data modified in the transaction may not have committed, resulting in transactional inconsistency. If possible, check the consistency of the associated data."),

1596 0x00001a90: ("ERROR_TRANSACTIONAL_CONFLICT", "The function attempted to use a name that is reserved for use by another transaction."),

1597 0x00001a91: ("ERROR_RM_NOT_ACTIVE", "Transaction support within the specified resource manager is not started or was shut down due to an error."),

1598 0x00001a92: ("ERROR_RM_METADATA_CORRUPT", "The metadata of the RM has been corrupted. The RM will not function."),

1599 0x00001a93: ("ERROR_DIRECTORY_NOT_RM", "The specified directory does not contain a resource manager."),

1600 0x00001a95: ("ERROR_TRANSACTIONS_UNSUPPORTED_REMOTE", "The remote server or share does not support transacted file operations."),

1601 0x00001a96: ("ERROR_LOG_RESIZE_INVALID_SIZE", "The requested log size is invalid."),

1602 0x00001a97: ("ERROR_OBJECT_NO_LONGER_EXISTS", "The object (file, stream, link) corresponding to the handle has been deleted by a Transaction Savepoint Rollback."),

1603 0x00001a98: ("ERROR_STREAM_MINIVERSION_NOT_FOUND", "The specified file miniversion was not found for this transacted file open."),

1604 0x00001a99: ("ERROR_STREAM_MINIVERSION_NOT_VALID", "The specified file miniversion was found but has been invalidated. Most likely cause is a transaction savepoint rollback."),

1605 0x00001a9a: ("ERROR_MINIVERSION_INACCESSIBLE_FROM_SPECIFIED_TRANSACTION", "A miniversion may only be opened in the context of the transaction that created it."),

1606 0x00001a9b: ("ERROR_CANT_OPEN_MINIVERSION_WITH_MODIFY_INTENT", "It is not possible to open a miniversion with modify access."),

1607 0x00001a9c: ("ERROR_CANT_CREATE_MORE_STREAM_MINIVERSIONS", "It is not possible to create any more miniversions for this stream."),

1608 0x00001a9e: ("ERROR_REMOTE_FILE_VERSION_MISMATCH", "The remote server sent mismatching version number or Fid for a file opened with transactions."),

1609 0x00001a9f: ("ERROR_HANDLE_NO_LONGER_VALID", "The handle has been invalidated by a transaction. The most likely cause is the presence of memory mapping on a file or an open handle when the transaction ended or rolled back to savepoint."),

1610 0x00001aa0: ("ERROR_NO_TXF_METADATA", "There is no transaction metadata on the file."),

1611 0x00001aa1: ("ERROR_LOG_CORRUPTION_DETECTED", "The log data is corrupt."),

1612 0x00001aa2: ("ERROR_CANT_RECOVER_WITH_HANDLE_OPEN", "The file can't be recovered because there is a handle still open on it."),

1613 0x00001aa3: ("ERROR_RM_DISCONNECTED", "The transaction outcome is unavailable because the resource manager responsible for it has disconnected."),

1614 0x00001aa4: ("ERROR_ENLISTMENT_NOT_SUPERIOR", "The request was rejected because the enlistment in question is not a superior enlistment."),

1615 0x00001aa5: ("ERROR_RECOVERY_NOT_NEEDED", "The transactional resource manager is already consistent. Recovery is not needed."),

1616 0x00001aa6: ("ERROR_RM_ALREADY_STARTED", "The transactional resource manager has already been started."),

1617 0x00001aa7: ("ERROR_FILE_IDENTITY_NOT_PERSISTENT", "The file cannot be opened transactionally, because its identity depends on the outcome of an unresolved transaction."),

1618 0x00001aa8: ("ERROR_CANT_BREAK_TRANSACTIONAL_DEPENDENCY", "The operation cannot be performed because another transaction is depending on the fact that this property will not change."),

1619 0x00001aa9: ("ERROR_CANT_CROSS_RM_BOUNDARY", "The operation would involve a single file with two transactional resource managers and is therefore not allowed."),

1620 0x00001aaa: ("ERROR_TXF_DIR_NOT_EMPTY", "The $Txf directory must be empty for this operation to succeed."),

1621 0x00001aab: ("ERROR_INDOUBT_TRANSACTIONS_EXIST", "The operation would leave a transactional resource manager in an inconsistent state and is therefore not allowed."),

1622 0x00001aac: ("ERROR_TM_VOLATILE", "The operation could not be completed because the transaction manager does not have a log."),

1623 0x00001aad: ("ERROR_ROLLBACK_TIMER_EXPIRED", "A rollback could not be scheduled because a previously scheduled rollback has already executed or been queued for execution."),

1624 0x00001aae: ("ERROR_TXF_ATTRIBUTE_CORRUPT", "The transactional metadata attribute on the file or directory is corrupt and unreadable."),

1625 0x00001aaf: ("ERROR_EFS_NOT_ALLOWED_IN_TRANSACTION", "The encryption operation could not be completed because a transaction is active."),

1626 0x00001ab0: ("ERROR_TRANSACTIONAL_OPEN_NOT_ALLOWED", "This object is not allowed to be opened in a transaction."),

1627 0x00001ab1: ("ERROR_LOG_GROWTH_FAILED", "An attempt to create space in the transactional resource manager's log failed. The failure status has been recorded in the event log."),

1628 0x00001ab2: ("ERROR_TRANSACTED_MAPPING_UNSUPPORTED_REMOTE", "Memory mapping (creating a mapped section) a remote file under a transaction is not supported."),

1629 0x00001ab3: ("ERROR_TXF_METADATA_ALREADY_PRESENT", "Transaction metadata is already present on this file and cannot be superseded."),

1630 0x00001ab4: ("ERROR_TRANSACTION_SCOPE_CALLBACKS_NOT_SET", "A transaction scope could not be entered because the scope handler has not been initialized."),

1631 0x00001ab5: ("ERROR_TRANSACTION_REQUIRED_PROMOTION", "Promotion was required in order to allow the resource manager to enlist, but the transaction was set to disallow it."),

1632 0x00001ab6: ("ERROR_CANNOT_EXECUTE_FILE_IN_TRANSACTION", "This file is open for modification in an unresolved transaction and may be opened for execute only by a transacted reader."),

1633 0x00001ab7: ("ERROR_TRANSACTIONS_NOT_FROZEN", "The request to thaw frozen transactions was ignored because transactions had not previously been frozen."),

1634 0x00001ab8: ("ERROR_TRANSACTION_FREEZE_IN_PROGRESS", "Transactions cannot be frozen because a freeze is already in progress."),

1635 0x00001ab9: ("ERROR_NOT_SNAPSHOT_VOLUME", "The target volume is not a snapshot volume. This operation is only valid on a volume mounted as a snapshot."),

1636 0x00001aba: ("ERROR_NO_SAVEPOINT_WITH_OPEN_FILES", "The savepoint operation failed because files are open on the transaction. This is not permitted."),

1637 0x00001abb: ("ERROR_DATA_LOST_REPAIR", "Windows has discovered corruption in a file, and that file has since been repaired. Data loss may have occurred."),

1638 0x00001abc: ("ERROR_SPARSE_NOT_ALLOWED_IN_TRANSACTION", "The sparse operation could not be completed because a transaction is active on the file."),

1639 0x00001abd: ("ERROR_TM_IDENTITY_MISMATCH", "The call to create a TransactionManager object failed because the Tm Identity stored in the logfile does not match the Tm Identity that was passed in as an argument."),

1640 0x00001abe: ("ERROR_FLOATED_SECTION", "I/O was attempted on a section object that has been floated as a result of a transaction ending. There is no valid data."),

1641 0x00001abf: ("ERROR_CANNOT_ACCEPT_TRANSACTED_WORK", "The transactional resource manager cannot currently accept transacted work due to a transient condition such as low resources."),

1642 0x00001ac0: ("ERROR_CANNOT_ABORT_TRANSACTIONS", "The transactional resource manager had too many transactions outstanding that could not be aborted. The transactional resource manager has been shut down."),

1643 0x00001ac1: ("ERROR_BAD_CLUSTERS", "The operation could not be completed due to bad clusters on disk."),

1644 0x00001ac2: ("ERROR_COMPRESSION_NOT_ALLOWED_IN_TRANSACTION", "The compression operation could not be completed because a transaction is active on the file."),

1645 0x00001ac3: ("ERROR_VOLUME_DIRTY", "The operation could not be completed because the volume is dirty. Please run chkdsk and try again."),

1646 0x00001ac4: ("ERROR_NO_LINK_TRACKING_IN_TRANSACTION", "The link tracking operation could not be completed because a transaction is active."),

1647 0x00001ac5: ("ERROR_OPERATION_NOT_SUPPORTED_IN_TRANSACTION", "This operation cannot be performed in a transaction."),

1648 0x00001ac6: ("ERROR_EXPIRED_HANDLE", "The handle is no longer properly associated with its transaction. It may have been opened in a transactional resource manager that was subsequently forced to restart. Please close the handle and open a new one."),

1649 0x00001ac7: ("ERROR_TRANSACTION_NOT_ENLISTED", "The specified operation could not be performed because the resource manager is not enlisted in the transaction."),

1650 0x00001b59: ("ERROR_CTX_WINSTATION_NAME_INVALID", "The specified session name is invalid."),

1651 0x00001b5a: ("ERROR_CTX_INVALID_PD", "The specified protocol driver is invalid."),

1652 0x00001b5b: ("ERROR_CTX_PD_NOT_FOUND", "The specified protocol driver was not found in the system path."),

1653 0x00001b5c: ("ERROR_CTX_WD_NOT_FOUND", "The specified terminal connection driver was not found in the system path."),

1654 0x00001b5d: ("ERROR_CTX_CANNOT_MAKE_EVENTLOG_ENTRY", "A registry key for event logging could not be created for this session."),

1655 0x00001b5e: ("ERROR_CTX_SERVICE_NAME_COLLISION", "A service with the same name already exists on the system."),

1656 0x00001b5f: ("ERROR_CTX_CLOSE_PENDING", "A close operation is pending on the session."),

1657 0x00001b60: ("ERROR_CTX_NO_OUTBUF", "There are no free output buffers available."),

1658 0x00001b61: ("ERROR_CTX_MODEM_INF_NOT_FOUND", "The MODEM.INF file was not found."),

1659 0x00001b62: ("ERROR_CTX_INVALID_MODEMNAME", "The modem name was not found in MODEM.INF."),

1660 0x00001b63: ("ERROR_CTX_MODEM_RESPONSE_ERROR", "The modem did not accept the command sent to it. Verify that the configured modem name matches the attached modem."),

1661 0x00001b64: ("ERROR_CTX_MODEM_RESPONSE_TIMEOUT", "The modem did not respond to the command sent to it. Verify that the modem is properly cabled and powered on."),

1662 0x00001b65: ("ERROR_CTX_MODEM_RESPONSE_NO_CARRIER", "Carrier detect has failed or carrier has been dropped due to disconnect."),

1663 0x00001b66: ("ERROR_CTX_MODEM_RESPONSE_NO_DIALTONE", "Dial tone not detected within the required time. Verify that the phone cable is properly attached and functional."),

1664 0x00001b67: ("ERROR_CTX_MODEM_RESPONSE_BUSY", "Busy signal detected at remote site on callback."),

1665 0x00001b68: ("ERROR_CTX_MODEM_RESPONSE_VOICE", "Voice detected at remote site on callback."),

1666 0x00001b69: ("ERROR_CTX_TD_ERROR", "Transport driver error"),

1667 0x00001b6e: ("ERROR_CTX_WINSTATION_NOT_FOUND", "The specified session cannot be found."),

1668 0x00001b6f: ("ERROR_CTX_WINSTATION_ALREADY_EXISTS", "The specified session name is already in use."),

1669 0x00001b70: ("ERROR_CTX_WINSTATION_BUSY", "The task you are trying to do can't be completed because Remote Desktop Services is currently busy. Please try again in a few minutes. Other users should still be able to log on."),

1670 0x00001b71: ("ERROR_CTX_BAD_VIDEO_MODE", "An attempt has been made to connect to a session whose video mode is not supported by the current client."),

1671 0x00001b7b: ("ERROR_CTX_GRAPHICS_INVALID", "The application attempted to enable DOS graphics mode. DOS graphics mode is not supported."),

1672 0x00001b7d: ("ERROR_CTX_LOGON_DISABLED", "Your interactive logon privilege has been disabled. Please contact your administrator."),

1673 0x00001b7e: ("ERROR_CTX_NOT_CONSOLE", "The requested operation can be performed only on the system console. This is most often the result of a driver or system DLL requiring direct console access."),

1674 0x00001b80: ("ERROR_CTX_CLIENT_QUERY_TIMEOUT", "The client failed to respond to the server connect message."),

1675 0x00001b81: ("ERROR_CTX_CONSOLE_DISCONNECT", "Disconnecting the console session is not supported."),

1676 0x00001b82: ("ERROR_CTX_CONSOLE_CONNECT", "Reconnecting a disconnected session to the console is not supported."),

1677 0x00001b84: ("ERROR_CTX_SHADOW_DENIED", "The request to control another session remotely was denied."),

1678 0x00001b85: ("ERROR_CTX_WINSTATION_ACCESS_DENIED", "The requested session access is denied."),

1679 0x00001b89: ("ERROR_CTX_INVALID_WD", "The specified terminal connection driver is invalid."),

1680 0x00001b8a: ("ERROR_CTX_SHADOW_INVALID", "The requested session cannot be controlled remotely."),

1681 0x00001b8b: ("ERROR_CTX_SHADOW_DISABLED", "The requested session is not configured to allow remote control."),

1682 0x00001b8c: ("ERROR_CTX_CLIENT_LICENSE_IN_USE", "Your request to connect to this Terminal Server has been rejected. Your Terminal Server client license number is currently being used by another user. Please call your system administrator to obtain a unique license number."),

1683 0x00001b8d: ("ERROR_CTX_CLIENT_LICENSE_NOT_SET", "Your request to connect to this Terminal Server has been rejected. Your Terminal Server client license number has not been entered for this copy of the Terminal Server client. Please contact your system administrator."),

1684 0x00001b8e: ("ERROR_CTX_LICENSE_NOT_AVAILABLE", "The number of connections to this computer is limited and all connections are in use right now. Try connecting later or contact your system administrator."),

1685 0x00001b8f: ("ERROR_CTX_LICENSE_CLIENT_INVALID", "The client you are using is not licensed to use this system. Your logon request is denied."),

1686 0x00001b90: ("ERROR_CTX_LICENSE_EXPIRED", "The system license has expired. Your logon request is denied."),

1687 0x00001b91: ("ERROR_CTX_SHADOW_NOT_RUNNING", "Remote control could not be terminated because the specified session is not currently being remotely controlled."),

1688 0x00001b92: ("ERROR_CTX_SHADOW_ENDED_BY_MODE_CHANGE", "The remote control of the console was terminated because the display mode was changed. Changing the display mode in a remote control session is not supported."),

1689 0x00001b93: ("ERROR_ACTIVATION_COUNT_EXCEEDED", "Activation has already been reset the maximum number of times for this installation. Your activation timer will not be cleared."),

1690 0x00001b94: ("ERROR_CTX_WINSTATIONS_DISABLED", "Remote logins are currently disabled."),

1691 0x00001b95: ("ERROR_CTX_ENCRYPTION_LEVEL_REQUIRED", "You do not have the proper encryption level to access this Session."),

1692 0x00001b96: ("ERROR_CTX_SESSION_IN_USE", "The user %s\\%s is currently logged on to this computer. Only the current user or an administrator can log on to this computer."),

1693 0x00001b97: ("ERROR_CTX_NO_FORCE_LOGOFF", "The user %s\\%s is already logged on to the console of this computer. You do not have permission to log in at this time. To resolve this issue, contact %s\\%s and have them log off."),

1694 0x00001b98: ("ERROR_CTX_ACCOUNT_RESTRICTION", "Unable to log you on because of an account restriction."),

1695 0x00001b99: ("ERROR_RDP_PROTOCOL_ERROR", "The RDP protocol component %2 detected an error in the protocol stream and has disconnected the client."),

1696 0x00001b9a: ("ERROR_CTX_CDM_CONNECT", "The Client Drive Mapping Service Has Connected on Terminal Connection."),

1697 0x00001b9b: ("ERROR_CTX_CDM_DISCONNECT", "The Client Drive Mapping Service Has Disconnected on Terminal Connection."),

1698 0x00001b9c: ("ERROR_CTX_SECURITY_LAYER_ERROR", "The Terminal Server security layer detected an error in the protocol stream and has disconnected the client."),

1699 0x00001b9d: ("ERROR_TS_INCOMPATIBLE_SESSIONS", "The target session is incompatible with the current session."),

1700 0x00001b9e: ("ERROR_TS_VIDEO_SUBSYSTEM_ERROR", "Windows can't connect to your session because a problem occurred in the Windows video subsystem. Try connecting again later, or contact the server administrator for assistance."),

1701 0x00001f41: ("FRS_ERR_INVALID_API_SEQUENCE", "The file replication service API was called incorrectly."),

1702 0x00001f42: ("FRS_ERR_STARTING_SERVICE", "The file replication service cannot be started."),

1703 0x00001f43: ("FRS_ERR_STOPPING_SERVICE", "The file replication service cannot be stopped."),

1704 0x00001f44: ("FRS_ERR_INTERNAL_API", "The file replication service API terminated the request. The event log may have more information."),

1705 0x00001f45: ("FRS_ERR_INTERNAL", "The file replication service terminated the request. The event log may have more information."),

1706 0x00001f46: ("FRS_ERR_SERVICE_COMM", "The file replication service cannot be contacted. The event log may have more information."),

1707 0x00001f47: ("FRS_ERR_INSUFFICIENT_PRIV", "The file replication service cannot satisfy the request because the user has insufficient privileges. The event log may have more information."),

1708 0x00001f48: ("FRS_ERR_AUTHENTICATION", "The file replication service cannot satisfy the request because authenticated RPC is not available. The event log may have more information."),

1709 0x00001f49: ("FRS_ERR_PARENT_INSUFFICIENT_PRIV", "The file replication service cannot satisfy the request because the user has insufficient privileges on the domain controller. The event log may have more information."),

1710 0x00001f4a: ("FRS_ERR_PARENT_AUTHENTICATION", "The file replication service cannot satisfy the request because authenticated RPC is not available on the domain controller. The event log may have more information."),

1711 0x00001f4b: ("FRS_ERR_CHILD_TO_PARENT_COMM", "The file replication service cannot communicate with the file replication service on the domain controller. The event log may have more information."),

1712 0x00001f4c: ("FRS_ERR_PARENT_TO_CHILD_COMM", "The file replication service on the domain controller cannot communicate with the file replication service on this computer. The event log may have more information."),

1713 0x00001f4d: ("FRS_ERR_SYSVOL_POPULATE", "The file replication service cannot populate the system volume because of an internal error. The event log may have more information."),

1714 0x00001f4e: ("FRS_ERR_SYSVOL_POPULATE_TIMEOUT", "The file replication service cannot populate the system volume because of an internal timeout. The event log may have more information."),

1715 0x00001f4f: ("FRS_ERR_SYSVOL_IS_BUSY", "The file replication service cannot process the request. The system volume is busy with a previous request."),

1716 0x00001f50: ("FRS_ERR_SYSVOL_DEMOTE", "The file replication service cannot stop replicating the system volume because of an internal error. The event log may have more information."),

1717 0x00001f51: ("FRS_ERR_INVALID_SERVICE_PARAMETER", "The file replication service detected an invalid parameter."),

1718 0x00002008: ("ERROR_DS_NOT_INSTALLED", "An error occurred while installing the directory service. For more information, see the event log."),

1719 0x00002009: ("ERROR_DS_MEMBERSHIP_EVALUATED_LOCALLY", "The directory service evaluated group memberships locally."),

1720 0x0000200a: ("ERROR_DS_NO_ATTRIBUTE_OR_VALUE", "The specified directory service attribute or value does not exist."),

1721 0x0000200b: ("ERROR_DS_INVALID_ATTRIBUTE_SYNTAX", "The attribute syntax specified to the directory service is invalid."),

1722 0x0000200c: ("ERROR_DS_ATTRIBUTE_TYPE_UNDEFINED", "The attribute type specified to the directory service is not defined."),

1723 0x0000200d: ("ERROR_DS_ATTRIBUTE_OR_VALUE_EXISTS", "The specified directory service attribute or value already exists."),

1724 0x0000200e: ("ERROR_DS_BUSY", "The directory service is busy."),

1725 0x0000200f: ("ERROR_DS_UNAVAILABLE", "The directory service is unavailable."),

1726 0x00002010: ("ERROR_DS_NO_RIDS_ALLOCATED", "The directory service was unable to allocate a relative identifier."),

1727 0x00002011: ("ERROR_DS_NO_MORE_RIDS", "The directory service has exhausted the pool of relative identifiers."),

1728 0x00002012: ("ERROR_DS_INCORRECT_ROLE_OWNER", "The requested operation could not be performed because the directory service is not the master for that type of operation."),

1729 0x00002013: ("ERROR_DS_RIDMGR_INIT_ERROR", "The directory service was unable to initialize the subsystem that allocates relative identifiers."),

1730 0x00002014: ("ERROR_DS_OBJ_CLASS_VIOLATION", "The requested operation did not satisfy one or more constraints associated with the class of the object."),

1731 0x00002015: ("ERROR_DS_CANT_ON_NON_LEAF", "The directory service can perform the requested operation only on a leaf object."),

1732 0x00002016: ("ERROR_DS_CANT_ON_RDN", "The directory service cannot perform the requested operation on the RDN attribute of an object."),

1733 0x00002017: ("ERROR_DS_CANT_MOD_OBJ_CLASS", "The directory service detected an attempt to modify the object class of an object."),

1734 0x00002018: ("ERROR_DS_CROSS_DOM_MOVE_ERROR", "The requested cross-domain move operation could not be performed."),

1735 0x00002019: ("ERROR_DS_GC_NOT_AVAILABLE", "Unable to contact the global catalog server."),

1736 0x0000201a: ("ERROR_SHARED_POLICY", "The policy object is shared and can only be modified at the root."),

1737 0x0000201b: ("ERROR_POLICY_OBJECT_NOT_FOUND", "The policy object does not exist."),

1738 0x0000201c: ("ERROR_POLICY_ONLY_IN_DS", "The requested policy information is only in the directory service."),

1739 0x0000201d: ("ERROR_PROMOTION_ACTIVE", "A domain controller promotion is currently active."),

1740 0x0000201e: ("ERROR_NO_PROMOTION_ACTIVE", "A domain controller promotion is not currently active"),

1741 0x00002020: ("ERROR_DS_OPERATIONS_ERROR", "An operations error occurred."),

1742 0x00002021: ("ERROR_DS_PROTOCOL_ERROR", "A protocol error occurred."),

1743 0x00002022: ("ERROR_DS_TIMELIMIT_EXCEEDED", "The time limit for this request was exceeded."),

1744 0x00002023: ("ERROR_DS_SIZELIMIT_EXCEEDED", "The size limit for this request was exceeded."),

1745 0x00002024: ("ERROR_DS_ADMIN_LIMIT_EXCEEDED", "The administrative limit for this request was exceeded."),

1746 0x00002025: ("ERROR_DS_COMPARE_FALSE", "The compare response was false."),

1747 0x00002026: ("ERROR_DS_COMPARE_TRUE", "The compare response was true."),

1748 0x00002027: ("ERROR_DS_AUTH_METHOD_NOT_SUPPORTED", "The requested authentication method is not supported by the server."),

1749 0x00002028: ("ERROR_DS_STRONG_AUTH_REQUIRED", "A more secure authentication method is required for this server."),

1750 0x00002029: ("ERROR_DS_INAPPROPRIATE_AUTH", "Inappropriate authentication."),

1751 0x0000202a: ("ERROR_DS_AUTH_UNKNOWN", "The authentication mechanism is unknown."),

1752 0x0000202b: ("ERROR_DS_REFERRAL", "A referral was returned from the server."),

1753 0x0000202c: ("ERROR_DS_UNAVAILABLE_CRIT_EXTENSION", "The server does not support the requested critical extension."),

1754 0x0000202d: ("ERROR_DS_CONFIDENTIALITY_REQUIRED", "This request requires a secure connection."),

1755 0x0000202e: ("ERROR_DS_INAPPROPRIATE_MATCHING", "Inappropriate matching."),

1756 0x0000202f: ("ERROR_DS_CONSTRAINT_VIOLATION", "A constraint violation occurred."),

1757 0x00002030: ("ERROR_DS_NO_SUCH_OBJECT", "There is no such object on the server."),

1758 0x00002031: ("ERROR_DS_ALIAS_PROBLEM", "There is an alias problem."),

1759 0x00002032: ("ERROR_DS_INVALID_DN_SYNTAX", "An invalid dn syntax has been specified."),

1760 0x00002033: ("ERROR_DS_IS_LEAF", "The object is a leaf object."),

1761 0x00002034: ("ERROR_DS_ALIAS_DEREF_PROBLEM", "There is an alias dereferencing problem."),

1762 0x00002035: ("ERROR_DS_UNWILLING_TO_PERFORM", "The server is unwilling to process the request."),

1763 0x00002036: ("ERROR_DS_LOOP_DETECT", "A loop has been detected."),

1764 0x00002037: ("ERROR_DS_NAMING_VIOLATION", "There is a naming violation."),

1765 0x00002038: ("ERROR_DS_OBJECT_RESULTS_TOO_LARGE", "The result set is too large."),

1766 0x00002039: ("ERROR_DS_AFFECTS_MULTIPLE_DSAS", "The operation affects multiple DSAs"),

1767 0x0000203a: ("ERROR_DS_SERVER_DOWN", "The server is not operational."),

1768 0x0000203b: ("ERROR_DS_LOCAL_ERROR", "A local error has occurred."),

1769 0x0000203c: ("ERROR_DS_ENCODING_ERROR", "An encoding error has occurred."),

1770 0x0000203d: ("ERROR_DS_DECODING_ERROR", "A decoding error has occurred."),

1771 0x0000203e: ("ERROR_DS_FILTER_UNKNOWN", "The search filter cannot be recognized."),

1772 0x0000203f: ("ERROR_DS_PARAM_ERROR", "One or more parameters are illegal."),

1773 0x00002040: ("ERROR_DS_NOT_SUPPORTED", "The specified method is not supported."),

1774 0x00002041: ("ERROR_DS_NO_RESULTS_RETURNED", "No results were returned."),

1775 0x00002042: ("ERROR_DS_CONTROL_NOT_FOUND", "The specified control is not supported by the server."),

1776 0x00002043: ("ERROR_DS_CLIENT_LOOP", "A referral loop was detected by the client."),

1777 0x00002044: ("ERROR_DS_REFERRAL_LIMIT_EXCEEDED", "The preset referral limit was exceeded."),

1778 0x00002045: ("ERROR_DS_SORT_CONTROL_MISSING", "The search requires a SORT control."),

1779 0x00002046: ("ERROR_DS_OFFSET_RANGE_ERROR", "The search results exceed the offset range specified."),

1780 0x00002047: ("ERROR_DS_RIDMGR_DISABLED", "The directory service detected the subsystem that allocates relative identifiers is disabled. This can occur as a protective mechanism when the system determines a significant portion of relative identifiers (RIDs) have been exhausted. Please see https://go.microsoft.com/fwlink/?LinkId=228610 for recommended diagnostic steps and the procedure to re-enable account creation."),

1781 0x0000206d: ("ERROR_DS_ROOT_MUST_BE_NC", "The root object must be the head of a naming context. The root object cannot have an instantiated parent."),

1782 0x0000206e: ("ERROR_DS_ADD_REPLICA_INHIBITED", "The add replica operation cannot be performed. The naming context must be writeable in order to create the replica."),

1783 0x0000206f: ("ERROR_DS_ATT_NOT_DEF_IN_SCHEMA", "A reference to an attribute that is not defined in the schema occurred."),

1784 0x00002070: ("ERROR_DS_MAX_OBJ_SIZE_EXCEEDED", "The maximum size of an object has been exceeded."),

1785 0x00002071: ("ERROR_DS_OBJ_STRING_NAME_EXISTS", "An attempt was made to add an object to the directory with a name that is already in use."),

1786 0x00002072: ("ERROR_DS_NO_RDN_DEFINED_IN_SCHEMA", "An attempt was made to add an object of a class that does not have an RDN defined in the schema."),

1787 0x00002073: ("ERROR_DS_RDN_DOESNT_MATCH_SCHEMA", "An attempt was made to add an object using an RDN that is not the RDN defined in the schema."),

1788 0x00002074: ("ERROR_DS_NO_REQUESTED_ATTS_FOUND", "None of the requested attributes were found on the objects."),

1789 0x00002075: ("ERROR_DS_USER_BUFFER_TO_SMALL", "The user buffer is too small."),

1790 0x00002076: ("ERROR_DS_ATT_IS_NOT_ON_OBJ", "The attribute specified in the operation is not present on the object."),

1791 0x00002077: ("ERROR_DS_ILLEGAL_MOD_OPERATION", "Illegal modify operation. Some aspect of the modification is not permitted."),

1792 0x00002078: ("ERROR_DS_OBJ_TOO_LARGE", "The specified object is too large."),

1793 0x00002079: ("ERROR_DS_BAD_INSTANCE_TYPE", "The specified instance type is not valid."),

1794 0x0000207a: ("ERROR_DS_MASTERDSA_REQUIRED", "The operation must be performed at a master DSA."),

1795 0x0000207b: ("ERROR_DS_OBJECT_CLASS_REQUIRED", "The object class attribute must be specified."),

1796 0x0000207c: ("ERROR_DS_MISSING_REQUIRED_ATT", "A required attribute is missing."),

1797 0x0000207d: ("ERROR_DS_ATT_NOT_DEF_FOR_CLASS", "An attempt was made to modify an object to include an attribute that is not legal for its class."),

1798 0x0000207e: ("ERROR_DS_ATT_ALREADY_EXISTS", "The specified attribute is already present on the object."),

1799 0x00002080: ("ERROR_DS_CANT_ADD_ATT_VALUES", "The specified attribute is not present, or has no values."),

1800 0x00002081: ("ERROR_DS_SINGLE_VALUE_CONSTRAINT", "Multiple values were specified for an attribute that can have only one value."),

1801 0x00002082: ("ERROR_DS_RANGE_CONSTRAINT", "A value for the attribute was not in the acceptable range of values."),

1802 0x00002083: ("ERROR_DS_ATT_VAL_ALREADY_EXISTS", "The specified value already exists."),

1803 0x00002084: ("ERROR_DS_CANT_REM_MISSING_ATT", "The attribute cannot be removed because it is not present on the object."),

1804 0x00002085: ("ERROR_DS_CANT_REM_MISSING_ATT_VAL", "The attribute value cannot be removed because it is not present on the object."),

1805 0x00002086: ("ERROR_DS_ROOT_CANT_BE_SUBREF", "The specified root object cannot be a subref."),

1806 0x00002087: ("ERROR_DS_NO_CHAINING", "Chaining is not permitted."),

1807 0x00002088: ("ERROR_DS_NO_CHAINED_EVAL", "Chained evaluation is not permitted."),

1808 0x00002089: ("ERROR_DS_NO_PARENT_OBJECT", "The operation could not be performed because the object's parent is either uninstantiated or deleted."),

1809 0x0000208a: ("ERROR_DS_PARENT_IS_AN_ALIAS", "Having a parent that is an alias is not permitted. Aliases are leaf objects."),

1810 0x0000208b: ("ERROR_DS_CANT_MIX_MASTER_AND_REPS", "The object and parent must be of the same type, either both masters or both replicas."),

1811 0x0000208c: ("ERROR_DS_CHILDREN_EXIST", "The operation cannot be performed because child objects exist. This operation can only be performed on a leaf object."),

1812 0x0000208d: ("ERROR_DS_OBJ_NOT_FOUND", "Directory object not found."),

1813 0x0000208e: ("ERROR_DS_ALIASED_OBJ_MISSING", "The aliased object is missing."),

1814 0x0000208f: ("ERROR_DS_BAD_NAME_SYNTAX", "The object name has bad syntax."),

1815 0x00002090: ("ERROR_DS_ALIAS_POINTS_TO_ALIAS", "It is not permitted for an alias to refer to another alias."),

1816 0x00002091: ("ERROR_DS_CANT_DEREF_ALIAS", "The alias cannot be dereferenced."),

1817 0x00002092: ("ERROR_DS_OUT_OF_SCOPE", "The operation is out of scope."),

1818 0x00002093: ("ERROR_DS_OBJECT_BEING_REMOVED", "The operation cannot continue because the object is in the process of being removed."),

1819 0x00002094: ("ERROR_DS_CANT_DELETE_DSA_OBJ", "The DSA object cannot be deleted."),

1820 0x00002095: ("ERROR_DS_GENERIC_ERROR", "A directory service error has occurred."),

1821 0x00002096: ("ERROR_DS_DSA_MUST_BE_INT_MASTER", "The operation can only be performed on an internal master DSA object."),

1822 0x00002097: ("ERROR_DS_CLASS_NOT_DSA", "The object must be of class DSA."),

1823 0x00002098: ("ERROR_DS_INSUFF_ACCESS_RIGHTS", "Insufficient access rights to perform the operation."),

1824 0x00002099: ("ERROR_DS_ILLEGAL_SUPERIOR", "The object cannot be added because the parent is not on the list of possible superiors."),

1825 0x0000209a: ("ERROR_DS_ATTRIBUTE_OWNED_BY_SAM", "Access to the attribute is not permitted because the attribute is owned by the Security Accounts Manager (SAM)."),

1826 0x0000209b: ("ERROR_DS_NAME_TOO_MANY_PARTS", "The name has too many parts."),

1827 0x0000209c: ("ERROR_DS_NAME_TOO_LONG", "The name is too long."),

1828 0x0000209d: ("ERROR_DS_NAME_VALUE_TOO_LONG", "The name value is too long."),

1829 0x0000209e: ("ERROR_DS_NAME_UNPARSEABLE", "The directory service encountered an error parsing a name."),

1830 0x0000209f: ("ERROR_DS_NAME_TYPE_UNKNOWN", "The directory service cannot get the attribute type for a name."),

1831 0x000020a0: ("ERROR_DS_NOT_AN_OBJECT", "The name does not identify an object; the name identifies a phantom."),

1832 0x000020a1: ("ERROR_DS_SEC_DESC_TOO_SHORT", "The security descriptor is too short."),

1833 0x000020a2: ("ERROR_DS_SEC_DESC_INVALID", "The security descriptor is invalid."),

1834 0x000020a3: ("ERROR_DS_NO_DELETED_NAME", "Failed to create name for deleted object."),

1835 0x000020a4: ("ERROR_DS_SUBREF_MUST_HAVE_PARENT", "The parent of a new subref must exist."),

1836 0x000020a5: ("ERROR_DS_NCNAME_MUST_BE_NC", "The object must be a naming context."),

1837 0x000020a6: ("ERROR_DS_CANT_ADD_SYSTEM_ONLY", "It is not permitted to add an attribute which is owned by the system."),

1838 0x000020a7: ("ERROR_DS_CLASS_MUST_BE_CONCRETE", "The class of the object must be structural; you cannot instantiate an abstract class."),

1839 0x000020a8: ("ERROR_DS_INVALID_DMD", "The schema object could not be found."),

1840 0x000020a9: ("ERROR_DS_OBJ_GUID_EXISTS", "A local object with this GUID (dead or alive) already exists."),

1841 0x000020aa: ("ERROR_DS_NOT_ON_BACKLINK", "The operation cannot be performed on a back link."),

1842 0x000020ab: ("ERROR_DS_NO_CROSSREF_FOR_NC", "The cross reference for the specified naming context could not be found."),

1843 0x000020ac: ("ERROR_DS_SHUTTING_DOWN", "The operation could not be performed because the directory service is shutting down."),

1844 0x000020ad: ("ERROR_DS_UNKNOWN_OPERATION", "The directory service request is invalid."),

1845 0x000020ae: ("ERROR_DS_INVALID_ROLE_OWNER", "The role owner attribute could not be read."),

1846 0x000020af: ("ERROR_DS_COULDNT_CONTACT_FSMO", "The requested FSMO operation failed. The current FSMO holder could not be contacted."),

1847 0x000020b0: ("ERROR_DS_CROSS_NC_DN_RENAME", "Modification of a DN across a naming context is not permitted."),

1848 0x000020b1: ("ERROR_DS_CANT_MOD_SYSTEM_ONLY", "The attribute cannot be modified because it is owned by the system."),

1849 0x000020b2: ("ERROR_DS_REPLICATOR_ONLY", "Only the replicator can perform this function."),

1850 0x000020b3: ("ERROR_DS_OBJ_CLASS_NOT_DEFINED", "The specified class is not defined."),

1851 0x000020b4: ("ERROR_DS_OBJ_CLASS_NOT_SUBCLASS", "The specified class is not a subclass."),

1852 0x000020b5: ("ERROR_DS_NAME_REFERENCE_INVALID", "The name reference is invalid."),

1853 0x000020b6: ("ERROR_DS_CROSS_REF_EXISTS", "A cross reference already exists."),

1854 0x000020b7: ("ERROR_DS_CANT_DEL_MASTER_CROSSREF", "It is not permitted to delete a master cross reference."),

1855 0x000020b8: ("ERROR_DS_SUBTREE_NOTIFY_NOT_NC_HEAD", "Subtree notifications are only supported on NC heads."),

1856 0x000020b9: ("ERROR_DS_NOTIFY_FILTER_TOO_COMPLEX", "Notification filter is too complex."),

1857 0x000020ba: ("ERROR_DS_DUP_RDN", "Schema update failed: duplicate RDN."),

1858 0x000020bb: ("ERROR_DS_DUP_OID", "Schema update failed: duplicate OID."),

1859 0x000020bc: ("ERROR_DS_DUP_MAPI_ID", "Schema update failed: duplicate MAPI identifier."),

1860 0x000020bd: ("ERROR_DS_DUP_SCHEMA_ID_GUID", "Schema update failed: duplicate schema-id GUID."),

1861 0x000020be: ("ERROR_DS_DUP_LDAP_DISPLAY_NAME", "Schema update failed: duplicate LDAP display name."),

1862 0x000020bf: ("ERROR_DS_SEMANTIC_ATT_TEST", "Schema update failed: range-lower less than range upper."),

1863 0x000020c0: ("ERROR_DS_SYNTAX_MISMATCH", "Schema update failed: syntax mismatch."),

1864 0x000020c1: ("ERROR_DS_EXISTS_IN_MUST_HAVE", "Schema deletion failed: attribute is used in must-contain."),

1865 0x000020c2: ("ERROR_DS_EXISTS_IN_MAY_HAVE", "Schema deletion failed: attribute is used in may-contain."),

1866 0x000020c3: ("ERROR_DS_NONEXISTENT_MAY_HAVE", "Schema update failed: attribute in may-contain does not exist."),

1867 0x000020c4: ("ERROR_DS_NONEXISTENT_MUST_HAVE", "Schema update failed: attribute in must-contain does not exist."),

1868 0x000020c5: ("ERROR_DS_AUX_CLS_TEST_FAIL", "Schema update failed: class in aux-class list does not exist or is not an auxiliary class."),

1869 0x000020c6: ("ERROR_DS_NONEXISTENT_POSS_SUP", "Schema update failed: class in poss-superiors does not exist."),

1870 0x000020c7: ("ERROR_DS_SUB_CLS_TEST_FAIL", "Schema update failed: class in subclassof list does not exist or does not satisfy hierarchy rules."),

1871 0x000020c8: ("ERROR_DS_BAD_RDN_ATT_ID_SYNTAX", "Schema update failed: Rdn-Att-Id has wrong syntax."),

1872 0x000020c9: ("ERROR_DS_EXISTS_IN_AUX_CLS", "Schema deletion failed: class is used as auxiliary class."),

1873 0x000020ca: ("ERROR_DS_EXISTS_IN_SUB_CLS", "Schema deletion failed: class is used as sub class."),

1874 0x000020cb: ("ERROR_DS_EXISTS_IN_POSS_SUP", "Schema deletion failed: class is used as poss superior."),

1875 0x000020cc: ("ERROR_DS_RECALCSCHEMA_FAILED", "Schema update failed in recalculating validation cache."),

1876 0x000020cd: ("ERROR_DS_TREE_DELETE_NOT_FINISHED", "The tree deletion is not finished. The request must be made again to continue deleting the tree."),

1877 0x000020ce: ("ERROR_DS_CANT_DELETE", "The requested delete operation could not be performed."),

1878 0x000020cf: ("ERROR_DS_ATT_SCHEMA_REQ_ID", "Cannot read the governs class identifier for the schema record."),

1879 0x000020d0: ("ERROR_DS_BAD_ATT_SCHEMA_SYNTAX", "The attribute schema has bad syntax."),

1880 0x000020d1: ("ERROR_DS_CANT_CACHE_ATT", "The attribute could not be cached."),

1881 0x000020d2: ("ERROR_DS_CANT_CACHE_CLASS", "The class could not be cached."),

1882 0x000020d3: ("ERROR_DS_CANT_REMOVE_ATT_CACHE", "The attribute could not be removed from the cache."),

1883 0x000020d4: ("ERROR_DS_CANT_REMOVE_CLASS_CACHE", "The class could not be removed from the cache."),

1884 0x000020d5: ("ERROR_DS_CANT_RETRIEVE_DN", "The distinguished name attribute could not be read."),

1885 0x000020d6: ("ERROR_DS_MISSING_SUPREF", "No superior reference has been configured for the directory service. The directory service is therefore unable to issue referrals to objects outside this forest."),

1886 0x000020d7: ("ERROR_DS_CANT_RETRIEVE_INSTANCE", "The instance type attribute could not be retrieved."),

1887 0x000020d8: ("ERROR_DS_CODE_INCONSISTENCY", "An internal error has occurred."),

1888 0x000020d9: ("ERROR_DS_DATABASE_ERROR", "A database error has occurred."),

1889 0x000020da: ("ERROR_DS_GOVERNSID_MISSING", "The attribute GOVERNSID is missing."),

1890 0x000020db: ("ERROR_DS_MISSING_EXPECTED_ATT", "An expected attribute is missing."),

1891 0x000020dc: ("ERROR_DS_NCNAME_MISSING_CR_REF", "The specified naming context is missing a cross reference."),

1892 0x000020dd: ("ERROR_DS_SECURITY_CHECKING_ERROR", "A security checking error has occurred."),

1893 0x000020de: ("ERROR_DS_SCHEMA_NOT_LOADED", "The schema is not loaded."),

1894 0x000020df: ("ERROR_DS_SCHEMA_ALLOC_FAILED", "Schema allocation failed. Please check if the machine is running low on memory."),

1895 0x000020e0: ("ERROR_DS_ATT_SCHEMA_REQ_SYNTAX", "Failed to obtain the required syntax for the attribute schema."),

1896 0x000020e1: ("ERROR_DS_GCVERIFY_ERROR", "The global catalog verification failed. The global catalog is not available or does not support the operation. Some part of the directory is currently not available."),

1897 0x000020e2: ("ERROR_DS_DRA_SCHEMA_MISMATCH", "The replication operation failed because of a schema mismatch between the servers involved."),

1898 0x000020e3: ("ERROR_DS_CANT_FIND_DSA_OBJ", "The DSA object could not be found."),

1899 0x000020e4: ("ERROR_DS_CANT_FIND_EXPECTED_NC", "The naming context could not be found."),

1900 0x000020e5: ("ERROR_DS_CANT_FIND_NC_IN_CACHE", "The naming context could not be found in the cache."),

1901 0x000020e6: ("ERROR_DS_CANT_RETRIEVE_CHILD", "The child object could not be retrieved."),

1902 0x000020e7: ("ERROR_DS_SECURITY_ILLEGAL_MODIFY", "The modification was not permitted for security reasons."),

1903 0x000020e8: ("ERROR_DS_CANT_REPLACE_HIDDEN_REC", "The operation cannot replace the hidden record."),

1904 0x000020e9: ("ERROR_DS_BAD_HIERARCHY_FILE", "The hierarchy file is invalid."),

1905 0x000020ea: ("ERROR_DS_BUILD_HIERARCHY_TABLE_FAILED", "The attempt to build the hierarchy table failed."),

1906 0x000020eb: ("ERROR_DS_CONFIG_PARAM_MISSING", "The directory configuration parameter is missing from the registry."),

1907 0x000020ec: ("ERROR_DS_COUNTING_AB_INDICES_FAILED", "The attempt to count the address book indices failed."),

1908 0x000020ed: ("ERROR_DS_HIERARCHY_TABLE_MALLOC_FAILED", "The allocation of the hierarchy table failed."),

1909 0x000020ee: ("ERROR_DS_INTERNAL_FAILURE", "The directory service encountered an internal failure."),

1910 0x000020ef: ("ERROR_DS_UNKNOWN_ERROR", "The directory service encountered an unknown failure."),

1911 0x000020f0: ("ERROR_DS_ROOT_REQUIRES_CLASS_TOP", "A root object requires a class of 'top'."),

1912 0x000020f1: ("ERROR_DS_REFUSING_FSMO_ROLES", "This directory server is shutting down, and cannot take ownership of new floating single-master operation roles."),

1913 0x000020f2: ("ERROR_DS_MISSING_FSMO_SETTINGS", "The directory service is missing mandatory configuration information, and is unable to determine the ownership of floating single-master operation roles."),

1914 0x000020f3: ("ERROR_DS_UNABLE_TO_SURRENDER_ROLES", "The directory service was unable to transfer ownership of one or more floating single-master operation roles to other servers."),

1915 0x000020f4: ("ERROR_DS_DRA_GENERIC", "The replication operation failed."),

1916 0x000020f5: ("ERROR_DS_DRA_INVALID_PARAMETER", "An invalid parameter was specified for this replication operation."),

1917 0x000020f6: ("ERROR_DS_DRA_BUSY", "The directory service is too busy to complete the replication operation at this time."),

1918 0x000020f7: ("ERROR_DS_DRA_BAD_DN", "The distinguished name specified for this replication operation is invalid."),

1919 0x000020f8: ("ERROR_DS_DRA_BAD_NC", "The naming context specified for this replication operation is invalid."),

1920 0x000020f9: ("ERROR_DS_DRA_DN_EXISTS", "The distinguished name specified for this replication operation already exists."),

1921 0x000020fa: ("ERROR_DS_DRA_INTERNAL_ERROR", "The replication system encountered an internal error."),

1922 0x000020fb: ("ERROR_DS_DRA_INCONSISTENT_DIT", "The replication operation encountered a database inconsistency."),

1923 0x000020fc: ("ERROR_DS_DRA_CONNECTION_FAILED", "The server specified for this replication operation could not be contacted."),

1924 0x000020fd: ("ERROR_DS_DRA_BAD_INSTANCE_TYPE", "The replication operation encountered an object with an invalid instance type."),

1925 0x000020fe: ("ERROR_DS_DRA_OUT_OF_MEM", "The replication operation failed to allocate memory."),

1926 0x000020ff: ("ERROR_DS_DRA_MAIL_PROBLEM", "The replication operation encountered an error with the mail system."),

1927 0x00002100: ("ERROR_DS_DRA_REF_ALREADY_EXISTS", "The replication reference information for the target server already exists."),

1928 0x00002101: ("ERROR_DS_DRA_REF_NOT_FOUND", "The replication reference information for the target server does not exist."),

1929 0x00002102: ("ERROR_DS_DRA_OBJ_IS_REP_SOURCE", "The naming context cannot be removed because it is replicated to another server."),

1930 0x00002103: ("ERROR_DS_DRA_DB_ERROR", "The replication operation encountered a database error."),

1931 0x00002104: ("ERROR_DS_DRA_NO_REPLICA", "The naming context is in the process of being removed or is not replicated from the specified server."),

1932 0x00002105: ("ERROR_DS_DRA_ACCESS_DENIED", "Replication access was denied."),

1933 0x00002106: ("ERROR_DS_DRA_NOT_SUPPORTED", "The requested operation is not supported by this version of the directory service."),

1934 0x00002107: ("ERROR_DS_DRA_RPC_CANCELLED", "The replication remote procedure call was cancelled."),

1935 0x00002108: ("ERROR_DS_DRA_SOURCE_DISABLED", "The source server is currently rejecting replication requests."),

1936 0x00002109: ("ERROR_DS_DRA_SINK_DISABLED", "The destination server is currently rejecting replication requests."),

1937 0x0000210a: ("ERROR_DS_DRA_NAME_COLLISION", "The replication operation failed due to a collision of object names."),

1938 0x0000210b: ("ERROR_DS_DRA_SOURCE_REINSTALLED", "The replication source has been reinstalled."),

1939 0x0000210c: ("ERROR_DS_DRA_MISSING_PARENT", "The replication operation failed because a required parent object is missing."),

1940 0x0000210d: ("ERROR_DS_DRA_PREEMPTED", "The replication operation was preempted."),

1941 0x0000210e: ("ERROR_DS_DRA_ABANDON_SYNC", "The replication synchronization attempt was abandoned because of a lack of updates."),

1942 0x0000210f: ("ERROR_DS_DRA_SHUTDOWN", "The replication operation was terminated because the system is shutting down."),

1943 0x00002110: ("ERROR_DS_DRA_INCOMPATIBLE_PARTIAL_SET", "Synchronization attempt failed because the destination DC is currently waiting to synchronize new partial attributes from source. This condition is normal if a recent schema change modified the partial attribute set. The destination partial attribute set is not a subset of source partial attribute set."),

1944 0x00002111: ("ERROR_DS_DRA_SOURCE_IS_PARTIAL_REPLICA", "The replication synchronization attempt failed because a master replica attempted to sync from a partial replica."),

1945 0x00002112: ("ERROR_DS_DRA_EXTN_CONNECTION_FAILED", "The server specified for this replication operation was contacted, but that server was unable to contact an additional server needed to complete the operation."),

1946 0x00002113: ("ERROR_DS_INSTALL_SCHEMA_MISMATCH", "The version of the directory service schema of the source forest is not compatible with the version of directory service on this computer."),

1947 0x00002114: ("ERROR_DS_DUP_LINK_ID", "Schema update failed: An attribute with the same link identifier already exists."),

1948 0x00002115: ("ERROR_DS_NAME_ERROR_RESOLVING", "Name translation: Generic processing error."),

1949 0x00002116: ("ERROR_DS_NAME_ERROR_NOT_FOUND", "Name translation: Could not find the name or insufficient right to see name."),

1950 0x00002117: ("ERROR_DS_NAME_ERROR_NOT_UNIQUE", "Name translation: Input name mapped to more than one output name."),

1951 0x00002118: ("ERROR_DS_NAME_ERROR_NO_MAPPING", "Name translation: Input name found, but not the associated output format."),

1952 0x00002119: ("ERROR_DS_NAME_ERROR_DOMAIN_ONLY", "Name translation: Unable to resolve completely, only the domain was found."),

1953 0x0000211a: ("ERROR_DS_NAME_ERROR_NO_SYNTACTICAL_MAPPING", "Name translation: Unable to perform purely syntactical mapping at the client without going out to the wire."),

1954 0x0000211b: ("ERROR_DS_CONSTRUCTED_ATT_MOD", "Modification of a constructed attribute is not allowed."),

1955 0x0000211c: ("ERROR_DS_WRONG_OM_OBJ_CLASS", "The OM-Object-Class specified is incorrect for an attribute with the specified syntax."),

1956 0x0000211d: ("ERROR_DS_DRA_REPL_PENDING", "The replication request has been posted; waiting for reply."),

1957 0x0000211e: ("ERROR_DS_DS_REQUIRED", "The requested operation requires a directory service, and none was available."),

1958 0x0000211f: ("ERROR_DS_INVALID_LDAP_DISPLAY_NAME", "The LDAP display name of the class or attribute contains non-ASCII characters."),

1959 0x00002120: ("ERROR_DS_NON_BASE_SEARCH", "The requested search operation is only supported for base searches."),

1960 0x00002121: ("ERROR_DS_CANT_RETRIEVE_ATTS", "The search failed to retrieve attributes from the database."),

1961 0x00002122: ("ERROR_DS_BACKLINK_WITHOUT_LINK", "The schema update operation tried to add a backward link attribute that has no corresponding forward link."),

1962 0x00002123: ("ERROR_DS_EPOCH_MISMATCH", "Source and destination of a cross-domain move do not agree on the object's epoch number. Either source or destination does not have the latest version of the object."),

1963 0x00002124: ("ERROR_DS_SRC_NAME_MISMATCH", "Source and destination of a cross-domain move do not agree on the object's current name. Either source or destination does not have the latest version of the object."),

1964 0x00002125: ("ERROR_DS_SRC_AND_DST_NC_IDENTICAL", "Source and destination for the cross-domain move operation are identical. Caller should use local move operation instead of cross-domain move operation."),

1965 0x00002126: ("ERROR_DS_DST_NC_MISMATCH", "Source and destination for a cross-domain move are not in agreement on the naming contexts in the forest. Either source or destination does not have the latest version of the Partitions container."),

1966 0x00002127: ("ERROR_DS_NOT_AUTHORITIVE_FOR_DST_NC", "Destination of a cross-domain move is not authoritative for the destination naming context."),

1967 0x00002128: ("ERROR_DS_SRC_GUID_MISMATCH", "Source and destination of a cross-domain move do not agree on the identity of the source object. Either source or destination does not have the latest version of the source object."),

1968 0x00002129: ("ERROR_DS_CANT_MOVE_DELETED_OBJECT", "Object being moved across-domains is already known to be deleted by the destination server. The source server does not have the latest version of the source object."),

1969 0x0000212a: ("ERROR_DS_PDC_OPERATION_IN_PROGRESS", "Another operation which requires exclusive access to the PDC FSMO is already in progress."),

1970 0x0000212b: ("ERROR_DS_CROSS_DOMAIN_CLEANUP_REQD", "A cross-domain move operation failed such that two versions of the moved object exist - one each in the source and destination domains. The destination object needs to be removed to restore the system to a consistent state."),

1971 0x0000212c: ("ERROR_DS_ILLEGAL_XDOM_MOVE_OPERATION", "This object may not be moved across domain boundaries either because cross-domain moves for this class are disallowed, or the object has some special characteristics, e.g.: trust account or restricted RID, which prevent its move."),

1972 0x0000212d: ("ERROR_DS_CANT_WITH_ACCT_GROUP_MEMBERSHPS", "Can't move objects with memberships across domain boundaries as once moved, this would violate the membership conditions of the account group. Remove the object from any account group memberships and retry."),

1973 0x0000212e: ("ERROR_DS_NC_MUST_HAVE_NC_PARENT", "A naming context head must be the immediate child of another naming context head, not of an interior node."),

1974 0x0000212f: ("ERROR_DS_CR_IMPOSSIBLE_TO_VALIDATE", "The directory cannot validate the proposed naming context name because it does not hold a replica of the naming context above the proposed naming context. Please ensure that the domain naming master role is held by a server that is configured as a global catalog server, and that the server is up to date with its replication partners. (Applies only to Windows 2000 Domain Naming masters)"),

1975 0x00002130: ("ERROR_DS_DST_DOMAIN_NOT_NATIVE", "Destination domain must be in native mode."),

1976 0x00002131: ("ERROR_DS_MISSING_INFRASTRUCTURE_CONTAINER", "The operation cannot be performed because the server does not have an infrastructure container in the domain of interest."),

1977 0x00002132: ("ERROR_DS_CANT_MOVE_ACCOUNT_GROUP", "Cross-domain move of non-empty account groups is not allowed."),

1978 0x00002133: ("ERROR_DS_CANT_MOVE_RESOURCE_GROUP", "Cross-domain move of non-empty resource groups is not allowed."),

1979 0x00002134: ("ERROR_DS_INVALID_SEARCH_FLAG", "The search flags for the attribute are invalid. The ANR bit is valid only on attributes of Unicode or Teletex strings."),

1980 0x00002135: ("ERROR_DS_NO_TREE_DELETE_ABOVE_NC", "Tree deletions starting at an object which has an NC head as a descendant are not allowed."),

1981 0x00002136: ("ERROR_DS_COULDNT_LOCK_TREE_FOR_DELETE", "The directory service failed to lock a tree in preparation for a tree deletion because the tree was in use."),

1982 0x00002137: ("ERROR_DS_COULDNT_IDENTIFY_OBJECTS_FOR_TREE_DELETE", "The directory service failed to identify the list of objects to delete while attempting a tree deletion."),

1983 0x00002138: ("ERROR_DS_SAM_INIT_FAILURE", "Security Accounts Manager initialization failed because of the following error: %1."),

1984 0x00002139: ("ERROR_DS_SENSITIVE_GROUP_VIOLATION", "Only an administrator can modify the membership list of an administrative group."),

1985 0x0000213a: ("ERROR_DS_CANT_MOD_PRIMARYGROUPID", "Cannot change the primary group ID of a domain controller account."),

1986 0x0000213b: ("ERROR_DS_ILLEGAL_BASE_SCHEMA_MOD", "An attempt is made to modify the base schema."),

1987 0x0000213c: ("ERROR_DS_NONSAFE_SCHEMA_CHANGE", "Adding a new mandatory attribute to an existing class, deleting a mandatory attribute from an existing class, or adding an optional attribute to the special class Top that is not a backlink attribute (directly or through inheritance, for example, by adding or deleting an auxiliary class) is not allowed."),

1988 0x0000213d: ("ERROR_DS_SCHEMA_UPDATE_DISALLOWED", "Schema update is not allowed on this DC because the DC is not the schema FSMO Role Owner."),

1989 0x0000213e: ("ERROR_DS_CANT_CREATE_UNDER_SCHEMA", "An object of this class cannot be created under the schema container. You can only create attribute-schema and class-schema objects under the schema container."),

1990 0x0000213f: ("ERROR_DS_INSTALL_NO_SRC_SCH_VERSION", "The replica/child install failed to get the objectVersion attribute on the schema container on the source DC. Either the attribute is missing on the schema container or the credentials supplied do not have permission to read it."),

1991 0x00002140: ("ERROR_DS_INSTALL_NO_SCH_VERSION_IN_INIFILE", "The replica/child install failed to read the objectVersion attribute in the SCHEMA section of the file schema.ini in the system32 directory."),

1992 0x00002141: ("ERROR_DS_INVALID_GROUP_TYPE", "The specified group type is invalid."),

1993 0x00002142: ("ERROR_DS_NO_NEST_GLOBALGROUP_IN_MIXEDDOMAIN", "You cannot nest global groups in a mixed domain if the group is security-enabled."),

1994 0x00002143: ("ERROR_DS_NO_NEST_LOCALGROUP_IN_MIXEDDOMAIN", "You cannot nest local groups in a mixed domain if the group is security-enabled."),

1995 0x00002144: ("ERROR_DS_GLOBAL_CANT_HAVE_LOCAL_MEMBER", "A global group cannot have a local group as a member."),

1996 0x00002145: ("ERROR_DS_GLOBAL_CANT_HAVE_UNIVERSAL_MEMBER", "A global group cannot have a universal group as a member."),

1997 0x00002146: ("ERROR_DS_UNIVERSAL_CANT_HAVE_LOCAL_MEMBER", "A universal group cannot have a local group as a member."),

1998 0x00002147: ("ERROR_DS_GLOBAL_CANT_HAVE_CROSSDOMAIN_MEMBER", "A global group cannot have a cross-domain member."),

1999 0x00002148: ("ERROR_DS_LOCAL_CANT_HAVE_CROSSDOMAIN_LOCAL_MEMBER", "A local group cannot have another cross domain local group as a member."),

2000 0x00002149: ("ERROR_DS_HAVE_PRIMARY_MEMBERS", "A group with primary members cannot change to a security-disabled group."),

2001 0x0000214a: ("ERROR_DS_STRING_SD_CONVERSION_FAILED", "The schema cache load failed to convert the string default SD on a class-schema object."),

2002 0x0000214b: ("ERROR_DS_NAMING_MASTER_GC", "Only DSAs configured to be Global Catalog servers should be allowed to hold the Domain Naming Master FSMO role. (Applies only to Windows 2000 servers)"),

2003 0x0000214c: ("ERROR_DS_DNS_LOOKUP_FAILURE", "The DSA operation is unable to proceed because of a DNS lookup failure."),

2004 0x0000214d: ("ERROR_DS_COULDNT_UPDATE_SPNS", "While processing a change to the DNS Host Name for an object, the Service Principal Name values could not be kept in sync."),

2005 0x0000214e: ("ERROR_DS_CANT_RETRIEVE_SD", "The Security Descriptor attribute could not be read."),

2006 0x0000214f: ("ERROR_DS_KEY_NOT_UNIQUE", "The object requested was not found, but an object with that key was found."),

2007 0x00002150: ("ERROR_DS_WRONG_LINKED_ATT_SYNTAX", "The syntax of the linked attribute being added is incorrect. Forward links can only have syntax 2.5.5.1, 2.5.5.7, and 2.5.5.14, and backlinks can only have syntax 2.5.5.1"),

2008 0x00002151: ("ERROR_DS_SAM_NEED_BOOTKEY_PASSWORD", "Security Account Manager needs to get the boot password."),

2009 0x00002152: ("ERROR_DS_SAM_NEED_BOOTKEY_FLOPPY", "Security Account Manager needs to get the boot key from floppy disk."),

2010 0x00002153: ("ERROR_DS_CANT_START", "Directory Service cannot start."),

2011 0x00002154: ("ERROR_DS_INIT_FAILURE", "Directory Services could not start."),

2012 0x00002155: ("ERROR_DS_NO_PKT_PRIVACY_ON_CONNECTION", "The connection between client and server requires packet privacy or better."),

2013 0x00002156: ("ERROR_DS_SOURCE_DOMAIN_IN_FOREST", "The source domain may not be in the same forest as destination."),

2014 0x00002157: ("ERROR_DS_DESTINATION_DOMAIN_NOT_IN_FOREST", "The destination domain must be in the forest."),

2015 0x00002158: ("ERROR_DS_DESTINATION_AUDITING_NOT_ENABLED", "The operation requires that destination domain auditing be enabled."),

2016 0x00002159: ("ERROR_DS_CANT_FIND_DC_FOR_SRC_DOMAIN", "The operation couldn't locate a DC for the source domain."),

2017 0x0000215a: ("ERROR_DS_SRC_OBJ_NOT_GROUP_OR_USER", "The source object must be a group or user."),

2018 0x0000215b: ("ERROR_DS_SRC_SID_EXISTS_IN_FOREST", "The source object's SID already exists in destination forest."),

2019 0x0000215c: ("ERROR_DS_SRC_AND_DST_OBJECT_CLASS_MISMATCH", "The source and destination object must be of the same type."),

2020 0x0000215d: ("ERROR_SAM_INIT_FAILURE", "Security Accounts Manager initialization failed because of the following error: %1."),

2021 0x0000215e: ("ERROR_DS_DRA_SCHEMA_INFO_SHIP", "Schema information could not be included in the replication request."),

2022 0x0000215f: ("ERROR_DS_DRA_SCHEMA_CONFLICT", "The replication operation could not be completed due to a schema incompatibility."),

2023 0x00002160: ("ERROR_DS_DRA_EARLIER_SCHEMA_CONFLICT", "The replication operation could not be completed due to a previous schema incompatibility."),

2024 0x00002161: ("ERROR_DS_DRA_OBJ_NC_MISMATCH", "The replication update could not be applied because either the source or the destination has not yet received information regarding a recent cross-domain move operation."),

2025 0x00002162: ("ERROR_DS_NC_STILL_HAS_DSAS", "The requested domain could not be deleted because there exist domain controllers that still host this domain."),

2026 0x00002163: ("ERROR_DS_GC_REQUIRED", "The requested operation can be performed only on a global catalog server."),

2027 0x00002164: ("ERROR_DS_LOCAL_MEMBER_OF_LOCAL_ONLY", "A local group can only be a member of other local groups in the same domain."),

2028 0x00002165: ("ERROR_DS_NO_FPO_IN_UNIVERSAL_GROUPS", "Foreign security principals cannot be members of universal groups."),

2029 0x00002166: ("ERROR_DS_CANT_ADD_TO_GC", "The attribute is not allowed to be replicated to the GC because of security reasons."),

2030 0x00002167: ("ERROR_DS_NO_CHECKPOINT_WITH_PDC", "The checkpoint with the PDC could not be taken because there too many modifications being processed currently."),

2031 0x00002168: ("ERROR_DS_SOURCE_AUDITING_NOT_ENABLED", "The operation requires that source domain auditing be enabled."),

2032 0x00002169: ("ERROR_DS_CANT_CREATE_IN_NONDOMAIN_NC", "Security principal objects can only be created inside domain naming contexts."),

2033 0x0000216a: ("ERROR_DS_INVALID_NAME_FOR_SPN", "A Service Principal Name (SPN) could not be constructed because the provided hostname is not in the necessary format."),

2034 0x0000216b: ("ERROR_DS_FILTER_USES_CONTRUCTED_ATTRS", "A Filter was passed that uses constructed attributes."),

2035 0x0000216c: ("ERROR_DS_UNICODEPWD_NOT_IN_QUOTES", "The unicodePwd attribute value must be enclosed in double quotes."),

2036 0x0000216d: ("ERROR_DS_MACHINE_ACCOUNT_QUOTA_EXCEEDED", "Your computer could not be joined to the domain. You have exceeded the maximum number of computer accounts you are allowed to create in this domain. Contact your system administrator to have this limit reset or increased."),

2037 0x0000216e: ("ERROR_DS_MUST_BE_RUN_ON_DST_DC", "For security reasons, the operation must be run on the destination DC."),

2038 0x0000216f: ("ERROR_DS_SRC_DC_MUST_BE_SP4_OR_GREATER", "For security reasons, the source DC must be NT4SP4 or greater."),

2039 0x00002170: ("ERROR_DS_CANT_TREE_DELETE_CRITICAL_OBJ", "Critical Directory Service System objects cannot be deleted during tree delete operations. The tree delete may have been partially performed."),

2040 0x00002171: ("ERROR_DS_INIT_FAILURE_CONSOLE", "Directory Services could not start because of the following error: %1."),

2041 0x00002172: ("ERROR_DS_SAM_INIT_FAILURE_CONSOLE", "Security Accounts Manager initialization failed because of the following error: %1."),

2042 0x00002173: ("ERROR_DS_FOREST_VERSION_TOO_HIGH", "The version of the operating system is incompatible with the current AD DS forest functional level or AD LDS Configuration Set functional level. You must upgrade to a new version of the operating system before this server can become an AD DS Domain Controller or add an AD LDS Instance in this AD DS Forest or AD LDS Configuration Set."),

2043 0x00002174: ("ERROR_DS_DOMAIN_VERSION_TOO_HIGH", "The version of the operating system installed is incompatible with the current domain functional level. You must upgrade to a new version of the operating system before this server can become a domain controller in this domain."),

2044 0x00002175: ("ERROR_DS_FOREST_VERSION_TOO_LOW", "The version of the operating system installed on this server no longer supports the current AD DS Forest functional level or AD LDS Configuration Set functional level. You must raise the AD DS Forest functional level or AD LDS Configuration Set functional level before this server can become an AD DS Domain Controller or an AD LDS Instance in this Forest or Configuration Set."),

2045 0x00002176: ("ERROR_DS_DOMAIN_VERSION_TOO_LOW", "The version of the operating system installed on this server no longer supports the current domain functional level. You must raise the domain functional level before this server can become a domain controller in this domain."),

2046 0x00002177: ("ERROR_DS_INCOMPATIBLE_VERSION", "The version of the operating system installed on this server is incompatible with the functional level of the domain or forest."),

2047 0x00002178: ("ERROR_DS_LOW_DSA_VERSION", "The functional level of the domain (or forest) cannot be raised to the requested value, because there exist one or more domain controllers in the domain (or forest) that are at a lower incompatible functional level."),

2048 0x00002179: ("ERROR_DS_NO_BEHAVIOR_VERSION_IN_MIXEDDOMAIN", "The forest functional level cannot be raised to the requested value since one or more domains are still in mixed domain mode. All domains in the forest must be in native mode, for you to raise the forest functional level."),

2049 0x0000217a: ("ERROR_DS_NOT_SUPPORTED_SORT_ORDER", "The sort order requested is not supported."),

2050 0x0000217b: ("ERROR_DS_NAME_NOT_UNIQUE", "The requested name already exists as a unique identifier."),

2051 0x0000217c: ("ERROR_DS_MACHINE_ACCOUNT_CREATED_PRENT4", "The machine account was created pre-NT4. The account needs to be recreated."),

2052 0x0000217d: ("ERROR_DS_OUT_OF_VERSION_STORE", "The database is out of version store."),

2053 0x0000217e: ("ERROR_DS_INCOMPATIBLE_CONTROLS_USED", "Unable to continue operation because multiple conflicting controls were used."),

2054 0x0000217f: ("ERROR_DS_NO_REF_DOMAIN", "Unable to find a valid security descriptor reference domain for this partition."),

2055 0x00002180: ("ERROR_DS_RESERVED_LINK_ID", "Schema update failed: The link identifier is reserved."),

2056 0x00002181: ("ERROR_DS_LINK_ID_NOT_AVAILABLE", "Schema update failed: There are no link identifiers available."),

2057 0x00002182: ("ERROR_DS_AG_CANT_HAVE_UNIVERSAL_MEMBER", "An account group cannot have a universal group as a member."),

2058 0x00002183: ("ERROR_DS_MODIFYDN_DISALLOWED_BY_INSTANCE_TYPE", "Rename or move operations on naming context heads or read-only objects are not allowed."),

2059 0x00002184: ("ERROR_DS_NO_OBJECT_MOVE_IN_SCHEMA_NC", "Move operations on objects in the schema naming context are not allowed."),

2060 0x00002185: ("ERROR_DS_MODIFYDN_DISALLOWED_BY_FLAG", "A system flag has been set on the object and does not allow the object to be moved or renamed."),

2061 0x00002186: ("ERROR_DS_MODIFYDN_WRONG_GRANDPARENT", "This object is not allowed to change its grandparent container. Moves are not forbidden on this object, but are restricted to sibling containers."),

2062 0x00002187: ("ERROR_DS_NAME_ERROR_TRUST_REFERRAL", "Unable to resolve completely, a referral to another forest is generated."),

2063 0x00002188: ("ERROR_NOT_SUPPORTED_ON_STANDARD_SERVER", "The requested action is not supported on standard server."),

2064 0x00002189: ("ERROR_DS_CANT_ACCESS_REMOTE_PART_OF_AD", "Could not access a partition of the directory service located on a remote server. Make sure at least one server is running for the partition in question."),

2065 0x0000218a: ("ERROR_DS_CR_IMPOSSIBLE_TO_VALIDATE_V2", "The directory cannot validate the proposed naming context (or partition) name because it does not hold a replica nor can it contact a replica of the naming context above the proposed naming context. Please ensure that the parent naming context is properly registered in DNS, and at least one replica of this naming context is reachable by the Domain Naming master."),

2066 0x0000218b: ("ERROR_DS_THREAD_LIMIT_EXCEEDED", "The thread limit for this request was exceeded."),

2067 0x0000218c: ("ERROR_DS_NOT_CLOSEST", "The Global catalog server is not in the closest site."),

2068 0x0000218d: ("ERROR_DS_CANT_DERIVE_SPN_WITHOUT_SERVER_REF", "The DS cannot derive a service principal name (SPN) with which to mutually authenticate the target server because the corresponding server object in the local DS database has no serverReference attribute."),

2069 0x0000218e: ("ERROR_DS_SINGLE_USER_MODE_FAILED", "The Directory Service failed to enter single user mode."),

2070 0x0000218f: ("ERROR_DS_NTDSCRIPT_SYNTAX_ERROR", "The Directory Service cannot parse the script because of a syntax error."),

2071 0x00002190: ("ERROR_DS_NTDSCRIPT_PROCESS_ERROR", "The Directory Service cannot process the script because of an error."),

2072 0x00002191: ("ERROR_DS_DIFFERENT_REPL_EPOCHS", "The directory service cannot perform the requested operation because the servers involved are of different replication epochs (which is usually related to a domain rename that is in progress)."),

2073 0x00002192: ("ERROR_DS_DRS_EXTENSIONS_CHANGED", "The directory service binding must be renegotiated due to a change in the server extensions information."),

2074 0x00002193: ("ERROR_DS_REPLICA_SET_CHANGE_NOT_ALLOWED_ON_DISABLED_CR", "Operation not allowed on a disabled cross ref."),

2075 0x00002194: ("ERROR_DS_NO_MSDS_INTID", "Schema update failed: No values for msDS-IntId are available."),

2076 0x00002195: ("ERROR_DS_DUP_MSDS_INTID", "Schema update failed: Duplicate msDS-INtId. Retry the operation."),

2077 0x00002196: ("ERROR_DS_EXISTS_IN_RDNATTID", "Schema deletion failed: attribute is used in rDNAttID."),

2078 0x00002197: ("ERROR_DS_AUTHORIZATION_FAILED", "The directory service failed to authorize the request."),

2079 0x00002198: ("ERROR_DS_INVALID_SCRIPT", "The Directory Service cannot process the script because it is invalid."),

2080 0x00002199: ("ERROR_DS_REMOTE_CROSSREF_OP_FAILED", "The remote create cross reference operation failed on the Domain Naming Master FSMO. The operation's error is in the extended data."),

2081 0x0000219a: ("ERROR_DS_CROSS_REF_BUSY", "A cross reference is in use locally with the same name."),

2082 0x0000219b: ("ERROR_DS_CANT_DERIVE_SPN_FOR_DELETED_DOMAIN", "The DS cannot derive a service principal name (SPN) with which to mutually authenticate the target server because the server's domain has been deleted from the forest."),

2083 0x0000219c: ("ERROR_DS_CANT_DEMOTE_WITH_WRITEABLE_NC", "Writeable NCs prevent this DC from demoting."),

2084 0x0000219d: ("ERROR_DS_DUPLICATE_ID_FOUND", "The requested object has a non-unique identifier and cannot be retrieved."),

2085 0x0000219e: ("ERROR_DS_INSUFFICIENT_ATTR_TO_CREATE_OBJECT", "Insufficient attributes were given to create an object. This object may not exist because it may have been deleted and already garbage collected."),

2086 0x0000219f: ("ERROR_DS_GROUP_CONVERSION_ERROR", "The group cannot be converted due to attribute restrictions on the requested group type."),

2087 0x000021a0: ("ERROR_DS_CANT_MOVE_APP_BASIC_GROUP", "Cross-domain move of non-empty basic application groups is not allowed."),

2088 0x000021a1: ("ERROR_DS_CANT_MOVE_APP_QUERY_GROUP", "Cross-domain move of non-empty query based application groups is not allowed."),

2089 0x000021a2: ("ERROR_DS_ROLE_NOT_VERIFIED", "The FSMO role ownership could not be verified because its directory partition has not replicated successfully with at least one replication partner."),

2090 0x000021a3: ("ERROR_DS_WKO_CONTAINER_CANNOT_BE_SPECIAL", "The target container for a redirection of a well known object container cannot already be a special container."),

2091 0x000021a4: ("ERROR_DS_DOMAIN_RENAME_IN_PROGRESS", "The Directory Service cannot perform the requested operation because a domain rename operation is in progress."),

2092 0x000021a5: ("ERROR_DS_EXISTING_AD_CHILD_NC", "The directory service detected a child partition below the requested partition name. The partition hierarchy must be created in a top down method."),

2093 0x000021a6: ("ERROR_DS_REPL_LIFETIME_EXCEEDED", "The directory service cannot replicate with this server because the time since the last replication with this server has exceeded the tombstone lifetime."),

2094 0x000021a7: ("ERROR_DS_DISALLOWED_IN_SYSTEM_CONTAINER", "The requested operation is not allowed on an object under the system container."),

2095 0x000021a8: ("ERROR_DS_LDAP_SEND_QUEUE_FULL", "The LDAP servers network send queue has filled up because the client is not processing the results of its requests fast enough. No more requests will be processed until the client catches up. If the client does not catch up then it will be disconnected."),

2096 0x000021a9: ("ERROR_DS_DRA_OUT_SCHEDULE_WINDOW", "The scheduled replication did not take place because the system was too busy to execute the request within the schedule window. The replication queue is overloaded. Consider reducing the number of partners or decreasing the scheduled replication frequency."),

2097 0x000021aa: ("ERROR_DS_POLICY_NOT_KNOWN", "At this time, it cannot be determined if the branch replication policy is available on the hub domain controller. Please retry at a later time to account for replication latencies."),

2098 0x000021ab: ("ERROR_NO_SITE_SETTINGS_OBJECT", "The site settings object for the specified site does not exist."),

2099 0x000021ac: ("ERROR_NO_SECRETS", "The local account store does not contain secret material for the specified account."),

2100 0x000021ad: ("ERROR_NO_WRITABLE_DC_FOUND", "Could not find a writable domain controller in the domain."),

2101 0x000021ae: ("ERROR_DS_NO_SERVER_OBJECT", "The server object for the domain controller does not exist."),

2102 0x000021af: ("ERROR_DS_NO_NTDSA_OBJECT", "The NTDS Settings object for the domain controller does not exist."),

2103 0x000021b0: ("ERROR_DS_NON_ASQ_SEARCH", "The requested search operation is not supported for ASQ searches."),

2104 0x000021b1: ("ERROR_DS_AUDIT_FAILURE", "A required audit event could not be generated for the operation."),

2105 0x000021b2: ("ERROR_DS_INVALID_SEARCH_FLAG_SUBTREE", "The search flags for the attribute are invalid. The subtree index bit is valid only on single valued attributes."),

2106 0x000021b3: ("ERROR_DS_INVALID_SEARCH_FLAG_TUPLE", "The search flags for the attribute are invalid. The tuple index bit is valid only on attributes of Unicode strings."),

2107 0x000021b4: ("ERROR_DS_HIERARCHY_TABLE_TOO_DEEP", "The address books are nested too deeply. Failed to build the hierarchy table."),

2108 0x000021b5: ("ERROR_DS_DRA_CORRUPT_UTD_VECTOR", "The specified up-to-date-ness vector is corrupt."),

2109 0x000021b6: ("ERROR_DS_DRA_SECRETS_DENIED", "The request to replicate secrets is denied."),

2110 0x000021b7: ("ERROR_DS_RESERVED_MAPI_ID", "Schema update failed: The MAPI identifier is reserved."),

2111 0x000021b8: ("ERROR_DS_MAPI_ID_NOT_AVAILABLE", "Schema update failed: There are no MAPI identifiers available."),

2112 0x000021b9: ("ERROR_DS_DRA_MISSING_KRBTGT_SECRET", "The replication operation failed because the required attributes of the local krbtgt object are missing."),

2113 0x000021ba: ("ERROR_DS_DOMAIN_NAME_EXISTS_IN_FOREST", "The domain name of the trusted domain already exists in the forest."),

2114 0x000021bb: ("ERROR_DS_FLAT_NAME_EXISTS_IN_FOREST", "The flat name of the trusted domain already exists in the forest."),

2115 0x000021bc: ("ERROR_INVALID_USER_PRINCIPAL_NAME", "The User Principal Name (UPN) is invalid."),

2116 0x000021bd: ("ERROR_DS_OID_MAPPED_GROUP_CANT_HAVE_MEMBERS", "OID mapped groups cannot have members."),

2117 0x000021be: ("ERROR_DS_OID_NOT_FOUND", "The specified OID cannot be found."),

2118 0x000021bf: ("ERROR_DS_DRA_RECYCLED_TARGET", "The replication operation failed because the target object referred by a link value is recycled."),

2119 0x000021c0: ("ERROR_DS_DISALLOWED_NC_REDIRECT", "The redirect operation failed because the target object is in a NC different from the domain NC of the current domain controller."),

2120 0x000021c1: ("ERROR_DS_HIGH_ADLDS_FFL", "The functional level of the AD LDS configuration set cannot be lowered to the requested value."),

2121 0x000021c2: ("ERROR_DS_HIGH_DSA_VERSION", "The functional level of the domain (or forest) cannot be lowered to the requested value."),

2122 0x000021c3: ("ERROR_DS_LOW_ADLDS_FFL", "The functional level of the AD LDS configuration set cannot be raised to the requested value, because there exist one or more ADLDS instances that are at a lower incompatible functional level."),

2123 0x000021c4: ("ERROR_DOMAIN_SID_SAME_AS_LOCAL_WORKSTATION", "The domain join cannot be completed because the SID of the domain you attempted to join was identical to the SID of this machine. This is a symptom of an improperly cloned operating system install. You should run sysprep on this machine in order to generate a new machine SID. Please see https://go.microsoft.com/fwlink/?LinkId=168895 for more information."),

2124 0x000021c5: ("ERROR_DS_UNDELETE_SAM_VALIDATION_FAILED", "The undelete operation failed because the Sam Account Name or Additional Sam Account Name of the object being undeleted conflicts with an existing live object."),

2125 0x000021c6: ("ERROR_INCORRECT_ACCOUNT_TYPE", "The system is not authoritative for the specified account and therefore cannot complete the operation. Please retry the operation using the provider associated with this account. If this is an online provider please use the provider's online site."),

2126 0x00002329: ("DNS_ERROR_RCODE_FORMAT_ERROR", "DNS server unable to interpret format."),

2127 0x0000232a: ("DNS_ERROR_RCODE_SERVER_FAILURE", "DNS server failure."),

2128 0x0000232b: ("DNS_ERROR_RCODE_NAME_ERROR", "DNS name does not exist."),

2129 0x0000232c: ("DNS_ERROR_RCODE_NOT_IMPLEMENTED", "DNS request not supported by name server."),

2130 0x0000232d: ("DNS_ERROR_RCODE_REFUSED", "DNS operation refused."),

2131 0x0000232e: ("DNS_ERROR_RCODE_YXDOMAIN", "DNS name that ought not exist, does exist."),

2132 0x0000232f: ("DNS_ERROR_RCODE_YXRRSET", "DNS RR set that ought not exist, does exist."),

2133 0x00002330: ("DNS_ERROR_RCODE_NXRRSET", "DNS RR set that ought to exist, does not exist."),

2134 0x00002331: ("DNS_ERROR_RCODE_NOTAUTH", "DNS server not authoritative for zone."),

2135 0x00002332: ("DNS_ERROR_RCODE_NOTZONE", "DNS name in update or prereq is not in zone."),

2136 0x00002338: ("DNS_ERROR_RCODE_BADSIG", "DNS signature failed to verify."),

2137 0x00002339: ("DNS_ERROR_RCODE_BADKEY", "DNS bad key."),

2138 0x0000233a: ("DNS_ERROR_RCODE_BADTIME", "DNS signature validity expired."),

2139 0x0000238d: ("DNS_ERROR_KEYMASTER_REQUIRED", "Only the DNS server acting as the key master for the zone may perform this operation."),

2140 0x0000238e: ("DNS_ERROR_NOT_ALLOWED_ON_SIGNED_ZONE", "This operation is not allowed on a zone that is signed or has signing keys."),

2141 0x0000238f: ("DNS_ERROR_NSEC3_INCOMPATIBLE_WITH_RSA_SHA1", "NSEC3 is not compatible with the RSA-SHA-1 algorithm. Choose a different algorithm or use NSEC."),

2142 0x00002390: ("DNS_ERROR_NOT_ENOUGH_SIGNING_KEY_DESCRIPTORS", "The zone does not have enough signing keys. There must be at least one key signing key (KSK) and at least one zone signing key (ZSK)."),

2143 0x00002391: ("DNS_ERROR_UNSUPPORTED_ALGORITHM", "The specified algorithm is not supported."),

2144 0x00002392: ("DNS_ERROR_INVALID_KEY_SIZE", "The specified key size is not supported."),

2145 0x00002393: ("DNS_ERROR_SIGNING_KEY_NOT_ACCESSIBLE", "One or more of the signing keys for a zone are not accessible to the DNS server. Zone signing will not be operational until this error is resolved."),

2146 0x00002394: ("DNS_ERROR_KSP_DOES_NOT_SUPPORT_PROTECTION", "The specified key storage provider does not support DPAPI++ data protection. Zone signing will not be operational until this error is resolved."),

2147 0x00002395: ("DNS_ERROR_UNEXPECTED_DATA_PROTECTION_ERROR", "An unexpected DPAPI++ error was encountered. Zone signing will not be operational until this error is resolved."),

2148 0x00002396: ("DNS_ERROR_UNEXPECTED_CNG_ERROR", "An unexpected crypto error was encountered. Zone signing may not be operational until this error is resolved."),

2149 0x00002397: ("DNS_ERROR_UNKNOWN_SIGNING_PARAMETER_VERSION", "The DNS server encountered a signing key with an unknown version. Zone signing will not be operational until this error is resolved."),

2150 0x00002398: ("DNS_ERROR_KSP_NOT_ACCESSIBLE", "The specified key service provider cannot be opened by the DNS server."),

2151 0x00002399: ("DNS_ERROR_TOO_MANY_SKDS", "The DNS server cannot accept any more signing keys with the specified algorithm and KSK flag value for this zone."),

2152 0x0000239a: ("DNS_ERROR_INVALID_ROLLOVER_PERIOD", "The specified rollover period is invalid."),

2153 0x0000239b: ("DNS_ERROR_INVALID_INITIAL_ROLLOVER_OFFSET", "The specified initial rollover offset is invalid."),

2154 0x0000239c: ("DNS_ERROR_ROLLOVER_IN_PROGRESS", "The specified signing key is already in process of rolling over keys."),

2155 0x0000239d: ("DNS_ERROR_STANDBY_KEY_NOT_PRESENT", "The specified signing key does not have a standby key to revoke."),

2156 0x0000239e: ("DNS_ERROR_NOT_ALLOWED_ON_ZSK", "This operation is not allowed on a zone signing key (ZSK)."),

2157 0x0000239f: ("DNS_ERROR_NOT_ALLOWED_ON_ACTIVE_SKD", "This operation is not allowed on an active signing key."),

2158 0x000023a0: ("DNS_ERROR_ROLLOVER_ALREADY_QUEUED", "The specified signing key is already queued for rollover."),

2159 0x000023a1: ("DNS_ERROR_NOT_ALLOWED_ON_UNSIGNED_ZONE", "This operation is not allowed on an unsigned zone."),

2160 0x000023a2: ("DNS_ERROR_BAD_KEYMASTER", "This operation could not be completed because the DNS server listed as the current key master for this zone is down or misconfigured. Resolve the problem on the current key master for this zone or use another DNS server to seize the key master role."),

2161 0x000023a3: ("DNS_ERROR_INVALID_SIGNATURE_VALIDITY_PERIOD", "The specified signature validity period is invalid."),

2162 0x000023a4: ("DNS_ERROR_INVALID_NSEC3_ITERATION_COUNT", "The specified NSEC3 iteration count is higher than allowed by the minimum key length used in the zone."),

2163 0x000023a5: ("DNS_ERROR_DNSSEC_IS_DISABLED", "This operation could not be completed because the DNS server has been configured with DNSSEC features disabled. Enable DNSSEC on the DNS server."),

2164 0x000023a6: ("DNS_ERROR_INVALID_XML", "This operation could not be completed because the XML stream received is empty or syntactically invalid."),

2165 0x000023a7: ("DNS_ERROR_NO_VALID_TRUST_ANCHORS", "This operation completed, but no trust anchors were added because all of the trust anchors received were either invalid, unsupported, expired, or would not become valid in less than 30 days."),

2166 0x000023a8: ("DNS_ERROR_ROLLOVER_NOT_POKEABLE", "The specified signing key is not waiting for parental DS update."),

2167 0x000023a9: ("DNS_ERROR_NSEC3_NAME_COLLISION", "Hash collision detected during NSEC3 signing. Specify a different user-provided salt, or use a randomly generated salt, and attempt to sign the zone again."),

2168 0x000023aa: ("DNS_ERROR_NSEC_INCOMPATIBLE_WITH_NSEC3_RSA_SHA1", "NSEC is not compatible with the NSEC3-RSA-SHA-1 algorithm. Choose a different algorithm or use NSEC3."),

2169 0x0000251d: ("DNS_INFO_NO_RECORDS", "No records found for given DNS query."),

2170 0x0000251e: ("DNS_ERROR_BAD_PACKET", "Bad DNS packet."),

2171 0x0000251f: ("DNS_ERROR_NO_PACKET", "No DNS packet."),

2172 0x00002520: ("DNS_ERROR_RCODE", "DNS error, check rcode."),

2173 0x00002521: ("DNS_ERROR_UNSECURE_PACKET", "Unsecured DNS packet."),

2174 0x00002522: ("DNS_REQUEST_PENDING", "DNS query request is pending."),

2175 0x0000254f: ("DNS_ERROR_INVALID_TYPE", "Invalid DNS type."),

2176 0x00002550: ("DNS_ERROR_INVALID_IP_ADDRESS", "Invalid IP address."),

2177 0x00002551: ("DNS_ERROR_INVALID_PROPERTY", "Invalid property."),

2178 0x00002552: ("DNS_ERROR_TRY_AGAIN_LATER", "Try DNS operation again later."),

2179 0x00002553: ("DNS_ERROR_NOT_UNIQUE", "Record for given name and type is not unique."),

2180 0x00002554: ("DNS_ERROR_NON_RFC_NAME", "DNS name does not comply with RFC specifications."),

2181 0x00002555: ("DNS_STATUS_FQDN", "DNS name is a fully-qualified DNS name."),

2182 0x00002556: ("DNS_STATUS_DOTTED_NAME", "DNS name is dotted (multi-label)."),

2183 0x00002557: ("DNS_STATUS_SINGLE_PART_NAME", "DNS name is a single-part name."),

2184 0x00002558: ("DNS_ERROR_INVALID_NAME_CHAR", "DNS name contains an invalid character."),

2185 0x00002559: ("DNS_ERROR_NUMERIC_NAME", "DNS name is entirely numeric."),

2186 0x0000255a: ("DNS_ERROR_NOT_ALLOWED_ON_ROOT_SERVER", "The operation requested is not permitted on a DNS root server."),

2187 0x0000255b: ("DNS_ERROR_NOT_ALLOWED_UNDER_DELEGATION", "The record could not be created because this part of the DNS namespace has been delegated to another server."),

2188 0x0000255c: ("DNS_ERROR_CANNOT_FIND_ROOT_HINTS", "The DNS server could not find a set of root hints."),

2189 0x0000255d: ("DNS_ERROR_INCONSISTENT_ROOT_HINTS", "The DNS server found root hints but they were not consistent across all adapters."),

2190 0x0000255e: ("DNS_ERROR_DWORD_VALUE_TOO_SMALL", "The specified value is too small for this parameter."),

2191 0x0000255f: ("DNS_ERROR_DWORD_VALUE_TOO_LARGE", "The specified value is too large for this parameter."),

2192 0x00002560: ("DNS_ERROR_BACKGROUND_LOADING", "This operation is not allowed while the DNS server is loading zones in the background. Please try again later."),

2193 0x00002561: ("DNS_ERROR_NOT_ALLOWED_ON_RODC", "The operation requested is not permitted on against a DNS server running on a read-only DC."),

2194 0x00002562: ("DNS_ERROR_NOT_ALLOWED_UNDER_DNAME", "No data is allowed to exist underneath a DNAME record."),

2195 0x00002563: ("DNS_ERROR_DELEGATION_REQUIRED", "This operation requires credentials delegation."),

2196 0x00002564: ("DNS_ERROR_INVALID_POLICY_TABLE", "Name resolution policy table has been corrupted. DNS resolution will fail until it is fixed. Contact your network administrator."),

2197 0x00002581: ("DNS_ERROR_ZONE_DOES_NOT_EXIST", "DNS zone does not exist."),

2198 0x00002582: ("DNS_ERROR_NO_ZONE_INFO", "DNS zone information not available."),

2199 0x00002583: ("DNS_ERROR_INVALID_ZONE_OPERATION", "Invalid operation for DNS zone."),

2200 0x00002584: ("DNS_ERROR_ZONE_CONFIGURATION_ERROR", "Invalid DNS zone configuration."),

2201 0x00002585: ("DNS_ERROR_ZONE_HAS_NO_SOA_RECORD", "DNS zone has no start of authority (SOA) record."),

2202 0x00002586: ("DNS_ERROR_ZONE_HAS_NO_NS_RECORDS", "DNS zone has no Name Server (NS) record."),

2203 0x00002587: ("DNS_ERROR_ZONE_LOCKED", "DNS zone is locked."),

2204 0x00002588: ("DNS_ERROR_ZONE_CREATION_FAILED", "DNS zone creation failed."),

2205 0x00002589: ("DNS_ERROR_ZONE_ALREADY_EXISTS", "DNS zone already exists."),

2206 0x0000258a: ("DNS_ERROR_AUTOZONE_ALREADY_EXISTS", "DNS automatic zone already exists."),

2207 0x0000258b: ("DNS_ERROR_INVALID_ZONE_TYPE", "Invalid DNS zone type."),

2208 0x0000258c: ("DNS_ERROR_SECONDARY_REQUIRES_MASTER_IP", "Secondary DNS zone requires master IP address."),

2209 0x0000258d: ("DNS_ERROR_ZONE_NOT_SECONDARY", "DNS zone not secondary."),

2210 0x0000258e: ("DNS_ERROR_NEED_SECONDARY_ADDRESSES", "Need secondary IP address."),

2211 0x0000258f: ("DNS_ERROR_WINS_INIT_FAILED", "WINS initialization failed."),

2212 0x00002590: ("DNS_ERROR_NEED_WINS_SERVERS", "Need WINS servers."),

2213 0x00002591: ("DNS_ERROR_NBSTAT_INIT_FAILED", "NBTSTAT initialization call failed."),

2214 0x00002592: ("DNS_ERROR_SOA_DELETE_INVALID", "Invalid delete of start of authority (SOA)"),

2215 0x00002593: ("DNS_ERROR_FORWARDER_ALREADY_EXISTS", "A conditional forwarding zone already exists for that name."),

2216 0x00002594: ("DNS_ERROR_ZONE_REQUIRES_MASTER_IP", "This zone must be configured with one or more master DNS server IP addresses."),

2217 0x00002595: ("DNS_ERROR_ZONE_IS_SHUTDOWN", "The operation cannot be performed because this zone is shut down."),

2218 0x00002596: ("DNS_ERROR_ZONE_LOCKED_FOR_SIGNING", "This operation cannot be performed because the zone is currently being signed. Please try again later."),

2219 0x000025b3: ("DNS_ERROR_PRIMARY_REQUIRES_DATAFILE", "Primary DNS zone requires datafile."),

2220 0x000025b4: ("DNS_ERROR_INVALID_DATAFILE_NAME", "Invalid datafile name for DNS zone."),

2221 0x000025b5: ("DNS_ERROR_DATAFILE_OPEN_FAILURE", "Failed to open datafile for DNS zone."),

2222 0x000025b6: ("DNS_ERROR_FILE_WRITEBACK_FAILED", "Failed to write datafile for DNS zone."),

2223 0x000025b7: ("DNS_ERROR_DATAFILE_PARSING", "Failure while reading datafile for DNS zone."),

2224 0x000025e5: ("DNS_ERROR_RECORD_DOES_NOT_EXIST", "DNS record does not exist."),

2225 0x000025e6: ("DNS_ERROR_RECORD_FORMAT", "DNS record format error."),

2226 0x000025e7: ("DNS_ERROR_NODE_CREATION_FAILED", "Node creation failure in DNS."),

2227 0x000025e8: ("DNS_ERROR_UNKNOWN_RECORD_TYPE", "Unknown DNS record type."),

2228 0x000025e9: ("DNS_ERROR_RECORD_TIMED_OUT", "DNS record timed out."),

2229 0x000025ea: ("DNS_ERROR_NAME_NOT_IN_ZONE", "Name not in DNS zone."),

2230 0x000025eb: ("DNS_ERROR_CNAME_LOOP", "CNAME loop detected."),

2231 0x000025ec: ("DNS_ERROR_NODE_IS_CNAME", "Node is a CNAME DNS record."),

2232 0x000025ed: ("DNS_ERROR_CNAME_COLLISION", "A CNAME record already exists for given name."),

2233 0x000025ee: ("DNS_ERROR_RECORD_ONLY_AT_ZONE_ROOT", "Record only at DNS zone root."),

2234 0x000025ef: ("DNS_ERROR_RECORD_ALREADY_EXISTS", "DNS record already exists."),

2235 0x000025f0: ("DNS_ERROR_SECONDARY_DATA", "Secondary DNS zone data error."),

2236 0x000025f1: ("DNS_ERROR_NO_CREATE_CACHE_DATA", "Could not create DNS cache data."),

2237 0x000025f2: ("DNS_ERROR_NAME_DOES_NOT_EXIST", "DNS name does not exist."),

2238 0x000025f3: ("DNS_WARNING_PTR_CREATE_FAILED", "Could not create pointer (PTR) record."),

2239 0x000025f4: ("DNS_WARNING_DOMAIN_UNDELETED", "DNS domain was undeleted."),

2240 0x000025f5: ("DNS_ERROR_DS_UNAVAILABLE", "The directory service is unavailable."),

2241 0x000025f6: ("DNS_ERROR_DS_ZONE_ALREADY_EXISTS", "DNS zone already exists in the directory service."),

2242 0x000025f7: ("DNS_ERROR_NO_BOOTFILE_IF_DS_ZONE", "DNS server not creating or reading the boot file for the directory service integrated DNS zone."),

2243 0x000025f8: ("DNS_ERROR_NODE_IS_DNAME", "Node is a DNAME DNS record."),

2244 0x000025f9: ("DNS_ERROR_DNAME_COLLISION", "A DNAME record already exists for given name."),

2245 0x000025fa: ("DNS_ERROR_ALIAS_LOOP", "An alias loop has been detected with either CNAME or DNAME records."),

2246 0x00002617: ("DNS_INFO_AXFR_COMPLETE", "DNS AXFR (zone transfer) complete."),

2247 0x00002618: ("DNS_ERROR_AXFR", "DNS zone transfer failed."),

2248 0x00002619: ("DNS_INFO_ADDED_LOCAL_WINS", "Added local WINS server."),

2249 0x00002649: ("DNS_STATUS_CONTINUE_NEEDED", "Secure update call needs to continue update request."),

2250 0x0000267b: ("DNS_ERROR_NO_TCPIP", "TCP/IP network protocol not installed."),

2251 0x0000267c: ("DNS_ERROR_NO_DNS_SERVERS", "No DNS servers configured for local system."),

2252 0x000026ad: ("DNS_ERROR_DP_DOES_NOT_EXIST", "The specified directory partition does not exist."),

2253 0x000026ae: ("DNS_ERROR_DP_ALREADY_EXISTS", "The specified directory partition already exists."),

2254 0x000026af: ("DNS_ERROR_DP_NOT_ENLISTED", "This DNS server is not enlisted in the specified directory partition."),

2255 0x000026b0: ("DNS_ERROR_DP_ALREADY_ENLISTED", "This DNS server is already enlisted in the specified directory partition."),

2256 0x000026b1: ("DNS_ERROR_DP_NOT_AVAILABLE", "The directory partition is not available at this time. Please wait a few minutes and try again."),

2257 0x000026b2: ("DNS_ERROR_DP_FSMO_ERROR", "The operation failed because the domain naming master FSMO role could not be reached. The domain controller holding the domain naming master FSMO role is down or unable to service the request or is not running Windows Server 2003 or later."),

2258 0x00002714: ("WSAEINTR", "A blocking operation was interrupted by a call to WSACancelBlockingCall."),

2259 0x00002719: ("WSAEBADF", "The file handle supplied is not valid."),

2260 0x0000271d: ("WSAEACCES", "An attempt was made to access a socket in a way forbidden by its access permissions."),

2261 0x0000271e: ("WSAEFAULT", "The system detected an invalid pointer address in attempting to use a pointer argument in a call."),

2262 0x00002726: ("WSAEINVAL", "An invalid argument was supplied."),

2263 0x00002728: ("WSAEMFILE", "Too many open sockets."),

2264 0x00002733: ("WSAEWOULDBLOCK", "A non-blocking socket operation could not be completed immediately."),

2265 0x00002734: ("WSAEINPROGRESS", "A blocking operation is currently executing."),

2266 0x00002735: ("WSAEALREADY", "An operation was attempted on a non-blocking socket that already had an operation in progress."),

2267 0x00002736: ("WSAENOTSOCK", "An operation was attempted on something that is not a socket."),

2268 0x00002737: ("WSAEDESTADDRREQ", "A required address was omitted from an operation on a socket."),

2269 0x00002738: ("WSAEMSGSIZE", "A message sent on a datagram socket was larger than the internal message buffer or some other network limit, or the buffer used to receive a datagram into was smaller than the datagram itself."),

2270 0x00002739: ("WSAEPROTOTYPE", "A protocol was specified in the socket function call that does not support the semantics of the socket type requested."),

2271 0x0000273a: ("WSAENOPROTOOPT", "An unknown, invalid, or unsupported option or level was specified in a getsockopt or setsockopt call."),

2272 0x0000273b: ("WSAEPROTONOSUPPORT", "The requested protocol has not been configured into the system, or no implementation for it exists."),

2273 0x0000273c: ("WSAESOCKTNOSUPPORT", "The support for the specified socket type does not exist in this address family."),

2274 0x0000273d: ("WSAEOPNOTSUPP", "The attempted operation is not supported for the type of object referenced."),

2275 0x0000273e: ("WSAEPFNOSUPPORT", "The protocol family has not been configured into the system or no implementation for it exists."),

2276 0x0000273f: ("WSAEAFNOSUPPORT", "An address incompatible with the requested protocol was used."),

2277 0x00002740: ("WSAEADDRINUSE", "Only one usage of each socket address (protocol/network address/port) is normally permitted."),

2278 0x00002741: ("WSAEADDRNOTAVAIL", "The requested address is not valid in its context."),

2279 0x00002742: ("WSAENETDOWN", "A socket operation encountered a dead network."),

2280 0x00002743: ("WSAENETUNREACH", "A socket operation was attempted to an unreachable network."),

2281 0x00002744: ("WSAENETRESET", "The connection has been broken due to keep-alive activity detecting a failure while the operation was in progress."),

2282 0x00002745: ("WSAECONNABORTED", "An established connection was aborted by the software in your host machine."),

2283 0x00002746: ("WSAECONNRESET", "An existing connection was forcibly closed by the remote host."),

2284 0x00002747: ("WSAENOBUFS", "An operation on a socket could not be performed because the system lacked sufficient buffer space or because a queue was full."),

2285 0x00002748: ("WSAEISCONN", "A connect request was made on an already connected socket."),

2286 0x00002749: ("WSAENOTCONN", "A request to send or receive data was disallowed because the socket is not connected and (when sending on a datagram socket using a sendto call) no address was supplied."),

2287 0x0000274a: ("WSAESHUTDOWN", "A request to send or receive data was disallowed because the socket had already been shut down in that direction with a previous shutdown call."),

2288 0x0000274b: ("WSAETOOMANYREFS", "Too many references to some kernel object."),

2289 0x0000274c: ("WSAETIMEDOUT", "A connection attempt failed because the connected party did not properly respond after a period of time, or established connection failed because connected host has failed to respond."),

2290 0x0000274d: ("WSAECONNREFUSED", "No connection could be made because the target machine actively refused it."),

2291 0x0000274e: ("WSAELOOP", "Cannot translate name."),

2292 0x0000274f: ("WSAENAMETOOLONG", "Name component or name was too long."),

2293 0x00002750: ("WSAEHOSTDOWN", "A socket operation failed because the destination host was down."),

2294 0x00002751: ("WSAEHOSTUNREACH", "A socket operation was attempted to an unreachable host."),

2295 0x00002752: ("WSAENOTEMPTY", "Cannot remove a directory that is not empty."),

2296 0x00002753: ("WSAEPROCLIM", "A Windows Sockets implementation may have a limit on the number of applications that may use it simultaneously."),

2297 0x00002754: ("WSAEUSERS", "Ran out of quota."),

2298 0x00002755: ("WSAEDQUOT", "Ran out of disk quota."),

2299 0x00002756: ("WSAESTALE", "File handle reference is no longer available."),

2300 0x00002757: ("WSAEREMOTE", "Item is not available locally."),

2301 0x0000276b: ("WSASYSNOTREADY", "WSAStartup cannot function at this time because the underlying system it uses to provide network services is currently unavailable."),

2302 0x0000276c: ("WSAVERNOTSUPPORTED", "The Windows Sockets version requested is not supported."),

2303 0x0000276d: ("WSANOTINITIALISED", "Either the application has not called WSAStartup, or WSAStartup failed."),

2304 0x00002775: ("WSAEDISCON", "Returned by WSARecv or WSARecvFrom to indicate the remote party has initiated a graceful shutdown sequence."),

2305 0x00002776: ("WSAENOMORE", "No more results can be returned by WSALookupServiceNext."),

2306 0x00002777: ("WSAECANCELLED", "A call to WSALookupServiceEnd was made while this call was still processing. The call has been canceled."),

2307 0x00002778: ("WSAEINVALIDPROCTABLE", "The procedure call table is invalid."),

2308 0x00002779: ("WSAEINVALIDPROVIDER", "The requested service provider is invalid."),

2309 0x0000277a: ("WSAEPROVIDERFAILEDINIT", "The requested service provider could not be loaded or initialized."),

2310 0x0000277b: ("WSASYSCALLFAILURE", "A system call has failed."),

2311 0x0000277c: ("WSASERVICE_NOT_FOUND", "No such service is known. The service cannot be found in the specified name space."),

2312 0x0000277d: ("WSATYPE_NOT_FOUND", "The specified class was not found."),

2313 0x0000277e: ("WSA_E_NO_MORE", "No more results can be returned by WSALookupServiceNext."),

2314 0x0000277f: ("WSA_E_CANCELLED", "A call to WSALookupServiceEnd was made while this call was still processing. The call has been canceled."),

2315 0x00002780: ("WSAEREFUSED", "A database query failed because it was actively refused."),

2316 0x00002af9: ("WSAHOST_NOT_FOUND", "No such host is known."),

2317 0x00002afa: ("WSATRY_AGAIN", "This is usually a temporary error during hostname resolution and means that the local server did not receive a response from an authoritative server."),

2318 0x00002afb: ("WSANO_RECOVERY", "A non-recoverable error occurred during a database lookup."),

2319 0x00002afc: ("WSANO_DATA", "The requested name is valid, but no data of the requested type was found."),

2320 0x00002afd: ("WSA_QOS_RECEIVERS", "At least one reserve has arrived."),

2321 0x00002afe: ("WSA_QOS_SENDERS", "At least one path has arrived."),

2322 0x00002aff: ("WSA_QOS_NO_SENDERS", "There are no senders."),

2323 0x00002b00: ("WSA_QOS_NO_RECEIVERS", "There are no receivers."),

2324 0x00002b01: ("WSA_QOS_REQUEST_CONFIRMED", "Reserve has been confirmed."),

2325 0x00002b02: ("WSA_QOS_ADMISSION_FAILURE", "Error due to lack of resources."),

2326 0x00002b03: ("WSA_QOS_POLICY_FAILURE", "Rejected for administrative reasons - bad credentials."),

2327 0x00002b04: ("WSA_QOS_BAD_STYLE", "Unknown or conflicting style."),

2328 0x00002b05: ("WSA_QOS_BAD_OBJECT", "Problem with some part of the filterspec or providerspecific buffer in general."),

2329 0x00002b06: ("WSA_QOS_TRAFFIC_CTRL_ERROR", "Problem with some part of the flowspec."),

2330 0x00002b07: ("WSA_QOS_GENERIC_ERROR", "General QOS error."),

2331 0x00002b08: ("WSA_QOS_ESERVICETYPE", "An invalid or unrecognized service type was found in the flowspec."),

2332 0x00002b09: ("WSA_QOS_EFLOWSPEC", "An invalid or inconsistent flowspec was found in the QOS structure."),

2333 0x00002b0a: ("WSA_QOS_EPROVSPECBUF", "Invalid QOS provider-specific buffer."),

2334 0x00002b0b: ("WSA_QOS_EFILTERSTYLE", "An invalid QOS filter style was used."),

2335 0x00002b0c: ("WSA_QOS_EFILTERTYPE", "An invalid QOS filter type was used."),

2336 0x00002b0d: ("WSA_QOS_EFILTERCOUNT", "An incorrect number of QOS FILTERSPECs were specified in the FLOWDESCRIPTOR."),

2337 0x00002b0e: ("WSA_QOS_EOBJLENGTH", "An object with an invalid ObjectLength field was specified in the QOS provider-specific buffer."),

2338 0x00002b0f: ("WSA_QOS_EFLOWCOUNT", "An incorrect number of flow descriptors was specified in the QOS structure."),

2339 0x00002b10: ("WSA_QOS_EUNKOWNPSOBJ", "An unrecognized object was found in the QOS provider-specific buffer."),

2340 0x00002b11: ("WSA_QOS_EPOLICYOBJ", "An invalid policy object was found in the QOS provider-specific buffer."),

2341 0x00002b12: ("WSA_QOS_EFLOWDESC", "An invalid QOS flow descriptor was found in the flow descriptor list."),

2342 0x00002b13: ("WSA_QOS_EPSFLOWSPEC", "An invalid or inconsistent flowspec was found in the QOS provider specific buffer."),

2343 0x00002b14: ("WSA_QOS_EPSFILTERSPEC", "An invalid FILTERSPEC was found in the QOS provider-specific buffer."),

2344 0x00002b15: ("WSA_QOS_ESDMODEOBJ", "An invalid shape discard mode object was found in the QOS provider specific buffer."),

2345 0x00002b16: ("WSA_QOS_ESHAPERATEOBJ", "An invalid shaping rate object was found in the QOS provider-specific buffer."),

2346 0x00002b17: ("WSA_QOS_RESERVED_PETYPE", "A reserved policy element was found in the QOS provider-specific buffer."),

2347 0x00002b18: ("WSA_SECURE_HOST_NOT_FOUND", "No such host is known securely."),

2348 0x00002b19: ("WSA_IPSEC_NAME_POLICY_ERROR", "Name based IPSEC policy could not be added."),

2349 0x000032c8: ("ERROR_IPSEC_QM_POLICY_EXISTS", "The specified quick mode policy already exists."),

2350 0x000032c9: ("ERROR_IPSEC_QM_POLICY_NOT_FOUND", "The specified quick mode policy was not found."),

2351 0x000032ca: ("ERROR_IPSEC_QM_POLICY_IN_USE", "The specified quick mode policy is being used."),

2352 0x000032cb: ("ERROR_IPSEC_MM_POLICY_EXISTS", "The specified main mode policy already exists."),

2353 0x000032cc: ("ERROR_IPSEC_MM_POLICY_NOT_FOUND", "The specified main mode policy was not found"),

2354 0x000032cd: ("ERROR_IPSEC_MM_POLICY_IN_USE", "The specified main mode policy is being used."),

2355 0x000032ce: ("ERROR_IPSEC_MM_FILTER_EXISTS", "The specified main mode filter already exists."),

2356 0x000032cf: ("ERROR_IPSEC_MM_FILTER_NOT_FOUND", "The specified main mode filter was not found."),

2357 0x000032d0: ("ERROR_IPSEC_TRANSPORT_FILTER_EXISTS", "The specified transport mode filter already exists."),

2358 0x000032d1: ("ERROR_IPSEC_TRANSPORT_FILTER_NOT_FOUND", "The specified transport mode filter does not exist."),

2359 0x000032d2: ("ERROR_IPSEC_MM_AUTH_EXISTS", "The specified main mode authentication list exists."),

2360 0x000032d3: ("ERROR_IPSEC_MM_AUTH_NOT_FOUND", "The specified main mode authentication list was not found."),

2361 0x000032d4: ("ERROR_IPSEC_MM_AUTH_IN_USE", "The specified main mode authentication list is being used."),

2362 0x000032d5: ("ERROR_IPSEC_DEFAULT_MM_POLICY_NOT_FOUND", "The specified default main mode policy was not found."),

2363 0x000032d6: ("ERROR_IPSEC_DEFAULT_MM_AUTH_NOT_FOUND", "The specified default main mode authentication list was not found."),

2364 0x000032d7: ("ERROR_IPSEC_DEFAULT_QM_POLICY_NOT_FOUND", "The specified default quick mode policy was not found."),

2365 0x000032d8: ("ERROR_IPSEC_TUNNEL_FILTER_EXISTS", "The specified tunnel mode filter exists."),

2366 0x000032d9: ("ERROR_IPSEC_TUNNEL_FILTER_NOT_FOUND", "The specified tunnel mode filter was not found."),

2367 0x000032da: ("ERROR_IPSEC_MM_FILTER_PENDING_DELETION", "The Main Mode filter is pending deletion."),

2368 0x000032db: ("ERROR_IPSEC_TRANSPORT_FILTER_PENDING_DELETION", "The transport filter is pending deletion."),

2369 0x000032dc: ("ERROR_IPSEC_TUNNEL_FILTER_PENDING_DELETION", "The tunnel filter is pending deletion."),

2370 0x000032dd: ("ERROR_IPSEC_MM_POLICY_PENDING_DELETION", "The Main Mode policy is pending deletion."),

2371 0x000032de: ("ERROR_IPSEC_MM_AUTH_PENDING_DELETION", "The Main Mode authentication bundle is pending deletion."),

2372 0x000032df: ("ERROR_IPSEC_QM_POLICY_PENDING_DELETION", "The Quick Mode policy is pending deletion."),

2373 0x000032e0: ("WARNING_IPSEC_MM_POLICY_PRUNED", "The Main Mode policy was successfully added, but some of the requested offers are not supported."),

2374 0x000032e1: ("WARNING_IPSEC_QM_POLICY_PRUNED", "The Quick Mode policy was successfully added, but some of the requested offers are not supported."),

2375 0x000035e8: ("ERROR_IPSEC_IKE_NEG_STATUS_BEGIN", " ERROR_IPSEC_IKE_NEG_STATUS_BEGIN"),

2376 0x000035e9: ("ERROR_IPSEC_IKE_AUTH_FAIL", "IKE authentication credentials are unacceptable"),

2377 0x000035ea: ("ERROR_IPSEC_IKE_ATTRIB_FAIL", "IKE security attributes are unacceptable"),

2378 0x000035eb: ("ERROR_IPSEC_IKE_NEGOTIATION_PENDING", "IKE Negotiation in progress"),

2379 0x000035ec: ("ERROR_IPSEC_IKE_GENERAL_PROCESSING_ERROR", "General processing error"),

2380 0x000035ed: ("ERROR_IPSEC_IKE_TIMED_OUT", "Negotiation timed out"),

2381 0x000035ee: ("ERROR_IPSEC_IKE_NO_CERT", "IKE failed to find valid machine certificate. Contact your Network Security Administrator about installing a valid certificate in the appropriate Certificate Store."),

2382 0x000035ef: ("ERROR_IPSEC_IKE_SA_DELETED", "IKE SA deleted by peer before establishment completed"),

2383 0x000035f0: ("ERROR_IPSEC_IKE_SA_REAPED", "IKE SA deleted before establishment completed"),

2384 0x000035f1: ("ERROR_IPSEC_IKE_MM_ACQUIRE_DROP", "Negotiation request sat in Queue too long"),

2385 0x000035f2: ("ERROR_IPSEC_IKE_QM_ACQUIRE_DROP", "Negotiation request sat in Queue too long"),

2386 0x000035f3: ("ERROR_IPSEC_IKE_QUEUE_DROP_MM", "Negotiation request sat in Queue too long"),

2387 0x000035f4: ("ERROR_IPSEC_IKE_QUEUE_DROP_NO_MM", "Negotiation request sat in Queue too long"),

2388 0x000035f5: ("ERROR_IPSEC_IKE_DROP_NO_RESPONSE", "No response from peer"),

2389 0x000035f6: ("ERROR_IPSEC_IKE_MM_DELAY_DROP", "Negotiation took too long"),

2390 0x000035f7: ("ERROR_IPSEC_IKE_QM_DELAY_DROP", "Negotiation took too long"),

2391 0x000035f8: ("ERROR_IPSEC_IKE_ERROR", "Unknown error occurred"),

2392 0x000035f9: ("ERROR_IPSEC_IKE_CRL_FAILED", "Certificate Revocation Check failed"),

2393 0x000035fa: ("ERROR_IPSEC_IKE_INVALID_KEY_USAGE", "Invalid certificate key usage"),

2394 0x000035fb: ("ERROR_IPSEC_IKE_INVALID_CERT_TYPE", "Invalid certificate type"),

2395 0x000035fc: ("ERROR_IPSEC_IKE_NO_PRIVATE_KEY", "IKE negotiation failed because the machine certificate used does not have a private key. IPsec certificates require a private key. Contact your Network Security administrator about replacing with a certificate that has a private key."),

2396 0x000035fd: ("ERROR_IPSEC_IKE_SIMULTANEOUS_REKEY", "Simultaneous rekeys were detected."),

2397 0x000035fe: ("ERROR_IPSEC_IKE_DH_FAIL", "Failure in Diffie-Hellman computation"),

2398 0x000035ff: ("ERROR_IPSEC_IKE_CRITICAL_PAYLOAD_NOT_RECOGNIZED", "Don't know how to process critical payload"),

2399 0x00003600: ("ERROR_IPSEC_IKE_INVALID_HEADER", "Invalid header"),

2400 0x00003601: ("ERROR_IPSEC_IKE_NO_POLICY", "No policy configured"),

2401 0x00003602: ("ERROR_IPSEC_IKE_INVALID_SIGNATURE", "Failed to verify signature"),

2402 0x00003603: ("ERROR_IPSEC_IKE_KERBEROS_ERROR", "Failed to authenticate using Kerberos"),

2403 0x00003604: ("ERROR_IPSEC_IKE_NO_PUBLIC_KEY", "Peer's certificate did not have a public key"),

2404 0x00003605: ("ERROR_IPSEC_IKE_PROCESS_ERR", "Error processing error payload"),

2405 0x00003606: ("ERROR_IPSEC_IKE_PROCESS_ERR_SA", "Error processing SA payload"),

2406 0x00003607: ("ERROR_IPSEC_IKE_PROCESS_ERR_PROP", "Error processing Proposal payload"),

2407 0x00003608: ("ERROR_IPSEC_IKE_PROCESS_ERR_TRANS", "Error processing Transform payload"),

2408 0x00003609: ("ERROR_IPSEC_IKE_PROCESS_ERR_KE", "Error processing KE payload"),

2409 0x0000360a: ("ERROR_IPSEC_IKE_PROCESS_ERR_ID", "Error processing ID payload"),

2410 0x0000360b: ("ERROR_IPSEC_IKE_PROCESS_ERR_CERT", "Error processing Cert payload"),

2411 0x0000360c: ("ERROR_IPSEC_IKE_PROCESS_ERR_CERT_REQ", "Error processing Certificate Request payload"),

2412 0x0000360d: ("ERROR_IPSEC_IKE_PROCESS_ERR_HASH", "Error processing Hash payload"),

2413 0x0000360e: ("ERROR_IPSEC_IKE_PROCESS_ERR_SIG", "Error processing Signature payload"),

2414 0x0000360f: ("ERROR_IPSEC_IKE_PROCESS_ERR_NONCE", "Error processing Nonce payload"),

2415 0x00003610: ("ERROR_IPSEC_IKE_PROCESS_ERR_NOTIFY", "Error processing Notify payload"),

2416 0x00003611: ("ERROR_IPSEC_IKE_PROCESS_ERR_DELETE", "Error processing Delete Payload"),

2417 0x00003612: ("ERROR_IPSEC_IKE_PROCESS_ERR_VENDOR", "Error processing VendorId payload"),

2418 0x00003613: ("ERROR_IPSEC_IKE_INVALID_PAYLOAD", "Invalid payload received"),

2419 0x00003614: ("ERROR_IPSEC_IKE_LOAD_SOFT_SA", "Soft SA loaded"),

2420 0x00003615: ("ERROR_IPSEC_IKE_SOFT_SA_TORN_DOWN", "Soft SA torn down"),

2421 0x00003616: ("ERROR_IPSEC_IKE_INVALID_COOKIE", "Invalid cookie received."),

2422 0x00003617: ("ERROR_IPSEC_IKE_NO_PEER_CERT", "Peer failed to send valid machine certificate"),

2423 0x00003618: ("ERROR_IPSEC_IKE_PEER_CRL_FAILED", "Certification Revocation check of peer's certificate failed"),

2424 0x00003619: ("ERROR_IPSEC_IKE_POLICY_CHANGE", "New policy invalidated SAs formed with old policy"),

2425 0x0000361a: ("ERROR_IPSEC_IKE_NO_MM_POLICY", "There is no available Main Mode IKE policy."),

2426 0x0000361b: ("ERROR_IPSEC_IKE_NOTCBPRIV", "Failed to enabled TCB privilege."),

2427 0x0000361c: ("ERROR_IPSEC_IKE_SECLOADFAIL", "Failed to load SECURITY.DLL."),

2428 0x0000361d: ("ERROR_IPSEC_IKE_FAILSSPINIT", "Failed to obtain security function table dispatch address from SSPI."),

2429 0x0000361e: ("ERROR_IPSEC_IKE_FAILQUERYSSP", "Failed to query Kerberos package to obtain max token size."),

2430 0x0000361f: ("ERROR_IPSEC_IKE_SRVACQFAIL", "Failed to obtain Kerberos server credentials for ISAKMP/ERROR_IPSEC_IKE service. Kerberos authentication will not function. The most likely reason for this is lack of domain membership. This is normal if your computer is a member of a workgroup."),

2431 0x00003620: ("ERROR_IPSEC_IKE_SRVQUERYCRED", "Failed to determine SSPI principal name for ISAKMP/ERROR_IPSEC_IKE service (QueryCredentialsAttributes)."),

2432 0x00003621: ("ERROR_IPSEC_IKE_GETSPIFAIL", "Failed to obtain new SPI for the inbound SA from IPsec driver. The most common cause for this is that the driver does not have the correct filter. Check your policy to verify the filters."),

2433 0x00003622: ("ERROR_IPSEC_IKE_INVALID_FILTER", "Given filter is invalid"),

2434 0x00003623: ("ERROR_IPSEC_IKE_OUT_OF_MEMORY", "Memory allocation failed."),

2435 0x00003624: ("ERROR_IPSEC_IKE_ADD_UPDATE_KEY_FAILED", "Failed to add Security Association to IPsec Driver. The most common cause for this is if the IKE negotiation took too long to complete. If the problem persists, reduce the load on the faulting machine."),

2436 0x00003625: ("ERROR_IPSEC_IKE_INVALID_POLICY", "Invalid policy"),

2437 0x00003626: ("ERROR_IPSEC_IKE_UNKNOWN_DOI", "Invalid DOI"),

2438 0x00003627: ("ERROR_IPSEC_IKE_INVALID_SITUATION", "Invalid situation"),

2439 0x00003628: ("ERROR_IPSEC_IKE_DH_FAILURE", "Diffie-Hellman failure"),

2440 0x00003629: ("ERROR_IPSEC_IKE_INVALID_GROUP", "Invalid Diffie-Hellman group"),

2441 0x0000362a: ("ERROR_IPSEC_IKE_ENCRYPT", "Error encrypting payload"),

2442 0x0000362b: ("ERROR_IPSEC_IKE_DECRYPT", "Error decrypting payload"),

2443 0x0000362c: ("ERROR_IPSEC_IKE_POLICY_MATCH", "Policy match error"),

2444 0x0000362d: ("ERROR_IPSEC_IKE_UNSUPPORTED_ID", "Unsupported ID"),

2445 0x0000362e: ("ERROR_IPSEC_IKE_INVALID_HASH", "Hash verification failed"),

2446 0x0000362f: ("ERROR_IPSEC_IKE_INVALID_HASH_ALG", "Invalid hash algorithm"),

2447 0x00003630: ("ERROR_IPSEC_IKE_INVALID_HASH_SIZE", "Invalid hash size"),

2448 0x00003631: ("ERROR_IPSEC_IKE_INVALID_ENCRYPT_ALG", "Invalid encryption algorithm"),

2449 0x00003632: ("ERROR_IPSEC_IKE_INVALID_AUTH_ALG", "Invalid authentication algorithm"),

2450 0x00003633: ("ERROR_IPSEC_IKE_INVALID_SIG", "Invalid certificate signature"),

2451 0x00003634: ("ERROR_IPSEC_IKE_LOAD_FAILED", "Load failed"),

2452 0x00003635: ("ERROR_IPSEC_IKE_RPC_DELETE", "Deleted via RPC call"),

2453 0x00003636: ("ERROR_IPSEC_IKE_BENIGN_REINIT", "Temporary state created to perform reinitialization. This is not a real failure."),

2454 0x00003637: ("ERROR_IPSEC_IKE_INVALID_RESPONDER_LIFETIME_NOTIFY", "The lifetime value received in the Responder Lifetime Notify is below the Windows 2000 configured minimum value. Please fix the policy on the peer machine."),

2455 0x00003638: ("ERROR_IPSEC_IKE_INVALID_MAJOR_VERSION", "The recipient cannot handle version of IKE specified in the header."),

2456 0x00003639: ("ERROR_IPSEC_IKE_INVALID_CERT_KEYLEN", "Key length in certificate is too small for configured security requirements."),

2457 0x0000363a: ("ERROR_IPSEC_IKE_MM_LIMIT", "Max number of established MM SAs to peer exceeded."),

2458 0x0000363b: ("ERROR_IPSEC_IKE_NEGOTIATION_DISABLED", "IKE received a policy that disables negotiation."),

2459 0x0000363c: ("ERROR_IPSEC_IKE_QM_LIMIT", "Reached maximum quick mode limit for the main mode. New main mode will be started."),

2460 0x0000363d: ("ERROR_IPSEC_IKE_MM_EXPIRED", "Main mode SA lifetime expired or peer sent a main mode delete."),

2461 0x0000363e: ("ERROR_IPSEC_IKE_PEER_MM_ASSUMED_INVALID", "Main mode SA assumed to be invalid because peer stopped responding."),

2462 0x0000363f: ("ERROR_IPSEC_IKE_CERT_CHAIN_POLICY_MISMATCH", "Certificate doesn't chain to a trusted root in IPsec policy."),

2463 0x00003640: ("ERROR_IPSEC_IKE_UNEXPECTED_MESSAGE_ID", "Received unexpected message ID."),

2464 0x00003641: ("ERROR_IPSEC_IKE_INVALID_AUTH_PAYLOAD", "Received invalid authentication offers."),

2465 0x00003642: ("ERROR_IPSEC_IKE_DOS_COOKIE_SENT", "Sent DoS cookie notify to initiator."),

2466 0x00003643: ("ERROR_IPSEC_IKE_SHUTTING_DOWN", "IKE service is shutting down."),

2467 0x00003644: ("ERROR_IPSEC_IKE_CGA_AUTH_FAILED", "Could not verify binding between CGA address and certificate."),

2468 0x00003645: ("ERROR_IPSEC_IKE_PROCESS_ERR_NATOA", "Error processing NatOA payload."),

2469 0x00003646: ("ERROR_IPSEC_IKE_INVALID_MM_FOR_QM", "Parameters of the main mode are invalid for this quick mode."),

2470 0x00003647: ("ERROR_IPSEC_IKE_QM_EXPIRED", "Quick mode SA was expired by IPsec driver."),

2471 0x00003648: ("ERROR_IPSEC_IKE_TOO_MANY_FILTERS", "Too many dynamically added IKEEXT filters were detected."),

2472 0x00003649: ("ERROR_IPSEC_IKE_NEG_STATUS_END", " ERROR_IPSEC_IKE_NEG_STATUS_END"),

2473 0x0000364a: ("ERROR_IPSEC_IKE_KILL_DUMMY_NAP_TUNNEL", "NAP reauth succeeded and must delete the dummy NAP IKEv2 tunnel."),

2474 0x0000364b: ("ERROR_IPSEC_IKE_INNER_IP_ASSIGNMENT_FAILURE", "Error in assigning inner IP address to initiator in tunnel mode."),

2475 0x0000364c: ("ERROR_IPSEC_IKE_REQUIRE_CP_PAYLOAD_MISSING", "Require configuration payload missing."),

2476 0x0000364d: ("ERROR_IPSEC_KEY_MODULE_IMPERSONATION_NEGOTIATION_PENDING", "A negotiation running as the security principle who issued the connection is in progress"),

2477 0x0000364e: ("ERROR_IPSEC_IKE_COEXISTENCE_SUPPRESS", "SA was deleted due to IKEv1/AuthIP co-existence suppress check."),

2478 0x0000364f: ("ERROR_IPSEC_IKE_RATELIMIT_DROP", "Incoming SA request was dropped due to peer IP address rate limiting."),

2479 0x00003650: ("ERROR_IPSEC_IKE_PEER_DOESNT_SUPPORT_MOBIKE", "Peer does not support MOBIKE."),

2480 0x00003651: ("ERROR_IPSEC_IKE_AUTHORIZATION_FAILURE", "SA establishment is not authorized."),

2481 0x00003652: ("ERROR_IPSEC_IKE_STRONG_CRED_AUTHORIZATION_FAILURE", "SA establishment is not authorized because there is not a sufficiently strong PKINIT-based credential."),

2482 0x00003653: ("ERROR_IPSEC_IKE_AUTHORIZATION_FAILURE_WITH_OPTIONAL_RETRY", "SA establishment is not authorized. You may need to enter updated or different credentials such as a smartcard."),

2483 0x00003654: ("ERROR_IPSEC_IKE_STRONG_CRED_AUTHORIZATION_AND_CERTMAP_FAILURE", "SA establishment is not authorized because there is not a sufficiently strong PKINIT-based credential. This might be related to certificate-to-account mapping failure for the SA."),

2484 0x00003655: ("ERROR_IPSEC_IKE_NEG_STATUS_EXTENDED_END", " ERROR_IPSEC_IKE_NEG_STATUS_EXTENDED_END"),

2485 0x00003656: ("ERROR_IPSEC_BAD_SPI", "The SPI in the packet does not match a valid IPsec SA."),

2486 0x00003657: ("ERROR_IPSEC_SA_LIFETIME_EXPIRED", "Packet was received on an IPsec SA whose lifetime has expired."),

2487 0x00003658: ("ERROR_IPSEC_WRONG_SA", "Packet was received on an IPsec SA that does not match the packet characteristics."),

2488 0x00003659: ("ERROR_IPSEC_REPLAY_CHECK_FAILED", "Packet sequence number replay check failed."),

2489 0x0000365a: ("ERROR_IPSEC_INVALID_PACKET", "IPsec header and/or trailer in the packet is invalid."),

2490 0x0000365b: ("ERROR_IPSEC_INTEGRITY_CHECK_FAILED", "IPsec integrity check failed."),

2491 0x0000365c: ("ERROR_IPSEC_CLEAR_TEXT_DROP", "IPsec dropped a clear text packet."),

2492 0x0000365d: ("ERROR_IPSEC_AUTH_FIREWALL_DROP", "IPsec dropped an incoming ESP packet in authenticated firewall mode. This drop is benign."),

2493 0x0000365e: ("ERROR_IPSEC_THROTTLE_DROP", "IPsec dropped a packet due to DoS throttling."),

2494 0x00003665: ("ERROR_IPSEC_DOSP_BLOCK", "IPsec DoS Protection matched an explicit block rule."),

2495 0x00003666: ("ERROR_IPSEC_DOSP_RECEIVED_MULTICAST", "IPsec DoS Protection received an IPsec specific multicast packet which is not allowed."),

2496 0x00003667: ("ERROR_IPSEC_DOSP_INVALID_PACKET", "IPsec DoS Protection received an incorrectly formatted packet."),

2497 0x00003668: ("ERROR_IPSEC_DOSP_STATE_LOOKUP_FAILED", "IPsec DoS Protection failed to look up state."),

2498 0x00003669: ("ERROR_IPSEC_DOSP_MAX_ENTRIES", "IPsec DoS Protection failed to create state because the maximum number of entries allowed by policy has been reached."),

2499 0x0000366a: ("ERROR_IPSEC_DOSP_KEYMOD_NOT_ALLOWED", "IPsec DoS Protection received an IPsec negotiation packet for a keying module which is not allowed by policy."),

2500 0x0000366b: ("ERROR_IPSEC_DOSP_NOT_INSTALLED", "IPsec DoS Protection has not been enabled."),

2501 0x0000366c: ("ERROR_IPSEC_DOSP_MAX_PER_IP_RATELIMIT_QUEUES", "IPsec DoS Protection failed to create a per internal IP rate limit queue because the maximum number of queues allowed by policy has been reached."),

2502 0x000036b0: ("ERROR_SXS_SECTION_NOT_FOUND", "The requested section was not present in the activation context."),

2503 0x000036b1: ("ERROR_SXS_CANT_GEN_ACTCTX", "The application has failed to start because its side-by-side configuration is incorrect. Please see the application event log or use the command-line sxstrace.exe tool for more detail."),

2504 0x000036b2: ("ERROR_SXS_INVALID_ACTCTXDATA_FORMAT", "The application binding data format is invalid."),

2505 0x000036b3: ("ERROR_SXS_ASSEMBLY_NOT_FOUND", "The referenced assembly is not installed on your system."),

2506 0x000036b4: ("ERROR_SXS_MANIFEST_FORMAT_ERROR", "The manifest file does not begin with the required tag and format information."),

2507 0x000036b5: ("ERROR_SXS_MANIFEST_PARSE_ERROR", "The manifest file contains one or more syntax errors."),

2508 0x000036b6: ("ERROR_SXS_ACTIVATION_CONTEXT_DISABLED", "The application attempted to activate a disabled activation context."),

2509 0x000036b7: ("ERROR_SXS_KEY_NOT_FOUND", "The requested lookup key was not found in any active activation context."),

2510 0x000036b8: ("ERROR_SXS_VERSION_CONFLICT", "A component version required by the application conflicts with another component version already active."),

2511 0x000036b9: ("ERROR_SXS_WRONG_SECTION_TYPE", "The type requested activation context section does not match the query API used."),

2512 0x000036ba: ("ERROR_SXS_THREAD_QUERIES_DISABLED", "Lack of system resources has required isolated activation to be disabled for the current thread of execution."),

2513 0x000036bb: ("ERROR_SXS_PROCESS_DEFAULT_ALREADY_SET", "An attempt to set the process default activation context failed because the process default activation context was already set."),

2514 0x000036bc: ("ERROR_SXS_UNKNOWN_ENCODING_GROUP", "The encoding group identifier specified is not recognized."),

2515 0x000036bd: ("ERROR_SXS_UNKNOWN_ENCODING", "The encoding requested is not recognized."),

2516 0x000036be: ("ERROR_SXS_INVALID_XML_NAMESPACE_URI", "The manifest contains a reference to an invalid URI."),

2517 0x000036bf: ("ERROR_SXS_ROOT_MANIFEST_DEPENDENCY_NOT_INSTALLED", "The application manifest contains a reference to a dependent assembly which is not installed"),

2518 0x000036c0: ("ERROR_SXS_LEAF_MANIFEST_DEPENDENCY_NOT_INSTALLED", "The manifest for an assembly used by the application has a reference to a dependent assembly which is not installed"),

2519 0x000036c1: ("ERROR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE", "The manifest contains an attribute for the assembly identity which is not valid."),

2520 0x000036c2: ("ERROR_SXS_MANIFEST_MISSING_REQUIRED_DEFAULT_NAMESPACE", "The manifest is missing the required default namespace specification on the assembly element."),

2521 0x000036c3: ("ERROR_SXS_MANIFEST_INVALID_REQUIRED_DEFAULT_NAMESPACE", "The manifest has a default namespace specified on the assembly element but its value is not 'urn:schemas-microsoft-com:asm.v1'."),

2522 0x000036c4: ("ERROR_SXS_PRIVATE_MANIFEST_CROSS_PATH_WITH_REPARSE_POINT", "The private manifest probed has crossed a path with an unsupported reparse point."),

2523 0x000036c5: ("ERROR_SXS_DUPLICATE_DLL_NAME", "Two or more components referenced directly or indirectly by the application manifest have files by the same name."),

2524 0x000036c6: ("ERROR_SXS_DUPLICATE_WINDOWCLASS_NAME", "Two or more components referenced directly or indirectly by the application manifest have window classes with the same name."),

2525 0x000036c7: ("ERROR_SXS_DUPLICATE_CLSID", "Two or more components referenced directly or indirectly by the application manifest have the same COM server CLSIDs."),

2526 0x000036c8: ("ERROR_SXS_DUPLICATE_IID", "Two or more components referenced directly or indirectly by the application manifest have proxies for the same COM interface IIDs."),

2527 0x000036c9: ("ERROR_SXS_DUPLICATE_TLBID", "Two or more components referenced directly or indirectly by the application manifest have the same COM type library TLBIDs."),

2528 0x000036ca: ("ERROR_SXS_DUPLICATE_PROGID", "Two or more components referenced directly or indirectly by the application manifest have the same COM ProgIDs."),

2529 0x000036cb: ("ERROR_SXS_DUPLICATE_ASSEMBLY_NAME", "Two or more components referenced directly or indirectly by the application manifest are different versions of the same component which is not permitted."),

2530 0x000036cc: ("ERROR_SXS_FILE_HASH_MISMATCH", "A component's file does not match the verification information present in the component manifest."),

2531 0x000036cd: ("ERROR_SXS_POLICY_PARSE_ERROR", "The policy manifest contains one or more syntax errors."),

2532 0x000036ce: ("ERROR_SXS_XML_E_MISSINGQUOTE", "Manifest Parse Error : A string literal was expected, but no opening quote character was found."),

2533 0x000036cf: ("ERROR_SXS_XML_E_COMMENTSYNTAX", "Manifest Parse Error : Incorrect syntax was used in a comment."),

2534 0x000036d0: ("ERROR_SXS_XML_E_BADSTARTNAMECHAR", "Manifest Parse Error : A name was started with an invalid character."),

2535 0x000036d1: ("ERROR_SXS_XML_E_BADNAMECHAR", "Manifest Parse Error : A name contained an invalid character."),

2536 0x000036d2: ("ERROR_SXS_XML_E_BADCHARINSTRING", "Manifest Parse Error : A string literal contained an invalid character."),

2537 0x000036d3: ("ERROR_SXS_XML_E_XMLDECLSYNTAX", "Manifest Parse Error : Invalid syntax for an xml declaration."),

2538 0x000036d4: ("ERROR_SXS_XML_E_BADCHARDATA", "Manifest Parse Error : An Invalid character was found in text content."),

2539 0x000036d5: ("ERROR_SXS_XML_E_MISSINGWHITESPACE", "Manifest Parse Error : Required white space was missing."),

2540 0x000036d6: ("ERROR_SXS_XML_E_EXPECTINGTAGEND", "Manifest Parse Error : The character '>' was expected."),

2541 0x000036d7: ("ERROR_SXS_XML_E_MISSINGSEMICOLON", "Manifest Parse Error : A semi colon character was expected."),

2542 0x000036d8: ("ERROR_SXS_XML_E_UNBALANCEDPAREN", "Manifest Parse Error : Unbalanced parentheses."),

2543 0x000036d9: ("ERROR_SXS_XML_E_INTERNALERROR", "Manifest Parse Error : Internal error."),

2544 0x000036da: ("ERROR_SXS_XML_E_UNEXPECTED_WHITESPACE", "Manifest Parse Error : Whitespace is not allowed at this location."),

2545 0x000036db: ("ERROR_SXS_XML_E_INCOMPLETE_ENCODING", "Manifest Parse Error : End of file reached in invalid state for current encoding."),

2546 0x000036dc: ("ERROR_SXS_XML_E_MISSING_PAREN", "Manifest Parse Error : Missing parenthesis."),

2547 0x000036dd: ("ERROR_SXS_XML_E_EXPECTINGCLOSEQUOTE", "Manifest Parse Error : A single or double closing quote character (\' or \") is missing."),

2548 0x000036de: ("ERROR_SXS_XML_E_MULTIPLE_COLONS", "Manifest Parse Error : Multiple colons are not allowed in a name."),

2549 0x000036df: ("ERROR_SXS_XML_E_INVALID_DECIMAL", "Manifest Parse Error : Invalid character for decimal digit."),

2550 0x000036e0: ("ERROR_SXS_XML_E_INVALID_HEXIDECIMAL", "Manifest Parse Error : Invalid character for hexadecimal digit."),

2551 0x000036e1: ("ERROR_SXS_XML_E_INVALID_UNICODE", "Manifest Parse Error : Invalid unicode character value for this platform."),

2552 0x000036e2: ("ERROR_SXS_XML_E_WHITESPACEORQUESTIONMARK", "Manifest Parse Error : Expecting whitespace or '?'."),

2553 0x000036e3: ("ERROR_SXS_XML_E_UNEXPECTEDENDTAG", "Manifest Parse Error : End tag was not expected at this location."),

2554 0x000036e4: ("ERROR_SXS_XML_E_UNCLOSEDTAG", "Manifest Parse Error : The following tags were not closed: %1."),

2555 0x000036e5: ("ERROR_SXS_XML_E_DUPLICATEATTRIBUTE", "Manifest Parse Error : Duplicate attribute."),

2556 0x000036e6: ("ERROR_SXS_XML_E_MULTIPLEROOTS", "Manifest Parse Error : Only one top level element is allowed in an XML document."),

2557 0x000036e7: ("ERROR_SXS_XML_E_INVALIDATROOTLEVEL", "Manifest Parse Error : Invalid at the top level of the document."),

2558 0x000036e8: ("ERROR_SXS_XML_E_BADXMLDECL", "Manifest Parse Error : Invalid xml declaration."),

2559 0x000036e9: ("ERROR_SXS_XML_E_MISSINGROOT", "Manifest Parse Error : XML document must have a top level element."),

2560 0x000036ea: ("ERROR_SXS_XML_E_UNEXPECTEDEOF", "Manifest Parse Error : Unexpected end of file."),

2561 0x000036eb: ("ERROR_SXS_XML_E_BADPEREFINSUBSET", "Manifest Parse Error : Parameter entities cannot be used inside markup declarations in an internal subset."),

2562 0x000036ec: ("ERROR_SXS_XML_E_UNCLOSEDSTARTTAG", "Manifest Parse Error : Element was not closed."),

2563 0x000036ed: ("ERROR_SXS_XML_E_UNCLOSEDENDTAG", "Manifest Parse Error : End element was missing the character '>'."),

2564 0x000036ee: ("ERROR_SXS_XML_E_UNCLOSEDSTRING", "Manifest Parse Error : A string literal was not closed."),

2565 0x000036ef: ("ERROR_SXS_XML_E_UNCLOSEDCOMMENT", "Manifest Parse Error : A comment was not closed."),

2566 0x000036f0: ("ERROR_SXS_XML_E_UNCLOSEDDECL", "Manifest Parse Error : A declaration was not closed."),

2567 0x000036f1: ("ERROR_SXS_XML_E_UNCLOSEDCDATA", "Manifest Parse Error : A CDATA section was not closed."),

2568 0x000036f2: ("ERROR_SXS_XML_E_RESERVEDNAMESPACE", "Manifest Parse Error : The namespace prefix is not allowed to start with the reserved string 'xml'."),

2569 0x000036f3: ("ERROR_SXS_XML_E_INVALIDENCODING", "Manifest Parse Error : System does not support the specified encoding."),

2570 0x000036f4: ("ERROR_SXS_XML_E_INVALIDSWITCH", "Manifest Parse Error : Switch from current encoding to specified encoding not supported."),

2571 0x000036f5: ("ERROR_SXS_XML_E_BADXMLCASE", "Manifest Parse Error : The name 'xml' is reserved and must be lower case."),

2572 0x000036f6: ("ERROR_SXS_XML_E_INVALID_STANDALONE", "Manifest Parse Error : The standalone attribute must have the value 'yes' or 'no'."),

2573 0x000036f7: ("ERROR_SXS_XML_E_UNEXPECTED_STANDALONE", "Manifest Parse Error : The standalone attribute cannot be used in external entities."),

2574 0x000036f8: ("ERROR_SXS_XML_E_INVALID_VERSION", "Manifest Parse Error : Invalid version number."),

2575 0x000036f9: ("ERROR_SXS_XML_E_MISSINGEQUALS", "Manifest Parse Error : Missing equals sign between attribute and attribute value."),

2576 0x000036fa: ("ERROR_SXS_PROTECTION_RECOVERY_FAILED", "Assembly Protection Error : Unable to recover the specified assembly."),

2577 0x000036fb: ("ERROR_SXS_PROTECTION_PUBLIC_KEY_TOO_SHORT", "Assembly Protection Error : The public key for an assembly was too short to be allowed."),

2578 0x000036fc: ("ERROR_SXS_PROTECTION_CATALOG_NOT_VALID", "Assembly Protection Error : The catalog for an assembly is not valid, or does not match the assembly's manifest."),

2579 0x000036fd: ("ERROR_SXS_UNTRANSLATABLE_HRESULT", "An HRESULT could not be translated to a corresponding Win32 error code."),

2580 0x000036fe: ("ERROR_SXS_PROTECTION_CATALOG_FILE_MISSING", "Assembly Protection Error : The catalog for an assembly is missing."),

2581 0x000036ff: ("ERROR_SXS_MISSING_ASSEMBLY_IDENTITY_ATTRIBUTE", "The supplied assembly identity is missing one or more attributes which must be present in this context."),

2582 0x00003700: ("ERROR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE_NAME", "The supplied assembly identity has one or more attribute names that contain characters not permitted in XML names."),

2583 0x00003701: ("ERROR_SXS_ASSEMBLY_MISSING", "The referenced assembly could not be found."),

2584 0x00003702: ("ERROR_SXS_CORRUPT_ACTIVATION_STACK", "The activation context activation stack for the running thread of execution is corrupt."),

2585 0x00003703: ("ERROR_SXS_CORRUPTION", "The application isolation metadata for this process or thread has become corrupt."),

2586 0x00003704: ("ERROR_SXS_EARLY_DEACTIVATION", "The activation context being deactivated is not the most recently activated one."),

2587 0x00003705: ("ERROR_SXS_INVALID_DEACTIVATION", "The activation context being deactivated is not active for the current thread of execution."),

2588 0x00003706: ("ERROR_SXS_MULTIPLE_DEACTIVATION", "The activation context being deactivated has already been deactivated."),

2589 0x00003707: ("ERROR_SXS_PROCESS_TERMINATION_REQUESTED", "A component used by the isolation facility has requested to terminate the process."),

2590 0x00003708: ("ERROR_SXS_RELEASE_ACTIVATION_CONTEXT", "A kernel mode component is releasing a reference on an activation context."),

2591 0x00003709: ("ERROR_SXS_SYSTEM_DEFAULT_ACTIVATION_CONTEXT_EMPTY", "The activation context of system default assembly could not be generated."),

2592 0x0000370a: ("ERROR_SXS_INVALID_IDENTITY_ATTRIBUTE_VALUE", "The value of an attribute in an identity is not within the legal range."),

2593 0x0000370b: ("ERROR_SXS_INVALID_IDENTITY_ATTRIBUTE_NAME", "The name of an attribute in an identity is not within the legal range."),

2594 0x0000370c: ("ERROR_SXS_IDENTITY_DUPLICATE_ATTRIBUTE", "An identity contains two definitions for the same attribute."),

2595 0x0000370d: ("ERROR_SXS_IDENTITY_PARSE_ERROR", "The identity string is malformed. This may be due to a trailing comma, more than two unnamed attributes, missing attribute name or missing attribute value."),

2596 0x0000370e: ("ERROR_MALFORMED_SUBSTITUTION_STRING", "A string containing localized substitutable content was malformed. Either a dollar sign ($) was followed by something other than a left parenthesis or another dollar sign or an substitution's right parenthesis was not found."),

2597 0x0000370f: ("ERROR_SXS_INCORRECT_PUBLIC_KEY_TOKEN", "The public key token does not correspond to the public key specified."),

2598 0x00003710: ("ERROR_UNMAPPED_SUBSTITUTION_STRING", "A substitution string had no mapping."),

2599 0x00003711: ("ERROR_SXS_ASSEMBLY_NOT_LOCKED", "The component must be locked before making the request."),

2600 0x00003712: ("ERROR_SXS_COMPONENT_STORE_CORRUPT", "The component store has been corrupted."),

2601 0x00003713: ("ERROR_ADVANCED_INSTALLER_FAILED", "An advanced installer failed during setup or servicing."),

2602 0x00003714: ("ERROR_XML_ENCODING_MISMATCH", "The character encoding in the XML declaration did not match the encoding used in the document."),

2603 0x00003715: ("ERROR_SXS_MANIFEST_IDENTITY_SAME_BUT_CONTENTS_DIFFERENT", "The identities of the manifests are identical but their contents are different."),

2604 0x00003716: ("ERROR_SXS_IDENTITIES_DIFFERENT", "The component identities are different."),

2605 0x00003717: ("ERROR_SXS_ASSEMBLY_IS_NOT_A_DEPLOYMENT", "The assembly is not a deployment."),

2606 0x00003718: ("ERROR_SXS_FILE_NOT_PART_OF_ASSEMBLY", "The file is not a part of the assembly."),

2607 0x00003719: ("ERROR_SXS_MANIFEST_TOO_BIG", "The size of the manifest exceeds the maximum allowed."),

2608 0x0000371a: ("ERROR_SXS_SETTING_NOT_REGISTERED", "The setting is not registered."),

2609 0x0000371b: ("ERROR_SXS_TRANSACTION_CLOSURE_INCOMPLETE", "One or more required members of the transaction are not present."),

2610 0x0000371c: ("ERROR_SMI_PRIMITIVE_INSTALLER_FAILED", "The SMI primitive installer failed during setup or servicing."),

2611 0x0000371d: ("ERROR_GENERIC_COMMAND_FAILED", "A generic command executable returned a result that indicates failure."),

2612 0x0000371e: ("ERROR_SXS_FILE_HASH_MISSING", "A component is missing file verification information in its manifest."),

2613 0x00003a98: ("ERROR_EVT_INVALID_CHANNEL_PATH", "The specified channel path is invalid."),

2614 0x00003a99: ("ERROR_EVT_INVALID_QUERY", "The specified query is invalid."),

2615 0x00003a9a: ("ERROR_EVT_PUBLISHER_METADATA_NOT_FOUND", "The publisher metadata cannot be found in the resource."),

2616 0x00003a9b: ("ERROR_EVT_EVENT_TEMPLATE_NOT_FOUND", "The template for an event definition cannot be found in the resource (error = %1)."),

2617 0x00003a9c: ("ERROR_EVT_INVALID_PUBLISHER_NAME", "The specified publisher name is invalid."),

2618 0x00003a9d: ("ERROR_EVT_INVALID_EVENT_DATA", "The event data raised by the publisher is not compatible with the event template definition in the publisher's manifest"),

2619 0x00003a9f: ("ERROR_EVT_CHANNEL_NOT_FOUND", "The specified channel could not be found. Check channel configuration."),

2620 0x00003aa0: ("ERROR_EVT_MALFORMED_XML_TEXT", "The specified xml text was not well-formed. See Extended Error for more details."),

2621 0x00003aa1: ("ERROR_EVT_SUBSCRIPTION_TO_DIRECT_CHANNEL", "The caller is trying to subscribe to a direct channel which is not allowed. The events for a direct channel go directly to a logfile and cannot be subscribed to."),

2622 0x00003aa2: ("ERROR_EVT_CONFIGURATION_ERROR", "Configuration error."),

2623 0x00003aa3: ("ERROR_EVT_QUERY_RESULT_STALE", "The query result is stale / invalid. This may be due to the log being cleared or rolling over after the query result was created. Users should handle this code by releasing the query result object and reissuing the query."),

2624 0x00003aa4: ("ERROR_EVT_QUERY_RESULT_INVALID_POSITION", "Query result is currently at an invalid position."),

2625 0x00003aa5: ("ERROR_EVT_NON_VALIDATING_MSXML", "Registered MSXML doesn't support validation."),

2626 0x00003aa6: ("ERROR_EVT_FILTER_ALREADYSCOPED", "An expression can only be followed by a change of scope operation if it itself evaluates to a node set and is not already part of some other change of scope operation."),

2627 0x00003aa7: ("ERROR_EVT_FILTER_NOTELTSET", "Can't perform a step operation from a term that does not represent an element set."),

2628 0x00003aa8: ("ERROR_EVT_FILTER_INVARG", "Left hand side arguments to binary operators must be either attributes, nodes or variables and right hand side arguments must be constants."),

2629 0x00003aa9: ("ERROR_EVT_FILTER_INVTEST", "A step operation must involve either a node test or, in the case of a predicate, an algebraic expression against which to test each node in the node set identified by the preceding node set can be evaluated."),

2630 0x00003aaa: ("ERROR_EVT_FILTER_INVTYPE", "This data type is currently unsupported."),

2631 0x00003aab: ("ERROR_EVT_FILTER_PARSEERR", "A syntax error occurred at position %1!d!"),

2632 0x00003aac: ("ERROR_EVT_FILTER_UNSUPPORTEDOP", "This operator is unsupported by this implementation of the filter."),

2633 0x00003aad: ("ERROR_EVT_FILTER_UNEXPECTEDTOKEN", "The token encountered was unexpected."),

2634 0x00003aae: ("ERROR_EVT_INVALID_OPERATION_OVER_ENABLED_DIRECT_CHANNEL", "The requested operation cannot be performed over an enabled direct channel. The channel must first be disabled before performing the requested operation."),

2635 0x00003aaf: ("ERROR_EVT_INVALID_CHANNEL_PROPERTY_VALUE", "Channel property %1!s! contains invalid value. The value has invalid type, is outside of valid range, can't be updated or is not supported by this type of channel."),

2636 0x00003ab0: ("ERROR_EVT_INVALID_PUBLISHER_PROPERTY_VALUE", "Publisher property %1!s! contains invalid value. The value has invalid type, is outside of valid range, can't be updated or is not supported by this type of publisher."),

2637 0x00003ab1: ("ERROR_EVT_CHANNEL_CANNOT_ACTIVATE", "The channel fails to activate."),

2638 0x00003ab2: ("ERROR_EVT_FILTER_TOO_COMPLEX", "The xpath expression exceeded supported complexity. Please symplify it or split it into two or more simple expressions."),

2639 0x00003ab3: ("ERROR_EVT_MESSAGE_NOT_FOUND", "the message resource is present but the message is not found in the string/message table"),

2640 0x00003ab4: ("ERROR_EVT_MESSAGE_ID_NOT_FOUND", "The message id for the desired message could not be found."),

2641 0x00003ab5: ("ERROR_EVT_UNRESOLVED_VALUE_INSERT", "The substitution string for insert index (%1) could not be found."),

2642 0x00003ab6: ("ERROR_EVT_UNRESOLVED_PARAMETER_INSERT", "The description string for parameter reference (%1) could not be found."),

2643 0x00003ab7: ("ERROR_EVT_MAX_INSERTS_REACHED", "The maximum number of replacements has been reached."),

2644 0x00003ab8: ("ERROR_EVT_EVENT_DEFINITION_NOT_FOUND", "The event definition could not be found for event id (%1)."),

2645 0x00003ab9: ("ERROR_EVT_MESSAGE_LOCALE_NOT_FOUND", "The locale specific resource for the desired message is not present."),

2646 0x00003aba: ("ERROR_EVT_VERSION_TOO_OLD", "The resource is too old to be compatible."),

2647 0x00003abb: ("ERROR_EVT_VERSION_TOO_NEW", "The resource is too new to be compatible."),

2648 0x00003abc: ("ERROR_EVT_CANNOT_OPEN_CHANNEL_OF_QUERY", "The channel at index %1!d! of the query can't be opened."),

2649 0x00003abd: ("ERROR_EVT_PUBLISHER_DISABLED", "The publisher has been disabled and its resource is not available. This usually occurs when the publisher is in the process of being uninstalled or upgraded."),

2650 0x00003abe: ("ERROR_EVT_FILTER_OUT_OF_RANGE", "Attempted to create a numeric type that is outside of its valid range."),

2651 0x00003ae8: ("ERROR_EC_SUBSCRIPTION_CANNOT_ACTIVATE", "The subscription fails to activate."),

2652 0x00003ae9: ("ERROR_EC_LOG_DISABLED", "The log of the subscription is in disabled state, and can not be used to forward events to. The log must first be enabled before the subscription can be activated."),

2653 0x00003aea: ("ERROR_EC_CIRCULAR_FORWARDING", "When forwarding events from local machine to itself, the query of the subscription can't contain target log of the subscription."),

2654 0x00003aeb: ("ERROR_EC_CREDSTORE_FULL", "The credential store that is used to save credentials is full."),

2655 0x00003aec: ("ERROR_EC_CRED_NOT_FOUND", "The credential used by this subscription can't be found in credential store."),

2656 0x00003aed: ("ERROR_EC_NO_ACTIVE_CHANNEL", "No active channel is found for the query."),

2657 0x00003afc: ("ERROR_MUI_FILE_NOT_FOUND", "The resource loader failed to find MUI file."),

2658 0x00003afd: ("ERROR_MUI_INVALID_FILE", "The resource loader failed to load MUI file because the file fail to pass validation."),

2659 0x00003afe: ("ERROR_MUI_INVALID_RC_CONFIG", "The RC Manifest is corrupted with garbage data or unsupported version or missing required item."),

2660 0x00003aff: ("ERROR_MUI_INVALID_LOCALE_NAME", "The RC Manifest has invalid culture name."),

2661 0x00003b00: ("ERROR_MUI_INVALID_ULTIMATEFALLBACK_NAME", "The RC Manifest has invalid ultimatefallback name."),

2662 0x00003b01: ("ERROR_MUI_FILE_NOT_LOADED", "The resource loader cache doesn't have loaded MUI entry."),

2663 0x00003b02: ("ERROR_RESOURCE_ENUM_USER_STOP", "User stopped resource enumeration."),

2664 0x00003b03: ("ERROR_MUI_INTLSETTINGS_UILANG_NOT_INSTALLED", "UI language installation failed."),

2665 0x00003b04: ("ERROR_MUI_INTLSETTINGS_INVALID_LOCALE_NAME", "Locale installation failed."),

2666 0x00003b06: ("ERROR_MRM_RUNTIME_NO_DEFAULT_OR_NEUTRAL_RESOURCE", "A resource does not have default or neutral value."),

2667 0x00003b07: ("ERROR_MRM_INVALID_PRICONFIG", "Invalid PRI config file."),

2668 0x00003b08: ("ERROR_MRM_INVALID_FILE_TYPE", "Invalid file type."),

2669 0x00003b09: ("ERROR_MRM_UNKNOWN_QUALIFIER", "Unknown qualifier."),

2670 0x00003b0a: ("ERROR_MRM_INVALID_QUALIFIER_VALUE", "Invalid qualifier value."),

2671 0x00003b0b: ("ERROR_MRM_NO_CANDIDATE", "No Candidate found."),

2672 0x00003b0c: ("ERROR_MRM_NO_MATCH_OR_DEFAULT_CANDIDATE", "The ResourceMap or NamedResource has an item that does not have default or neutral resource.."),

2673 0x00003b0d: ("ERROR_MRM_RESOURCE_TYPE_MISMATCH", "Invalid ResourceCandidate type."),

2674 0x00003b0e: ("ERROR_MRM_DUPLICATE_MAP_NAME", "Duplicate Resource Map."),

2675 0x00003b0f: ("ERROR_MRM_DUPLICATE_ENTRY", "Duplicate Entry."),

2676 0x00003b10: ("ERROR_MRM_INVALID_RESOURCE_IDENTIFIER", "Invalid Resource Identifier."),

2677 0x00003b11: ("ERROR_MRM_FILEPATH_TOO_LONG", "Filepath too long."),

2678 0x00003b12: ("ERROR_MRM_UNSUPPORTED_DIRECTORY_TYPE", "Unsupported directory type."),

2679 0x00003b16: ("ERROR_MRM_INVALID_PRI_FILE", "Invalid PRI File."),

2680 0x00003b17: ("ERROR_MRM_NAMED_RESOURCE_NOT_FOUND", "NamedResource Not Found."),

2681 0x00003b1f: ("ERROR_MRM_MAP_NOT_FOUND", "ResourceMap Not Found."),

2682 0x00003b20: ("ERROR_MRM_UNSUPPORTED_PROFILE_TYPE", "Unsupported MRT profile type."),

2683 0x00003b21: ("ERROR_MRM_INVALID_QUALIFIER_OPERATOR", "Invalid qualifier operator."),

2684 0x00003b22: ("ERROR_MRM_INDETERMINATE_QUALIFIER_VALUE", "Unable to determine qualifier value or qualifier value has not been set."),

2685 0x00003b23: ("ERROR_MRM_AUTOMERGE_ENABLED", "Automerge is enabled in the PRI file."),

2686 0x00003b24: ("ERROR_MRM_TOO_MANY_RESOURCES", "Too many resources defined for package."),

2687 0x00003b60: ("ERROR_MCA_INVALID_CAPABILITIES_STRING", "The monitor returned a DDC/CI capabilities string that did not comply with the ACCESS.bus 3.0, DDC/CI 1.1 or MCCS 2 Revision 1 specification."),

2688 0x00003b61: ("ERROR_MCA_INVALID_VCP_VERSION", "The monitor's VCP Version (0xDF) VCP code returned an invalid version value."),

2689 0x00003b62: ("ERROR_MCA_MONITOR_VIOLATES_MCCS_SPECIFICATION", "The monitor does not comply with the MCCS specification it claims to support."),

2690 0x00003b63: ("ERROR_MCA_MCCS_VERSION_MISMATCH", "The MCCS version in a monitor's mccs_ver capability does not match the MCCS version the monitor reports when the VCP Version (0xDF) VCP code is used."),

2691 0x00003b64: ("ERROR_MCA_UNSUPPORTED_MCCS_VERSION", "The Monitor Configuration API only works with monitors that support the MCCS 1.0 specification, MCCS 2.0 specification or the MCCS 2.0 Revision 1 specification."),

2692 0x00003b65: ("ERROR_MCA_INTERNAL_ERROR", "An internal Monitor Configuration API error occurred."),

2693 0x00003b66: ("ERROR_MCA_INVALID_TECHNOLOGY_TYPE_RETURNED", "The monitor returned an invalid monitor technology type. CRT, Plasma and LCD (TFT) are examples of monitor technology types. This error implies that the monitor violated the MCCS 2.0 or MCCS 2.0 Revision 1 specification."),

2694 0x00003b67: ("ERROR_MCA_UNSUPPORTED_COLOR_TEMPERATURE", "The caller of SetMonitorColorTemperature specified a color temperature that the current monitor did not support. This error implies that the monitor violated the MCCS 2.0 or MCCS 2.0 Revision 1 specification."),

2695 0x00003b92: ("ERROR_AMBIGUOUS_SYSTEM_DEVICE", "The requested system device cannot be identified due to multiple indistinguishable devices potentially matching the identification criteria."),

2696 0x00003bc3: ("ERROR_SYSTEM_DEVICE_NOT_FOUND", "The requested system device cannot be found."),

2697 0x00003bc4: ("ERROR_HASH_NOT_SUPPORTED", "Hash generation for the specified hash version and hash type is not enabled on the server."),

2698 0x00003bc5: ("ERROR_HASH_NOT_PRESENT", "The hash requested from the server is not available or no longer valid."),

2699 0x00003bd9: ("ERROR_SECONDARY_IC_PROVIDER_NOT_REGISTERED", "The secondary interrupt controller instance that manages the specified interrupt is not registered."),

2700 0x00003bda: ("ERROR_GPIO_CLIENT_INFORMATION_INVALID", "The information supplied by the GPIO client driver is invalid."),

2701 0x00003bdb: ("ERROR_GPIO_VERSION_NOT_SUPPORTED", "The version specified by the GPIO client driver is not supported."),

2702 0x00003bdc: ("ERROR_GPIO_INVALID_REGISTRATION_PACKET", "The registration packet supplied by the GPIO client driver is not valid."),

2703 0x00003bdd: ("ERROR_GPIO_OPERATION_DENIED", "The requested operation is not supported for the specified handle."),

2704 0x00003bde: ("ERROR_GPIO_INCOMPATIBLE_CONNECT_MODE", "The requested connect mode conflicts with an existing mode on one or more of the specified pins."),

2705 0x00003bdf: ("ERROR_GPIO_INTERRUPT_ALREADY_UNMASKED", "The interrupt requested to be unmasked is not masked."),

2706 0x00003c28: ("ERROR_CANNOT_SWITCH_RUNLEVEL", "The requested run level switch cannot be completed successfully."),

2707 0x00003c29: ("ERROR_INVALID_RUNLEVEL_SETTING", "The service has an invalid run level setting. The run level for a service"),

2708 0x00003c2a: ("ERROR_RUNLEVEL_SWITCH_TIMEOUT", "The requested run level switch cannot be completed successfully since"),

2709 0x00003c2b: ("ERROR_RUNLEVEL_SWITCH_AGENT_TIMEOUT", "A run level switch agent did not respond within the specified timeout."),

2710 0x00003c2c: ("ERROR_RUNLEVEL_SWITCH_IN_PROGRESS", "A run level switch is currently in progress."),

2711 0x00003c2d: ("ERROR_SERVICES_FAILED_AUTOSTART", "One or more services failed to start during the service startup phase of a run level switch."),

2712 0x00003c8d: ("ERROR_COM_TASK_STOP_PENDING", "The task stop request cannot be completed immediately since"),

2713 0x00003cf0: ("ERROR_INSTALL_OPEN_PACKAGE_FAILED", "Package could not be opened."),

2714 0x00003cf1: ("ERROR_INSTALL_PACKAGE_NOT_FOUND", "Package was not found."),

2715 0x00003cf2: ("ERROR_INSTALL_INVALID_PACKAGE", "Package data is invalid."),

2716 0x00003cf3: ("ERROR_INSTALL_RESOLVE_DEPENDENCY_FAILED", "Package failed updates, dependency or conflict validation."),

2717 0x00003cf4: ("ERROR_INSTALL_OUT_OF_DISK_SPACE", "There is not enough disk space on your computer. Please free up some space and try again."),

2718 0x00003cf5: ("ERROR_INSTALL_NETWORK_FAILURE", "There was a problem downloading your product."),

2719 0x00003cf6: ("ERROR_INSTALL_REGISTRATION_FAILURE", "Package could not be registered."),

2720 0x00003cf7: ("ERROR_INSTALL_DEREGISTRATION_FAILURE", "Package could not be unregistered."),

2721 0x00003cf8: ("ERROR_INSTALL_CANCEL", "User cancelled the install request."),

2722 0x00003cf9: ("ERROR_INSTALL_FAILED", "Install failed. Please contact your software vendor."),

2723 0x00003cfa: ("ERROR_REMOVE_FAILED", "Removal failed. Please contact your software vendor."),

2724 0x00003cfb: ("ERROR_PACKAGE_ALREADY_EXISTS", "The provided package is already installed, and reinstallation of the package was blocked. Check the AppXDeployment-Server event log for details."),

2725 0x00003cfc: ("ERROR_NEEDS_REMEDIATION", "The application cannot be started. Try reinstalling the application to fix the problem."),

2726 0x00003cfd: ("ERROR_INSTALL_PREREQUISITE_FAILED", "A Prerequisite for an install could not be satisfied."),

2727 0x00003cfe: ("ERROR_PACKAGE_REPOSITORY_CORRUPTED", "The package repository is corrupted."),

2728 0x00003cff: ("ERROR_INSTALL_POLICY_FAILURE", "To install this application you need either a Windows developer license or a sideloading-enabled system."),

2729 0x00003d00: ("ERROR_PACKAGE_UPDATING", "The application cannot be started because it is currently updating."),

2730 0x00003d01: ("ERROR_DEPLOYMENT_BLOCKED_BY_POLICY", "The package deployment operation is blocked by policy. Please contact your system administrator."),

2731 0x00003d02: ("ERROR_PACKAGES_IN_USE", "The package could not be installed because resources it modifies are currently in use."),

2732 0x00003d03: ("ERROR_RECOVERY_FILE_CORRUPT", "The package could not be recovered because necessary data for recovery have been corrupted."),

2733 0x00003d04: ("ERROR_INVALID_STAGED_SIGNATURE", "The signature is invalid. To register in developer mode, AppxSignature.p7x and AppxBlockMap.xml must be valid or should not be present."),

2734 0x00003d05: ("ERROR_DELETING_EXISTING_APPLICATIONDATA_STORE_FAILED", "An error occurred while deleting the package's previously existing application data."),

2735 0x00003d06: ("ERROR_INSTALL_PACKAGE_DOWNGRADE", "The package could not be installed because a higher version of this package is already installed."),

2736 0x00003d07: ("ERROR_SYSTEM_NEEDS_REMEDIATION", "An error in a system binary was detected. Try refreshing the PC to fix the problem."),

2737 0x00003d08: ("ERROR_APPX_INTEGRITY_FAILURE_CLR_NGEN", "A corrupted CLR NGEN binary was detected on the system."),

2738 0x00003d09: ("ERROR_RESILIENCY_FILE_CORRUPT", "The operation could not be resumed because necessary data for recovery have been corrupted."),

2739 0x00003d0a: ("ERROR_INSTALL_FIREWALL_SERVICE_NOT_RUNNING", "The package could not be installed because the Windows Firewall service is not running. Enable the Windows Firewall service and try again."),

2740 0x00003d54: ("APPMODEL_ERROR_NO_PACKAGE", "The process has no package identity."),

2741 0x00003d55: ("APPMODEL_ERROR_PACKAGE_RUNTIME_CORRUPT", "The package runtime information is corrupted."),

2742 0x00003d56: ("APPMODEL_ERROR_PACKAGE_IDENTITY_CORRUPT", "The package identity is corrupted."),

2743 0x00003d57: ("APPMODEL_ERROR_NO_APPLICATION", "The process has no application identity."),

2744 0x00003db8: ("ERROR_STATE_LOAD_STORE_FAILED", "Loading the state store failed."),

2745 0x00003db9: ("ERROR_STATE_GET_VERSION_FAILED", "Retrieving the state version for the application failed."),

2746 0x00003dba: ("ERROR_STATE_SET_VERSION_FAILED", "Setting the state version for the application failed."),

2747 0x00003dbb: ("ERROR_STATE_STRUCTURED_RESET_FAILED", "Resetting the structured state of the application failed."),

2748 0x00003dbc: ("ERROR_STATE_OPEN_CONTAINER_FAILED", "State Manager failed to open the container."),

2749 0x00003dbd: ("ERROR_STATE_CREATE_CONTAINER_FAILED", "State Manager failed to create the container."),

2750 0x00003dbe: ("ERROR_STATE_DELETE_CONTAINER_FAILED", "State Manager failed to delete the container."),

2751 0x00003dbf: ("ERROR_STATE_READ_SETTING_FAILED", "State Manager failed to read the setting."),

2752 0x00003dc0: ("ERROR_STATE_WRITE_SETTING_FAILED", "State Manager failed to write the setting."),

2753 0x00003dc1: ("ERROR_STATE_DELETE_SETTING_FAILED", "State Manager failed to delete the setting."),

2754 0x00003dc2: ("ERROR_STATE_QUERY_SETTING_FAILED", "State Manager failed to query the setting."),

2755 0x00003dc3: ("ERROR_STATE_READ_COMPOSITE_SETTING_FAILED", "State Manager failed to read the composite setting."),

2756 0x00003dc4: ("ERROR_STATE_WRITE_COMPOSITE_SETTING_FAILED", "State Manager failed to write the composite setting."),

2757 0x00003dc5: ("ERROR_STATE_ENUMERATE_CONTAINER_FAILED", "State Manager failed to enumerate the containers."),

2758 0x00003dc6: ("ERROR_STATE_ENUMERATE_SETTINGS_FAILED", "State Manager failed to enumerate the settings."),

2759 0x00003dc7: ("ERROR_STATE_COMPOSITE_SETTING_VALUE_SIZE_LIMIT_EXCEEDED", "The size of the state manager composite setting value has exceeded the limit."),

2760 0x00003dc8: ("ERROR_STATE_SETTING_VALUE_SIZE_LIMIT_EXCEEDED", "The size of the state manager setting value has exceeded the limit."),

2761 0x00003dc9: ("ERROR_STATE_SETTING_NAME_SIZE_LIMIT_EXCEEDED", "The length of the state manager setting name has exceeded the limit."),

2762 0x00003dca: ("ERROR_STATE_CONTAINER_NAME_SIZE_LIMIT_EXCEEDED", "The length of the state manager container name has exceeded the limit."),

2763 0x00003de1: ("ERROR_API_UNAVAILABLE", "This API cannot be used in the context of the caller's application type."),

2764 0x00003df5: ("STORE_ERROR_UNLICENSED", "This PC does not have a valid license for the application or product."),

2765 0x00003df6: ("STORE_ERROR_UNLICENSED_USER", "The authenticated user does not have a valid license for the application or product."),

2766}

2767

2768

2769# Error Codes

2770

2771 ERROR_SUCCESS = 0x00000000

2772 ERROR_INVALID_FUNCTION = 0x00000001

2773 ERROR_FILE_NOT_FOUND = 0x00000002

2774 ERROR_PATH_NOT_FOUND = 0x00000003

2775 ERROR_TOO_MANY_OPEN_FILES = 0x00000004

2776 ERROR_ACCESS_DENIED = 0x00000005

2777 ERROR_INVALID_HANDLE = 0x00000006

2778 ERROR_ARENA_TRASHED = 0x00000007

2779 ERROR_NOT_ENOUGH_MEMORY = 0x00000008

2780 ERROR_INVALID_BLOCK = 0x00000009

2781 ERROR_BAD_ENVIRONMENT = 0x0000000a

2782 ERROR_BAD_FORMAT = 0x0000000b

2783 ERROR_INVALID_ACCESS = 0x0000000c

2784 ERROR_INVALID_DATA = 0x0000000d

2785 ERROR_OUTOFMEMORY = 0x0000000e

2786 ERROR_INVALID_DRIVE = 0x0000000f

2787 ERROR_CURRENT_DIRECTORY = 0x00000010

2788 ERROR_NOT_SAME_DEVICE = 0x00000011

2789 ERROR_NO_MORE_FILES = 0x00000012

2790 ERROR_WRITE_PROTECT = 0x00000013

2791 ERROR_BAD_UNIT = 0x00000014

2792 ERROR_NOT_READY = 0x00000015

2793 ERROR_BAD_COMMAND = 0x00000016

2794 ERROR_CRC = 0x00000017

2795 ERROR_BAD_LENGTH = 0x00000018

2796 ERROR_SEEK = 0x00000019

2797 ERROR_NOT_DOS_DISK = 0x0000001a

2798 ERROR_SECTOR_NOT_FOUND = 0x0000001b

2799 ERROR_OUT_OF_PAPER = 0x0000001c

2800 ERROR_WRITE_FAULT = 0x0000001d

2801 ERROR_READ_FAULT = 0x0000001e

2802 ERROR_GEN_FAILURE = 0x0000001f

2803 ERROR_SHARING_VIOLATION = 0x00000020

2804 ERROR_LOCK_VIOLATION = 0x00000021

2805 ERROR_WRONG_DISK = 0x00000022

2806 ERROR_SHARING_BUFFER_EXCEEDED = 0x00000024

2807 ERROR_HANDLE_EOF = 0x00000026

2808 ERROR_HANDLE_DISK_FULL = 0x00000027

2809 ERROR_NOT_SUPPORTED = 0x00000032

2810 ERROR_REM_NOT_LIST = 0x00000033

2811 ERROR_DUP_NAME = 0x00000034

2812 ERROR_BAD_NETPATH = 0x00000035

2813 ERROR_NETWORK_BUSY = 0x00000036

2814 ERROR_DEV_NOT_EXIST = 0x00000037

2815 ERROR_TOO_MANY_CMDS = 0x00000038

2816 ERROR_ADAP_HDW_ERR = 0x00000039

2817 ERROR_BAD_NET_RESP = 0x0000003a

2818 ERROR_UNEXP_NET_ERR = 0x0000003b

2819 ERROR_BAD_REM_ADAP = 0x0000003c

2820 ERROR_PRINTQ_FULL = 0x0000003d

2821 ERROR_NO_SPOOL_SPACE = 0x0000003e

2822 ERROR_PRINT_CANCELLED = 0x0000003f

2823 ERROR_NETNAME_DELETED = 0x00000040

2824 ERROR_NETWORK_ACCESS_DENIED = 0x00000041

2825 ERROR_BAD_DEV_TYPE = 0x00000042

2826 ERROR_BAD_NET_NAME = 0x00000043

2827 ERROR_TOO_MANY_NAMES = 0x00000044

2828 ERROR_TOO_MANY_SESS = 0x00000045

2829 ERROR_SHARING_PAUSED = 0x00000046

2830 ERROR_REQ_NOT_ACCEP = 0x00000047

2831 ERROR_REDIR_PAUSED = 0x00000048

2832 ERROR_FILE_EXISTS = 0x00000050

2833 ERROR_CANNOT_MAKE = 0x00000052

2834 ERROR_FAIL_I24 = 0x00000053

2835 ERROR_OUT_OF_STRUCTURES = 0x00000054

2836 ERROR_ALREADY_ASSIGNED = 0x00000055

2837 ERROR_INVALID_PASSWORD = 0x00000056

2838 ERROR_INVALID_PARAMETER = 0x00000057

2839 ERROR_NET_WRITE_FAULT = 0x00000058

2840 ERROR_NO_PROC_SLOTS = 0x00000059

2841 ERROR_TOO_MANY_SEMAPHORES = 0x00000064

2842 ERROR_EXCL_SEM_ALREADY_OWNED = 0x00000065

2843 ERROR_SEM_IS_SET = 0x00000066

2844 ERROR_TOO_MANY_SEM_REQUESTS = 0x00000067

2845 ERROR_INVALID_AT_INTERRUPT_TIME = 0x00000068

2846 ERROR_SEM_OWNER_DIED = 0x00000069

2847 ERROR_SEM_USER_LIMIT = 0x0000006a

2848 ERROR_DISK_CHANGE = 0x0000006b

2849 ERROR_DRIVE_LOCKED = 0x0000006c

2850 ERROR_BROKEN_PIPE = 0x0000006d

2851 ERROR_OPEN_FAILED = 0x0000006e

2852 ERROR_BUFFER_OVERFLOW = 0x0000006f

2853 ERROR_DISK_FULL = 0x00000070

2854 ERROR_NO_MORE_SEARCH_HANDLES = 0x00000071

2855 ERROR_INVALID_TARGET_HANDLE = 0x00000072

2856 ERROR_INVALID_CATEGORY = 0x00000075

2857 ERROR_INVALID_VERIFY_SWITCH = 0x00000076

2858 ERROR_BAD_DRIVER_LEVEL = 0x00000077

2859 ERROR_CALL_NOT_IMPLEMENTED = 0x00000078

2860 ERROR_SEM_TIMEOUT = 0x00000079

2861 ERROR_INSUFFICIENT_BUFFER = 0x0000007a

2862 ERROR_INVALID_NAME = 0x0000007b

2863 ERROR_INVALID_LEVEL = 0x0000007c

2864 ERROR_NO_VOLUME_LABEL = 0x0000007d

2865 ERROR_MOD_NOT_FOUND = 0x0000007e

2866 ERROR_PROC_NOT_FOUND = 0x0000007f

2867 ERROR_WAIT_NO_CHILDREN = 0x00000080

2868 ERROR_CHILD_NOT_COMPLETE = 0x00000081

2869 ERROR_DIRECT_ACCESS_HANDLE = 0x00000082

2870 ERROR_NEGATIVE_SEEK = 0x00000083

2871 ERROR_SEEK_ON_DEVICE = 0x00000084

2872 ERROR_IS_JOIN_TARGET = 0x00000085

2873 ERROR_IS_JOINED = 0x00000086

2874 ERROR_IS_SUBSTED = 0x00000087

2875 ERROR_NOT_JOINED = 0x00000088

2876 ERROR_NOT_SUBSTED = 0x00000089

2877 ERROR_JOIN_TO_JOIN = 0x0000008a

2878 ERROR_SUBST_TO_SUBST = 0x0000008b

2879 ERROR_JOIN_TO_SUBST = 0x0000008c

2880 ERROR_SUBST_TO_JOIN = 0x0000008d

2881 ERROR_BUSY_DRIVE = 0x0000008e

2882 ERROR_SAME_DRIVE = 0x0000008f

2883 ERROR_DIR_NOT_ROOT = 0x00000090

2884 ERROR_DIR_NOT_EMPTY = 0x00000091

2885 ERROR_IS_SUBST_PATH = 0x00000092

2886 ERROR_IS_JOIN_PATH = 0x00000093

2887 ERROR_PATH_BUSY = 0x00000094

2888 ERROR_IS_SUBST_TARGET = 0x00000095

2889 ERROR_SYSTEM_TRACE = 0x00000096

2890 ERROR_INVALID_EVENT_COUNT = 0x00000097

2891 ERROR_TOO_MANY_MUXWAITERS = 0x00000098

2892 ERROR_INVALID_LIST_FORMAT = 0x00000099

2893 ERROR_LABEL_TOO_LONG = 0x0000009a

2894 ERROR_TOO_MANY_TCBS = 0x0000009b

2895 ERROR_SIGNAL_REFUSED = 0x0000009c

2896 ERROR_DISCARDED = 0x0000009d

2897 ERROR_NOT_LOCKED = 0x0000009e

2898 ERROR_BAD_THREADID_ADDR = 0x0000009f

2899 ERROR_BAD_ARGUMENTS = 0x000000a0

2900 ERROR_BAD_PATHNAME = 0x000000a1

2901 ERROR_SIGNAL_PENDING = 0x000000a2

2902 ERROR_MAX_THRDS_REACHED = 0x000000a4

2903 ERROR_LOCK_FAILED = 0x000000a7

2904 ERROR_BUSY = 0x000000aa

2905 ERROR_DEVICE_SUPPORT_IN_PROGRESS = 0x000000ab

2906 ERROR_CANCEL_VIOLATION = 0x000000ad

2907 ERROR_ATOMIC_LOCKS_NOT_SUPPORTED = 0x000000ae

2908 ERROR_INVALID_SEGMENT_NUMBER = 0x000000b4

2909 ERROR_INVALID_ORDINAL = 0x000000b6

2910 ERROR_ALREADY_EXISTS = 0x000000b7

2911 ERROR_INVALID_FLAG_NUMBER = 0x000000ba

2912 ERROR_SEM_NOT_FOUND = 0x000000bb

2913 ERROR_INVALID_STARTING_CODESEG = 0x000000bc

2914 ERROR_INVALID_STACKSEG = 0x000000bd

2915 ERROR_INVALID_MODULETYPE = 0x000000be

2916 ERROR_INVALID_EXE_SIGNATURE = 0x000000bf

2917 ERROR_EXE_MARKED_INVALID = 0x000000c0

2918 ERROR_BAD_EXE_FORMAT = 0x000000c1

2919 ERROR_ITERATED_DATA_EXCEEDS_64k = 0x000000c2

2920 ERROR_INVALID_MINALLOCSIZE = 0x000000c3

2921 ERROR_DYNLINK_FROM_INVALID_RING = 0x000000c4

2922 ERROR_IOPL_NOT_ENABLED = 0x000000c5

2923 ERROR_INVALID_SEGDPL = 0x000000c6

2924 ERROR_AUTODATASEG_EXCEEDS_64k = 0x000000c7

2925 ERROR_RING2SEG_MUST_BE_MOVABLE = 0x000000c8

2926 ERROR_RELOC_CHAIN_XEEDS_SEGLIM = 0x000000c9

2927 ERROR_INFLOOP_IN_RELOC_CHAIN = 0x000000ca

2928 ERROR_ENVVAR_NOT_FOUND = 0x000000cb

2929 ERROR_NO_SIGNAL_SENT = 0x000000cd

2930 ERROR_FILENAME_EXCED_RANGE = 0x000000ce

2931 ERROR_RING2_STACK_IN_USE = 0x000000cf

2932 ERROR_META_EXPANSION_TOO_LONG = 0x000000d0

2933 ERROR_INVALID_SIGNAL_NUMBER = 0x000000d1

2934 ERROR_THREAD_1_INACTIVE = 0x000000d2

2935 ERROR_LOCKED = 0x000000d4

2936 ERROR_TOO_MANY_MODULES = 0x000000d6

2937 ERROR_NESTING_NOT_ALLOWED = 0x000000d7

2938 ERROR_EXE_MACHINE_TYPE_MISMATCH = 0x000000d8

2939 ERROR_EXE_CANNOT_MODIFY_SIGNED_BINARY = 0x000000d9

2940 ERROR_EXE_CANNOT_MODIFY_STRONG_SIGNED_BINARY = 0x000000da

2941 ERROR_FILE_CHECKED_OUT = 0x000000dc

2942 ERROR_CHECKOUT_REQUIRED = 0x000000dd

2943 ERROR_BAD_FILE_TYPE = 0x000000de

2944 ERROR_FILE_TOO_LARGE = 0x000000df

2945 ERROR_FORMS_AUTH_REQUIRED = 0x000000e0

2946 ERROR_VIRUS_INFECTED = 0x000000e1

2947 ERROR_VIRUS_DELETED = 0x000000e2

2948 ERROR_PIPE_LOCAL = 0x000000e5

2949 ERROR_BAD_PIPE = 0x000000e6

2950 ERROR_PIPE_BUSY = 0x000000e7

2951 ERROR_NO_DATA = 0x000000e8

2952 ERROR_PIPE_NOT_CONNECTED = 0x000000e9

2953 ERROR_MORE_DATA = 0x000000ea

2954 ERROR_VC_DISCONNECTED = 0x000000f0

2955 ERROR_INVALID_EA_NAME = 0x000000fe

2956 ERROR_EA_LIST_INCONSISTENT = 0x000000ff

2957 WAIT_TIMEOUT = 0x00000102

2958 ERROR_NO_MORE_ITEMS = 0x00000103

2959 ERROR_CANNOT_COPY = 0x0000010a

2960 ERROR_DIRECTORY = 0x0000010b

2961 ERROR_EAS_DIDNT_FIT = 0x00000113

2962 ERROR_EA_FILE_CORRUPT = 0x00000114

2963 ERROR_EA_TABLE_FULL = 0x00000115

2964 ERROR_INVALID_EA_HANDLE = 0x00000116

2965 ERROR_EAS_NOT_SUPPORTED = 0x0000011a

2966 ERROR_NOT_OWNER = 0x00000120

2967 ERROR_TOO_MANY_POSTS = 0x0000012a

2968 ERROR_PARTIAL_COPY = 0x0000012b

2969 ERROR_OPLOCK_NOT_GRANTED = 0x0000012c

2970 ERROR_INVALID_OPLOCK_PROTOCOL = 0x0000012d

2971 ERROR_DISK_TOO_FRAGMENTED = 0x0000012e

2972 ERROR_DELETE_PENDING = 0x0000012f

2973 ERROR_INCOMPATIBLE_WITH_GLOBAL_SHORT_NAME_REGISTRY_SETTING = 0x00000130

2974 ERROR_SHORT_NAMES_NOT_ENABLED_ON_VOLUME = 0x00000131

2975 ERROR_SECURITY_STREAM_IS_INCONSISTENT = 0x00000132

2976 ERROR_INVALID_LOCK_RANGE = 0x00000133

2977 ERROR_IMAGE_SUBSYSTEM_NOT_PRESENT = 0x00000134

2978 ERROR_NOTIFICATION_GUID_ALREADY_DEFINED = 0x00000135

2979 ERROR_INVALID_EXCEPTION_HANDLER = 0x00000136

2980 ERROR_DUPLICATE_PRIVILEGES = 0x00000137

2981 ERROR_NO_RANGES_PROCESSED = 0x00000138

2982 ERROR_NOT_ALLOWED_ON_SYSTEM_FILE = 0x00000139

2983 ERROR_DISK_RESOURCES_EXHAUSTED = 0x0000013a

2984 ERROR_INVALID_TOKEN = 0x0000013b

2985 ERROR_DEVICE_FEATURE_NOT_SUPPORTED = 0x0000013c

2986 ERROR_MR_MID_NOT_FOUND = 0x0000013d

2987 ERROR_SCOPE_NOT_FOUND = 0x0000013e

2988 ERROR_UNDEFINED_SCOPE = 0x0000013f

2989 ERROR_INVALID_CAP = 0x00000140

2990 ERROR_DEVICE_UNREACHABLE = 0x00000141

2991 ERROR_DEVICE_NO_RESOURCES = 0x00000142

2992 ERROR_DATA_CHECKSUM_ERROR = 0x00000143

2993 ERROR_INTERMIXED_KERNEL_EA_OPERATION = 0x00000144

2994 ERROR_FILE_LEVEL_TRIM_NOT_SUPPORTED = 0x00000146

2995 ERROR_OFFSET_ALIGNMENT_VIOLATION = 0x00000147

2996 ERROR_INVALID_FIELD_IN_PARAMETER_LIST = 0x00000148

2997 ERROR_OPERATION_IN_PROGRESS = 0x00000149

2998 ERROR_BAD_DEVICE_PATH = 0x0000014a

2999 ERROR_TOO_MANY_DESCRIPTORS = 0x0000014b

3000 ERROR_SCRUB_DATA_DISABLED = 0x0000014c

3001 ERROR_NOT_REDUNDANT_STORAGE = 0x0000014d

3002 ERROR_RESIDENT_FILE_NOT_SUPPORTED = 0x0000014e

3003 ERROR_COMPRESSED_FILE_NOT_SUPPORTED = 0x0000014f

3004 ERROR_DIRECTORY_NOT_SUPPORTED = 0x00000150

3005 ERROR_NOT_READ_FROM_COPY = 0x00000151

3006 ERROR_FT_WRITE_FAILURE = 0x00000152

3007 ERROR_FT_DI_SCAN_REQUIRED = 0x00000153

3008 ERROR_INVALID_KERNEL_INFO_VERSION = 0x00000154

3009 ERROR_INVALID_PEP_INFO_VERSION = 0x00000155

3010 ERROR_FAIL_NOACTION_REBOOT = 0x0000015e

3011 ERROR_FAIL_SHUTDOWN = 0x0000015f

3012 ERROR_FAIL_RESTART = 0x00000160

3013 ERROR_MAX_SESSIONS_REACHED = 0x00000161

3014 ERROR_THREAD_MODE_ALREADY_BACKGROUND = 0x00000190

3015 ERROR_THREAD_MODE_NOT_BACKGROUND = 0x00000191

3016 ERROR_PROCESS_MODE_ALREADY_BACKGROUND = 0x00000192

3017 ERROR_PROCESS_MODE_NOT_BACKGROUND = 0x00000193

3018 ERROR_INVALID_ADDRESS = 0x000001e7

3019 ERROR_USER_PROFILE_LOAD = 0x000001f4

3020 ERROR_ARITHMETIC_OVERFLOW = 0x00000216

3021 ERROR_PIPE_CONNECTED = 0x00000217

3022 ERROR_PIPE_LISTENING = 0x00000218

3023 ERROR_VERIFIER_STOP = 0x00000219

3024 ERROR_ABIOS_ERROR = 0x0000021a

3025 ERROR_WX86_WARNING = 0x0000021b

3026 ERROR_WX86_ERROR = 0x0000021c

3027 ERROR_TIMER_NOT_CANCELED = 0x0000021d

3028 ERROR_UNWIND = 0x0000021e

3029 ERROR_BAD_STACK = 0x0000021f

3030 ERROR_INVALID_UNWIND_TARGET = 0x00000220

3031 ERROR_INVALID_PORT_ATTRIBUTES = 0x00000221

3032 ERROR_PORT_MESSAGE_TOO_LONG = 0x00000222

3033 ERROR_INVALID_QUOTA_LOWER = 0x00000223

3034 ERROR_DEVICE_ALREADY_ATTACHED = 0x00000224

3035 ERROR_INSTRUCTION_MISALIGNMENT = 0x00000225

3036 ERROR_PROFILING_NOT_STARTED = 0x00000226

3037 ERROR_PROFILING_NOT_STOPPED = 0x00000227

3038 ERROR_COULD_NOT_INTERPRET = 0x00000228

3039 ERROR_PROFILING_AT_LIMIT = 0x00000229

3040 ERROR_CANT_WAIT = 0x0000022a

3041 ERROR_CANT_TERMINATE_SELF = 0x0000022b

3042 ERROR_UNEXPECTED_MM_CREATE_ERR = 0x0000022c

3043 ERROR_UNEXPECTED_MM_MAP_ERROR = 0x0000022d

3044 ERROR_UNEXPECTED_MM_EXTEND_ERR = 0x0000022e

3045 ERROR_BAD_FUNCTION_TABLE = 0x0000022f

3046 ERROR_NO_GUID_TRANSLATION = 0x00000230

3047 ERROR_INVALID_LDT_SIZE = 0x00000231

3048 ERROR_INVALID_LDT_OFFSET = 0x00000233

3049 ERROR_INVALID_LDT_DESCRIPTOR = 0x00000234

3050 ERROR_TOO_MANY_THREADS = 0x00000235

3051 ERROR_THREAD_NOT_IN_PROCESS = 0x00000236

3052 ERROR_PAGEFILE_QUOTA_EXCEEDED = 0x00000237

3053 ERROR_LOGON_SERVER_CONFLICT = 0x00000238

3054 ERROR_SYNCHRONIZATION_REQUIRED = 0x00000239

3055 ERROR_NET_OPEN_FAILED = 0x0000023a

3056 ERROR_IO_PRIVILEGE_FAILED = 0x0000023b

3057 ERROR_CONTROL_C_EXIT = 0x0000023c

3058 ERROR_MISSING_SYSTEMFILE = 0x0000023d

3059 ERROR_UNHANDLED_EXCEPTION = 0x0000023e

3060 ERROR_APP_INIT_FAILURE = 0x0000023f

3061 ERROR_PAGEFILE_CREATE_FAILED = 0x00000240

3062 ERROR_INVALID_IMAGE_HASH = 0x00000241

3063 ERROR_NO_PAGEFILE = 0x00000242

3064 ERROR_ILLEGAL_FLOAT_CONTEXT = 0x00000243

3065 ERROR_NO_EVENT_PAIR = 0x00000244

3066 ERROR_DOMAIN_CTRLR_CONFIG_ERROR = 0x00000245

3067 ERROR_ILLEGAL_CHARACTER = 0x00000246

3068 ERROR_UNDEFINED_CHARACTER = 0x00000247

3069 ERROR_FLOPPY_VOLUME = 0x00000248

3070 ERROR_BIOS_FAILED_TO_CONNECT_INTERRUPT = 0x00000249

3071 ERROR_BACKUP_CONTROLLER = 0x0000024a

3072 ERROR_MUTANT_LIMIT_EXCEEDED = 0x0000024b

3073 ERROR_FS_DRIVER_REQUIRED = 0x0000024c

3074 ERROR_CANNOT_LOAD_REGISTRY_FILE = 0x0000024d

3075 ERROR_DEBUG_ATTACH_FAILED = 0x0000024e

3076 ERROR_SYSTEM_PROCESS_TERMINATED = 0x0000024f

3077 ERROR_DATA_NOT_ACCEPTED = 0x00000250

3078 ERROR_VDM_HARD_ERROR = 0x00000251

3079 ERROR_DRIVER_CANCEL_TIMEOUT = 0x00000252

3080 ERROR_REPLY_MESSAGE_MISMATCH = 0x00000253

3081 ERROR_LOST_WRITEBEHIND_DATA = 0x00000254

3082 ERROR_CLIENT_SERVER_PARAMETERS_INVALID = 0x00000255

3083 ERROR_NOT_TINY_STREAM = 0x00000256

3084 ERROR_STACK_OVERFLOW_READ = 0x00000257

3085 ERROR_CONVERT_TO_LARGE = 0x00000258

3086 ERROR_FOUND_OUT_OF_SCOPE = 0x00000259

3087 ERROR_ALLOCATE_BUCKET = 0x0000025a

3088 ERROR_MARSHALL_OVERFLOW = 0x0000025b

3089 ERROR_INVALID_VARIANT = 0x0000025c

3090 ERROR_BAD_COMPRESSION_BUFFER = 0x0000025d

3091 ERROR_AUDIT_FAILED = 0x0000025e

3092 ERROR_TIMER_RESOLUTION_NOT_SET = 0x0000025f

3093 ERROR_INSUFFICIENT_LOGON_INFO = 0x00000260

3094 ERROR_BAD_DLL_ENTRYPOINT = 0x00000261

3095 ERROR_BAD_SERVICE_ENTRYPOINT = 0x00000262

3096 ERROR_IP_ADDRESS_CONFLICT1 = 0x00000263

3097 ERROR_IP_ADDRESS_CONFLICT2 = 0x00000264

3098 ERROR_REGISTRY_QUOTA_LIMIT = 0x00000265

3099 ERROR_NO_CALLBACK_ACTIVE = 0x00000266

3100 ERROR_PWD_TOO_SHORT = 0x00000267

3101 ERROR_PWD_TOO_RECENT = 0x00000268

3102 ERROR_PWD_HISTORY_CONFLICT = 0x00000269

3103 ERROR_UNSUPPORTED_COMPRESSION = 0x0000026a

3104 ERROR_INVALID_HW_PROFILE = 0x0000026b

3105 ERROR_INVALID_PLUGPLAY_DEVICE_PATH = 0x0000026c

3106 ERROR_QUOTA_LIST_INCONSISTENT = 0x0000026d

3107 ERROR_EVALUATION_EXPIRATION = 0x0000026e

3108 ERROR_ILLEGAL_DLL_RELOCATION = 0x0000026f

3109 ERROR_DLL_INIT_FAILED_LOGOFF = 0x00000270

3110 ERROR_VALIDATE_CONTINUE = 0x00000271

3111 ERROR_NO_MORE_MATCHES = 0x00000272

3112 ERROR_RANGE_LIST_CONFLICT = 0x00000273

3113 ERROR_SERVER_SID_MISMATCH = 0x00000274

3114 ERROR_CANT_ENABLE_DENY_ONLY = 0x00000275

3115 ERROR_FLOAT_MULTIPLE_FAULTS = 0x00000276

3116 ERROR_FLOAT_MULTIPLE_TRAPS = 0x00000277

3117 ERROR_NOINTERFACE = 0x00000278

3118 ERROR_DRIVER_FAILED_SLEEP = 0x00000279

3119 ERROR_CORRUPT_SYSTEM_FILE = 0x0000027a

3120 ERROR_COMMITMENT_MINIMUM = 0x0000027b

3121 ERROR_PNP_RESTART_ENUMERATION = 0x0000027c

3122 ERROR_SYSTEM_IMAGE_BAD_SIGNATURE = 0x0000027d

3123 ERROR_PNP_REBOOT_REQUIRED = 0x0000027e

3124 ERROR_INSUFFICIENT_POWER = 0x0000027f

3125 ERROR_MULTIPLE_FAULT_VIOLATION = 0x00000280

3126 ERROR_SYSTEM_SHUTDOWN = 0x00000281

3127 ERROR_PORT_NOT_SET = 0x00000282

3128 ERROR_DS_VERSION_CHECK_FAILURE = 0x00000283

3129 ERROR_RANGE_NOT_FOUND = 0x00000284

3130 ERROR_NOT_SAFE_MODE_DRIVER = 0x00000286

3131 ERROR_FAILED_DRIVER_ENTRY = 0x00000287

3132 ERROR_DEVICE_ENUMERATION_ERROR = 0x00000288

3133 ERROR_MOUNT_POINT_NOT_RESOLVED = 0x00000289

3134 ERROR_INVALID_DEVICE_OBJECT_PARAMETER = 0x0000028a

3135 ERROR_MCA_OCCURED = 0x0000028b

3136 ERROR_DRIVER_DATABASE_ERROR = 0x0000028c

3137 ERROR_SYSTEM_HIVE_TOO_LARGE = 0x0000028d

3138 ERROR_DRIVER_FAILED_PRIOR_UNLOAD = 0x0000028e

3139 ERROR_VOLSNAP_PREPARE_HIBERNATE = 0x0000028f

3140 ERROR_HIBERNATION_FAILURE = 0x00000290

3141 ERROR_PWD_TOO_LONG = 0x00000291

3142 ERROR_FILE_SYSTEM_LIMITATION = 0x00000299

3143 ERROR_ASSERTION_FAILURE = 0x0000029c

3144 ERROR_ACPI_ERROR = 0x0000029d

3145 ERROR_WOW_ASSERTION = 0x0000029e

3146 ERROR_PNP_BAD_MPS_TABLE = 0x0000029f

3147 ERROR_PNP_TRANSLATION_FAILED = 0x000002a0

3148 ERROR_PNP_IRQ_TRANSLATION_FAILED = 0x000002a1

3149 ERROR_PNP_INVALID_ID = 0x000002a2

3150 ERROR_WAKE_SYSTEM_DEBUGGER = 0x000002a3

3151 ERROR_HANDLES_CLOSED = 0x000002a4

3152 ERROR_EXTRANEOUS_INFORMATION = 0x000002a5

3153 ERROR_RXACT_COMMIT_NECESSARY = 0x000002a6

3154 ERROR_MEDIA_CHECK = 0x000002a7

3155 ERROR_GUID_SUBSTITUTION_MADE = 0x000002a8

3156 ERROR_STOPPED_ON_SYMLINK = 0x000002a9

3157 ERROR_LONGJUMP = 0x000002aa

3158 ERROR_PLUGPLAY_QUERY_VETOED = 0x000002ab

3159 ERROR_UNWIND_CONSOLIDATE = 0x000002ac

3160 ERROR_REGISTRY_HIVE_RECOVERED = 0x000002ad

3161 ERROR_DLL_MIGHT_BE_INSECURE = 0x000002ae

3162 ERROR_DLL_MIGHT_BE_INCOMPATIBLE = 0x000002af

3163 ERROR_DBG_EXCEPTION_NOT_HANDLED = 0x000002b0

3164 ERROR_DBG_REPLY_LATER = 0x000002b1

3165 ERROR_DBG_UNABLE_TO_PROVIDE_HANDLE = 0x000002b2

3166 ERROR_DBG_TERMINATE_THREAD = 0x000002b3

3167 ERROR_DBG_TERMINATE_PROCESS = 0x000002b4

3168 ERROR_DBG_CONTROL_C = 0x000002b5

3169 ERROR_DBG_PRINTEXCEPTION_C = 0x000002b6

3170 ERROR_DBG_RIPEXCEPTION = 0x000002b7

3171 ERROR_DBG_CONTROL_BREAK = 0x000002b8

3172 ERROR_DBG_COMMAND_EXCEPTION = 0x000002b9

3173 ERROR_OBJECT_NAME_EXISTS = 0x000002ba

3174 ERROR_THREAD_WAS_SUSPENDED = 0x000002bb

3175 ERROR_IMAGE_NOT_AT_BASE = 0x000002bc

3176 ERROR_RXACT_STATE_CREATED = 0x000002bd

3177 ERROR_SEGMENT_NOTIFICATION = 0x000002be

3178 ERROR_BAD_CURRENT_DIRECTORY = 0x000002bf

3179 ERROR_FT_READ_RECOVERY_FROM_BACKUP = 0x000002c0

3180 ERROR_FT_WRITE_RECOVERY = 0x000002c1

3181 ERROR_IMAGE_MACHINE_TYPE_MISMATCH = 0x000002c2

3182 ERROR_RECEIVE_PARTIAL = 0x000002c3

3183 ERROR_RECEIVE_EXPEDITED = 0x000002c4

3184 ERROR_RECEIVE_PARTIAL_EXPEDITED = 0x000002c5

3185 ERROR_EVENT_DONE = 0x000002c6

3186 ERROR_EVENT_PENDING = 0x000002c7

3187 ERROR_CHECKING_FILE_SYSTEM = 0x000002c8

3188 ERROR_FATAL_APP_EXIT = 0x000002c9

3189 ERROR_PREDEFINED_HANDLE = 0x000002ca

3190 ERROR_WAS_UNLOCKED = 0x000002cb

3191 ERROR_SERVICE_NOTIFICATION = 0x000002cc

3192 ERROR_WAS_LOCKED = 0x000002cd

3193 ERROR_LOG_HARD_ERROR = 0x000002ce

3194 ERROR_ALREADY_WIN32 = 0x000002cf

3195 ERROR_IMAGE_MACHINE_TYPE_MISMATCH_EXE = 0x000002d0

3196 ERROR_NO_YIELD_PERFORMED = 0x000002d1

3197 ERROR_TIMER_RESUME_IGNORED = 0x000002d2

3198 ERROR_ARBITRATION_UNHANDLED = 0x000002d3

3199 ERROR_CARDBUS_NOT_SUPPORTED = 0x000002d4

3200 ERROR_MP_PROCESSOR_MISMATCH = 0x000002d5

3201 ERROR_HIBERNATED = 0x000002d6

3202 ERROR_RESUME_HIBERNATION = 0x000002d7

3203 ERROR_FIRMWARE_UPDATED = 0x000002d8

3204 ERROR_DRIVERS_LEAKING_LOCKED_PAGES = 0x000002d9

3205 ERROR_WAKE_SYSTEM = 0x000002da

3206 ERROR_WAIT_1 = 0x000002db

3207 ERROR_WAIT_2 = 0x000002dc

3208 ERROR_WAIT_3 = 0x000002dd

3209 ERROR_WAIT_63 = 0x000002de

3210 ERROR_ABANDONED_WAIT_0 = 0x000002df

3211 ERROR_ABANDONED_WAIT_63 = 0x000002e0

3212 ERROR_USER_APC = 0x000002e1

3213 ERROR_KERNEL_APC = 0x000002e2

3214 ERROR_ALERTED = 0x000002e3

3215 ERROR_ELEVATION_REQUIRED = 0x000002e4

3216 ERROR_REPARSE = 0x000002e5

3217 ERROR_OPLOCK_BREAK_IN_PROGRESS = 0x000002e6

3218 ERROR_VOLUME_MOUNTED = 0x000002e7

3219 ERROR_RXACT_COMMITTED = 0x000002e8

3220 ERROR_NOTIFY_CLEANUP = 0x000002e9

3221 ERROR_PRIMARY_TRANSPORT_CONNECT_FAILED = 0x000002ea

3222 ERROR_PAGE_FAULT_TRANSITION = 0x000002eb

3223 ERROR_PAGE_FAULT_DEMAND_ZERO = 0x000002ec

3224 ERROR_PAGE_FAULT_COPY_ON_WRITE = 0x000002ed

3225 ERROR_PAGE_FAULT_GUARD_PAGE = 0x000002ee

3226 ERROR_PAGE_FAULT_PAGING_FILE = 0x000002ef

3227 ERROR_CACHE_PAGE_LOCKED = 0x000002f0

3228 ERROR_CRASH_DUMP = 0x000002f1

3229 ERROR_BUFFER_ALL_ZEROS = 0x000002f2

3230 ERROR_REPARSE_OBJECT = 0x000002f3

3231 ERROR_RESOURCE_REQUIREMENTS_CHANGED = 0x000002f4

3232 ERROR_TRANSLATION_COMPLETE = 0x000002f5

3233 ERROR_NOTHING_TO_TERMINATE = 0x000002f6

3234 ERROR_PROCESS_NOT_IN_JOB = 0x000002f7

3235 ERROR_PROCESS_IN_JOB = 0x000002f8

3236 ERROR_VOLSNAP_HIBERNATE_READY = 0x000002f9

3237 ERROR_FSFILTER_OP_COMPLETED_SUCCESSFULLY = 0x000002fa

3238 ERROR_INTERRUPT_VECTOR_ALREADY_CONNECTED = 0x000002fb

3239 ERROR_INTERRUPT_STILL_CONNECTED = 0x000002fc

3240 ERROR_WAIT_FOR_OPLOCK = 0x000002fd

3241 ERROR_DBG_EXCEPTION_HANDLED = 0x000002fe

3242 ERROR_DBG_CONTINUE = 0x000002ff

3243 ERROR_CALLBACK_POP_STACK = 0x00000300

3244 ERROR_COMPRESSION_DISABLED = 0x00000301

3245 ERROR_CANTFETCHBACKWARDS = 0x00000302

3246 ERROR_CANTSCROLLBACKWARDS = 0x00000303

3247 ERROR_ROWSNOTRELEASED = 0x00000304

3248 ERROR_BAD_ACCESSOR_FLAGS = 0x00000305

3249 ERROR_ERRORS_ENCOUNTERED = 0x00000306

3250 ERROR_NOT_CAPABLE = 0x00000307

3251 ERROR_REQUEST_OUT_OF_SEQUENCE = 0x00000308

3252 ERROR_VERSION_PARSE_ERROR = 0x00000309

3253 ERROR_BADSTARTPOSITION = 0x0000030a

3254 ERROR_MEMORY_HARDWARE = 0x0000030b

3255 ERROR_DISK_REPAIR_DISABLED = 0x0000030c

3256 ERROR_INSUFFICIENT_RESOURCE_FOR_SPECIFIED_SHARED_SECTION_SIZE = 0x0000030d

3257 ERROR_SYSTEM_POWERSTATE_TRANSITION = 0x0000030e

3258 ERROR_SYSTEM_POWERSTATE_COMPLEX_TRANSITION = 0x0000030f

3259 ERROR_MCA_EXCEPTION = 0x00000310

3260 ERROR_ACCESS_AUDIT_BY_POLICY = 0x00000311

3261 ERROR_ACCESS_DISABLED_NO_SAFER_UI_BY_POLICY = 0x00000312

3262 ERROR_ABANDON_HIBERFILE = 0x00000313

3263 ERROR_LOST_WRITEBEHIND_DATA_NETWORK_DISCONNECTED = 0x00000314

3264 ERROR_LOST_WRITEBEHIND_DATA_NETWORK_SERVER_ERROR = 0x00000315

3265 ERROR_LOST_WRITEBEHIND_DATA_LOCAL_DISK_ERROR = 0x00000316

3266 ERROR_BAD_MCFG_TABLE = 0x00000317

3267 ERROR_DISK_REPAIR_REDIRECTED = 0x00000318

3268 ERROR_DISK_REPAIR_UNSUCCESSFUL = 0x00000319

3269 ERROR_CORRUPT_LOG_OVERFULL = 0x0000031a

3270 ERROR_CORRUPT_LOG_CORRUPTED = 0x0000031b

3271 ERROR_CORRUPT_LOG_UNAVAILABLE = 0x0000031c

3272 ERROR_CORRUPT_LOG_DELETED_FULL = 0x0000031d

3273 ERROR_CORRUPT_LOG_CLEARED = 0x0000031e

3274 ERROR_ORPHAN_NAME_EXHAUSTED = 0x0000031f

3275 ERROR_OPLOCK_SWITCHED_TO_NEW_HANDLE = 0x00000320

3276 ERROR_CANNOT_GRANT_REQUESTED_OPLOCK = 0x00000321

3277 ERROR_CANNOT_BREAK_OPLOCK = 0x00000322

3278 ERROR_OPLOCK_HANDLE_CLOSED = 0x00000323

3279 ERROR_NO_ACE_CONDITION = 0x00000324

3280 ERROR_INVALID_ACE_CONDITION = 0x00000325

3281 ERROR_FILE_HANDLE_REVOKED = 0x00000326

3282 ERROR_IMAGE_AT_DIFFERENT_BASE = 0x00000327

3283 ERROR_EA_ACCESS_DENIED = 0x000003e2

3284 ERROR_OPERATION_ABORTED = 0x000003e3

3285 ERROR_IO_INCOMPLETE = 0x000003e4

3286 ERROR_IO_PENDING = 0x000003e5

3287 ERROR_NOACCESS = 0x000003e6

3288 ERROR_SWAPERROR = 0x000003e7

3289 ERROR_STACK_OVERFLOW = 0x000003e9

3290 ERROR_INVALID_MESSAGE = 0x000003ea

3291 ERROR_CAN_NOT_COMPLETE = 0x000003eb

3292 ERROR_INVALID_FLAGS = 0x000003ec

3293 ERROR_UNRECOGNIZED_VOLUME = 0x000003ed

3294 ERROR_FILE_INVALID = 0x000003ee

3295 ERROR_FULLSCREEN_MODE = 0x000003ef

3296 ERROR_NO_TOKEN = 0x000003f0

3297 ERROR_BADDB = 0x000003f1

3298 ERROR_BADKEY = 0x000003f2

3299 ERROR_CANTOPEN = 0x000003f3

3300 ERROR_CANTREAD = 0x000003f4

3301 ERROR_CANTWRITE = 0x000003f5

3302 ERROR_REGISTRY_RECOVERED = 0x000003f6

3303 ERROR_REGISTRY_CORRUPT = 0x000003f7

3304 ERROR_REGISTRY_IO_FAILED = 0x000003f8

3305 ERROR_NOT_REGISTRY_FILE = 0x000003f9

3306 ERROR_KEY_DELETED = 0x000003fa

3307 ERROR_NO_LOG_SPACE = 0x000003fb

3308 ERROR_KEY_HAS_CHILDREN = 0x000003fc

3309 ERROR_CHILD_MUST_BE_VOLATILE = 0x000003fd

3310 ERROR_NOTIFY_ENUM_DIR = 0x000003fe

3311 ERROR_DEPENDENT_SERVICES_RUNNING = 0x0000041b

3312 ERROR_INVALID_SERVICE_CONTROL = 0x0000041c

3313 ERROR_SERVICE_REQUEST_TIMEOUT = 0x0000041d

3314 ERROR_SERVICE_NO_THREAD = 0x0000041e

3315 ERROR_SERVICE_DATABASE_LOCKED = 0x0000041f

3316 ERROR_SERVICE_ALREADY_RUNNING = 0x00000420

3317 ERROR_INVALID_SERVICE_ACCOUNT = 0x00000421

3318 ERROR_SERVICE_DISABLED = 0x00000422

3319 ERROR_CIRCULAR_DEPENDENCY = 0x00000423

3320 ERROR_SERVICE_DOES_NOT_EXIST = 0x00000424

3321 ERROR_SERVICE_CANNOT_ACCEPT_CTRL = 0x00000425

3322 ERROR_SERVICE_NOT_ACTIVE = 0x00000426

3323 ERROR_FAILED_SERVICE_CONTROLLER_CONNECT = 0x00000427

3324 ERROR_EXCEPTION_IN_SERVICE = 0x00000428

3325 ERROR_DATABASE_DOES_NOT_EXIST = 0x00000429

3326 ERROR_SERVICE_SPECIFIC_ERROR = 0x0000042a

3327 ERROR_PROCESS_ABORTED = 0x0000042b

3328 ERROR_SERVICE_DEPENDENCY_FAIL = 0x0000042c

3329 ERROR_SERVICE_LOGON_FAILED = 0x0000042d

3330 ERROR_SERVICE_START_HANG = 0x0000042e

3331 ERROR_INVALID_SERVICE_LOCK = 0x0000042f

3332 ERROR_SERVICE_MARKED_FOR_DELETE = 0x00000430

3333 ERROR_SERVICE_EXISTS = 0x00000431

3334 ERROR_ALREADY_RUNNING_LKG = 0x00000432

3335 ERROR_SERVICE_DEPENDENCY_DELETED = 0x00000433

3336 ERROR_BOOT_ALREADY_ACCEPTED = 0x00000434

3337 ERROR_SERVICE_NEVER_STARTED = 0x00000435

3338 ERROR_DUPLICATE_SERVICE_NAME = 0x00000436

3339 ERROR_DIFFERENT_SERVICE_ACCOUNT = 0x00000437

3340 ERROR_CANNOT_DETECT_DRIVER_FAILURE = 0x00000438

3341 ERROR_CANNOT_DETECT_PROCESS_ABORT = 0x00000439

3342 ERROR_NO_RECOVERY_PROGRAM = 0x0000043a

3343 ERROR_SERVICE_NOT_IN_EXE = 0x0000043b

3344 ERROR_NOT_SAFEBOOT_SERVICE = 0x0000043c

3345 ERROR_END_OF_MEDIA = 0x0000044c

3346 ERROR_FILEMARK_DETECTED = 0x0000044d

3347 ERROR_BEGINNING_OF_MEDIA = 0x0000044e

3348 ERROR_SETMARK_DETECTED = 0x0000044f

3349 ERROR_NO_DATA_DETECTED = 0x00000450

3350 ERROR_PARTITION_FAILURE = 0x00000451

3351 ERROR_INVALID_BLOCK_LENGTH = 0x00000452

3352 ERROR_DEVICE_NOT_PARTITIONED = 0x00000453

3353 ERROR_UNABLE_TO_LOCK_MEDIA = 0x00000454

3354 ERROR_UNABLE_TO_UNLOAD_MEDIA = 0x00000455

3355 ERROR_MEDIA_CHANGED = 0x00000456

3356 ERROR_BUS_RESET = 0x00000457

3357 ERROR_NO_MEDIA_IN_DRIVE = 0x00000458

3358 ERROR_NO_UNICODE_TRANSLATION = 0x00000459

3359 ERROR_DLL_INIT_FAILED = 0x0000045a

3360 ERROR_SHUTDOWN_IN_PROGRESS = 0x0000045b

3361 ERROR_NO_SHUTDOWN_IN_PROGRESS = 0x0000045c

3362 ERROR_IO_DEVICE = 0x0000045d

3363 ERROR_SERIAL_NO_DEVICE = 0x0000045e

3364 ERROR_IRQ_BUSY = 0x0000045f

3365 ERROR_MORE_WRITES = 0x00000460

3366 ERROR_COUNTER_TIMEOUT = 0x00000461

3367 ERROR_FLOPPY_ID_MARK_NOT_FOUND = 0x00000462

3368 ERROR_FLOPPY_WRONG_CYLINDER = 0x00000463

3369 ERROR_FLOPPY_UNKNOWN_ERROR = 0x00000464

3370 ERROR_FLOPPY_BAD_REGISTERS = 0x00000465

3371 ERROR_DISK_RECALIBRATE_FAILED = 0x00000466

3372 ERROR_DISK_OPERATION_FAILED = 0x00000467

3373 ERROR_DISK_RESET_FAILED = 0x00000468

3374 ERROR_EOM_OVERFLOW = 0x00000469

3375 ERROR_NOT_ENOUGH_SERVER_MEMORY = 0x0000046a

3376 ERROR_POSSIBLE_DEADLOCK = 0x0000046b

3377 ERROR_MAPPED_ALIGNMENT = 0x0000046c

3378 ERROR_SET_POWER_STATE_VETOED = 0x00000474

3379 ERROR_SET_POWER_STATE_FAILED = 0x00000475

3380 ERROR_TOO_MANY_LINKS = 0x00000476

3381 ERROR_OLD_WIN_VERSION = 0x0000047e

3382 ERROR_APP_WRONG_OS = 0x0000047f

3383 ERROR_SINGLE_INSTANCE_APP = 0x00000480

3384 ERROR_RMODE_APP = 0x00000481

3385 ERROR_INVALID_DLL = 0x00000482

3386 ERROR_NO_ASSOCIATION = 0x00000483

3387 ERROR_DDE_FAIL = 0x00000484

3388 ERROR_DLL_NOT_FOUND = 0x00000485

3389 ERROR_NO_MORE_USER_HANDLES = 0x00000486

3390 ERROR_MESSAGE_SYNC_ONLY = 0x00000487

3391 ERROR_SOURCE_ELEMENT_EMPTY = 0x00000488

3392 ERROR_DESTINATION_ELEMENT_FULL = 0x00000489

3393 ERROR_ILLEGAL_ELEMENT_ADDRESS = 0x0000048a

3394 ERROR_MAGAZINE_NOT_PRESENT = 0x0000048b

3395 ERROR_DEVICE_REINITIALIZATION_NEEDED = 0x0000048c

3396 ERROR_DEVICE_REQUIRES_CLEANING = 0x0000048d

3397 ERROR_DEVICE_DOOR_OPEN = 0x0000048e

3398 ERROR_DEVICE_NOT_CONNECTED = 0x0000048f

3399 ERROR_NOT_FOUND = 0x00000490

3400 ERROR_NO_MATCH = 0x00000491

3401 ERROR_SET_NOT_FOUND = 0x00000492

3402 ERROR_POINT_NOT_FOUND = 0x00000493

3403 ERROR_NO_TRACKING_SERVICE = 0x00000494

3404 ERROR_NO_VOLUME_ID = 0x00000495

3405 ERROR_UNABLE_TO_REMOVE_REPLACED = 0x00000497

3406 ERROR_UNABLE_TO_MOVE_REPLACEMENT = 0x00000498

3407 ERROR_UNABLE_TO_MOVE_REPLACEMENT_2 = 0x00000499

3408 ERROR_JOURNAL_DELETE_IN_PROGRESS = 0x0000049a

3409 ERROR_JOURNAL_NOT_ACTIVE = 0x0000049b

3410 ERROR_POTENTIAL_FILE_FOUND = 0x0000049c

3411 ERROR_JOURNAL_ENTRY_DELETED = 0x0000049d

3412 ERROR_SHUTDOWN_IS_SCHEDULED = 0x000004a6

3413 ERROR_SHUTDOWN_USERS_LOGGED_ON = 0x000004a7

3414 ERROR_BAD_DEVICE = 0x000004b0

3415 ERROR_CONNECTION_UNAVAIL = 0x000004b1

3416 ERROR_DEVICE_ALREADY_REMEMBERED = 0x000004b2

3417 ERROR_NO_NET_OR_BAD_PATH = 0x000004b3

3418 ERROR_BAD_PROVIDER = 0x000004b4

3419 ERROR_CANNOT_OPEN_PROFILE = 0x000004b5

3420 ERROR_BAD_PROFILE = 0x000004b6

3421 ERROR_NOT_CONTAINER = 0x000004b7

3422 ERROR_EXTENDED_ERROR = 0x000004b8

3423 ERROR_INVALID_GROUPNAME = 0x000004b9

3424 ERROR_INVALID_COMPUTERNAME = 0x000004ba

3425 ERROR_INVALID_EVENTNAME = 0x000004bb

3426 ERROR_INVALID_DOMAINNAME = 0x000004bc

3427 ERROR_INVALID_SERVICENAME = 0x000004bd

3428 ERROR_INVALID_NETNAME = 0x000004be

3429 ERROR_INVALID_SHARENAME = 0x000004bf

3430 ERROR_INVALID_PASSWORDNAME = 0x000004c0

3431 ERROR_INVALID_MESSAGENAME = 0x000004c1

3432 ERROR_INVALID_MESSAGEDEST = 0x000004c2

3433 ERROR_SESSION_CREDENTIAL_CONFLICT = 0x000004c3

3434 ERROR_REMOTE_SESSION_LIMIT_EXCEEDED = 0x000004c4

3435 ERROR_DUP_DOMAINNAME = 0x000004c5

3436 ERROR_NO_NETWORK = 0x000004c6

3437 ERROR_CANCELLED = 0x000004c7

3438 ERROR_USER_MAPPED_FILE = 0x000004c8

3439 ERROR_CONNECTION_REFUSED = 0x000004c9

3440 ERROR_GRACEFUL_DISCONNECT = 0x000004ca

3441 ERROR_ADDRESS_ALREADY_ASSOCIATED = 0x000004cb

3442 ERROR_ADDRESS_NOT_ASSOCIATED = 0x000004cc

3443 ERROR_CONNECTION_INVALID = 0x000004cd

3444 ERROR_CONNECTION_ACTIVE = 0x000004ce

3445 ERROR_NETWORK_UNREACHABLE = 0x000004cf

3446 ERROR_HOST_UNREACHABLE = 0x000004d0

3447 ERROR_PROTOCOL_UNREACHABLE = 0x000004d1

3448 ERROR_PORT_UNREACHABLE = 0x000004d2

3449 ERROR_REQUEST_ABORTED = 0x000004d3

3450 ERROR_CONNECTION_ABORTED = 0x000004d4

3451 ERROR_RETRY = 0x000004d5

3452 ERROR_CONNECTION_COUNT_LIMIT = 0x000004d6

3453 ERROR_LOGIN_TIME_RESTRICTION = 0x000004d7

3454 ERROR_LOGIN_WKSTA_RESTRICTION = 0x000004d8

3455 ERROR_INCORRECT_ADDRESS = 0x000004d9

3456 ERROR_ALREADY_REGISTERED = 0x000004da

3457 ERROR_SERVICE_NOT_FOUND = 0x000004db

3458 ERROR_NOT_AUTHENTICATED = 0x000004dc

3459 ERROR_NOT_LOGGED_ON = 0x000004dd

3460 ERROR_CONTINUE = 0x000004de

3461 ERROR_ALREADY_INITIALIZED = 0x000004df

3462 ERROR_NO_MORE_DEVICES = 0x000004e0

3463 ERROR_NO_SUCH_SITE = 0x000004e1

3464 ERROR_DOMAIN_CONTROLLER_EXISTS = 0x000004e2

3465 ERROR_ONLY_IF_CONNECTED = 0x000004e3

3466 ERROR_OVERRIDE_NOCHANGES = 0x000004e4

3467 ERROR_BAD_USER_PROFILE = 0x000004e5

3468 ERROR_NOT_SUPPORTED_ON_SBS = 0x000004e6

3469 ERROR_SERVER_SHUTDOWN_IN_PROGRESS = 0x000004e7

3470 ERROR_HOST_DOWN = 0x000004e8

3471 ERROR_NON_ACCOUNT_SID = 0x000004e9

3472 ERROR_NON_DOMAIN_SID = 0x000004ea

3473 ERROR_APPHELP_BLOCK = 0x000004eb

3474 ERROR_ACCESS_DISABLED_BY_POLICY = 0x000004ec

3475 ERROR_REG_NAT_CONSUMPTION = 0x000004ed

3476 ERROR_CSCSHARE_OFFLINE = 0x000004ee

3477 ERROR_PKINIT_FAILURE = 0x000004ef

3478 ERROR_SMARTCARD_SUBSYSTEM_FAILURE = 0x000004f0

3479 ERROR_DOWNGRADE_DETECTED = 0x000004f1

3480 ERROR_MACHINE_LOCKED = 0x000004f7

3481 ERROR_CALLBACK_SUPPLIED_INVALID_DATA = 0x000004f9

3482 ERROR_SYNC_FOREGROUND_REFRESH_REQUIRED = 0x000004fa

3483 ERROR_DRIVER_BLOCKED = 0x000004fb

3484 ERROR_INVALID_IMPORT_OF_NON_DLL = 0x000004fc

3485 ERROR_ACCESS_DISABLED_WEBBLADE = 0x000004fd

3486 ERROR_ACCESS_DISABLED_WEBBLADE_TAMPER = 0x000004fe

3487 ERROR_RECOVERY_FAILURE = 0x000004ff

3488 ERROR_ALREADY_FIBER = 0x00000500

3489 ERROR_ALREADY_THREAD = 0x00000501

3490 ERROR_STACK_BUFFER_OVERRUN = 0x00000502

3491 ERROR_PARAMETER_QUOTA_EXCEEDED = 0x00000503

3492 ERROR_DEBUGGER_INACTIVE = 0x00000504

3493 ERROR_DELAY_LOAD_FAILED = 0x00000505

3494 ERROR_VDM_DISALLOWED = 0x00000506

3495 ERROR_UNIDENTIFIED_ERROR = 0x00000507

3496 ERROR_INVALID_CRUNTIME_PARAMETER = 0x00000508

3497 ERROR_BEYOND_VDL = 0x00000509

3498 ERROR_INCOMPATIBLE_SERVICE_SID_TYPE = 0x0000050a

3499 ERROR_DRIVER_PROCESS_TERMINATED = 0x0000050b

3500 ERROR_IMPLEMENTATION_LIMIT = 0x0000050c

3501 ERROR_PROCESS_IS_PROTECTED = 0x0000050d

3502 ERROR_SERVICE_NOTIFY_CLIENT_LAGGING = 0x0000050e

3503 ERROR_DISK_QUOTA_EXCEEDED = 0x0000050f

3504 ERROR_CONTENT_BLOCKED = 0x00000510

3505 ERROR_INCOMPATIBLE_SERVICE_PRIVILEGE = 0x00000511

3506 ERROR_APP_HANG = 0x00000512

3507 ERROR_INVALID_LABEL = 0x00000513

3508 ERROR_NOT_ALL_ASSIGNED = 0x00000514

3509 ERROR_SOME_NOT_MAPPED = 0x00000515

3510 ERROR_NO_QUOTAS_FOR_ACCOUNT = 0x00000516

3511 ERROR_LOCAL_USER_SESSION_KEY = 0x00000517

3512 ERROR_NULL_LM_PASSWORD = 0x00000518

3513 ERROR_UNKNOWN_REVISION = 0x00000519

3514 ERROR_REVISION_MISMATCH = 0x0000051a

3515 ERROR_INVALID_OWNER = 0x0000051b

3516 ERROR_INVALID_PRIMARY_GROUP = 0x0000051c

3517 ERROR_NO_IMPERSONATION_TOKEN = 0x0000051d

3518 ERROR_CANT_DISABLE_MANDATORY = 0x0000051e

3519 ERROR_NO_LOGON_SERVERS = 0x0000051f

3520 ERROR_NO_SUCH_LOGON_SESSION = 0x00000520

3521 ERROR_NO_SUCH_PRIVILEGE = 0x00000521

3522 ERROR_PRIVILEGE_NOT_HELD = 0x00000522

3523 ERROR_INVALID_ACCOUNT_NAME = 0x00000523

3524 ERROR_USER_EXISTS = 0x00000524

3525 ERROR_NO_SUCH_USER = 0x00000525

3526 ERROR_GROUP_EXISTS = 0x00000526

3527 ERROR_NO_SUCH_GROUP = 0x00000527

3528 ERROR_MEMBER_IN_GROUP = 0x00000528

3529 ERROR_MEMBER_NOT_IN_GROUP = 0x00000529

3530 ERROR_LAST_ADMIN = 0x0000052a

3531 ERROR_WRONG_PASSWORD = 0x0000052b

3532 ERROR_ILL_FORMED_PASSWORD = 0x0000052c

3533 ERROR_PASSWORD_RESTRICTION = 0x0000052d

3534 ERROR_LOGON_FAILURE = 0x0000052e

3535 ERROR_ACCOUNT_RESTRICTION = 0x0000052f

3536 ERROR_INVALID_LOGON_HOURS = 0x00000530

3537 ERROR_INVALID_WORKSTATION = 0x00000531

3538 ERROR_PASSWORD_EXPIRED = 0x00000532

3539 ERROR_ACCOUNT_DISABLED = 0x00000533

3540 ERROR_NONE_MAPPED = 0x00000534

3541 ERROR_TOO_MANY_LUIDS_REQUESTED = 0x00000535

3542 ERROR_LUIDS_EXHAUSTED = 0x00000536

3543 ERROR_INVALID_SUB_AUTHORITY = 0x00000537

3544 ERROR_INVALID_ACL = 0x00000538

3545 ERROR_INVALID_SID = 0x00000539

3546 ERROR_INVALID_SECURITY_DESCR = 0x0000053a

3547 ERROR_BAD_INHERITANCE_ACL = 0x0000053c

3548 ERROR_SERVER_DISABLED = 0x0000053d

3549 ERROR_SERVER_NOT_DISABLED = 0x0000053e

3550 ERROR_INVALID_ID_AUTHORITY = 0x0000053f

3551 ERROR_ALLOTTED_SPACE_EXCEEDED = 0x00000540

3552 ERROR_INVALID_GROUP_ATTRIBUTES = 0x00000541

3553 ERROR_BAD_IMPERSONATION_LEVEL = 0x00000542

3554 ERROR_CANT_OPEN_ANONYMOUS = 0x00000543

3555 ERROR_BAD_VALIDATION_CLASS = 0x00000544

3556 ERROR_BAD_TOKEN_TYPE = 0x00000545

3557 ERROR_NO_SECURITY_ON_OBJECT = 0x00000546

3558 ERROR_CANT_ACCESS_DOMAIN_INFO = 0x00000547

3559 ERROR_INVALID_SERVER_STATE = 0x00000548

3560 ERROR_INVALID_DOMAIN_STATE = 0x00000549

3561 ERROR_INVALID_DOMAIN_ROLE = 0x0000054a

3562 ERROR_NO_SUCH_DOMAIN = 0x0000054b

3563 ERROR_DOMAIN_EXISTS = 0x0000054c

3564 ERROR_DOMAIN_LIMIT_EXCEEDED = 0x0000054d

3565 ERROR_INTERNAL_DB_CORRUPTION = 0x0000054e

3566 ERROR_INTERNAL_ERROR = 0x0000054f

3567 ERROR_GENERIC_NOT_MAPPED = 0x00000550

3568 ERROR_BAD_DESCRIPTOR_FORMAT = 0x00000551

3569 ERROR_NOT_LOGON_PROCESS = 0x00000552

3570 ERROR_LOGON_SESSION_EXISTS = 0x00000553

3571 ERROR_NO_SUCH_PACKAGE = 0x00000554

3572 ERROR_BAD_LOGON_SESSION_STATE = 0x00000555

3573 ERROR_LOGON_SESSION_COLLISION = 0x00000556

3574 ERROR_INVALID_LOGON_TYPE = 0x00000557

3575 ERROR_CANNOT_IMPERSONATE = 0x00000558

3576 ERROR_RXACT_INVALID_STATE = 0x00000559

3577 ERROR_RXACT_COMMIT_FAILURE = 0x0000055a

3578 ERROR_SPECIAL_ACCOUNT = 0x0000055b

3579 ERROR_SPECIAL_GROUP = 0x0000055c

3580 ERROR_SPECIAL_USER = 0x0000055d

3581 ERROR_MEMBERS_PRIMARY_GROUP = 0x0000055e

3582 ERROR_TOKEN_ALREADY_IN_USE = 0x0000055f

3583 ERROR_NO_SUCH_ALIAS = 0x00000560

3584 ERROR_MEMBER_NOT_IN_ALIAS = 0x00000561

3585 ERROR_MEMBER_IN_ALIAS = 0x00000562

3586 ERROR_ALIAS_EXISTS = 0x00000563

3587 ERROR_LOGON_NOT_GRANTED = 0x00000564

3588 ERROR_TOO_MANY_SECRETS = 0x00000565

3589 ERROR_SECRET_TOO_LONG = 0x00000566

3590 ERROR_INTERNAL_DB_ERROR = 0x00000567

3591 ERROR_TOO_MANY_CONTEXT_IDS = 0x00000568

3592 ERROR_LOGON_TYPE_NOT_GRANTED = 0x00000569

3593 ERROR_NT_CROSS_ENCRYPTION_REQUIRED = 0x0000056a

3594 ERROR_NO_SUCH_MEMBER = 0x0000056b

3595 ERROR_INVALID_MEMBER = 0x0000056c

3596 ERROR_TOO_MANY_SIDS = 0x0000056d

3597 ERROR_LM_CROSS_ENCRYPTION_REQUIRED = 0x0000056e

3598 ERROR_NO_INHERITANCE = 0x0000056f

3599 ERROR_FILE_CORRUPT = 0x00000570

3600 ERROR_DISK_CORRUPT = 0x00000571

3601 ERROR_NO_USER_SESSION_KEY = 0x00000572

3602 ERROR_LICENSE_QUOTA_EXCEEDED = 0x00000573

3603 ERROR_WRONG_TARGET_NAME = 0x00000574

3604 ERROR_MUTUAL_AUTH_FAILED = 0x00000575

3605 ERROR_TIME_SKEW = 0x00000576

3606 ERROR_CURRENT_DOMAIN_NOT_ALLOWED = 0x00000577

3607 ERROR_INVALID_WINDOW_HANDLE = 0x00000578

3608 ERROR_INVALID_MENU_HANDLE = 0x00000579

3609 ERROR_INVALID_CURSOR_HANDLE = 0x0000057a

3610 ERROR_INVALID_ACCEL_HANDLE = 0x0000057b

3611 ERROR_INVALID_HOOK_HANDLE = 0x0000057c

3612 ERROR_INVALID_DWP_HANDLE = 0x0000057d

3613 ERROR_TLW_WITH_WSCHILD = 0x0000057e

3614 ERROR_CANNOT_FIND_WND_CLASS = 0x0000057f

3615 ERROR_WINDOW_OF_OTHER_THREAD = 0x00000580

3616 ERROR_HOTKEY_ALREADY_REGISTERED = 0x00000581

3617 ERROR_CLASS_ALREADY_EXISTS = 0x00000582

3618 ERROR_CLASS_DOES_NOT_EXIST = 0x00000583

3619 ERROR_CLASS_HAS_WINDOWS = 0x00000584

3620 ERROR_INVALID_INDEX = 0x00000585

3621 ERROR_INVALID_ICON_HANDLE = 0x00000586

3622 ERROR_PRIVATE_DIALOG_INDEX = 0x00000587

3623 ERROR_LISTBOX_ID_NOT_FOUND = 0x00000588

3624 ERROR_NO_WILDCARD_CHARACTERS = 0x00000589

3625 ERROR_CLIPBOARD_NOT_OPEN = 0x0000058a

3626 ERROR_HOTKEY_NOT_REGISTERED = 0x0000058b

3627 ERROR_WINDOW_NOT_DIALOG = 0x0000058c

3628 ERROR_CONTROL_ID_NOT_FOUND = 0x0000058d

3629 ERROR_INVALID_COMBOBOX_MESSAGE = 0x0000058e

3630 ERROR_WINDOW_NOT_COMBOBOX = 0x0000058f

3631 ERROR_INVALID_EDIT_HEIGHT = 0x00000590

3632 ERROR_DC_NOT_FOUND = 0x00000591

3633 ERROR_INVALID_HOOK_FILTER = 0x00000592

3634 ERROR_INVALID_FILTER_PROC = 0x00000593

3635 ERROR_HOOK_NEEDS_HMOD = 0x00000594

3636 ERROR_GLOBAL_ONLY_HOOK = 0x00000595

3637 ERROR_JOURNAL_HOOK_SET = 0x00000596

3638 ERROR_HOOK_NOT_INSTALLED = 0x00000597

3639 ERROR_INVALID_LB_MESSAGE = 0x00000598

3640 ERROR_SETCOUNT_ON_BAD_LB = 0x00000599

3641 ERROR_LB_WITHOUT_TABSTOPS = 0x0000059a

3642 ERROR_DESTROY_OBJECT_OF_OTHER_THREAD = 0x0000059b

3643 ERROR_CHILD_WINDOW_MENU = 0x0000059c

3644 ERROR_NO_SYSTEM_MENU = 0x0000059d

3645 ERROR_INVALID_MSGBOX_STYLE = 0x0000059e

3646 ERROR_INVALID_SPI_VALUE = 0x0000059f

3647 ERROR_SCREEN_ALREADY_LOCKED = 0x000005a0

3648 ERROR_HWNDS_HAVE_DIFF_PARENT = 0x000005a1

3649 ERROR_NOT_CHILD_WINDOW = 0x000005a2

3650 ERROR_INVALID_GW_COMMAND = 0x000005a3

3651 ERROR_INVALID_THREAD_ID = 0x000005a4

3652 ERROR_NON_MDICHILD_WINDOW = 0x000005a5

3653 ERROR_POPUP_ALREADY_ACTIVE = 0x000005a6

3654 ERROR_NO_SCROLLBARS = 0x000005a7

3655 ERROR_INVALID_SCROLLBAR_RANGE = 0x000005a8

3656 ERROR_INVALID_SHOWWIN_COMMAND = 0x000005a9

3657 ERROR_NO_SYSTEM_RESOURCES = 0x000005aa

3658 ERROR_NONPAGED_SYSTEM_RESOURCES = 0x000005ab

3659 ERROR_PAGED_SYSTEM_RESOURCES = 0x000005ac

3660 ERROR_WORKING_SET_QUOTA = 0x000005ad

3661 ERROR_PAGEFILE_QUOTA = 0x000005ae

3662 ERROR_COMMITMENT_LIMIT = 0x000005af

3663 ERROR_MENU_ITEM_NOT_FOUND = 0x000005b0

3664 ERROR_INVALID_KEYBOARD_HANDLE = 0x000005b1

3665 ERROR_HOOK_TYPE_NOT_ALLOWED = 0x000005b2

3666 ERROR_REQUIRES_INTERACTIVE_WINDOWSTATION = 0x000005b3

3667 ERROR_TIMEOUT = 0x000005b4

3668 ERROR_INVALID_MONITOR_HANDLE = 0x000005b5

3669 ERROR_INCORRECT_SIZE = 0x000005b6

3670 ERROR_SYMLINK_CLASS_DISABLED = 0x000005b7

3671 ERROR_SYMLINK_NOT_SUPPORTED = 0x000005b8

3672 ERROR_XML_PARSE_ERROR = 0x000005b9

3673 ERROR_XMLDSIG_ERROR = 0x000005ba

3674 ERROR_RESTART_APPLICATION = 0x000005bb

3675 ERROR_WRONG_COMPARTMENT = 0x000005bc

3676 ERROR_AUTHIP_FAILURE = 0x000005bd

3677 ERROR_NO_NVRAM_RESOURCES = 0x000005be

3678 ERROR_NOT_GUI_PROCESS = 0x000005bf

3679 ERROR_EVENTLOG_FILE_CORRUPT = 0x000005dc

3680 ERROR_EVENTLOG_CANT_START = 0x000005dd

3681 ERROR_LOG_FILE_FULL = 0x000005de

3682 ERROR_EVENTLOG_FILE_CHANGED = 0x000005df

3683 ERROR_INVALID_TASK_NAME = 0x0000060e

3684 ERROR_INVALID_TASK_INDEX = 0x0000060f

3685 ERROR_THREAD_ALREADY_IN_TASK = 0x00000610

3686 ERROR_INSTALL_SERVICE_FAILURE = 0x00000641

3687 ERROR_INSTALL_USEREXIT = 0x00000642

3688 ERROR_INSTALL_FAILURE = 0x00000643

3689 ERROR_INSTALL_SUSPEND = 0x00000644

3690 ERROR_UNKNOWN_PRODUCT = 0x00000645

3691 ERROR_UNKNOWN_FEATURE = 0x00000646

3692 ERROR_UNKNOWN_COMPONENT = 0x00000647

3693 ERROR_UNKNOWN_PROPERTY = 0x00000648

3694 ERROR_INVALID_HANDLE_STATE = 0x00000649

3695 ERROR_BAD_CONFIGURATION = 0x0000064a

3696 ERROR_INDEX_ABSENT = 0x0000064b

3697 ERROR_INSTALL_SOURCE_ABSENT = 0x0000064c

3698 ERROR_INSTALL_PACKAGE_VERSION = 0x0000064d

3699 ERROR_PRODUCT_UNINSTALLED = 0x0000064e

3700 ERROR_BAD_QUERY_SYNTAX = 0x0000064f

3701 ERROR_INVALID_FIELD = 0x00000650

3702 ERROR_DEVICE_REMOVED = 0x00000651

3703 ERROR_INSTALL_ALREADY_RUNNING = 0x00000652

3704 ERROR_INSTALL_PACKAGE_OPEN_FAILED = 0x00000653

3705 ERROR_INSTALL_PACKAGE_INVALID = 0x00000654

3706 ERROR_INSTALL_UI_FAILURE = 0x00000655

3707 ERROR_INSTALL_LOG_FAILURE = 0x00000656

3708 ERROR_INSTALL_LANGUAGE_UNSUPPORTED = 0x00000657

3709 ERROR_INSTALL_TRANSFORM_FAILURE = 0x00000658

3710 ERROR_INSTALL_PACKAGE_REJECTED = 0x00000659

3711 ERROR_FUNCTION_NOT_CALLED = 0x0000065a

3712 ERROR_FUNCTION_FAILED = 0x0000065b

3713 ERROR_INVALID_TABLE = 0x0000065c

3714 ERROR_DATATYPE_MISMATCH = 0x0000065d

3715 ERROR_UNSUPPORTED_TYPE = 0x0000065e

3716 ERROR_CREATE_FAILED = 0x0000065f

3717 ERROR_INSTALL_TEMP_UNWRITABLE = 0x00000660

3718 ERROR_INSTALL_PLATFORM_UNSUPPORTED = 0x00000661

3719 ERROR_INSTALL_NOTUSED = 0x00000662

3720 ERROR_PATCH_PACKAGE_OPEN_FAILED = 0x00000663

3721 ERROR_PATCH_PACKAGE_INVALID = 0x00000664

3722 ERROR_PATCH_PACKAGE_UNSUPPORTED = 0x00000665

3723 ERROR_PRODUCT_VERSION = 0x00000666

3724 ERROR_INVALID_COMMAND_LINE = 0x00000667

3725 ERROR_INSTALL_REMOTE_DISALLOWED = 0x00000668

3726 ERROR_SUCCESS_REBOOT_INITIATED = 0x00000669

3727 ERROR_PATCH_TARGET_NOT_FOUND = 0x0000066a

3728 ERROR_PATCH_PACKAGE_REJECTED = 0x0000066b

3729 ERROR_INSTALL_TRANSFORM_REJECTED = 0x0000066c

3730 ERROR_INSTALL_REMOTE_PROHIBITED = 0x0000066d

3731 ERROR_PATCH_REMOVAL_UNSUPPORTED = 0x0000066e

3732 ERROR_UNKNOWN_PATCH = 0x0000066f

3733 ERROR_PATCH_NO_SEQUENCE = 0x00000670

3734 ERROR_PATCH_REMOVAL_DISALLOWED = 0x00000671

3735 ERROR_INVALID_PATCH_XML = 0x00000672

3736 ERROR_PATCH_MANAGED_ADVERTISED_PRODUCT = 0x00000673

3737 ERROR_INSTALL_SERVICE_SAFEBOOT = 0x00000674

3738 ERROR_FAIL_FAST_EXCEPTION = 0x00000675

3739 ERROR_INSTALL_REJECTED = 0x00000676

3740 RPC_S_INVALID_STRING_BINDING = 0x000006a4

3741 RPC_S_WRONG_KIND_OF_BINDING = 0x000006a5

3742 RPC_S_INVALID_BINDING = 0x000006a6

3743 RPC_S_PROTSEQ_NOT_SUPPORTED = 0x000006a7

3744 RPC_S_INVALID_RPC_PROTSEQ = 0x000006a8

3745 RPC_S_INVALID_STRING_UUID = 0x000006a9

3746 RPC_S_INVALID_ENDPOINT_FORMAT = 0x000006aa

3747 RPC_S_INVALID_NET_ADDR = 0x000006ab

3748 RPC_S_NO_ENDPOINT_FOUND = 0x000006ac

3749 RPC_S_INVALID_TIMEOUT = 0x000006ad

3750 RPC_S_OBJECT_NOT_FOUND = 0x000006ae

3751 RPC_S_ALREADY_REGISTERED = 0x000006af

3752 RPC_S_TYPE_ALREADY_REGISTERED = 0x000006b0

3753 RPC_S_ALREADY_LISTENING = 0x000006b1

3754 RPC_S_NO_PROTSEQS_REGISTERED = 0x000006b2

3755 RPC_S_NOT_LISTENING = 0x000006b3

3756 RPC_S_UNKNOWN_MGR_TYPE = 0x000006b4

3757 RPC_S_UNKNOWN_IF = 0x000006b5

3758 RPC_S_NO_BINDINGS = 0x000006b6

3759 RPC_S_NO_PROTSEQS = 0x000006b7

3760 RPC_S_CANT_CREATE_ENDPOINT = 0x000006b8

3761 RPC_S_OUT_OF_RESOURCES = 0x000006b9

3762 RPC_S_SERVER_UNAVAILABLE = 0x000006ba

3763 RPC_S_SERVER_TOO_BUSY = 0x000006bb

3764 RPC_S_INVALID_NETWORK_OPTIONS = 0x000006bc

3765 RPC_S_NO_CALL_ACTIVE = 0x000006bd

3766 RPC_S_CALL_FAILED = 0x000006be

3767 RPC_S_CALL_FAILED_DNE = 0x000006bf

3768 RPC_S_PROTOCOL_ERROR = 0x000006c0

3769 RPC_S_PROXY_ACCESS_DENIED = 0x000006c1

3770 RPC_S_UNSUPPORTED_TRANS_SYN = 0x000006c2

3771 RPC_S_UNSUPPORTED_TYPE = 0x000006c4

3772 RPC_S_INVALID_TAG = 0x000006c5

3773 RPC_S_INVALID_BOUND = 0x000006c6

3774 RPC_S_NO_ENTRY_NAME = 0x000006c7

3775 RPC_S_INVALID_NAME_SYNTAX = 0x000006c8

3776 RPC_S_UNSUPPORTED_NAME_SYNTAX = 0x000006c9

3777 RPC_S_UUID_NO_ADDRESS = 0x000006cb

3778 RPC_S_DUPLICATE_ENDPOINT = 0x000006cc

3779 RPC_S_UNKNOWN_AUTHN_TYPE = 0x000006cd

3780 RPC_S_MAX_CALLS_TOO_SMALL = 0x000006ce

3781 RPC_S_STRING_TOO_LONG = 0x000006cf

3782 RPC_S_PROTSEQ_NOT_FOUND = 0x000006d0

3783 RPC_S_PROCNUM_OUT_OF_RANGE = 0x000006d1

3784 RPC_S_BINDING_HAS_NO_AUTH = 0x000006d2

3785 RPC_S_UNKNOWN_AUTHN_SERVICE = 0x000006d3

3786 RPC_S_UNKNOWN_AUTHN_LEVEL = 0x000006d4

3787 RPC_S_INVALID_AUTH_IDENTITY = 0x000006d5

3788 RPC_S_UNKNOWN_AUTHZ_SERVICE = 0x000006d6

3789 EPT_S_INVALID_ENTRY = 0x000006d7

3790 EPT_S_CANT_PERFORM_OP = 0x000006d8

3791 EPT_S_NOT_REGISTERED = 0x000006d9

3792 RPC_S_NOTHING_TO_EXPORT = 0x000006da

3793 RPC_S_INCOMPLETE_NAME = 0x000006db

3794 RPC_S_INVALID_VERS_OPTION = 0x000006dc

3795 RPC_S_NO_MORE_MEMBERS = 0x000006dd

3796 RPC_S_NOT_ALL_OBJS_UNEXPORTED = 0x000006de

3797 RPC_S_INTERFACE_NOT_FOUND = 0x000006df

3798 RPC_S_ENTRY_ALREADY_EXISTS = 0x000006e0

3799 RPC_S_ENTRY_NOT_FOUND = 0x000006e1

3800 RPC_S_NAME_SERVICE_UNAVAILABLE = 0x000006e2

3801 RPC_S_INVALID_NAF_ID = 0x000006e3

3802 RPC_S_CANNOT_SUPPORT = 0x000006e4

3803 RPC_S_NO_CONTEXT_AVAILABLE = 0x000006e5

3804 RPC_S_INTERNAL_ERROR = 0x000006e6

3805 RPC_S_ZERO_DIVIDE = 0x000006e7

3806 RPC_S_ADDRESS_ERROR = 0x000006e8

3807 RPC_S_FP_DIV_ZERO = 0x000006e9

3808 RPC_S_FP_UNDERFLOW = 0x000006ea

3809 RPC_S_FP_OVERFLOW = 0x000006eb

3810 RPC_X_NO_MORE_ENTRIES = 0x000006ec

3811 RPC_X_SS_CHAR_TRANS_OPEN_FAIL = 0x000006ed

3812 RPC_X_SS_CHAR_TRANS_SHORT_FILE = 0x000006ee

3813 RPC_X_SS_IN_NULL_CONTEXT = 0x000006ef

3814 RPC_X_SS_CONTEXT_DAMAGED = 0x000006f1

3815 RPC_X_SS_HANDLES_MISMATCH = 0x000006f2

3816 RPC_X_SS_CANNOT_GET_CALL_HANDLE = 0x000006f3

3817 RPC_X_NULL_REF_POINTER = 0x000006f4

3818 RPC_X_ENUM_VALUE_OUT_OF_RANGE = 0x000006f5

3819 RPC_X_BYTE_COUNT_TOO_SMALL = 0x000006f6

3820 RPC_X_BAD_STUB_DATA = 0x000006f7

3821 ERROR_INVALID_USER_BUFFER = 0x000006f8

3822 ERROR_UNRECOGNIZED_MEDIA = 0x000006f9

3823 ERROR_NO_TRUST_LSA_SECRET = 0x000006fa

3824 ERROR_NO_TRUST_SAM_ACCOUNT = 0x000006fb

3825 ERROR_TRUSTED_DOMAIN_FAILURE = 0x000006fc

3826 ERROR_TRUSTED_RELATIONSHIP_FAILURE = 0x000006fd

3827 ERROR_TRUST_FAILURE = 0x000006fe

3828 RPC_S_CALL_IN_PROGRESS = 0x000006ff

3829 ERROR_NETLOGON_NOT_STARTED = 0x00000700

3830 ERROR_ACCOUNT_EXPIRED = 0x00000701

3831 ERROR_REDIRECTOR_HAS_OPEN_HANDLES = 0x00000702

3832 ERROR_PRINTER_DRIVER_ALREADY_INSTALLED = 0x00000703

3833 ERROR_UNKNOWN_PORT = 0x00000704

3834 ERROR_UNKNOWN_PRINTER_DRIVER = 0x00000705

3835 ERROR_UNKNOWN_PRINTPROCESSOR = 0x00000706

3836 ERROR_INVALID_SEPARATOR_FILE = 0x00000707

3837 ERROR_INVALID_PRIORITY = 0x00000708

3838 ERROR_INVALID_PRINTER_NAME = 0x00000709

3839 ERROR_PRINTER_ALREADY_EXISTS = 0x0000070a

3840 ERROR_INVALID_PRINTER_COMMAND = 0x0000070b

3841 ERROR_INVALID_DATATYPE = 0x0000070c

3842 ERROR_INVALID_ENVIRONMENT = 0x0000070d

3843 RPC_S_NO_MORE_BINDINGS = 0x0000070e

3844 ERROR_NOLOGON_INTERDOMAIN_TRUST_ACCOUNT = 0x0000070f

3845 ERROR_NOLOGON_WORKSTATION_TRUST_ACCOUNT = 0x00000710

3846 ERROR_NOLOGON_SERVER_TRUST_ACCOUNT = 0x00000711

3847 ERROR_DOMAIN_TRUST_INCONSISTENT = 0x00000712

3848 ERROR_SERVER_HAS_OPEN_HANDLES = 0x00000713

3849 ERROR_RESOURCE_DATA_NOT_FOUND = 0x00000714

3850 ERROR_RESOURCE_TYPE_NOT_FOUND = 0x00000715

3851 ERROR_RESOURCE_NAME_NOT_FOUND = 0x00000716

3852 ERROR_RESOURCE_LANG_NOT_FOUND = 0x00000717

3853 ERROR_NOT_ENOUGH_QUOTA = 0x00000718

3854 RPC_S_NO_INTERFACES = 0x00000719

3855 RPC_S_CALL_CANCELLED = 0x0000071a

3856 RPC_S_BINDING_INCOMPLETE = 0x0000071b

3857 RPC_S_COMM_FAILURE = 0x0000071c

3858 RPC_S_UNSUPPORTED_AUTHN_LEVEL = 0x0000071d

3859 RPC_S_NO_PRINC_NAME = 0x0000071e

3860 RPC_S_NOT_RPC_ERROR = 0x0000071f

3861 RPC_S_UUID_LOCAL_ONLY = 0x00000720

3862 RPC_S_SEC_PKG_ERROR = 0x00000721

3863 RPC_S_NOT_CANCELLED = 0x00000722

3864 RPC_X_INVALID_ES_ACTION = 0x00000723

3865 RPC_X_WRONG_ES_VERSION = 0x00000724

3866 RPC_X_WRONG_STUB_VERSION = 0x00000725

3867 RPC_X_INVALID_PIPE_OBJECT = 0x00000726

3868 RPC_X_WRONG_PIPE_ORDER = 0x00000727

3869 RPC_X_WRONG_PIPE_VERSION = 0x00000728

3870 RPC_S_COOKIE_AUTH_FAILED = 0x00000729

3871 RPC_S_GROUP_MEMBER_NOT_FOUND = 0x0000076a

3872 EPT_S_CANT_CREATE = 0x0000076b

3873 RPC_S_INVALID_OBJECT = 0x0000076c

3874 ERROR_INVALID_TIME = 0x0000076d

3875 ERROR_INVALID_FORM_NAME = 0x0000076e

3876 ERROR_INVALID_FORM_SIZE = 0x0000076f

3877 ERROR_ALREADY_WAITING = 0x00000770

3878 ERROR_PRINTER_DELETED = 0x00000771

3879 ERROR_INVALID_PRINTER_STATE = 0x00000772

3880 ERROR_PASSWORD_MUST_CHANGE = 0x00000773

3881 ERROR_DOMAIN_CONTROLLER_NOT_FOUND = 0x00000774

3882 ERROR_ACCOUNT_LOCKED_OUT = 0x00000775

3883 OR_INVALID_OXID = 0x00000776

3884 OR_INVALID_OID = 0x00000777

3885 OR_INVALID_SET = 0x00000778

3886 RPC_S_SEND_INCOMPLETE = 0x00000779

3887 RPC_S_INVALID_ASYNC_HANDLE = 0x0000077a

3888 RPC_S_INVALID_ASYNC_CALL = 0x0000077b

3889 RPC_X_PIPE_CLOSED = 0x0000077c

3890 RPC_X_PIPE_DISCIPLINE_ERROR = 0x0000077d

3891 RPC_X_PIPE_EMPTY = 0x0000077e

3892 ERROR_NO_SITENAME = 0x0000077f

3893 ERROR_CANT_ACCESS_FILE = 0x00000780

3894 ERROR_CANT_RESOLVE_FILENAME = 0x00000781

3895 RPC_S_ENTRY_TYPE_MISMATCH = 0x00000782

3896 RPC_S_NOT_ALL_OBJS_EXPORTED = 0x00000783

3897 RPC_S_INTERFACE_NOT_EXPORTED = 0x00000784

3898 RPC_S_PROFILE_NOT_ADDED = 0x00000785

3899 RPC_S_PRF_ELT_NOT_ADDED = 0x00000786

3900 RPC_S_PRF_ELT_NOT_REMOVED = 0x00000787

3901 RPC_S_GRP_ELT_NOT_ADDED = 0x00000788

3902 RPC_S_GRP_ELT_NOT_REMOVED = 0x00000789

3903 ERROR_KM_DRIVER_BLOCKED = 0x0000078a

3904 ERROR_CONTEXT_EXPIRED = 0x0000078b

3905 ERROR_PER_USER_TRUST_QUOTA_EXCEEDED = 0x0000078c

3906 ERROR_ALL_USER_TRUST_QUOTA_EXCEEDED = 0x0000078d

3907 ERROR_USER_DELETE_TRUST_QUOTA_EXCEEDED = 0x0000078e

3908 ERROR_AUTHENTICATION_FIREWALL_FAILED = 0x0000078f

3909 ERROR_REMOTE_PRINT_CONNECTIONS_BLOCKED = 0x00000790

3910 ERROR_NTLM_BLOCKED = 0x00000791

3911 ERROR_PASSWORD_CHANGE_REQUIRED = 0x00000792

3912 ERROR_INVALID_PIXEL_FORMAT = 0x000007d0

3913 ERROR_BAD_DRIVER = 0x000007d1

3914 ERROR_INVALID_WINDOW_STYLE = 0x000007d2

3915 ERROR_METAFILE_NOT_SUPPORTED = 0x000007d3

3916 ERROR_TRANSFORM_NOT_SUPPORTED = 0x000007d4

3917 ERROR_CLIPPING_NOT_SUPPORTED = 0x000007d5

3918 ERROR_INVALID_CMM = 0x000007da

3919 ERROR_INVALID_PROFILE = 0x000007db

3920 ERROR_TAG_NOT_FOUND = 0x000007dc

3921 ERROR_TAG_NOT_PRESENT = 0x000007dd

3922 ERROR_DUPLICATE_TAG = 0x000007de

3923 ERROR_PROFILE_NOT_ASSOCIATED_WITH_DEVICE = 0x000007df

3924 ERROR_PROFILE_NOT_FOUND = 0x000007e0

3925 ERROR_INVALID_COLORSPACE = 0x000007e1

3926 ERROR_ICM_NOT_ENABLED = 0x000007e2

3927 ERROR_DELETING_ICM_XFORM = 0x000007e3

3928 ERROR_INVALID_TRANSFORM = 0x000007e4

3929 ERROR_COLORSPACE_MISMATCH = 0x000007e5

3930 ERROR_INVALID_COLORINDEX = 0x000007e6

3931 ERROR_PROFILE_DOES_NOT_MATCH_DEVICE = 0x000007e7

3932 ERROR_CONNECTED_OTHER_PASSWORD = 0x0000083c

3933 ERROR_CONNECTED_OTHER_PASSWORD_DEFAULT = 0x0000083d

3934 ERROR_BAD_USERNAME = 0x0000089a

3935 ERROR_NOT_CONNECTED = 0x000008ca

3936 ERROR_OPEN_FILES = 0x00000961

3937 ERROR_ACTIVE_CONNECTIONS = 0x00000962

3938 ERROR_DEVICE_IN_USE = 0x00000964

3939 ERROR_UNKNOWN_PRINT_MONITOR = 0x00000bb8

3940 ERROR_PRINTER_DRIVER_IN_USE = 0x00000bb9

3941 ERROR_SPOOL_FILE_NOT_FOUND = 0x00000bba

3942 ERROR_SPL_NO_STARTDOC = 0x00000bbb

3943 ERROR_SPL_NO_ADDJOB = 0x00000bbc

3944 ERROR_PRINT_PROCESSOR_ALREADY_INSTALLED = 0x00000bbd

3945 ERROR_PRINT_MONITOR_ALREADY_INSTALLED = 0x00000bbe

3946 ERROR_INVALID_PRINT_MONITOR = 0x00000bbf

3947 ERROR_PRINT_MONITOR_IN_USE = 0x00000bc0

3948 ERROR_PRINTER_HAS_JOBS_QUEUED = 0x00000bc1

3949 ERROR_SUCCESS_REBOOT_REQUIRED = 0x00000bc2

3950 ERROR_SUCCESS_RESTART_REQUIRED = 0x00000bc3

3951 ERROR_PRINTER_NOT_FOUND = 0x00000bc4

3952 ERROR_PRINTER_DRIVER_WARNED = 0x00000bc5

3953 ERROR_PRINTER_DRIVER_BLOCKED = 0x00000bc6

3954 ERROR_PRINTER_DRIVER_PACKAGE_IN_USE = 0x00000bc7

3955 ERROR_CORE_DRIVER_PACKAGE_NOT_FOUND = 0x00000bc8

3956 ERROR_FAIL_REBOOT_REQUIRED = 0x00000bc9

3957 ERROR_FAIL_REBOOT_INITIATED = 0x00000bca

3958 ERROR_PRINTER_DRIVER_DOWNLOAD_NEEDED = 0x00000bcb

3959 ERROR_PRINT_JOB_RESTART_REQUIRED = 0x00000bcc

3960 ERROR_INVALID_PRINTER_DRIVER_MANIFEST = 0x00000bcd

3961 ERROR_PRINTER_NOT_SHAREABLE = 0x00000bce

3962 ERROR_REQUEST_PAUSED = 0x00000bea

3963 ERROR_IO_REISSUE_AS_CACHED = 0x00000f6e

3964 ERROR_WINS_INTERNAL = 0x00000fa0

3965 ERROR_CAN_NOT_DEL_LOCAL_WINS = 0x00000fa1

3966 ERROR_STATIC_INIT = 0x00000fa2

3967 ERROR_INC_BACKUP = 0x00000fa3

3968 ERROR_FULL_BACKUP = 0x00000fa4

3969 ERROR_REC_NON_EXISTENT = 0x00000fa5

3970 ERROR_RPL_NOT_ALLOWED = 0x00000fa6

3971 PEERDIST_ERROR_CONTENTINFO_VERSION_UNSUPPORTED = 0x00000fd2

3972 PEERDIST_ERROR_CANNOT_PARSE_CONTENTINFO = 0x00000fd3

3973 PEERDIST_ERROR_MISSING_DATA = 0x00000fd4

3974 PEERDIST_ERROR_NO_MORE = 0x00000fd5

3975 PEERDIST_ERROR_NOT_INITIALIZED = 0x00000fd6

3976 PEERDIST_ERROR_ALREADY_INITIALIZED = 0x00000fd7

3977 PEERDIST_ERROR_SHUTDOWN_IN_PROGRESS = 0x00000fd8

3978 PEERDIST_ERROR_INVALIDATED = 0x00000fd9

3979 PEERDIST_ERROR_ALREADY_EXISTS = 0x00000fda

3980 PEERDIST_ERROR_OPERATION_NOTFOUND = 0x00000fdb

3981 PEERDIST_ERROR_ALREADY_COMPLETED = 0x00000fdc

3982 PEERDIST_ERROR_OUT_OF_BOUNDS = 0x00000fdd

3983 PEERDIST_ERROR_VERSION_UNSUPPORTED = 0x00000fde

3984 PEERDIST_ERROR_INVALID_CONFIGURATION = 0x00000fdf

3985 PEERDIST_ERROR_NOT_LICENSED = 0x00000fe0

3986 PEERDIST_ERROR_SERVICE_UNAVAILABLE = 0x00000fe1

3987 PEERDIST_ERROR_TRUST_FAILURE = 0x00000fe2

3988 ERROR_DHCP_ADDRESS_CONFLICT = 0x00001004

3989 ERROR_WMI_GUID_NOT_FOUND = 0x00001068

3990 ERROR_WMI_INSTANCE_NOT_FOUND = 0x00001069

3991 ERROR_WMI_ITEMID_NOT_FOUND = 0x0000106a

3992 ERROR_WMI_TRY_AGAIN = 0x0000106b

3993 ERROR_WMI_DP_NOT_FOUND = 0x0000106c

3994 ERROR_WMI_UNRESOLVED_INSTANCE_REF = 0x0000106d

3995 ERROR_WMI_ALREADY_ENABLED = 0x0000106e

3996 ERROR_WMI_GUID_DISCONNECTED = 0x0000106f

3997 ERROR_WMI_SERVER_UNAVAILABLE = 0x00001070

3998 ERROR_WMI_DP_FAILED = 0x00001071

3999 ERROR_WMI_INVALID_MOF = 0x00001072

4000 ERROR_WMI_INVALID_REGINFO = 0x00001073

4001 ERROR_WMI_ALREADY_DISABLED = 0x00001074

4002 ERROR_WMI_READ_ONLY = 0x00001075

4003 ERROR_WMI_SET_FAILURE = 0x00001076

4004 ERROR_NOT_APPCONTAINER = 0x0000109a

4005 ERROR_APPCONTAINER_REQUIRED = 0x0000109b

4006 ERROR_NOT_SUPPORTED_IN_APPCONTAINER = 0x0000109c

4007 ERROR_INVALID_PACKAGE_SID_LENGTH = 0x0000109d

4008 ERROR_INVALID_MEDIA = 0x000010cc

4009 ERROR_INVALID_LIBRARY = 0x000010cd

4010 ERROR_INVALID_MEDIA_POOL = 0x000010ce

4011 ERROR_DRIVE_MEDIA_MISMATCH = 0x000010cf

4012 ERROR_MEDIA_OFFLINE = 0x000010d0

4013 ERROR_LIBRARY_OFFLINE = 0x000010d1

4014 ERROR_EMPTY = 0x000010d2

4015 ERROR_NOT_EMPTY = 0x000010d3

4016 ERROR_MEDIA_UNAVAILABLE = 0x000010d4

4017 ERROR_RESOURCE_DISABLED = 0x000010d5

4018 ERROR_INVALID_CLEANER = 0x000010d6

4019 ERROR_UNABLE_TO_CLEAN = 0x000010d7

4020 ERROR_OBJECT_NOT_FOUND = 0x000010d8

4021 ERROR_DATABASE_FAILURE = 0x000010d9

4022 ERROR_DATABASE_FULL = 0x000010da

4023 ERROR_MEDIA_INCOMPATIBLE = 0x000010db

4024 ERROR_RESOURCE_NOT_PRESENT = 0x000010dc

4025 ERROR_INVALID_OPERATION = 0x000010dd

4026 ERROR_MEDIA_NOT_AVAILABLE = 0x000010de

4027 ERROR_DEVICE_NOT_AVAILABLE = 0x000010df

4028 ERROR_REQUEST_REFUSED = 0x000010e0

4029 ERROR_INVALID_DRIVE_OBJECT = 0x000010e1

4030 ERROR_LIBRARY_FULL = 0x000010e2

4031 ERROR_MEDIUM_NOT_ACCESSIBLE = 0x000010e3

4032 ERROR_UNABLE_TO_LOAD_MEDIUM = 0x000010e4

4033 ERROR_UNABLE_TO_INVENTORY_DRIVE = 0x000010e5

4034 ERROR_UNABLE_TO_INVENTORY_SLOT = 0x000010e6

4035 ERROR_UNABLE_TO_INVENTORY_TRANSPORT = 0x000010e7

4036 ERROR_TRANSPORT_FULL = 0x000010e8

4037 ERROR_CONTROLLING_IEPORT = 0x000010e9

4038 ERROR_UNABLE_TO_EJECT_MOUNTED_MEDIA = 0x000010ea

4039 ERROR_CLEANER_SLOT_SET = 0x000010eb

4040 ERROR_CLEANER_SLOT_NOT_SET = 0x000010ec

4041 ERROR_CLEANER_CARTRIDGE_SPENT = 0x000010ed

4042 ERROR_UNEXPECTED_OMID = 0x000010ee

4043 ERROR_CANT_DELETE_LAST_ITEM = 0x000010ef

4044 ERROR_MESSAGE_EXCEEDS_MAX_SIZE = 0x000010f0

4045 ERROR_VOLUME_CONTAINS_SYS_FILES = 0x000010f1

4046 ERROR_INDIGENOUS_TYPE = 0x000010f2

4047 ERROR_NO_SUPPORTING_DRIVES = 0x000010f3

4048 ERROR_CLEANER_CARTRIDGE_INSTALLED = 0x000010f4

4049 ERROR_IEPORT_FULL = 0x000010f5

4050 ERROR_FILE_OFFLINE = 0x000010fe

4051 ERROR_REMOTE_STORAGE_NOT_ACTIVE = 0x000010ff

4052 ERROR_REMOTE_STORAGE_MEDIA_ERROR = 0x00001100

4053 ERROR_NOT_A_REPARSE_POINT = 0x00001126

4054 ERROR_REPARSE_ATTRIBUTE_CONFLICT = 0x00001127

4055 ERROR_INVALID_REPARSE_DATA = 0x00001128

4056 ERROR_REPARSE_TAG_INVALID = 0x00001129

4057 ERROR_REPARSE_TAG_MISMATCH = 0x0000112a

4058 ERROR_APP_DATA_NOT_FOUND = 0x00001130

4059 ERROR_APP_DATA_EXPIRED = 0x00001131

4060 ERROR_APP_DATA_CORRUPT = 0x00001132

4061 ERROR_APP_DATA_LIMIT_EXCEEDED = 0x00001133

4062 ERROR_APP_DATA_REBOOT_REQUIRED = 0x00001134

4063 ERROR_SECUREBOOT_ROLLBACK_DETECTED = 0x00001144

4064 ERROR_SECUREBOOT_POLICY_VIOLATION = 0x00001145

4065 ERROR_SECUREBOOT_INVALID_POLICY = 0x00001146

4066 ERROR_SECUREBOOT_POLICY_PUBLISHER_NOT_FOUND = 0x00001147

4067 ERROR_SECUREBOOT_POLICY_NOT_SIGNED = 0x00001148

4068 ERROR_SECUREBOOT_NOT_ENABLED = 0x00001149

4069 ERROR_SECUREBOOT_FILE_REPLACED = 0x0000114a

4070 ERROR_OFFLOAD_READ_FLT_NOT_SUPPORTED = 0x00001158

4071 ERROR_OFFLOAD_WRITE_FLT_NOT_SUPPORTED = 0x00001159

4072 ERROR_OFFLOAD_READ_FILE_NOT_SUPPORTED = 0x0000115a

4073 ERROR_OFFLOAD_WRITE_FILE_NOT_SUPPORTED = 0x0000115b

4074 ERROR_VOLUME_NOT_SIS_ENABLED = 0x00001194

4075 ERROR_DEPENDENT_RESOURCE_EXISTS = 0x00001389

4076 ERROR_DEPENDENCY_NOT_FOUND = 0x0000138a

4077 ERROR_DEPENDENCY_ALREADY_EXISTS = 0x0000138b

4078 ERROR_RESOURCE_NOT_ONLINE = 0x0000138c

4079 ERROR_HOST_NODE_NOT_AVAILABLE = 0x0000138d

4080 ERROR_RESOURCE_NOT_AVAILABLE = 0x0000138e

4081 ERROR_RESOURCE_NOT_FOUND = 0x0000138f

4082 ERROR_SHUTDOWN_CLUSTER = 0x00001390

4083 ERROR_CANT_EVICT_ACTIVE_NODE = 0x00001391

4084 ERROR_OBJECT_ALREADY_EXISTS = 0x00001392

4085 ERROR_OBJECT_IN_LIST = 0x00001393

4086 ERROR_GROUP_NOT_AVAILABLE = 0x00001394

4087 ERROR_GROUP_NOT_FOUND = 0x00001395

4088 ERROR_GROUP_NOT_ONLINE = 0x00001396

4089 ERROR_HOST_NODE_NOT_RESOURCE_OWNER = 0x00001397

4090 ERROR_HOST_NODE_NOT_GROUP_OWNER = 0x00001398

4091 ERROR_RESMON_CREATE_FAILED = 0x00001399

4092 ERROR_RESMON_ONLINE_FAILED = 0x0000139a

4093 ERROR_RESOURCE_ONLINE = 0x0000139b

4094 ERROR_QUORUM_RESOURCE = 0x0000139c

4095 ERROR_NOT_QUORUM_CAPABLE = 0x0000139d

4096 ERROR_CLUSTER_SHUTTING_DOWN = 0x0000139e

4097 ERROR_INVALID_STATE = 0x0000139f

4098 ERROR_RESOURCE_PROPERTIES_STORED = 0x000013a0

4099 ERROR_NOT_QUORUM_CLASS = 0x000013a1

4100 ERROR_CORE_RESOURCE = 0x000013a2

4101 ERROR_QUORUM_RESOURCE_ONLINE_FAILED = 0x000013a3

4102 ERROR_QUORUMLOG_OPEN_FAILED = 0x000013a4

4103 ERROR_CLUSTERLOG_CORRUPT = 0x000013a5

4104 ERROR_CLUSTERLOG_RECORD_EXCEEDS_MAXSIZE = 0x000013a6

4105 ERROR_CLUSTERLOG_EXCEEDS_MAXSIZE = 0x000013a7

4106 ERROR_CLUSTERLOG_CHKPOINT_NOT_FOUND = 0x000013a8

4107 ERROR_CLUSTERLOG_NOT_ENOUGH_SPACE = 0x000013a9

4108 ERROR_QUORUM_OWNER_ALIVE = 0x000013aa

4109 ERROR_NETWORK_NOT_AVAILABLE = 0x000013ab

4110 ERROR_NODE_NOT_AVAILABLE = 0x000013ac

4111 ERROR_ALL_NODES_NOT_AVAILABLE = 0x000013ad

4112 ERROR_RESOURCE_FAILED = 0x000013ae

4113 ERROR_CLUSTER_INVALID_NODE = 0x000013af

4114 ERROR_CLUSTER_NODE_EXISTS = 0x000013b0

4115 ERROR_CLUSTER_JOIN_IN_PROGRESS = 0x000013b1

4116 ERROR_CLUSTER_NODE_NOT_FOUND = 0x000013b2

4117 ERROR_CLUSTER_LOCAL_NODE_NOT_FOUND = 0x000013b3

4118 ERROR_CLUSTER_NETWORK_EXISTS = 0x000013b4

4119 ERROR_CLUSTER_NETWORK_NOT_FOUND = 0x000013b5

4120 ERROR_CLUSTER_NETINTERFACE_EXISTS = 0x000013b6

4121 ERROR_CLUSTER_NETINTERFACE_NOT_FOUND = 0x000013b7

4122 ERROR_CLUSTER_INVALID_REQUEST = 0x000013b8

4123 ERROR_CLUSTER_INVALID_NETWORK_PROVIDER = 0x000013b9

4124 ERROR_CLUSTER_NODE_DOWN = 0x000013ba

4125 ERROR_CLUSTER_NODE_UNREACHABLE = 0x000013bb

4126 ERROR_CLUSTER_NODE_NOT_MEMBER = 0x000013bc

4127 ERROR_CLUSTER_JOIN_NOT_IN_PROGRESS = 0x000013bd

4128 ERROR_CLUSTER_INVALID_NETWORK = 0x000013be

4129 ERROR_CLUSTER_NODE_UP = 0x000013c0

4130 ERROR_CLUSTER_IPADDR_IN_USE = 0x000013c1

4131 ERROR_CLUSTER_NODE_NOT_PAUSED = 0x000013c2

4132 ERROR_CLUSTER_NO_SECURITY_CONTEXT = 0x000013c3

4133 ERROR_CLUSTER_NETWORK_NOT_INTERNAL = 0x000013c4

4134 ERROR_CLUSTER_NODE_ALREADY_UP = 0x000013c5

4135 ERROR_CLUSTER_NODE_ALREADY_DOWN = 0x000013c6

4136 ERROR_CLUSTER_NETWORK_ALREADY_ONLINE = 0x000013c7

4137 ERROR_CLUSTER_NETWORK_ALREADY_OFFLINE = 0x000013c8

4138 ERROR_CLUSTER_NODE_ALREADY_MEMBER = 0x000013c9

4139 ERROR_CLUSTER_LAST_INTERNAL_NETWORK = 0x000013ca

4140 ERROR_CLUSTER_NETWORK_HAS_DEPENDENTS = 0x000013cb

4141 ERROR_INVALID_OPERATION_ON_QUORUM = 0x000013cc

4142 ERROR_DEPENDENCY_NOT_ALLOWED = 0x000013cd

4143 ERROR_CLUSTER_NODE_PAUSED = 0x000013ce

4144 ERROR_NODE_CANT_HOST_RESOURCE = 0x000013cf

4145 ERROR_CLUSTER_NODE_NOT_READY = 0x000013d0

4146 ERROR_CLUSTER_NODE_SHUTTING_DOWN = 0x000013d1

4147 ERROR_CLUSTER_JOIN_ABORTED = 0x000013d2

4148 ERROR_CLUSTER_INCOMPATIBLE_VERSIONS = 0x000013d3

4149 ERROR_CLUSTER_MAXNUM_OF_RESOURCES_EXCEEDED = 0x000013d4

4150 ERROR_CLUSTER_SYSTEM_CONFIG_CHANGED = 0x000013d5

4151 ERROR_CLUSTER_RESOURCE_TYPE_NOT_FOUND = 0x000013d6

4152 ERROR_CLUSTER_RESTYPE_NOT_SUPPORTED = 0x000013d7

4153 ERROR_CLUSTER_RESNAME_NOT_FOUND = 0x000013d8

4154 ERROR_CLUSTER_NO_RPC_PACKAGES_REGISTERED = 0x000013d9

4155 ERROR_CLUSTER_OWNER_NOT_IN_PREFLIST = 0x000013da

4156 ERROR_CLUSTER_DATABASE_SEQMISMATCH = 0x000013db

4157 ERROR_RESMON_INVALID_STATE = 0x000013dc

4158 ERROR_CLUSTER_GUM_NOT_LOCKER = 0x000013dd

4159 ERROR_QUORUM_DISK_NOT_FOUND = 0x000013de

4160 ERROR_DATABASE_BACKUP_CORRUPT = 0x000013df

4161 ERROR_CLUSTER_NODE_ALREADY_HAS_DFS_ROOT = 0x000013e0

4162 ERROR_RESOURCE_PROPERTY_UNCHANGEABLE = 0x000013e1

4163 ERROR_CLUSTER_MEMBERSHIP_INVALID_STATE = 0x00001702

4164 ERROR_CLUSTER_QUORUMLOG_NOT_FOUND = 0x00001703

4165 ERROR_CLUSTER_MEMBERSHIP_HALT = 0x00001704

4166 ERROR_CLUSTER_INSTANCE_ID_MISMATCH = 0x00001705

4167 ERROR_CLUSTER_NETWORK_NOT_FOUND_FOR_IP = 0x00001706

4168 ERROR_CLUSTER_PROPERTY_DATA_TYPE_MISMATCH = 0x00001707

4169 ERROR_CLUSTER_EVICT_WITHOUT_CLEANUP = 0x00001708

4170 ERROR_CLUSTER_PARAMETER_MISMATCH = 0x00001709

4171 ERROR_NODE_CANNOT_BE_CLUSTERED = 0x0000170a

4172 ERROR_CLUSTER_WRONG_OS_VERSION = 0x0000170b

4173 ERROR_CLUSTER_CANT_CREATE_DUP_CLUSTER_NAME = 0x0000170c

4174 ERROR_CLUSCFG_ALREADY_COMMITTED = 0x0000170d

4175 ERROR_CLUSCFG_ROLLBACK_FAILED = 0x0000170e

4176 ERROR_CLUSCFG_SYSTEM_DISK_DRIVE_LETTER_CONFLICT = 0x0000170f

4177 ERROR_CLUSTER_OLD_VERSION = 0x00001710

4178 ERROR_CLUSTER_MISMATCHED_COMPUTER_ACCT_NAME = 0x00001711

4179 ERROR_CLUSTER_NO_NET_ADAPTERS = 0x00001712

4180 ERROR_CLUSTER_POISONED = 0x00001713

4181 ERROR_CLUSTER_GROUP_MOVING = 0x00001714

4182 ERROR_CLUSTER_RESOURCE_TYPE_BUSY = 0x00001715

4183 ERROR_RESOURCE_CALL_TIMED_OUT = 0x00001716

4184 ERROR_INVALID_CLUSTER_IPV6_ADDRESS = 0x00001717

4185 ERROR_CLUSTER_INTERNAL_INVALID_FUNCTION = 0x00001718

4186 ERROR_CLUSTER_PARAMETER_OUT_OF_BOUNDS = 0x00001719

4187 ERROR_CLUSTER_PARTIAL_SEND = 0x0000171a

4188 ERROR_CLUSTER_REGISTRY_INVALID_FUNCTION = 0x0000171b

4189 ERROR_CLUSTER_INVALID_STRING_TERMINATION = 0x0000171c

4190 ERROR_CLUSTER_INVALID_STRING_FORMAT = 0x0000171d

4191 ERROR_CLUSTER_DATABASE_TRANSACTION_IN_PROGRESS = 0x0000171e

4192 ERROR_CLUSTER_DATABASE_TRANSACTION_NOT_IN_PROGRESS = 0x0000171f

4193 ERROR_CLUSTER_NULL_DATA = 0x00001720

4194 ERROR_CLUSTER_PARTIAL_READ = 0x00001721

4195 ERROR_CLUSTER_PARTIAL_WRITE = 0x00001722

4196 ERROR_CLUSTER_CANT_DESERIALIZE_DATA = 0x00001723

4197 ERROR_DEPENDENT_RESOURCE_PROPERTY_CONFLICT = 0x00001724

4198 ERROR_CLUSTER_NO_QUORUM = 0x00001725

4199 ERROR_CLUSTER_INVALID_IPV6_NETWORK = 0x00001726

4200 ERROR_CLUSTER_INVALID_IPV6_TUNNEL_NETWORK = 0x00001727

4201 ERROR_QUORUM_NOT_ALLOWED_IN_THIS_GROUP = 0x00001728

4202 ERROR_DEPENDENCY_TREE_TOO_COMPLEX = 0x00001729

4203 ERROR_EXCEPTION_IN_RESOURCE_CALL = 0x0000172a

4204 ERROR_CLUSTER_RHS_FAILED_INITIALIZATION = 0x0000172b

4205 ERROR_CLUSTER_NOT_INSTALLED = 0x0000172c

4206 ERROR_CLUSTER_RESOURCES_MUST_BE_ONLINE_ON_THE_SAME_NODE = 0x0000172d

4207 ERROR_CLUSTER_MAX_NODES_IN_CLUSTER = 0x0000172e

4208 ERROR_CLUSTER_TOO_MANY_NODES = 0x0000172f

4209 ERROR_CLUSTER_OBJECT_ALREADY_USED = 0x00001730

4210 ERROR_NONCORE_GROUPS_FOUND = 0x00001731

4211 ERROR_FILE_SHARE_RESOURCE_CONFLICT = 0x00001732

4212 ERROR_CLUSTER_EVICT_INVALID_REQUEST = 0x00001733

4213 ERROR_CLUSTER_SINGLETON_RESOURCE = 0x00001734

4214 ERROR_CLUSTER_GROUP_SINGLETON_RESOURCE = 0x00001735

4215 ERROR_CLUSTER_RESOURCE_PROVIDER_FAILED = 0x00001736

4216 ERROR_CLUSTER_RESOURCE_CONFIGURATION_ERROR = 0x00001737

4217 ERROR_CLUSTER_GROUP_BUSY = 0x00001738

4218 ERROR_CLUSTER_NOT_SHARED_VOLUME = 0x00001739

4219 ERROR_CLUSTER_INVALID_SECURITY_DESCRIPTOR = 0x0000173a

4220 ERROR_CLUSTER_SHARED_VOLUMES_IN_USE = 0x0000173b

4221 ERROR_CLUSTER_USE_SHARED_VOLUMES_API = 0x0000173c

4222 ERROR_CLUSTER_BACKUP_IN_PROGRESS = 0x0000173d

4223 ERROR_NON_CSV_PATH = 0x0000173e

4224 ERROR_CSV_VOLUME_NOT_LOCAL = 0x0000173f

4225 ERROR_CLUSTER_WATCHDOG_TERMINATING = 0x00001740

4226 ERROR_CLUSTER_RESOURCE_VETOED_MOVE_INCOMPATIBLE_NODES = 0x00001741

4227 ERROR_CLUSTER_INVALID_NODE_WEIGHT = 0x00001742

4228 ERROR_CLUSTER_RESOURCE_VETOED_CALL = 0x00001743

4229 ERROR_RESMON_SYSTEM_RESOURCES_LACKING = 0x00001744

4230 ERROR_CLUSTER_RESOURCE_VETOED_MOVE_NOT_ENOUGH_RESOURCES_ON_DESTINATION = 0x00001745

4231 ERROR_CLUSTER_RESOURCE_VETOED_MOVE_NOT_ENOUGH_RESOURCES_ON_SOURCE = 0x00001746

4232 ERROR_CLUSTER_GROUP_QUEUED = 0x00001747

4233 ERROR_CLUSTER_RESOURCE_LOCKED_STATUS = 0x00001748

4234 ERROR_CLUSTER_SHARED_VOLUME_FAILOVER_NOT_ALLOWED = 0x00001749

4235 ERROR_CLUSTER_NODE_DRAIN_IN_PROGRESS = 0x0000174a

4236 ERROR_CLUSTER_DISK_NOT_CONNECTED = 0x0000174b

4237 ERROR_DISK_NOT_CSV_CAPABLE = 0x0000174c

4238 ERROR_RESOURCE_NOT_IN_AVAILABLE_STORAGE = 0x0000174d

4239 ERROR_CLUSTER_SHARED_VOLUME_REDIRECTED = 0x0000174e

4240 ERROR_CLUSTER_SHARED_VOLUME_NOT_REDIRECTED = 0x0000174f

4241 ERROR_CLUSTER_CANNOT_RETURN_PROPERTIES = 0x00001750

4242 ERROR_CLUSTER_RESOURCE_CONTAINS_UNSUPPORTED_DIFF_AREA_FOR_SHARED_VOLUMES = 0x00001751

4243 ERROR_CLUSTER_RESOURCE_IS_IN_MAINTENANCE_MODE = 0x00001752

4244 ERROR_CLUSTER_AFFINITY_CONFLICT = 0x00001753

4245 ERROR_CLUSTER_RESOURCE_IS_REPLICA_VIRTUAL_MACHINE = 0x00001754

4246 ERROR_ENCRYPTION_FAILED = 0x00001770

4247 ERROR_DECRYPTION_FAILED = 0x00001771

4248 ERROR_FILE_ENCRYPTED = 0x00001772

4249 ERROR_NO_RECOVERY_POLICY = 0x00001773

4250 ERROR_NO_EFS = 0x00001774

4251 ERROR_WRONG_EFS = 0x00001775

4252 ERROR_NO_USER_KEYS = 0x00001776

4253 ERROR_FILE_NOT_ENCRYPTED = 0x00001777

4254 ERROR_NOT_EXPORT_FORMAT = 0x00001778

4255 ERROR_FILE_READ_ONLY = 0x00001779

4256 ERROR_DIR_EFS_DISALLOWED = 0x0000177a

4257 ERROR_EFS_SERVER_NOT_TRUSTED = 0x0000177b

4258 ERROR_BAD_RECOVERY_POLICY = 0x0000177c

4259 ERROR_EFS_ALG_BLOB_TOO_BIG = 0x0000177d

4260 ERROR_VOLUME_NOT_SUPPORT_EFS = 0x0000177e

4261 ERROR_EFS_DISABLED = 0x0000177f

4262 ERROR_EFS_VERSION_NOT_SUPPORT = 0x00001780

4263 ERROR_CS_ENCRYPTION_INVALID_SERVER_RESPONSE = 0x00001781

4264 ERROR_CS_ENCRYPTION_UNSUPPORTED_SERVER = 0x00001782

4265 ERROR_CS_ENCRYPTION_EXISTING_ENCRYPTED_FILE = 0x00001783

4266 ERROR_CS_ENCRYPTION_NEW_ENCRYPTED_FILE = 0x00001784

4267 ERROR_CS_ENCRYPTION_FILE_NOT_CSE = 0x00001785

4268 ERROR_ENCRYPTION_POLICY_DENIES_OPERATION = 0x00001786

4269 ERROR_NO_BROWSER_SERVERS_FOUND = 0x000017e6

4270 SCHED_E_SERVICE_NOT_LOCALSYSTEM = 0x00001838

4271 ERROR_LOG_SECTOR_INVALID = 0x000019c8

4272 ERROR_LOG_SECTOR_PARITY_INVALID = 0x000019c9

4273 ERROR_LOG_SECTOR_REMAPPED = 0x000019ca

4274 ERROR_LOG_BLOCK_INCOMPLETE = 0x000019cb

4275 ERROR_LOG_INVALID_RANGE = 0x000019cc

4276 ERROR_LOG_BLOCKS_EXHAUSTED = 0x000019cd

4277 ERROR_LOG_READ_CONTEXT_INVALID = 0x000019ce

4278 ERROR_LOG_RESTART_INVALID = 0x000019cf

4279 ERROR_LOG_BLOCK_VERSION = 0x000019d0

4280 ERROR_LOG_BLOCK_INVALID = 0x000019d1

4281 ERROR_LOG_READ_MODE_INVALID = 0x000019d2

4282 ERROR_LOG_NO_RESTART = 0x000019d3

4283 ERROR_LOG_METADATA_CORRUPT = 0x000019d4

4284 ERROR_LOG_METADATA_INVALID = 0x000019d5

4285 ERROR_LOG_METADATA_INCONSISTENT = 0x000019d6

4286 ERROR_LOG_RESERVATION_INVALID = 0x000019d7

4287 ERROR_LOG_CANT_DELETE = 0x000019d8

4288 ERROR_LOG_CONTAINER_LIMIT_EXCEEDED = 0x000019d9

4289 ERROR_LOG_START_OF_LOG = 0x000019da

4290 ERROR_LOG_POLICY_ALREADY_INSTALLED = 0x000019db

4291 ERROR_LOG_POLICY_NOT_INSTALLED = 0x000019dc

4292 ERROR_LOG_POLICY_INVALID = 0x000019dd

4293 ERROR_LOG_POLICY_CONFLICT = 0x000019de

4294 ERROR_LOG_PINNED_ARCHIVE_TAIL = 0x000019df

4295 ERROR_LOG_RECORD_NONEXISTENT = 0x000019e0

4296 ERROR_LOG_RECORDS_RESERVED_INVALID = 0x000019e1

4297 ERROR_LOG_SPACE_RESERVED_INVALID = 0x000019e2

4298 ERROR_LOG_TAIL_INVALID = 0x000019e3

4299 ERROR_LOG_FULL = 0x000019e4

4300 ERROR_COULD_NOT_RESIZE_LOG = 0x000019e5

4301 ERROR_LOG_MULTIPLEXED = 0x000019e6

4302 ERROR_LOG_DEDICATED = 0x000019e7

4303 ERROR_LOG_ARCHIVE_NOT_IN_PROGRESS = 0x000019e8

4304 ERROR_LOG_ARCHIVE_IN_PROGRESS = 0x000019e9

4305 ERROR_LOG_EPHEMERAL = 0x000019ea

4306 ERROR_LOG_NOT_ENOUGH_CONTAINERS = 0x000019eb

4307 ERROR_LOG_CLIENT_ALREADY_REGISTERED = 0x000019ec

4308 ERROR_LOG_CLIENT_NOT_REGISTERED = 0x000019ed

4309 ERROR_LOG_FULL_HANDLER_IN_PROGRESS = 0x000019ee

4310 ERROR_LOG_CONTAINER_READ_FAILED = 0x000019ef

4311 ERROR_LOG_CONTAINER_WRITE_FAILED = 0x000019f0

4312 ERROR_LOG_CONTAINER_OPEN_FAILED = 0x000019f1

4313 ERROR_LOG_CONTAINER_STATE_INVALID = 0x000019f2

4314 ERROR_LOG_STATE_INVALID = 0x000019f3

4315 ERROR_LOG_PINNED = 0x000019f4

4316 ERROR_LOG_METADATA_FLUSH_FAILED = 0x000019f5

4317 ERROR_LOG_INCONSISTENT_SECURITY = 0x000019f6

4318 ERROR_LOG_APPENDED_FLUSH_FAILED = 0x000019f7

4319 ERROR_LOG_PINNED_RESERVATION = 0x000019f8

4320 ERROR_INVALID_TRANSACTION = 0x00001a2c

4321 ERROR_TRANSACTION_NOT_ACTIVE = 0x00001a2d

4322 ERROR_TRANSACTION_REQUEST_NOT_VALID = 0x00001a2e

4323 ERROR_TRANSACTION_NOT_REQUESTED = 0x00001a2f

4324 ERROR_TRANSACTION_ALREADY_ABORTED = 0x00001a30

4325 ERROR_TRANSACTION_ALREADY_COMMITTED = 0x00001a31

4326 ERROR_TM_INITIALIZATION_FAILED = 0x00001a32

4327 ERROR_RESOURCEMANAGER_READ_ONLY = 0x00001a33

4328 ERROR_TRANSACTION_NOT_JOINED = 0x00001a34

4329 ERROR_TRANSACTION_SUPERIOR_EXISTS = 0x00001a35

4330 ERROR_CRM_PROTOCOL_ALREADY_EXISTS = 0x00001a36

4331 ERROR_TRANSACTION_PROPAGATION_FAILED = 0x00001a37

4332 ERROR_CRM_PROTOCOL_NOT_FOUND = 0x00001a38

4333 ERROR_TRANSACTION_INVALID_MARSHALL_BUFFER = 0x00001a39

4334 ERROR_CURRENT_TRANSACTION_NOT_VALID = 0x00001a3a

4335 ERROR_TRANSACTION_NOT_FOUND = 0x00001a3b

4336 ERROR_RESOURCEMANAGER_NOT_FOUND = 0x00001a3c

4337 ERROR_ENLISTMENT_NOT_FOUND = 0x00001a3d

4338 ERROR_TRANSACTIONMANAGER_NOT_FOUND = 0x00001a3e

4339 ERROR_TRANSACTIONMANAGER_NOT_ONLINE = 0x00001a3f

4340 ERROR_TRANSACTIONMANAGER_RECOVERY_NAME_COLLISION = 0x00001a40

4341 ERROR_TRANSACTION_NOT_ROOT = 0x00001a41

4342 ERROR_TRANSACTION_OBJECT_EXPIRED = 0x00001a42

4343 ERROR_TRANSACTION_RESPONSE_NOT_ENLISTED = 0x00001a43

4344 ERROR_TRANSACTION_RECORD_TOO_LONG = 0x00001a44

4345 ERROR_IMPLICIT_TRANSACTION_NOT_SUPPORTED = 0x00001a45

4346 ERROR_TRANSACTION_INTEGRITY_VIOLATED = 0x00001a46

4347 ERROR_TRANSACTIONMANAGER_IDENTITY_MISMATCH = 0x00001a47

4348 ERROR_RM_CANNOT_BE_FROZEN_FOR_SNAPSHOT = 0x00001a48

4349 ERROR_TRANSACTION_MUST_WRITETHROUGH = 0x00001a49

4350 ERROR_TRANSACTION_NO_SUPERIOR = 0x00001a4a

4351 ERROR_HEURISTIC_DAMAGE_POSSIBLE = 0x00001a4b

4352 ERROR_TRANSACTIONAL_CONFLICT = 0x00001a90

4353 ERROR_RM_NOT_ACTIVE = 0x00001a91

4354 ERROR_RM_METADATA_CORRUPT = 0x00001a92

4355 ERROR_DIRECTORY_NOT_RM = 0x00001a93

4356 ERROR_TRANSACTIONS_UNSUPPORTED_REMOTE = 0x00001a95

4357 ERROR_LOG_RESIZE_INVALID_SIZE = 0x00001a96

4358 ERROR_OBJECT_NO_LONGER_EXISTS = 0x00001a97

4359 ERROR_STREAM_MINIVERSION_NOT_FOUND = 0x00001a98

4360 ERROR_STREAM_MINIVERSION_NOT_VALID = 0x00001a99

4361 ERROR_MINIVERSION_INACCESSIBLE_FROM_SPECIFIED_TRANSACTION = 0x00001a9a

4362 ERROR_CANT_OPEN_MINIVERSION_WITH_MODIFY_INTENT = 0x00001a9b

4363 ERROR_CANT_CREATE_MORE_STREAM_MINIVERSIONS = 0x00001a9c

4364 ERROR_REMOTE_FILE_VERSION_MISMATCH = 0x00001a9e

4365 ERROR_HANDLE_NO_LONGER_VALID = 0x00001a9f

4366 ERROR_NO_TXF_METADATA = 0x00001aa0

4367 ERROR_LOG_CORRUPTION_DETECTED = 0x00001aa1

4368 ERROR_CANT_RECOVER_WITH_HANDLE_OPEN = 0x00001aa2

4369 ERROR_RM_DISCONNECTED = 0x00001aa3

4370 ERROR_ENLISTMENT_NOT_SUPERIOR = 0x00001aa4

4371 ERROR_RECOVERY_NOT_NEEDED = 0x00001aa5

4372 ERROR_RM_ALREADY_STARTED = 0x00001aa6

4373 ERROR_FILE_IDENTITY_NOT_PERSISTENT = 0x00001aa7

4374 ERROR_CANT_BREAK_TRANSACTIONAL_DEPENDENCY = 0x00001aa8

4375 ERROR_CANT_CROSS_RM_BOUNDARY = 0x00001aa9

4376 ERROR_TXF_DIR_NOT_EMPTY = 0x00001aaa

4377 ERROR_INDOUBT_TRANSACTIONS_EXIST = 0x00001aab

4378 ERROR_TM_VOLATILE = 0x00001aac

4379 ERROR_ROLLBACK_TIMER_EXPIRED = 0x00001aad

4380 ERROR_TXF_ATTRIBUTE_CORRUPT = 0x00001aae

4381 ERROR_EFS_NOT_ALLOWED_IN_TRANSACTION = 0x00001aaf

4382 ERROR_TRANSACTIONAL_OPEN_NOT_ALLOWED = 0x00001ab0

4383 ERROR_LOG_GROWTH_FAILED = 0x00001ab1

4384 ERROR_TRANSACTED_MAPPING_UNSUPPORTED_REMOTE = 0x00001ab2

4385 ERROR_TXF_METADATA_ALREADY_PRESENT = 0x00001ab3

4386 ERROR_TRANSACTION_SCOPE_CALLBACKS_NOT_SET = 0x00001ab4

4387 ERROR_TRANSACTION_REQUIRED_PROMOTION = 0x00001ab5

4388 ERROR_CANNOT_EXECUTE_FILE_IN_TRANSACTION = 0x00001ab6

4389 ERROR_TRANSACTIONS_NOT_FROZEN = 0x00001ab7

4390 ERROR_TRANSACTION_FREEZE_IN_PROGRESS = 0x00001ab8

4391 ERROR_NOT_SNAPSHOT_VOLUME = 0x00001ab9

4392 ERROR_NO_SAVEPOINT_WITH_OPEN_FILES = 0x00001aba

4393 ERROR_DATA_LOST_REPAIR = 0x00001abb

4394 ERROR_SPARSE_NOT_ALLOWED_IN_TRANSACTION = 0x00001abc

4395 ERROR_TM_IDENTITY_MISMATCH = 0x00001abd

4396 ERROR_FLOATED_SECTION = 0x00001abe

4397 ERROR_CANNOT_ACCEPT_TRANSACTED_WORK = 0x00001abf

4398 ERROR_CANNOT_ABORT_TRANSACTIONS = 0x00001ac0

4399 ERROR_BAD_CLUSTERS = 0x00001ac1

4400 ERROR_COMPRESSION_NOT_ALLOWED_IN_TRANSACTION = 0x00001ac2

4401 ERROR_VOLUME_DIRTY = 0x00001ac3

4402 ERROR_NO_LINK_TRACKING_IN_TRANSACTION = 0x00001ac4

4403 ERROR_OPERATION_NOT_SUPPORTED_IN_TRANSACTION = 0x00001ac5

4404 ERROR_EXPIRED_HANDLE = 0x00001ac6

4405 ERROR_TRANSACTION_NOT_ENLISTED = 0x00001ac7

4406 ERROR_CTX_WINSTATION_NAME_INVALID = 0x00001b59

4407 ERROR_CTX_INVALID_PD = 0x00001b5a

4408 ERROR_CTX_PD_NOT_FOUND = 0x00001b5b

4409 ERROR_CTX_WD_NOT_FOUND = 0x00001b5c

4410 ERROR_CTX_CANNOT_MAKE_EVENTLOG_ENTRY = 0x00001b5d

4411 ERROR_CTX_SERVICE_NAME_COLLISION = 0x00001b5e

4412 ERROR_CTX_CLOSE_PENDING = 0x00001b5f

4413 ERROR_CTX_NO_OUTBUF = 0x00001b60

4414 ERROR_CTX_MODEM_INF_NOT_FOUND = 0x00001b61

4415 ERROR_CTX_INVALID_MODEMNAME = 0x00001b62

4416 ERROR_CTX_MODEM_RESPONSE_ERROR = 0x00001b63

4417 ERROR_CTX_MODEM_RESPONSE_TIMEOUT = 0x00001b64

4418 ERROR_CTX_MODEM_RESPONSE_NO_CARRIER = 0x00001b65

4419 ERROR_CTX_MODEM_RESPONSE_NO_DIALTONE = 0x00001b66

4420 ERROR_CTX_MODEM_RESPONSE_BUSY = 0x00001b67

4421 ERROR_CTX_MODEM_RESPONSE_VOICE = 0x00001b68

4422 ERROR_CTX_TD_ERROR = 0x00001b69

4423 ERROR_CTX_WINSTATION_NOT_FOUND = 0x00001b6e

4424 ERROR_CTX_WINSTATION_ALREADY_EXISTS = 0x00001b6f

4425 ERROR_CTX_WINSTATION_BUSY = 0x00001b70

4426 ERROR_CTX_BAD_VIDEO_MODE = 0x00001b71

4427 ERROR_CTX_GRAPHICS_INVALID = 0x00001b7b

4428 ERROR_CTX_LOGON_DISABLED = 0x00001b7d

4429 ERROR_CTX_NOT_CONSOLE = 0x00001b7e

4430 ERROR_CTX_CLIENT_QUERY_TIMEOUT = 0x00001b80

4431 ERROR_CTX_CONSOLE_DISCONNECT = 0x00001b81

4432 ERROR_CTX_CONSOLE_CONNECT = 0x00001b82

4433 ERROR_CTX_SHADOW_DENIED = 0x00001b84

4434 ERROR_CTX_WINSTATION_ACCESS_DENIED = 0x00001b85

4435 ERROR_CTX_INVALID_WD = 0x00001b89

4436 ERROR_CTX_SHADOW_INVALID = 0x00001b8a

4437 ERROR_CTX_SHADOW_DISABLED = 0x00001b8b

4438 ERROR_CTX_CLIENT_LICENSE_IN_USE = 0x00001b8c

4439 ERROR_CTX_CLIENT_LICENSE_NOT_SET = 0x00001b8d

4440 ERROR_CTX_LICENSE_NOT_AVAILABLE = 0x00001b8e

4441 ERROR_CTX_LICENSE_CLIENT_INVALID = 0x00001b8f

4442 ERROR_CTX_LICENSE_EXPIRED = 0x00001b90

4443 ERROR_CTX_SHADOW_NOT_RUNNING = 0x00001b91

4444 ERROR_CTX_SHADOW_ENDED_BY_MODE_CHANGE = 0x00001b92

4445 ERROR_ACTIVATION_COUNT_EXCEEDED = 0x00001b93

4446 ERROR_CTX_WINSTATIONS_DISABLED = 0x00001b94

4447 ERROR_CTX_ENCRYPTION_LEVEL_REQUIRED = 0x00001b95

4448 ERROR_CTX_SESSION_IN_USE = 0x00001b96

4449 ERROR_CTX_NO_FORCE_LOGOFF = 0x00001b97

4450 ERROR_CTX_ACCOUNT_RESTRICTION = 0x00001b98

4451 ERROR_RDP_PROTOCOL_ERROR = 0x00001b99

4452 ERROR_CTX_CDM_CONNECT = 0x00001b9a

4453 ERROR_CTX_CDM_DISCONNECT = 0x00001b9b

4454 ERROR_CTX_SECURITY_LAYER_ERROR = 0x00001b9c

4455 ERROR_TS_INCOMPATIBLE_SESSIONS = 0x00001b9d

4456 ERROR_TS_VIDEO_SUBSYSTEM_ERROR = 0x00001b9e

4457 FRS_ERR_INVALID_API_SEQUENCE = 0x00001f41

4458 FRS_ERR_STARTING_SERVICE = 0x00001f42

4459 FRS_ERR_STOPPING_SERVICE = 0x00001f43

4460 FRS_ERR_INTERNAL_API = 0x00001f44

4461 FRS_ERR_INTERNAL = 0x00001f45

4462 FRS_ERR_SERVICE_COMM = 0x00001f46

4463 FRS_ERR_INSUFFICIENT_PRIV = 0x00001f47

4464 FRS_ERR_AUTHENTICATION = 0x00001f48

4465 FRS_ERR_PARENT_INSUFFICIENT_PRIV = 0x00001f49

4466 FRS_ERR_PARENT_AUTHENTICATION = 0x00001f4a

4467 FRS_ERR_CHILD_TO_PARENT_COMM = 0x00001f4b

4468 FRS_ERR_PARENT_TO_CHILD_COMM = 0x00001f4c

4469 FRS_ERR_SYSVOL_POPULATE = 0x00001f4d

4470 FRS_ERR_SYSVOL_POPULATE_TIMEOUT = 0x00001f4e

4471 FRS_ERR_SYSVOL_IS_BUSY = 0x00001f4f

4472 FRS_ERR_SYSVOL_DEMOTE = 0x00001f50

4473 FRS_ERR_INVALID_SERVICE_PARAMETER = 0x00001f51

4474 ERROR_DS_NOT_INSTALLED = 0x00002008

4475 ERROR_DS_MEMBERSHIP_EVALUATED_LOCALLY = 0x00002009

4476 ERROR_DS_NO_ATTRIBUTE_OR_VALUE = 0x0000200a

4477 ERROR_DS_INVALID_ATTRIBUTE_SYNTAX = 0x0000200b

4478 ERROR_DS_ATTRIBUTE_TYPE_UNDEFINED = 0x0000200c

4479 ERROR_DS_ATTRIBUTE_OR_VALUE_EXISTS = 0x0000200d

4480 ERROR_DS_BUSY = 0x0000200e

4481 ERROR_DS_UNAVAILABLE = 0x0000200f

4482 ERROR_DS_NO_RIDS_ALLOCATED = 0x00002010

4483 ERROR_DS_NO_MORE_RIDS = 0x00002011

4484 ERROR_DS_INCORRECT_ROLE_OWNER = 0x00002012

4485 ERROR_DS_RIDMGR_INIT_ERROR = 0x00002013

4486 ERROR_DS_OBJ_CLASS_VIOLATION = 0x00002014

4487 ERROR_DS_CANT_ON_NON_LEAF = 0x00002015

4488 ERROR_DS_CANT_ON_RDN = 0x00002016

4489 ERROR_DS_CANT_MOD_OBJ_CLASS = 0x00002017

4490 ERROR_DS_CROSS_DOM_MOVE_ERROR = 0x00002018

4491 ERROR_DS_GC_NOT_AVAILABLE = 0x00002019

4492 ERROR_SHARED_POLICY = 0x0000201a

4493 ERROR_POLICY_OBJECT_NOT_FOUND = 0x0000201b

4494 ERROR_POLICY_ONLY_IN_DS = 0x0000201c

4495 ERROR_PROMOTION_ACTIVE = 0x0000201d

4496 ERROR_NO_PROMOTION_ACTIVE = 0x0000201e

4497 ERROR_DS_OPERATIONS_ERROR = 0x00002020

4498 ERROR_DS_PROTOCOL_ERROR = 0x00002021

4499 ERROR_DS_TIMELIMIT_EXCEEDED = 0x00002022

4500 ERROR_DS_SIZELIMIT_EXCEEDED = 0x00002023

4501 ERROR_DS_ADMIN_LIMIT_EXCEEDED = 0x00002024

4502 ERROR_DS_COMPARE_FALSE = 0x00002025

4503 ERROR_DS_COMPARE_TRUE = 0x00002026

4504 ERROR_DS_AUTH_METHOD_NOT_SUPPORTED = 0x00002027

4505 ERROR_DS_STRONG_AUTH_REQUIRED = 0x00002028

4506 ERROR_DS_INAPPROPRIATE_AUTH = 0x00002029

4507 ERROR_DS_AUTH_UNKNOWN = 0x0000202a

4508 ERROR_DS_REFERRAL = 0x0000202b

4509 ERROR_DS_UNAVAILABLE_CRIT_EXTENSION = 0x0000202c

4510 ERROR_DS_CONFIDENTIALITY_REQUIRED = 0x0000202d

4511 ERROR_DS_INAPPROPRIATE_MATCHING = 0x0000202e

4512 ERROR_DS_CONSTRAINT_VIOLATION = 0x0000202f

4513 ERROR_DS_NO_SUCH_OBJECT = 0x00002030

4514 ERROR_DS_ALIAS_PROBLEM = 0x00002031

4515 ERROR_DS_INVALID_DN_SYNTAX = 0x00002032

4516 ERROR_DS_IS_LEAF = 0x00002033

4517 ERROR_DS_ALIAS_DEREF_PROBLEM = 0x00002034

4518 ERROR_DS_UNWILLING_TO_PERFORM = 0x00002035

4519 ERROR_DS_LOOP_DETECT = 0x00002036

4520 ERROR_DS_NAMING_VIOLATION = 0x00002037

4521 ERROR_DS_OBJECT_RESULTS_TOO_LARGE = 0x00002038

4522 ERROR_DS_AFFECTS_MULTIPLE_DSAS = 0x00002039

4523 ERROR_DS_SERVER_DOWN = 0x0000203a

4524 ERROR_DS_LOCAL_ERROR = 0x0000203b

4525 ERROR_DS_ENCODING_ERROR = 0x0000203c

4526 ERROR_DS_DECODING_ERROR = 0x0000203d

4527 ERROR_DS_FILTER_UNKNOWN = 0x0000203e

4528 ERROR_DS_PARAM_ERROR = 0x0000203f

4529 ERROR_DS_NOT_SUPPORTED = 0x00002040

4530 ERROR_DS_NO_RESULTS_RETURNED = 0x00002041

4531 ERROR_DS_CONTROL_NOT_FOUND = 0x00002042

4532 ERROR_DS_CLIENT_LOOP = 0x00002043

4533 ERROR_DS_REFERRAL_LIMIT_EXCEEDED = 0x00002044

4534 ERROR_DS_SORT_CONTROL_MISSING = 0x00002045

4535 ERROR_DS_OFFSET_RANGE_ERROR = 0x00002046

4536 ERROR_DS_RIDMGR_DISABLED = 0x00002047

4537 ERROR_DS_ROOT_MUST_BE_NC = 0x0000206d

4538 ERROR_DS_ADD_REPLICA_INHIBITED = 0x0000206e

4539 ERROR_DS_ATT_NOT_DEF_IN_SCHEMA = 0x0000206f

4540 ERROR_DS_MAX_OBJ_SIZE_EXCEEDED = 0x00002070

4541 ERROR_DS_OBJ_STRING_NAME_EXISTS = 0x00002071

4542 ERROR_DS_NO_RDN_DEFINED_IN_SCHEMA = 0x00002072

4543 ERROR_DS_RDN_DOESNT_MATCH_SCHEMA = 0x00002073

4544 ERROR_DS_NO_REQUESTED_ATTS_FOUND = 0x00002074

4545 ERROR_DS_USER_BUFFER_TO_SMALL = 0x00002075

4546 ERROR_DS_ATT_IS_NOT_ON_OBJ = 0x00002076

4547 ERROR_DS_ILLEGAL_MOD_OPERATION = 0x00002077

4548 ERROR_DS_OBJ_TOO_LARGE = 0x00002078

4549 ERROR_DS_BAD_INSTANCE_TYPE = 0x00002079

4550 ERROR_DS_MASTERDSA_REQUIRED = 0x0000207a

4551 ERROR_DS_OBJECT_CLASS_REQUIRED = 0x0000207b

4552 ERROR_DS_MISSING_REQUIRED_ATT = 0x0000207c

4553 ERROR_DS_ATT_NOT_DEF_FOR_CLASS = 0x0000207d

4554 ERROR_DS_ATT_ALREADY_EXISTS = 0x0000207e

4555 ERROR_DS_CANT_ADD_ATT_VALUES = 0x00002080

4556 ERROR_DS_SINGLE_VALUE_CONSTRAINT = 0x00002081

4557 ERROR_DS_RANGE_CONSTRAINT = 0x00002082

4558 ERROR_DS_ATT_VAL_ALREADY_EXISTS = 0x00002083

4559 ERROR_DS_CANT_REM_MISSING_ATT = 0x00002084

4560 ERROR_DS_CANT_REM_MISSING_ATT_VAL = 0x00002085

4561 ERROR_DS_ROOT_CANT_BE_SUBREF = 0x00002086

4562 ERROR_DS_NO_CHAINING = 0x00002087

4563 ERROR_DS_NO_CHAINED_EVAL = 0x00002088

4564 ERROR_DS_NO_PARENT_OBJECT = 0x00002089

4565 ERROR_DS_PARENT_IS_AN_ALIAS = 0x0000208a

4566 ERROR_DS_CANT_MIX_MASTER_AND_REPS = 0x0000208b

4567 ERROR_DS_CHILDREN_EXIST = 0x0000208c

4568 ERROR_DS_OBJ_NOT_FOUND = 0x0000208d

4569 ERROR_DS_ALIASED_OBJ_MISSING = 0x0000208e

4570 ERROR_DS_BAD_NAME_SYNTAX = 0x0000208f

4571 ERROR_DS_ALIAS_POINTS_TO_ALIAS = 0x00002090

4572 ERROR_DS_CANT_DEREF_ALIAS = 0x00002091

4573 ERROR_DS_OUT_OF_SCOPE = 0x00002092

4574 ERROR_DS_OBJECT_BEING_REMOVED = 0x00002093

4575 ERROR_DS_CANT_DELETE_DSA_OBJ = 0x00002094

4576 ERROR_DS_GENERIC_ERROR = 0x00002095

4577 ERROR_DS_DSA_MUST_BE_INT_MASTER = 0x00002096

4578 ERROR_DS_CLASS_NOT_DSA = 0x00002097

4579 ERROR_DS_INSUFF_ACCESS_RIGHTS = 0x00002098

4580 ERROR_DS_ILLEGAL_SUPERIOR = 0x00002099

4581 ERROR_DS_ATTRIBUTE_OWNED_BY_SAM = 0x0000209a

4582 ERROR_DS_NAME_TOO_MANY_PARTS = 0x0000209b

4583 ERROR_DS_NAME_TOO_LONG = 0x0000209c

4584 ERROR_DS_NAME_VALUE_TOO_LONG = 0x0000209d

4585 ERROR_DS_NAME_UNPARSEABLE = 0x0000209e

4586 ERROR_DS_NAME_TYPE_UNKNOWN = 0x0000209f

4587 ERROR_DS_NOT_AN_OBJECT = 0x000020a0

4588 ERROR_DS_SEC_DESC_TOO_SHORT = 0x000020a1

4589 ERROR_DS_SEC_DESC_INVALID = 0x000020a2

4590 ERROR_DS_NO_DELETED_NAME = 0x000020a3

4591 ERROR_DS_SUBREF_MUST_HAVE_PARENT = 0x000020a4

4592 ERROR_DS_NCNAME_MUST_BE_NC = 0x000020a5

4593 ERROR_DS_CANT_ADD_SYSTEM_ONLY = 0x000020a6

4594 ERROR_DS_CLASS_MUST_BE_CONCRETE = 0x000020a7

4595 ERROR_DS_INVALID_DMD = 0x000020a8

4596 ERROR_DS_OBJ_GUID_EXISTS = 0x000020a9

4597 ERROR_DS_NOT_ON_BACKLINK = 0x000020aa

4598 ERROR_DS_NO_CROSSREF_FOR_NC = 0x000020ab

4599 ERROR_DS_SHUTTING_DOWN = 0x000020ac

4600 ERROR_DS_UNKNOWN_OPERATION = 0x000020ad

4601 ERROR_DS_INVALID_ROLE_OWNER = 0x000020ae

4602 ERROR_DS_COULDNT_CONTACT_FSMO = 0x000020af

4603 ERROR_DS_CROSS_NC_DN_RENAME = 0x000020b0

4604 ERROR_DS_CANT_MOD_SYSTEM_ONLY = 0x000020b1

4605 ERROR_DS_REPLICATOR_ONLY = 0x000020b2

4606 ERROR_DS_OBJ_CLASS_NOT_DEFINED = 0x000020b3

4607 ERROR_DS_OBJ_CLASS_NOT_SUBCLASS = 0x000020b4

4608 ERROR_DS_NAME_REFERENCE_INVALID = 0x000020b5

4609 ERROR_DS_CROSS_REF_EXISTS = 0x000020b6

4610 ERROR_DS_CANT_DEL_MASTER_CROSSREF = 0x000020b7

4611 ERROR_DS_SUBTREE_NOTIFY_NOT_NC_HEAD = 0x000020b8

4612 ERROR_DS_NOTIFY_FILTER_TOO_COMPLEX = 0x000020b9

4613 ERROR_DS_DUP_RDN = 0x000020ba

4614 ERROR_DS_DUP_OID = 0x000020bb

4615 ERROR_DS_DUP_MAPI_ID = 0x000020bc

4616 ERROR_DS_DUP_SCHEMA_ID_GUID = 0x000020bd

4617 ERROR_DS_DUP_LDAP_DISPLAY_NAME = 0x000020be

4618 ERROR_DS_SEMANTIC_ATT_TEST = 0x000020bf

4619 ERROR_DS_SYNTAX_MISMATCH = 0x000020c0

4620 ERROR_DS_EXISTS_IN_MUST_HAVE = 0x000020c1

4621 ERROR_DS_EXISTS_IN_MAY_HAVE = 0x000020c2

4622 ERROR_DS_NONEXISTENT_MAY_HAVE = 0x000020c3

4623 ERROR_DS_NONEXISTENT_MUST_HAVE = 0x000020c4

4624 ERROR_DS_AUX_CLS_TEST_FAIL = 0x000020c5

4625 ERROR_DS_NONEXISTENT_POSS_SUP = 0x000020c6

4626 ERROR_DS_SUB_CLS_TEST_FAIL = 0x000020c7

4627 ERROR_DS_BAD_RDN_ATT_ID_SYNTAX = 0x000020c8

4628 ERROR_DS_EXISTS_IN_AUX_CLS = 0x000020c9

4629 ERROR_DS_EXISTS_IN_SUB_CLS = 0x000020ca

4630 ERROR_DS_EXISTS_IN_POSS_SUP = 0x000020cb

4631 ERROR_DS_RECALCSCHEMA_FAILED = 0x000020cc

4632 ERROR_DS_TREE_DELETE_NOT_FINISHED = 0x000020cd

4633 ERROR_DS_CANT_DELETE = 0x000020ce

4634 ERROR_DS_ATT_SCHEMA_REQ_ID = 0x000020cf

4635 ERROR_DS_BAD_ATT_SCHEMA_SYNTAX = 0x000020d0

4636 ERROR_DS_CANT_CACHE_ATT = 0x000020d1

4637 ERROR_DS_CANT_CACHE_CLASS = 0x000020d2

4638 ERROR_DS_CANT_REMOVE_ATT_CACHE = 0x000020d3

4639 ERROR_DS_CANT_REMOVE_CLASS_CACHE = 0x000020d4

4640 ERROR_DS_CANT_RETRIEVE_DN = 0x000020d5

4641 ERROR_DS_MISSING_SUPREF = 0x000020d6

4642 ERROR_DS_CANT_RETRIEVE_INSTANCE = 0x000020d7

4643 ERROR_DS_CODE_INCONSISTENCY = 0x000020d8

4644 ERROR_DS_DATABASE_ERROR = 0x000020d9

4645 ERROR_DS_GOVERNSID_MISSING = 0x000020da

4646 ERROR_DS_MISSING_EXPECTED_ATT = 0x000020db

4647 ERROR_DS_NCNAME_MISSING_CR_REF = 0x000020dc

4648 ERROR_DS_SECURITY_CHECKING_ERROR = 0x000020dd

4649 ERROR_DS_SCHEMA_NOT_LOADED = 0x000020de

4650 ERROR_DS_SCHEMA_ALLOC_FAILED = 0x000020df

4651 ERROR_DS_ATT_SCHEMA_REQ_SYNTAX = 0x000020e0

4652 ERROR_DS_GCVERIFY_ERROR = 0x000020e1

4653 ERROR_DS_DRA_SCHEMA_MISMATCH = 0x000020e2

4654 ERROR_DS_CANT_FIND_DSA_OBJ = 0x000020e3

4655 ERROR_DS_CANT_FIND_EXPECTED_NC = 0x000020e4

4656 ERROR_DS_CANT_FIND_NC_IN_CACHE = 0x000020e5

4657 ERROR_DS_CANT_RETRIEVE_CHILD = 0x000020e6

4658 ERROR_DS_SECURITY_ILLEGAL_MODIFY = 0x000020e7

4659 ERROR_DS_CANT_REPLACE_HIDDEN_REC = 0x000020e8

4660 ERROR_DS_BAD_HIERARCHY_FILE = 0x000020e9

4661 ERROR_DS_BUILD_HIERARCHY_TABLE_FAILED = 0x000020ea

4662 ERROR_DS_CONFIG_PARAM_MISSING = 0x000020eb

4663 ERROR_DS_COUNTING_AB_INDICES_FAILED = 0x000020ec

4664 ERROR_DS_HIERARCHY_TABLE_MALLOC_FAILED = 0x000020ed

4665 ERROR_DS_INTERNAL_FAILURE = 0x000020ee

4666 ERROR_DS_UNKNOWN_ERROR = 0x000020ef

4667 ERROR_DS_ROOT_REQUIRES_CLASS_TOP = 0x000020f0

4668 ERROR_DS_REFUSING_FSMO_ROLES = 0x000020f1

4669 ERROR_DS_MISSING_FSMO_SETTINGS = 0x000020f2

4670 ERROR_DS_UNABLE_TO_SURRENDER_ROLES = 0x000020f3

4671 ERROR_DS_DRA_GENERIC = 0x000020f4

4672 ERROR_DS_DRA_INVALID_PARAMETER = 0x000020f5

4673 ERROR_DS_DRA_BUSY = 0x000020f6

4674 ERROR_DS_DRA_BAD_DN = 0x000020f7

4675 ERROR_DS_DRA_BAD_NC = 0x000020f8

4676 ERROR_DS_DRA_DN_EXISTS = 0x000020f9

4677 ERROR_DS_DRA_INTERNAL_ERROR = 0x000020fa

4678 ERROR_DS_DRA_INCONSISTENT_DIT = 0x000020fb

4679 ERROR_DS_DRA_CONNECTION_FAILED = 0x000020fc

4680 ERROR_DS_DRA_BAD_INSTANCE_TYPE = 0x000020fd

4681 ERROR_DS_DRA_OUT_OF_MEM = 0x000020fe

4682 ERROR_DS_DRA_MAIL_PROBLEM = 0x000020ff

4683 ERROR_DS_DRA_REF_ALREADY_EXISTS = 0x00002100

4684 ERROR_DS_DRA_REF_NOT_FOUND = 0x00002101

4685 ERROR_DS_DRA_OBJ_IS_REP_SOURCE = 0x00002102

4686 ERROR_DS_DRA_DB_ERROR = 0x00002103

4687 ERROR_DS_DRA_NO_REPLICA = 0x00002104

4688 ERROR_DS_DRA_ACCESS_DENIED = 0x00002105

4689 ERROR_DS_DRA_NOT_SUPPORTED = 0x00002106

4690 ERROR_DS_DRA_RPC_CANCELLED = 0x00002107

4691 ERROR_DS_DRA_SOURCE_DISABLED = 0x00002108

4692 ERROR_DS_DRA_SINK_DISABLED = 0x00002109

4693 ERROR_DS_DRA_NAME_COLLISION = 0x0000210a

4694 ERROR_DS_DRA_SOURCE_REINSTALLED = 0x0000210b

4695 ERROR_DS_DRA_MISSING_PARENT = 0x0000210c

4696 ERROR_DS_DRA_PREEMPTED = 0x0000210d

4697 ERROR_DS_DRA_ABANDON_SYNC = 0x0000210e

4698 ERROR_DS_DRA_SHUTDOWN = 0x0000210f

4699 ERROR_DS_DRA_INCOMPATIBLE_PARTIAL_SET = 0x00002110

4700 ERROR_DS_DRA_SOURCE_IS_PARTIAL_REPLICA = 0x00002111

4701 ERROR_DS_DRA_EXTN_CONNECTION_FAILED = 0x00002112

4702 ERROR_DS_INSTALL_SCHEMA_MISMATCH = 0x00002113

4703 ERROR_DS_DUP_LINK_ID = 0x00002114

4704 ERROR_DS_NAME_ERROR_RESOLVING = 0x00002115

4705 ERROR_DS_NAME_ERROR_NOT_FOUND = 0x00002116

4706 ERROR_DS_NAME_ERROR_NOT_UNIQUE = 0x00002117

4707 ERROR_DS_NAME_ERROR_NO_MAPPING = 0x00002118

4708 ERROR_DS_NAME_ERROR_DOMAIN_ONLY = 0x00002119

4709 ERROR_DS_NAME_ERROR_NO_SYNTACTICAL_MAPPING = 0x0000211a

4710 ERROR_DS_CONSTRUCTED_ATT_MOD = 0x0000211b

4711 ERROR_DS_WRONG_OM_OBJ_CLASS = 0x0000211c

4712 ERROR_DS_DRA_REPL_PENDING = 0x0000211d

4713 ERROR_DS_DS_REQUIRED = 0x0000211e

4714 ERROR_DS_INVALID_LDAP_DISPLAY_NAME = 0x0000211f

4715 ERROR_DS_NON_BASE_SEARCH = 0x00002120

4716 ERROR_DS_CANT_RETRIEVE_ATTS = 0x00002121

4717 ERROR_DS_BACKLINK_WITHOUT_LINK = 0x00002122

4718 ERROR_DS_EPOCH_MISMATCH = 0x00002123

4719 ERROR_DS_SRC_NAME_MISMATCH = 0x00002124

4720 ERROR_DS_SRC_AND_DST_NC_IDENTICAL = 0x00002125

4721 ERROR_DS_DST_NC_MISMATCH = 0x00002126

4722 ERROR_DS_NOT_AUTHORITIVE_FOR_DST_NC = 0x00002127

4723 ERROR_DS_SRC_GUID_MISMATCH = 0x00002128

4724 ERROR_DS_CANT_MOVE_DELETED_OBJECT = 0x00002129

4725 ERROR_DS_PDC_OPERATION_IN_PROGRESS = 0x0000212a

4726 ERROR_DS_CROSS_DOMAIN_CLEANUP_REQD = 0x0000212b

4727 ERROR_DS_ILLEGAL_XDOM_MOVE_OPERATION = 0x0000212c

4728 ERROR_DS_CANT_WITH_ACCT_GROUP_MEMBERSHPS = 0x0000212d

4729 ERROR_DS_NC_MUST_HAVE_NC_PARENT = 0x0000212e

4730 ERROR_DS_CR_IMPOSSIBLE_TO_VALIDATE = 0x0000212f

4731 ERROR_DS_DST_DOMAIN_NOT_NATIVE = 0x00002130

4732 ERROR_DS_MISSING_INFRASTRUCTURE_CONTAINER = 0x00002131

4733 ERROR_DS_CANT_MOVE_ACCOUNT_GROUP = 0x00002132

4734 ERROR_DS_CANT_MOVE_RESOURCE_GROUP = 0x00002133

4735 ERROR_DS_INVALID_SEARCH_FLAG = 0x00002134

4736 ERROR_DS_NO_TREE_DELETE_ABOVE_NC = 0x00002135

4737 ERROR_DS_COULDNT_LOCK_TREE_FOR_DELETE = 0x00002136

4738 ERROR_DS_COULDNT_IDENTIFY_OBJECTS_FOR_TREE_DELETE = 0x00002137

4739 ERROR_DS_SAM_INIT_FAILURE = 0x00002138

4740 ERROR_DS_SENSITIVE_GROUP_VIOLATION = 0x00002139

4741 ERROR_DS_CANT_MOD_PRIMARYGROUPID = 0x0000213a

4742 ERROR_DS_ILLEGAL_BASE_SCHEMA_MOD = 0x0000213b

4743 ERROR_DS_NONSAFE_SCHEMA_CHANGE = 0x0000213c

4744 ERROR_DS_SCHEMA_UPDATE_DISALLOWED = 0x0000213d

4745 ERROR_DS_CANT_CREATE_UNDER_SCHEMA = 0x0000213e

4746 ERROR_DS_INSTALL_NO_SRC_SCH_VERSION = 0x0000213f

4747 ERROR_DS_INSTALL_NO_SCH_VERSION_IN_INIFILE = 0x00002140

4748 ERROR_DS_INVALID_GROUP_TYPE = 0x00002141

4749 ERROR_DS_NO_NEST_GLOBALGROUP_IN_MIXEDDOMAIN = 0x00002142

4750 ERROR_DS_NO_NEST_LOCALGROUP_IN_MIXEDDOMAIN = 0x00002143

4751 ERROR_DS_GLOBAL_CANT_HAVE_LOCAL_MEMBER = 0x00002144

4752 ERROR_DS_GLOBAL_CANT_HAVE_UNIVERSAL_MEMBER = 0x00002145

4753 ERROR_DS_UNIVERSAL_CANT_HAVE_LOCAL_MEMBER = 0x00002146

4754 ERROR_DS_GLOBAL_CANT_HAVE_CROSSDOMAIN_MEMBER = 0x00002147

4755 ERROR_DS_LOCAL_CANT_HAVE_CROSSDOMAIN_LOCAL_MEMBER = 0x00002148

4756 ERROR_DS_HAVE_PRIMARY_MEMBERS = 0x00002149

4757 ERROR_DS_STRING_SD_CONVERSION_FAILED = 0x0000214a

4758 ERROR_DS_NAMING_MASTER_GC = 0x0000214b

4759 ERROR_DS_DNS_LOOKUP_FAILURE = 0x0000214c

4760 ERROR_DS_COULDNT_UPDATE_SPNS = 0x0000214d

4761 ERROR_DS_CANT_RETRIEVE_SD = 0x0000214e

4762 ERROR_DS_KEY_NOT_UNIQUE = 0x0000214f

4763 ERROR_DS_WRONG_LINKED_ATT_SYNTAX = 0x00002150

4764 ERROR_DS_SAM_NEED_BOOTKEY_PASSWORD = 0x00002151

4765 ERROR_DS_SAM_NEED_BOOTKEY_FLOPPY = 0x00002152

4766 ERROR_DS_CANT_START = 0x00002153

4767 ERROR_DS_INIT_FAILURE = 0x00002154

4768 ERROR_DS_NO_PKT_PRIVACY_ON_CONNECTION = 0x00002155

4769 ERROR_DS_SOURCE_DOMAIN_IN_FOREST = 0x00002156

4770 ERROR_DS_DESTINATION_DOMAIN_NOT_IN_FOREST = 0x00002157

4771 ERROR_DS_DESTINATION_AUDITING_NOT_ENABLED = 0x00002158

4772 ERROR_DS_CANT_FIND_DC_FOR_SRC_DOMAIN = 0x00002159

4773 ERROR_DS_SRC_OBJ_NOT_GROUP_OR_USER = 0x0000215a

4774 ERROR_DS_SRC_SID_EXISTS_IN_FOREST = 0x0000215b

4775 ERROR_DS_SRC_AND_DST_OBJECT_CLASS_MISMATCH = 0x0000215c

4776 ERROR_SAM_INIT_FAILURE = 0x0000215d

4777 ERROR_DS_DRA_SCHEMA_INFO_SHIP = 0x0000215e

4778 ERROR_DS_DRA_SCHEMA_CONFLICT = 0x0000215f

4779 ERROR_DS_DRA_EARLIER_SCHEMA_CONFLICT = 0x00002160

4780 ERROR_DS_DRA_OBJ_NC_MISMATCH = 0x00002161

4781 ERROR_DS_NC_STILL_HAS_DSAS = 0x00002162

4782 ERROR_DS_GC_REQUIRED = 0x00002163

4783 ERROR_DS_LOCAL_MEMBER_OF_LOCAL_ONLY = 0x00002164

4784 ERROR_DS_NO_FPO_IN_UNIVERSAL_GROUPS = 0x00002165

4785 ERROR_DS_CANT_ADD_TO_GC = 0x00002166

4786 ERROR_DS_NO_CHECKPOINT_WITH_PDC = 0x00002167

4787 ERROR_DS_SOURCE_AUDITING_NOT_ENABLED = 0x00002168

4788 ERROR_DS_CANT_CREATE_IN_NONDOMAIN_NC = 0x00002169

4789 ERROR_DS_INVALID_NAME_FOR_SPN = 0x0000216a

4790 ERROR_DS_FILTER_USES_CONTRUCTED_ATTRS = 0x0000216b

4791 ERROR_DS_UNICODEPWD_NOT_IN_QUOTES = 0x0000216c

4792 ERROR_DS_MACHINE_ACCOUNT_QUOTA_EXCEEDED = 0x0000216d

4793 ERROR_DS_MUST_BE_RUN_ON_DST_DC = 0x0000216e

4794 ERROR_DS_SRC_DC_MUST_BE_SP4_OR_GREATER = 0x0000216f

4795 ERROR_DS_CANT_TREE_DELETE_CRITICAL_OBJ = 0x00002170

4796 ERROR_DS_INIT_FAILURE_CONSOLE = 0x00002171

4797 ERROR_DS_SAM_INIT_FAILURE_CONSOLE = 0x00002172

4798 ERROR_DS_FOREST_VERSION_TOO_HIGH = 0x00002173

4799 ERROR_DS_DOMAIN_VERSION_TOO_HIGH = 0x00002174

4800 ERROR_DS_FOREST_VERSION_TOO_LOW = 0x00002175

4801 ERROR_DS_DOMAIN_VERSION_TOO_LOW = 0x00002176

4802 ERROR_DS_INCOMPATIBLE_VERSION = 0x00002177

4803 ERROR_DS_LOW_DSA_VERSION = 0x00002178

4804 ERROR_DS_NO_BEHAVIOR_VERSION_IN_MIXEDDOMAIN = 0x00002179

4805 ERROR_DS_NOT_SUPPORTED_SORT_ORDER = 0x0000217a

4806 ERROR_DS_NAME_NOT_UNIQUE = 0x0000217b

4807 ERROR_DS_MACHINE_ACCOUNT_CREATED_PRENT4 = 0x0000217c

4808 ERROR_DS_OUT_OF_VERSION_STORE = 0x0000217d

4809 ERROR_DS_INCOMPATIBLE_CONTROLS_USED = 0x0000217e

4810 ERROR_DS_NO_REF_DOMAIN = 0x0000217f

4811 ERROR_DS_RESERVED_LINK_ID = 0x00002180

4812 ERROR_DS_LINK_ID_NOT_AVAILABLE = 0x00002181

4813 ERROR_DS_AG_CANT_HAVE_UNIVERSAL_MEMBER = 0x00002182

4814 ERROR_DS_MODIFYDN_DISALLOWED_BY_INSTANCE_TYPE = 0x00002183

4815 ERROR_DS_NO_OBJECT_MOVE_IN_SCHEMA_NC = 0x00002184

4816 ERROR_DS_MODIFYDN_DISALLOWED_BY_FLAG = 0x00002185

4817 ERROR_DS_MODIFYDN_WRONG_GRANDPARENT = 0x00002186

4818 ERROR_DS_NAME_ERROR_TRUST_REFERRAL = 0x00002187

4819 ERROR_NOT_SUPPORTED_ON_STANDARD_SERVER = 0x00002188

4820 ERROR_DS_CANT_ACCESS_REMOTE_PART_OF_AD = 0x00002189

4821 ERROR_DS_CR_IMPOSSIBLE_TO_VALIDATE_V2 = 0x0000218a

4822 ERROR_DS_THREAD_LIMIT_EXCEEDED = 0x0000218b

4823 ERROR_DS_NOT_CLOSEST = 0x0000218c

4824 ERROR_DS_CANT_DERIVE_SPN_WITHOUT_SERVER_REF = 0x0000218d

4825 ERROR_DS_SINGLE_USER_MODE_FAILED = 0x0000218e

4826 ERROR_DS_NTDSCRIPT_SYNTAX_ERROR = 0x0000218f

4827 ERROR_DS_NTDSCRIPT_PROCESS_ERROR = 0x00002190

4828 ERROR_DS_DIFFERENT_REPL_EPOCHS = 0x00002191

4829 ERROR_DS_DRS_EXTENSIONS_CHANGED = 0x00002192

4830 ERROR_DS_REPLICA_SET_CHANGE_NOT_ALLOWED_ON_DISABLED_CR = 0x00002193

4831 ERROR_DS_NO_MSDS_INTID = 0x00002194

4832 ERROR_DS_DUP_MSDS_INTID = 0x00002195

4833 ERROR_DS_EXISTS_IN_RDNATTID = 0x00002196

4834 ERROR_DS_AUTHORIZATION_FAILED = 0x00002197

4835 ERROR_DS_INVALID_SCRIPT = 0x00002198

4836 ERROR_DS_REMOTE_CROSSREF_OP_FAILED = 0x00002199

4837 ERROR_DS_CROSS_REF_BUSY = 0x0000219a

4838 ERROR_DS_CANT_DERIVE_SPN_FOR_DELETED_DOMAIN = 0x0000219b

4839 ERROR_DS_CANT_DEMOTE_WITH_WRITEABLE_NC = 0x0000219c

4840 ERROR_DS_DUPLICATE_ID_FOUND = 0x0000219d

4841 ERROR_DS_INSUFFICIENT_ATTR_TO_CREATE_OBJECT = 0x0000219e

4842 ERROR_DS_GROUP_CONVERSION_ERROR = 0x0000219f

4843 ERROR_DS_CANT_MOVE_APP_BASIC_GROUP = 0x000021a0

4844 ERROR_DS_CANT_MOVE_APP_QUERY_GROUP = 0x000021a1

4845 ERROR_DS_ROLE_NOT_VERIFIED = 0x000021a2

4846 ERROR_DS_WKO_CONTAINER_CANNOT_BE_SPECIAL = 0x000021a3

4847 ERROR_DS_DOMAIN_RENAME_IN_PROGRESS = 0x000021a4

4848 ERROR_DS_EXISTING_AD_CHILD_NC = 0x000021a5

4849 ERROR_DS_REPL_LIFETIME_EXCEEDED = 0x000021a6

4850 ERROR_DS_DISALLOWED_IN_SYSTEM_CONTAINER = 0x000021a7

4851 ERROR_DS_LDAP_SEND_QUEUE_FULL = 0x000021a8

4852 ERROR_DS_DRA_OUT_SCHEDULE_WINDOW = 0x000021a9

4853 ERROR_DS_POLICY_NOT_KNOWN = 0x000021aa

4854 ERROR_NO_SITE_SETTINGS_OBJECT = 0x000021ab

4855 ERROR_NO_SECRETS = 0x000021ac

4856 ERROR_NO_WRITABLE_DC_FOUND = 0x000021ad

4857 ERROR_DS_NO_SERVER_OBJECT = 0x000021ae

4858 ERROR_DS_NO_NTDSA_OBJECT = 0x000021af

4859 ERROR_DS_NON_ASQ_SEARCH = 0x000021b0

4860 ERROR_DS_AUDIT_FAILURE = 0x000021b1

4861 ERROR_DS_INVALID_SEARCH_FLAG_SUBTREE = 0x000021b2

4862 ERROR_DS_INVALID_SEARCH_FLAG_TUPLE = 0x000021b3

4863 ERROR_DS_HIERARCHY_TABLE_TOO_DEEP = 0x000021b4

4864 ERROR_DS_DRA_CORRUPT_UTD_VECTOR = 0x000021b5

4865 ERROR_DS_DRA_SECRETS_DENIED = 0x000021b6

4866 ERROR_DS_RESERVED_MAPI_ID = 0x000021b7

4867 ERROR_DS_MAPI_ID_NOT_AVAILABLE = 0x000021b8

4868 ERROR_DS_DRA_MISSING_KRBTGT_SECRET = 0x000021b9

4869 ERROR_DS_DOMAIN_NAME_EXISTS_IN_FOREST = 0x000021ba

4870 ERROR_DS_FLAT_NAME_EXISTS_IN_FOREST = 0x000021bb

4871 ERROR_INVALID_USER_PRINCIPAL_NAME = 0x000021bc

4872 ERROR_DS_OID_MAPPED_GROUP_CANT_HAVE_MEMBERS = 0x000021bd

4873 ERROR_DS_OID_NOT_FOUND = 0x000021be

4874 ERROR_DS_DRA_RECYCLED_TARGET = 0x000021bf

4875 ERROR_DS_DISALLOWED_NC_REDIRECT = 0x000021c0

4876 ERROR_DS_HIGH_ADLDS_FFL = 0x000021c1

4877 ERROR_DS_HIGH_DSA_VERSION = 0x000021c2

4878 ERROR_DS_LOW_ADLDS_FFL = 0x000021c3

4879 ERROR_DOMAIN_SID_SAME_AS_LOCAL_WORKSTATION = 0x000021c4

4880 ERROR_DS_UNDELETE_SAM_VALIDATION_FAILED = 0x000021c5

4881 ERROR_INCORRECT_ACCOUNT_TYPE = 0x000021c6

4882 DNS_ERROR_RCODE_FORMAT_ERROR = 0x00002329

4883 DNS_ERROR_RCODE_SERVER_FAILURE = 0x0000232a

4884 DNS_ERROR_RCODE_NAME_ERROR = 0x0000232b

4885 DNS_ERROR_RCODE_NOT_IMPLEMENTED = 0x0000232c

4886 DNS_ERROR_RCODE_REFUSED = 0x0000232d

4887 DNS_ERROR_RCODE_YXDOMAIN = 0x0000232e

4888 DNS_ERROR_RCODE_YXRRSET = 0x0000232f

4889 DNS_ERROR_RCODE_NXRRSET = 0x00002330

4890 DNS_ERROR_RCODE_NOTAUTH = 0x00002331

4891 DNS_ERROR_RCODE_NOTZONE = 0x00002332

4892 DNS_ERROR_RCODE_BADSIG = 0x00002338

4893 DNS_ERROR_RCODE_BADKEY = 0x00002339

4894 DNS_ERROR_RCODE_BADTIME = 0x0000233a

4895 DNS_ERROR_KEYMASTER_REQUIRED = 0x0000238d

4896 DNS_ERROR_NOT_ALLOWED_ON_SIGNED_ZONE = 0x0000238e

4897 DNS_ERROR_NSEC3_INCOMPATIBLE_WITH_RSA_SHA1 = 0x0000238f

4898 DNS_ERROR_NOT_ENOUGH_SIGNING_KEY_DESCRIPTORS = 0x00002390

4899 DNS_ERROR_UNSUPPORTED_ALGORITHM = 0x00002391

4900 DNS_ERROR_INVALID_KEY_SIZE = 0x00002392

4901 DNS_ERROR_SIGNING_KEY_NOT_ACCESSIBLE = 0x00002393

4902 DNS_ERROR_KSP_DOES_NOT_SUPPORT_PROTECTION = 0x00002394

4903 DNS_ERROR_UNEXPECTED_DATA_PROTECTION_ERROR = 0x00002395

4904 DNS_ERROR_UNEXPECTED_CNG_ERROR = 0x00002396

4905 DNS_ERROR_UNKNOWN_SIGNING_PARAMETER_VERSION = 0x00002397

4906 DNS_ERROR_KSP_NOT_ACCESSIBLE = 0x00002398

4907 DNS_ERROR_TOO_MANY_SKDS = 0x00002399

4908 DNS_ERROR_INVALID_ROLLOVER_PERIOD = 0x0000239a

4909 DNS_ERROR_INVALID_INITIAL_ROLLOVER_OFFSET = 0x0000239b

4910 DNS_ERROR_ROLLOVER_IN_PROGRESS = 0x0000239c

4911 DNS_ERROR_STANDBY_KEY_NOT_PRESENT = 0x0000239d

4912 DNS_ERROR_NOT_ALLOWED_ON_ZSK = 0x0000239e

4913 DNS_ERROR_NOT_ALLOWED_ON_ACTIVE_SKD = 0x0000239f

4914 DNS_ERROR_ROLLOVER_ALREADY_QUEUED = 0x000023a0

4915 DNS_ERROR_NOT_ALLOWED_ON_UNSIGNED_ZONE = 0x000023a1

4916 DNS_ERROR_BAD_KEYMASTER = 0x000023a2

4917 DNS_ERROR_INVALID_SIGNATURE_VALIDITY_PERIOD = 0x000023a3

4918 DNS_ERROR_INVALID_NSEC3_ITERATION_COUNT = 0x000023a4

4919 DNS_ERROR_DNSSEC_IS_DISABLED = 0x000023a5

4920 DNS_ERROR_INVALID_XML = 0x000023a6

4921 DNS_ERROR_NO_VALID_TRUST_ANCHORS = 0x000023a7

4922 DNS_ERROR_ROLLOVER_NOT_POKEABLE = 0x000023a8

4923 DNS_ERROR_NSEC3_NAME_COLLISION = 0x000023a9

4924 DNS_ERROR_NSEC_INCOMPATIBLE_WITH_NSEC3_RSA_SHA1 = 0x000023aa

4925 DNS_INFO_NO_RECORDS = 0x0000251d

4926 DNS_ERROR_BAD_PACKET = 0x0000251e

4927 DNS_ERROR_NO_PACKET = 0x0000251f

4928 DNS_ERROR_RCODE = 0x00002520

4929 DNS_ERROR_UNSECURE_PACKET = 0x00002521

4930 DNS_REQUEST_PENDING = 0x00002522

4931 DNS_ERROR_INVALID_TYPE = 0x0000254f

4932 DNS_ERROR_INVALID_IP_ADDRESS = 0x00002550

4933 DNS_ERROR_INVALID_PROPERTY = 0x00002551

4934 DNS_ERROR_TRY_AGAIN_LATER = 0x00002552

4935 DNS_ERROR_NOT_UNIQUE = 0x00002553

4936 DNS_ERROR_NON_RFC_NAME = 0x00002554

4937 DNS_STATUS_FQDN = 0x00002555

4938 DNS_STATUS_DOTTED_NAME = 0x00002556

4939 DNS_STATUS_SINGLE_PART_NAME = 0x00002557

4940 DNS_ERROR_INVALID_NAME_CHAR = 0x00002558

4941 DNS_ERROR_NUMERIC_NAME = 0x00002559

4942 DNS_ERROR_NOT_ALLOWED_ON_ROOT_SERVER = 0x0000255a

4943 DNS_ERROR_NOT_ALLOWED_UNDER_DELEGATION = 0x0000255b

4944 DNS_ERROR_CANNOT_FIND_ROOT_HINTS = 0x0000255c

4945 DNS_ERROR_INCONSISTENT_ROOT_HINTS = 0x0000255d

4946 DNS_ERROR_DWORD_VALUE_TOO_SMALL = 0x0000255e

4947 DNS_ERROR_DWORD_VALUE_TOO_LARGE = 0x0000255f

4948 DNS_ERROR_BACKGROUND_LOADING = 0x00002560

4949 DNS_ERROR_NOT_ALLOWED_ON_RODC = 0x00002561

4950 DNS_ERROR_NOT_ALLOWED_UNDER_DNAME = 0x00002562

4951 DNS_ERROR_DELEGATION_REQUIRED = 0x00002563

4952 DNS_ERROR_INVALID_POLICY_TABLE = 0x00002564

4953 DNS_ERROR_ZONE_DOES_NOT_EXIST = 0x00002581

4954 DNS_ERROR_NO_ZONE_INFO = 0x00002582

4955 DNS_ERROR_INVALID_ZONE_OPERATION = 0x00002583

4956 DNS_ERROR_ZONE_CONFIGURATION_ERROR = 0x00002584

4957 DNS_ERROR_ZONE_HAS_NO_SOA_RECORD = 0x00002585

4958 DNS_ERROR_ZONE_HAS_NO_NS_RECORDS = 0x00002586

4959 DNS_ERROR_ZONE_LOCKED = 0x00002587

4960 DNS_ERROR_ZONE_CREATION_FAILED = 0x00002588

4961 DNS_ERROR_ZONE_ALREADY_EXISTS = 0x00002589

4962 DNS_ERROR_AUTOZONE_ALREADY_EXISTS = 0x0000258a

4963 DNS_ERROR_INVALID_ZONE_TYPE = 0x0000258b

4964 DNS_ERROR_SECONDARY_REQUIRES_MASTER_IP = 0x0000258c

4965 DNS_ERROR_ZONE_NOT_SECONDARY = 0x0000258d

4966 DNS_ERROR_NEED_SECONDARY_ADDRESSES = 0x0000258e

4967 DNS_ERROR_WINS_INIT_FAILED = 0x0000258f

4968 DNS_ERROR_NEED_WINS_SERVERS = 0x00002590

4969 DNS_ERROR_NBSTAT_INIT_FAILED = 0x00002591

4970 DNS_ERROR_SOA_DELETE_INVALID = 0x00002592

4971 DNS_ERROR_FORWARDER_ALREADY_EXISTS = 0x00002593

4972 DNS_ERROR_ZONE_REQUIRES_MASTER_IP = 0x00002594

4973 DNS_ERROR_ZONE_IS_SHUTDOWN = 0x00002595

4974 DNS_ERROR_ZONE_LOCKED_FOR_SIGNING = 0x00002596

4975 DNS_ERROR_PRIMARY_REQUIRES_DATAFILE = 0x000025b3

4976 DNS_ERROR_INVALID_DATAFILE_NAME = 0x000025b4

4977 DNS_ERROR_DATAFILE_OPEN_FAILURE = 0x000025b5

4978 DNS_ERROR_FILE_WRITEBACK_FAILED = 0x000025b6

4979 DNS_ERROR_DATAFILE_PARSING = 0x000025b7

4980 DNS_ERROR_RECORD_DOES_NOT_EXIST = 0x000025e5

4981 DNS_ERROR_RECORD_FORMAT = 0x000025e6

4982 DNS_ERROR_NODE_CREATION_FAILED = 0x000025e7

4983 DNS_ERROR_UNKNOWN_RECORD_TYPE = 0x000025e8

4984 DNS_ERROR_RECORD_TIMED_OUT = 0x000025e9

4985 DNS_ERROR_NAME_NOT_IN_ZONE = 0x000025ea

4986 DNS_ERROR_CNAME_LOOP = 0x000025eb

4987 DNS_ERROR_NODE_IS_CNAME = 0x000025ec

4988 DNS_ERROR_CNAME_COLLISION = 0x000025ed

4989 DNS_ERROR_RECORD_ONLY_AT_ZONE_ROOT = 0x000025ee

4990 DNS_ERROR_RECORD_ALREADY_EXISTS = 0x000025ef

4991 DNS_ERROR_SECONDARY_DATA = 0x000025f0

4992 DNS_ERROR_NO_CREATE_CACHE_DATA = 0x000025f1

4993 DNS_ERROR_NAME_DOES_NOT_EXIST = 0x000025f2

4994 DNS_WARNING_PTR_CREATE_FAILED = 0x000025f3

4995 DNS_WARNING_DOMAIN_UNDELETED = 0x000025f4

4996 DNS_ERROR_DS_UNAVAILABLE = 0x000025f5

4997 DNS_ERROR_DS_ZONE_ALREADY_EXISTS = 0x000025f6

4998 DNS_ERROR_NO_BOOTFILE_IF_DS_ZONE = 0x000025f7

4999 DNS_ERROR_NODE_IS_DNAME = 0x000025f8

5000 DNS_ERROR_DNAME_COLLISION = 0x000025f9

5001 DNS_ERROR_ALIAS_LOOP = 0x000025fa

5002 DNS_INFO_AXFR_COMPLETE = 0x00002617

5003 DNS_ERROR_AXFR = 0x00002618

5004 DNS_INFO_ADDED_LOCAL_WINS = 0x00002619

5005 DNS_STATUS_CONTINUE_NEEDED = 0x00002649

5006 DNS_ERROR_NO_TCPIP = 0x0000267b

5007 DNS_ERROR_NO_DNS_SERVERS = 0x0000267c

5008 DNS_ERROR_DP_DOES_NOT_EXIST = 0x000026ad

5009 DNS_ERROR_DP_ALREADY_EXISTS = 0x000026ae

5010 DNS_ERROR_DP_NOT_ENLISTED = 0x000026af

5011 DNS_ERROR_DP_ALREADY_ENLISTED = 0x000026b0

5012 DNS_ERROR_DP_NOT_AVAILABLE = 0x000026b1

5013 DNS_ERROR_DP_FSMO_ERROR = 0x000026b2

5014 WSAEINTR = 0x00002714

5015 WSAEBADF = 0x00002719

5016 WSAEACCES = 0x0000271d

5017 WSAEFAULT = 0x0000271e

5018 WSAEINVAL = 0x00002726

5019 WSAEMFILE = 0x00002728

5020 WSAEWOULDBLOCK = 0x00002733

5021 WSAEINPROGRESS = 0x00002734

5022 WSAEALREADY = 0x00002735

5023 WSAENOTSOCK = 0x00002736

5024 WSAEDESTADDRREQ = 0x00002737

5025 WSAEMSGSIZE = 0x00002738

5026 WSAEPROTOTYPE = 0x00002739

5027 WSAENOPROTOOPT = 0x0000273a

5028 WSAEPROTONOSUPPORT = 0x0000273b

5029 WSAESOCKTNOSUPPORT = 0x0000273c

5030 WSAEOPNOTSUPP = 0x0000273d

5031 WSAEPFNOSUPPORT = 0x0000273e

5032 WSAEAFNOSUPPORT = 0x0000273f

5033 WSAEADDRINUSE = 0x00002740

5034 WSAEADDRNOTAVAIL = 0x00002741

5035 WSAENETDOWN = 0x00002742

5036 WSAENETUNREACH = 0x00002743

5037 WSAENETRESET = 0x00002744

5038 WSAECONNABORTED = 0x00002745

5039 WSAECONNRESET = 0x00002746

5040 WSAENOBUFS = 0x00002747

5041 WSAEISCONN = 0x00002748

5042 WSAENOTCONN = 0x00002749

5043 WSAESHUTDOWN = 0x0000274a

5044 WSAETOOMANYREFS = 0x0000274b

5045 WSAETIMEDOUT = 0x0000274c

5046 WSAECONNREFUSED = 0x0000274d

5047 WSAELOOP = 0x0000274e

5048 WSAENAMETOOLONG = 0x0000274f

5049 WSAEHOSTDOWN = 0x00002750

5050 WSAEHOSTUNREACH = 0x00002751

5051 WSAENOTEMPTY = 0x00002752

5052 WSAEPROCLIM = 0x00002753

5053 WSAEUSERS = 0x00002754

5054 WSAEDQUOT = 0x00002755

5055 WSAESTALE = 0x00002756

5056 WSAEREMOTE = 0x00002757

5057 WSASYSNOTREADY = 0x0000276b

5058 WSAVERNOTSUPPORTED = 0x0000276c

5059 WSANOTINITIALISED = 0x0000276d

5060 WSAEDISCON = 0x00002775

5061 WSAENOMORE = 0x00002776

5062 WSAECANCELLED = 0x00002777

5063 WSAEINVALIDPROCTABLE = 0x00002778

5064 WSAEINVALIDPROVIDER = 0x00002779

5065 WSAEPROVIDERFAILEDINIT = 0x0000277a

5066 WSASYSCALLFAILURE = 0x0000277b

5067 WSASERVICE_NOT_FOUND = 0x0000277c

5068 WSATYPE_NOT_FOUND = 0x0000277d

5069 WSA_E_NO_MORE = 0x0000277e

5070 WSA_E_CANCELLED = 0x0000277f

5071 WSAEREFUSED = 0x00002780

5072 WSAHOST_NOT_FOUND = 0x00002af9

5073 WSATRY_AGAIN = 0x00002afa

5074 WSANO_RECOVERY = 0x00002afb

5075 WSANO_DATA = 0x00002afc

5076 WSA_QOS_RECEIVERS = 0x00002afd

5077 WSA_QOS_SENDERS = 0x00002afe

5078 WSA_QOS_NO_SENDERS = 0x00002aff

5079 WSA_QOS_NO_RECEIVERS = 0x00002b00

5080 WSA_QOS_REQUEST_CONFIRMED = 0x00002b01

5081 WSA_QOS_ADMISSION_FAILURE = 0x00002b02

5082 WSA_QOS_POLICY_FAILURE = 0x00002b03

5083 WSA_QOS_BAD_STYLE = 0x00002b04

5084 WSA_QOS_BAD_OBJECT = 0x00002b05

5085 WSA_QOS_TRAFFIC_CTRL_ERROR = 0x00002b06

5086 WSA_QOS_GENERIC_ERROR = 0x00002b07

5087 WSA_QOS_ESERVICETYPE = 0x00002b08

5088 WSA_QOS_EFLOWSPEC = 0x00002b09

5089 WSA_QOS_EPROVSPECBUF = 0x00002b0a

5090 WSA_QOS_EFILTERSTYLE = 0x00002b0b

5091 WSA_QOS_EFILTERTYPE = 0x00002b0c

5092 WSA_QOS_EFILTERCOUNT = 0x00002b0d

5093 WSA_QOS_EOBJLENGTH = 0x00002b0e

5094 WSA_QOS_EFLOWCOUNT = 0x00002b0f

5095 WSA_QOS_EUNKOWNPSOBJ = 0x00002b10

5096 WSA_QOS_EPOLICYOBJ = 0x00002b11

5097 WSA_QOS_EFLOWDESC = 0x00002b12

5098 WSA_QOS_EPSFLOWSPEC = 0x00002b13

5099 WSA_QOS_EPSFILTERSPEC = 0x00002b14

5100 WSA_QOS_ESDMODEOBJ = 0x00002b15

5101 WSA_QOS_ESHAPERATEOBJ = 0x00002b16

5102 WSA_QOS_RESERVED_PETYPE = 0x00002b17

5103 WSA_SECURE_HOST_NOT_FOUND = 0x00002b18

5104 WSA_IPSEC_NAME_POLICY_ERROR = 0x00002b19

5105 ERROR_IPSEC_QM_POLICY_EXISTS = 0x000032c8

5106 ERROR_IPSEC_QM_POLICY_NOT_FOUND = 0x000032c9

5107 ERROR_IPSEC_QM_POLICY_IN_USE = 0x000032ca

5108 ERROR_IPSEC_MM_POLICY_EXISTS = 0x000032cb

5109 ERROR_IPSEC_MM_POLICY_NOT_FOUND = 0x000032cc

5110 ERROR_IPSEC_MM_POLICY_IN_USE = 0x000032cd

5111 ERROR_IPSEC_MM_FILTER_EXISTS = 0x000032ce

5112 ERROR_IPSEC_MM_FILTER_NOT_FOUND = 0x000032cf

5113 ERROR_IPSEC_TRANSPORT_FILTER_EXISTS = 0x000032d0

5114 ERROR_IPSEC_TRANSPORT_FILTER_NOT_FOUND = 0x000032d1

5115 ERROR_IPSEC_MM_AUTH_EXISTS = 0x000032d2

5116 ERROR_IPSEC_MM_AUTH_NOT_FOUND = 0x000032d3

5117 ERROR_IPSEC_MM_AUTH_IN_USE = 0x000032d4

5118 ERROR_IPSEC_DEFAULT_MM_POLICY_NOT_FOUND = 0x000032d5

5119 ERROR_IPSEC_DEFAULT_MM_AUTH_NOT_FOUND = 0x000032d6

5120 ERROR_IPSEC_DEFAULT_QM_POLICY_NOT_FOUND = 0x000032d7

5121 ERROR_IPSEC_TUNNEL_FILTER_EXISTS = 0x000032d8

5122 ERROR_IPSEC_TUNNEL_FILTER_NOT_FOUND = 0x000032d9

5123 ERROR_IPSEC_MM_FILTER_PENDING_DELETION = 0x000032da

5124 ERROR_IPSEC_TRANSPORT_FILTER_PENDING_DELETION = 0x000032db

5125 ERROR_IPSEC_TUNNEL_FILTER_PENDING_DELETION = 0x000032dc

5126 ERROR_IPSEC_MM_POLICY_PENDING_DELETION = 0x000032dd

5127 ERROR_IPSEC_MM_AUTH_PENDING_DELETION = 0x000032de

5128 ERROR_IPSEC_QM_POLICY_PENDING_DELETION = 0x000032df

5129 WARNING_IPSEC_MM_POLICY_PRUNED = 0x000032e0

5130 WARNING_IPSEC_QM_POLICY_PRUNED = 0x000032e1

5131 ERROR_IPSEC_IKE_NEG_STATUS_BEGIN = 0x000035e8

5132 ERROR_IPSEC_IKE_AUTH_FAIL = 0x000035e9

5133 ERROR_IPSEC_IKE_ATTRIB_FAIL = 0x000035ea

5134 ERROR_IPSEC_IKE_NEGOTIATION_PENDING = 0x000035eb

5135 ERROR_IPSEC_IKE_GENERAL_PROCESSING_ERROR = 0x000035ec

5136 ERROR_IPSEC_IKE_TIMED_OUT = 0x000035ed

5137 ERROR_IPSEC_IKE_NO_CERT = 0x000035ee

5138 ERROR_IPSEC_IKE_SA_DELETED = 0x000035ef

5139 ERROR_IPSEC_IKE_SA_REAPED = 0x000035f0

5140 ERROR_IPSEC_IKE_MM_ACQUIRE_DROP = 0x000035f1

5141 ERROR_IPSEC_IKE_QM_ACQUIRE_DROP = 0x000035f2

5142 ERROR_IPSEC_IKE_QUEUE_DROP_MM = 0x000035f3

5143 ERROR_IPSEC_IKE_QUEUE_DROP_NO_MM = 0x000035f4

5144 ERROR_IPSEC_IKE_DROP_NO_RESPONSE = 0x000035f5

5145 ERROR_IPSEC_IKE_MM_DELAY_DROP = 0x000035f6

5146 ERROR_IPSEC_IKE_QM_DELAY_DROP = 0x000035f7

5147 ERROR_IPSEC_IKE_ERROR = 0x000035f8

5148 ERROR_IPSEC_IKE_CRL_FAILED = 0x000035f9

5149 ERROR_IPSEC_IKE_INVALID_KEY_USAGE = 0x000035fa

5150 ERROR_IPSEC_IKE_INVALID_CERT_TYPE = 0x000035fb

5151 ERROR_IPSEC_IKE_NO_PRIVATE_KEY = 0x000035fc

5152 ERROR_IPSEC_IKE_SIMULTANEOUS_REKEY = 0x000035fd

5153 ERROR_IPSEC_IKE_DH_FAIL = 0x000035fe

5154 ERROR_IPSEC_IKE_CRITICAL_PAYLOAD_NOT_RECOGNIZED = 0x000035ff

5155 ERROR_IPSEC_IKE_INVALID_HEADER = 0x00003600

5156 ERROR_IPSEC_IKE_NO_POLICY = 0x00003601

5157 ERROR_IPSEC_IKE_INVALID_SIGNATURE = 0x00003602

5158 ERROR_IPSEC_IKE_KERBEROS_ERROR = 0x00003603

5159 ERROR_IPSEC_IKE_NO_PUBLIC_KEY = 0x00003604

5160 ERROR_IPSEC_IKE_PROCESS_ERR = 0x00003605

5161 ERROR_IPSEC_IKE_PROCESS_ERR_SA = 0x00003606

5162 ERROR_IPSEC_IKE_PROCESS_ERR_PROP = 0x00003607

5163 ERROR_IPSEC_IKE_PROCESS_ERR_TRANS = 0x00003608

5164 ERROR_IPSEC_IKE_PROCESS_ERR_KE = 0x00003609

5165 ERROR_IPSEC_IKE_PROCESS_ERR_ID = 0x0000360a

5166 ERROR_IPSEC_IKE_PROCESS_ERR_CERT = 0x0000360b

5167 ERROR_IPSEC_IKE_PROCESS_ERR_CERT_REQ = 0x0000360c

5168 ERROR_IPSEC_IKE_PROCESS_ERR_HASH = 0x0000360d

5169 ERROR_IPSEC_IKE_PROCESS_ERR_SIG = 0x0000360e

5170 ERROR_IPSEC_IKE_PROCESS_ERR_NONCE = 0x0000360f

5171 ERROR_IPSEC_IKE_PROCESS_ERR_NOTIFY = 0x00003610

5172 ERROR_IPSEC_IKE_PROCESS_ERR_DELETE = 0x00003611

5173 ERROR_IPSEC_IKE_PROCESS_ERR_VENDOR = 0x00003612

5174 ERROR_IPSEC_IKE_INVALID_PAYLOAD = 0x00003613

5175 ERROR_IPSEC_IKE_LOAD_SOFT_SA = 0x00003614

5176 ERROR_IPSEC_IKE_SOFT_SA_TORN_DOWN = 0x00003615

5177 ERROR_IPSEC_IKE_INVALID_COOKIE = 0x00003616

5178 ERROR_IPSEC_IKE_NO_PEER_CERT = 0x00003617

5179 ERROR_IPSEC_IKE_PEER_CRL_FAILED = 0x00003618

5180 ERROR_IPSEC_IKE_POLICY_CHANGE = 0x00003619

5181 ERROR_IPSEC_IKE_NO_MM_POLICY = 0x0000361a

5182 ERROR_IPSEC_IKE_NOTCBPRIV = 0x0000361b

5183 ERROR_IPSEC_IKE_SECLOADFAIL = 0x0000361c

5184 ERROR_IPSEC_IKE_FAILSSPINIT = 0x0000361d

5185 ERROR_IPSEC_IKE_FAILQUERYSSP = 0x0000361e

5186 ERROR_IPSEC_IKE_SRVACQFAIL = 0x0000361f

5187 ERROR_IPSEC_IKE_SRVQUERYCRED = 0x00003620

5188 ERROR_IPSEC_IKE_GETSPIFAIL = 0x00003621

5189 ERROR_IPSEC_IKE_INVALID_FILTER = 0x00003622

5190 ERROR_IPSEC_IKE_OUT_OF_MEMORY = 0x00003623

5191 ERROR_IPSEC_IKE_ADD_UPDATE_KEY_FAILED = 0x00003624

5192 ERROR_IPSEC_IKE_INVALID_POLICY = 0x00003625

5193 ERROR_IPSEC_IKE_UNKNOWN_DOI = 0x00003626

5194 ERROR_IPSEC_IKE_INVALID_SITUATION = 0x00003627

5195 ERROR_IPSEC_IKE_DH_FAILURE = 0x00003628

5196 ERROR_IPSEC_IKE_INVALID_GROUP = 0x00003629

5197 ERROR_IPSEC_IKE_ENCRYPT = 0x0000362a

5198 ERROR_IPSEC_IKE_DECRYPT = 0x0000362b

5199 ERROR_IPSEC_IKE_POLICY_MATCH = 0x0000362c

5200 ERROR_IPSEC_IKE_UNSUPPORTED_ID = 0x0000362d

5201 ERROR_IPSEC_IKE_INVALID_HASH = 0x0000362e

5202 ERROR_IPSEC_IKE_INVALID_HASH_ALG = 0x0000362f

5203 ERROR_IPSEC_IKE_INVALID_HASH_SIZE = 0x00003630

5204 ERROR_IPSEC_IKE_INVALID_ENCRYPT_ALG = 0x00003631

5205 ERROR_IPSEC_IKE_INVALID_AUTH_ALG = 0x00003632

5206 ERROR_IPSEC_IKE_INVALID_SIG = 0x00003633

5207 ERROR_IPSEC_IKE_LOAD_FAILED = 0x00003634

5208 ERROR_IPSEC_IKE_RPC_DELETE = 0x00003635

5209 ERROR_IPSEC_IKE_BENIGN_REINIT = 0x00003636

5210 ERROR_IPSEC_IKE_INVALID_RESPONDER_LIFETIME_NOTIFY = 0x00003637

5211 ERROR_IPSEC_IKE_INVALID_MAJOR_VERSION = 0x00003638

5212 ERROR_IPSEC_IKE_INVALID_CERT_KEYLEN = 0x00003639

5213 ERROR_IPSEC_IKE_MM_LIMIT = 0x0000363a

5214 ERROR_IPSEC_IKE_NEGOTIATION_DISABLED = 0x0000363b

5215 ERROR_IPSEC_IKE_QM_LIMIT = 0x0000363c

5216 ERROR_IPSEC_IKE_MM_EXPIRED = 0x0000363d

5217 ERROR_IPSEC_IKE_PEER_MM_ASSUMED_INVALID = 0x0000363e

5218 ERROR_IPSEC_IKE_CERT_CHAIN_POLICY_MISMATCH = 0x0000363f

5219 ERROR_IPSEC_IKE_UNEXPECTED_MESSAGE_ID = 0x00003640

5220 ERROR_IPSEC_IKE_INVALID_AUTH_PAYLOAD = 0x00003641

5221 ERROR_IPSEC_IKE_DOS_COOKIE_SENT = 0x00003642

5222 ERROR_IPSEC_IKE_SHUTTING_DOWN = 0x00003643

5223 ERROR_IPSEC_IKE_CGA_AUTH_FAILED = 0x00003644

5224 ERROR_IPSEC_IKE_PROCESS_ERR_NATOA = 0x00003645

5225 ERROR_IPSEC_IKE_INVALID_MM_FOR_QM = 0x00003646

5226 ERROR_IPSEC_IKE_QM_EXPIRED = 0x00003647

5227 ERROR_IPSEC_IKE_TOO_MANY_FILTERS = 0x00003648

5228 ERROR_IPSEC_IKE_NEG_STATUS_END = 0x00003649

5229 ERROR_IPSEC_IKE_KILL_DUMMY_NAP_TUNNEL = 0x0000364a

5230 ERROR_IPSEC_IKE_INNER_IP_ASSIGNMENT_FAILURE = 0x0000364b

5231 ERROR_IPSEC_IKE_REQUIRE_CP_PAYLOAD_MISSING = 0x0000364c

5232 ERROR_IPSEC_KEY_MODULE_IMPERSONATION_NEGOTIATION_PENDING = 0x0000364d

5233 ERROR_IPSEC_IKE_COEXISTENCE_SUPPRESS = 0x0000364e

5234 ERROR_IPSEC_IKE_RATELIMIT_DROP = 0x0000364f

5235 ERROR_IPSEC_IKE_PEER_DOESNT_SUPPORT_MOBIKE = 0x00003650

5236 ERROR_IPSEC_IKE_AUTHORIZATION_FAILURE = 0x00003651

5237 ERROR_IPSEC_IKE_STRONG_CRED_AUTHORIZATION_FAILURE = 0x00003652

5238 ERROR_IPSEC_IKE_AUTHORIZATION_FAILURE_WITH_OPTIONAL_RETRY = 0x00003653

5239 ERROR_IPSEC_IKE_STRONG_CRED_AUTHORIZATION_AND_CERTMAP_FAILURE = 0x00003654

5240 ERROR_IPSEC_IKE_NEG_STATUS_EXTENDED_END = 0x00003655

5241 ERROR_IPSEC_BAD_SPI = 0x00003656

5242 ERROR_IPSEC_SA_LIFETIME_EXPIRED = 0x00003657

5243 ERROR_IPSEC_WRONG_SA = 0x00003658

5244 ERROR_IPSEC_REPLAY_CHECK_FAILED = 0x00003659

5245 ERROR_IPSEC_INVALID_PACKET = 0x0000365a

5246 ERROR_IPSEC_INTEGRITY_CHECK_FAILED = 0x0000365b

5247 ERROR_IPSEC_CLEAR_TEXT_DROP = 0x0000365c

5248 ERROR_IPSEC_AUTH_FIREWALL_DROP = 0x0000365d

5249 ERROR_IPSEC_THROTTLE_DROP = 0x0000365e

5250 ERROR_IPSEC_DOSP_BLOCK = 0x00003665

5251 ERROR_IPSEC_DOSP_RECEIVED_MULTICAST = 0x00003666

5252 ERROR_IPSEC_DOSP_INVALID_PACKET = 0x00003667

5253 ERROR_IPSEC_DOSP_STATE_LOOKUP_FAILED = 0x00003668

5254 ERROR_IPSEC_DOSP_MAX_ENTRIES = 0x00003669

5255 ERROR_IPSEC_DOSP_KEYMOD_NOT_ALLOWED = 0x0000366a

5256 ERROR_IPSEC_DOSP_NOT_INSTALLED = 0x0000366b

5257 ERROR_IPSEC_DOSP_MAX_PER_IP_RATELIMIT_QUEUES = 0x0000366c

5258 ERROR_SXS_SECTION_NOT_FOUND = 0x000036b0

5259 ERROR_SXS_CANT_GEN_ACTCTX = 0x000036b1

5260 ERROR_SXS_INVALID_ACTCTXDATA_FORMAT = 0x000036b2

5261 ERROR_SXS_ASSEMBLY_NOT_FOUND = 0x000036b3

5262 ERROR_SXS_MANIFEST_FORMAT_ERROR = 0x000036b4

5263 ERROR_SXS_MANIFEST_PARSE_ERROR = 0x000036b5

5264 ERROR_SXS_ACTIVATION_CONTEXT_DISABLED = 0x000036b6

5265 ERROR_SXS_KEY_NOT_FOUND = 0x000036b7

5266 ERROR_SXS_VERSION_CONFLICT = 0x000036b8

5267 ERROR_SXS_WRONG_SECTION_TYPE = 0x000036b9

5268 ERROR_SXS_THREAD_QUERIES_DISABLED = 0x000036ba

5269 ERROR_SXS_PROCESS_DEFAULT_ALREADY_SET = 0x000036bb

5270 ERROR_SXS_UNKNOWN_ENCODING_GROUP = 0x000036bc

5271 ERROR_SXS_UNKNOWN_ENCODING = 0x000036bd

5272 ERROR_SXS_INVALID_XML_NAMESPACE_URI = 0x000036be

5273 ERROR_SXS_ROOT_MANIFEST_DEPENDENCY_NOT_INSTALLED = 0x000036bf

5274 ERROR_SXS_LEAF_MANIFEST_DEPENDENCY_NOT_INSTALLED = 0x000036c0

5275 ERROR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE = 0x000036c1

5276 ERROR_SXS_MANIFEST_MISSING_REQUIRED_DEFAULT_NAMESPACE = 0x000036c2

5277 ERROR_SXS_MANIFEST_INVALID_REQUIRED_DEFAULT_NAMESPACE = 0x000036c3

5278 ERROR_SXS_PRIVATE_MANIFEST_CROSS_PATH_WITH_REPARSE_POINT = 0x000036c4

5279 ERROR_SXS_DUPLICATE_DLL_NAME = 0x000036c5

5280 ERROR_SXS_DUPLICATE_WINDOWCLASS_NAME = 0x000036c6

5281 ERROR_SXS_DUPLICATE_CLSID = 0x000036c7

5282 ERROR_SXS_DUPLICATE_IID = 0x000036c8

5283 ERROR_SXS_DUPLICATE_TLBID = 0x000036c9

5284 ERROR_SXS_DUPLICATE_PROGID = 0x000036ca

5285 ERROR_SXS_DUPLICATE_ASSEMBLY_NAME = 0x000036cb

5286 ERROR_SXS_FILE_HASH_MISMATCH = 0x000036cc

5287 ERROR_SXS_POLICY_PARSE_ERROR = 0x000036cd

5288 ERROR_SXS_XML_E_MISSINGQUOTE = 0x000036ce

5289 ERROR_SXS_XML_E_COMMENTSYNTAX = 0x000036cf

5290 ERROR_SXS_XML_E_BADSTARTNAMECHAR = 0x000036d0

5291 ERROR_SXS_XML_E_BADNAMECHAR = 0x000036d1

5292 ERROR_SXS_XML_E_BADCHARINSTRING = 0x000036d2

5293 ERROR_SXS_XML_E_XMLDECLSYNTAX = 0x000036d3

5294 ERROR_SXS_XML_E_BADCHARDATA = 0x000036d4

5295 ERROR_SXS_XML_E_MISSINGWHITESPACE = 0x000036d5

5296 ERROR_SXS_XML_E_EXPECTINGTAGEND = 0x000036d6

5297 ERROR_SXS_XML_E_MISSINGSEMICOLON = 0x000036d7

5298 ERROR_SXS_XML_E_UNBALANCEDPAREN = 0x000036d8

5299 ERROR_SXS_XML_E_INTERNALERROR = 0x000036d9

5300 ERROR_SXS_XML_E_UNEXPECTED_WHITESPACE = 0x000036da

5301 ERROR_SXS_XML_E_INCOMPLETE_ENCODING = 0x000036db

5302 ERROR_SXS_XML_E_MISSING_PAREN = 0x000036dc

5303 ERROR_SXS_XML_E_EXPECTINGCLOSEQUOTE = 0x000036dd

5304 ERROR_SXS_XML_E_MULTIPLE_COLONS = 0x000036de

5305 ERROR_SXS_XML_E_INVALID_DECIMAL = 0x000036df

5306 ERROR_SXS_XML_E_INVALID_HEXIDECIMAL = 0x000036e0

5307 ERROR_SXS_XML_E_INVALID_UNICODE = 0x000036e1

5308 ERROR_SXS_XML_E_WHITESPACEORQUESTIONMARK = 0x000036e2

5309 ERROR_SXS_XML_E_UNEXPECTEDENDTAG = 0x000036e3

5310 ERROR_SXS_XML_E_UNCLOSEDTAG = 0x000036e4

5311 ERROR_SXS_XML_E_DUPLICATEATTRIBUTE = 0x000036e5

5312 ERROR_SXS_XML_E_MULTIPLEROOTS = 0x000036e6

5313 ERROR_SXS_XML_E_INVALIDATROOTLEVEL = 0x000036e7

5314 ERROR_SXS_XML_E_BADXMLDECL = 0x000036e8

5315 ERROR_SXS_XML_E_MISSINGROOT = 0x000036e9

5316 ERROR_SXS_XML_E_UNEXPECTEDEOF = 0x000036ea

5317 ERROR_SXS_XML_E_BADPEREFINSUBSET = 0x000036eb

5318 ERROR_SXS_XML_E_UNCLOSEDSTARTTAG = 0x000036ec

5319 ERROR_SXS_XML_E_UNCLOSEDENDTAG = 0x000036ed

5320 ERROR_SXS_XML_E_UNCLOSEDSTRING = 0x000036ee

5321 ERROR_SXS_XML_E_UNCLOSEDCOMMENT = 0x000036ef

5322 ERROR_SXS_XML_E_UNCLOSEDDECL = 0x000036f0

5323 ERROR_SXS_XML_E_UNCLOSEDCDATA = 0x000036f1

5324 ERROR_SXS_XML_E_RESERVEDNAMESPACE = 0x000036f2

5325 ERROR_SXS_XML_E_INVALIDENCODING = 0x000036f3

5326 ERROR_SXS_XML_E_INVALIDSWITCH = 0x000036f4

5327 ERROR_SXS_XML_E_BADXMLCASE = 0x000036f5

5328 ERROR_SXS_XML_E_INVALID_STANDALONE = 0x000036f6

5329 ERROR_SXS_XML_E_UNEXPECTED_STANDALONE = 0x000036f7

5330 ERROR_SXS_XML_E_INVALID_VERSION = 0x000036f8

5331 ERROR_SXS_XML_E_MISSINGEQUALS = 0x000036f9

5332 ERROR_SXS_PROTECTION_RECOVERY_FAILED = 0x000036fa

5333 ERROR_SXS_PROTECTION_PUBLIC_KEY_TOO_SHORT = 0x000036fb

5334 ERROR_SXS_PROTECTION_CATALOG_NOT_VALID = 0x000036fc

5335 ERROR_SXS_UNTRANSLATABLE_HRESULT = 0x000036fd

5336 ERROR_SXS_PROTECTION_CATALOG_FILE_MISSING = 0x000036fe

5337 ERROR_SXS_MISSING_ASSEMBLY_IDENTITY_ATTRIBUTE = 0x000036ff

5338 ERROR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE_NAME = 0x00003700

5339 ERROR_SXS_ASSEMBLY_MISSING = 0x00003701

5340 ERROR_SXS_CORRUPT_ACTIVATION_STACK = 0x00003702

5341 ERROR_SXS_CORRUPTION = 0x00003703

5342 ERROR_SXS_EARLY_DEACTIVATION = 0x00003704

5343 ERROR_SXS_INVALID_DEACTIVATION = 0x00003705

5344 ERROR_SXS_MULTIPLE_DEACTIVATION = 0x00003706

5345 ERROR_SXS_PROCESS_TERMINATION_REQUESTED = 0x00003707

5346 ERROR_SXS_RELEASE_ACTIVATION_CONTEXT = 0x00003708

5347 ERROR_SXS_SYSTEM_DEFAULT_ACTIVATION_CONTEXT_EMPTY = 0x00003709

5348 ERROR_SXS_INVALID_IDENTITY_ATTRIBUTE_VALUE = 0x0000370a

5349 ERROR_SXS_INVALID_IDENTITY_ATTRIBUTE_NAME = 0x0000370b

5350 ERROR_SXS_IDENTITY_DUPLICATE_ATTRIBUTE = 0x0000370c

5351 ERROR_SXS_IDENTITY_PARSE_ERROR = 0x0000370d

5352 ERROR_MALFORMED_SUBSTITUTION_STRING = 0x0000370e

5353 ERROR_SXS_INCORRECT_PUBLIC_KEY_TOKEN = 0x0000370f

5354 ERROR_UNMAPPED_SUBSTITUTION_STRING = 0x00003710

5355 ERROR_SXS_ASSEMBLY_NOT_LOCKED = 0x00003711

5356 ERROR_SXS_COMPONENT_STORE_CORRUPT = 0x00003712

5357 ERROR_ADVANCED_INSTALLER_FAILED = 0x00003713

5358 ERROR_XML_ENCODING_MISMATCH = 0x00003714

5359 ERROR_SXS_MANIFEST_IDENTITY_SAME_BUT_CONTENTS_DIFFERENT = 0x00003715

5360 ERROR_SXS_IDENTITIES_DIFFERENT = 0x00003716

5361 ERROR_SXS_ASSEMBLY_IS_NOT_A_DEPLOYMENT = 0x00003717

5362 ERROR_SXS_FILE_NOT_PART_OF_ASSEMBLY = 0x00003718

5363 ERROR_SXS_MANIFEST_TOO_BIG = 0x00003719

5364 ERROR_SXS_SETTING_NOT_REGISTERED = 0x0000371a

5365 ERROR_SXS_TRANSACTION_CLOSURE_INCOMPLETE = 0x0000371b

5366 ERROR_SMI_PRIMITIVE_INSTALLER_FAILED = 0x0000371c

5367 ERROR_GENERIC_COMMAND_FAILED = 0x0000371d

5368 ERROR_SXS_FILE_HASH_MISSING = 0x0000371e

5369 ERROR_EVT_INVALID_CHANNEL_PATH = 0x00003a98

5370 ERROR_EVT_INVALID_QUERY = 0x00003a99

5371 ERROR_EVT_PUBLISHER_METADATA_NOT_FOUND = 0x00003a9a

5372 ERROR_EVT_EVENT_TEMPLATE_NOT_FOUND = 0x00003a9b

5373 ERROR_EVT_INVALID_PUBLISHER_NAME = 0x00003a9c

5374 ERROR_EVT_INVALID_EVENT_DATA = 0x00003a9d

5375 ERROR_EVT_CHANNEL_NOT_FOUND = 0x00003a9f

5376 ERROR_EVT_MALFORMED_XML_TEXT = 0x00003aa0

5377 ERROR_EVT_SUBSCRIPTION_TO_DIRECT_CHANNEL = 0x00003aa1

5378 ERROR_EVT_CONFIGURATION_ERROR = 0x00003aa2

5379 ERROR_EVT_QUERY_RESULT_STALE = 0x00003aa3

5380 ERROR_EVT_QUERY_RESULT_INVALID_POSITION = 0x00003aa4

5381 ERROR_EVT_NON_VALIDATING_MSXML = 0x00003aa5

5382 ERROR_EVT_FILTER_ALREADYSCOPED = 0x00003aa6

5383 ERROR_EVT_FILTER_NOTELTSET = 0x00003aa7

5384 ERROR_EVT_FILTER_INVARG = 0x00003aa8

5385 ERROR_EVT_FILTER_INVTEST = 0x00003aa9

5386 ERROR_EVT_FILTER_INVTYPE = 0x00003aaa

5387 ERROR_EVT_FILTER_PARSEERR = 0x00003aab

5388 ERROR_EVT_FILTER_UNSUPPORTEDOP = 0x00003aac

5389 ERROR_EVT_FILTER_UNEXPECTEDTOKEN = 0x00003aad

5390 ERROR_EVT_INVALID_OPERATION_OVER_ENABLED_DIRECT_CHANNEL = 0x00003aae

5391 ERROR_EVT_INVALID_CHANNEL_PROPERTY_VALUE = 0x00003aaf

5392 ERROR_EVT_INVALID_PUBLISHER_PROPERTY_VALUE = 0x00003ab0

5393 ERROR_EVT_CHANNEL_CANNOT_ACTIVATE = 0x00003ab1

5394 ERROR_EVT_FILTER_TOO_COMPLEX = 0x00003ab2

5395 ERROR_EVT_MESSAGE_NOT_FOUND = 0x00003ab3

5396 ERROR_EVT_MESSAGE_ID_NOT_FOUND = 0x00003ab4

5397 ERROR_EVT_UNRESOLVED_VALUE_INSERT = 0x00003ab5

5398 ERROR_EVT_UNRESOLVED_PARAMETER_INSERT = 0x00003ab6

5399 ERROR_EVT_MAX_INSERTS_REACHED = 0x00003ab7

5400 ERROR_EVT_EVENT_DEFINITION_NOT_FOUND = 0x00003ab8

5401 ERROR_EVT_MESSAGE_LOCALE_NOT_FOUND = 0x00003ab9

5402 ERROR_EVT_VERSION_TOO_OLD = 0x00003aba

5403 ERROR_EVT_VERSION_TOO_NEW = 0x00003abb

5404 ERROR_EVT_CANNOT_OPEN_CHANNEL_OF_QUERY = 0x00003abc

5405 ERROR_EVT_PUBLISHER_DISABLED = 0x00003abd

5406 ERROR_EVT_FILTER_OUT_OF_RANGE = 0x00003abe

5407 ERROR_EC_SUBSCRIPTION_CANNOT_ACTIVATE = 0x00003ae8

5408 ERROR_EC_LOG_DISABLED = 0x00003ae9

5409 ERROR_EC_CIRCULAR_FORWARDING = 0x00003aea

5410 ERROR_EC_CREDSTORE_FULL = 0x00003aeb

5411 ERROR_EC_CRED_NOT_FOUND = 0x00003aec

5412 ERROR_EC_NO_ACTIVE_CHANNEL = 0x00003aed

5413 ERROR_MUI_FILE_NOT_FOUND = 0x00003afc

5414 ERROR_MUI_INVALID_FILE = 0x00003afd

5415 ERROR_MUI_INVALID_RC_CONFIG = 0x00003afe

5416 ERROR_MUI_INVALID_LOCALE_NAME = 0x00003aff

5417 ERROR_MUI_INVALID_ULTIMATEFALLBACK_NAME = 0x00003b00

5418 ERROR_MUI_FILE_NOT_LOADED = 0x00003b01

5419 ERROR_RESOURCE_ENUM_USER_STOP = 0x00003b02

5420 ERROR_MUI_INTLSETTINGS_UILANG_NOT_INSTALLED = 0x00003b03

5421 ERROR_MUI_INTLSETTINGS_INVALID_LOCALE_NAME = 0x00003b04

5422 ERROR_MRM_RUNTIME_NO_DEFAULT_OR_NEUTRAL_RESOURCE = 0x00003b06

5423 ERROR_MRM_INVALID_PRICONFIG = 0x00003b07

5424 ERROR_MRM_INVALID_FILE_TYPE = 0x00003b08

5425 ERROR_MRM_UNKNOWN_QUALIFIER = 0x00003b09

5426 ERROR_MRM_INVALID_QUALIFIER_VALUE = 0x00003b0a

5427 ERROR_MRM_NO_CANDIDATE = 0x00003b0b

5428 ERROR_MRM_NO_MATCH_OR_DEFAULT_CANDIDATE = 0x00003b0c

5429 ERROR_MRM_RESOURCE_TYPE_MISMATCH = 0x00003b0d

5430 ERROR_MRM_DUPLICATE_MAP_NAME = 0x00003b0e

5431 ERROR_MRM_DUPLICATE_ENTRY = 0x00003b0f

5432 ERROR_MRM_INVALID_RESOURCE_IDENTIFIER = 0x00003b10

5433 ERROR_MRM_FILEPATH_TOO_LONG = 0x00003b11

5434 ERROR_MRM_UNSUPPORTED_DIRECTORY_TYPE = 0x00003b12

5435 ERROR_MRM_INVALID_PRI_FILE = 0x00003b16

5436 ERROR_MRM_NAMED_RESOURCE_NOT_FOUND = 0x00003b17

5437 ERROR_MRM_MAP_NOT_FOUND = 0x00003b1f

5438 ERROR_MRM_UNSUPPORTED_PROFILE_TYPE = 0x00003b20

5439 ERROR_MRM_INVALID_QUALIFIER_OPERATOR = 0x00003b21

5440 ERROR_MRM_INDETERMINATE_QUALIFIER_VALUE = 0x00003b22

5441 ERROR_MRM_AUTOMERGE_ENABLED = 0x00003b23

5442 ERROR_MRM_TOO_MANY_RESOURCES = 0x00003b24

5443 ERROR_MCA_INVALID_CAPABILITIES_STRING = 0x00003b60

5444 ERROR_MCA_INVALID_VCP_VERSION = 0x00003b61

5445 ERROR_MCA_MONITOR_VIOLATES_MCCS_SPECIFICATION = 0x00003b62

5446 ERROR_MCA_MCCS_VERSION_MISMATCH = 0x00003b63

5447 ERROR_MCA_UNSUPPORTED_MCCS_VERSION = 0x00003b64

5448 ERROR_MCA_INTERNAL_ERROR = 0x00003b65

5449 ERROR_MCA_INVALID_TECHNOLOGY_TYPE_RETURNED = 0x00003b66

5450 ERROR_MCA_UNSUPPORTED_COLOR_TEMPERATURE = 0x00003b67

5451 ERROR_AMBIGUOUS_SYSTEM_DEVICE = 0x00003b92

5452 ERROR_SYSTEM_DEVICE_NOT_FOUND = 0x00003bc3

5453 ERROR_HASH_NOT_SUPPORTED = 0x00003bc4

5454 ERROR_HASH_NOT_PRESENT = 0x00003bc5

5455 ERROR_SECONDARY_IC_PROVIDER_NOT_REGISTERED = 0x00003bd9

5456 ERROR_GPIO_CLIENT_INFORMATION_INVALID = 0x00003bda

5457 ERROR_GPIO_VERSION_NOT_SUPPORTED = 0x00003bdb

5458 ERROR_GPIO_INVALID_REGISTRATION_PACKET = 0x00003bdc

5459 ERROR_GPIO_OPERATION_DENIED = 0x00003bdd

5460 ERROR_GPIO_INCOMPATIBLE_CONNECT_MODE = 0x00003bde

5461 ERROR_GPIO_INTERRUPT_ALREADY_UNMASKED = 0x00003bdf

5462 ERROR_CANNOT_SWITCH_RUNLEVEL = 0x00003c28

5463 ERROR_INVALID_RUNLEVEL_SETTING = 0x00003c29

5464 ERROR_RUNLEVEL_SWITCH_TIMEOUT = 0x00003c2a

5465 ERROR_RUNLEVEL_SWITCH_AGENT_TIMEOUT = 0x00003c2b

5466 ERROR_RUNLEVEL_SWITCH_IN_PROGRESS = 0x00003c2c

5467 ERROR_SERVICES_FAILED_AUTOSTART = 0x00003c2d

5468 ERROR_COM_TASK_STOP_PENDING = 0x00003c8d

5469 ERROR_INSTALL_OPEN_PACKAGE_FAILED = 0x00003cf0

5470 ERROR_INSTALL_PACKAGE_NOT_FOUND = 0x00003cf1

5471 ERROR_INSTALL_INVALID_PACKAGE = 0x00003cf2

5472 ERROR_INSTALL_RESOLVE_DEPENDENCY_FAILED = 0x00003cf3

5473 ERROR_INSTALL_OUT_OF_DISK_SPACE = 0x00003cf4

5474 ERROR_INSTALL_NETWORK_FAILURE = 0x00003cf5

5475 ERROR_INSTALL_REGISTRATION_FAILURE = 0x00003cf6

5476 ERROR_INSTALL_DEREGISTRATION_FAILURE = 0x00003cf7

5477 ERROR_INSTALL_CANCEL = 0x00003cf8

5478 ERROR_INSTALL_FAILED = 0x00003cf9

5479 ERROR_REMOVE_FAILED = 0x00003cfa

5480 ERROR_PACKAGE_ALREADY_EXISTS = 0x00003cfb

5481 ERROR_NEEDS_REMEDIATION = 0x00003cfc

5482 ERROR_INSTALL_PREREQUISITE_FAILED = 0x00003cfd

5483 ERROR_PACKAGE_REPOSITORY_CORRUPTED = 0x00003cfe

5484 ERROR_INSTALL_POLICY_FAILURE = 0x00003cff

5485 ERROR_PACKAGE_UPDATING = 0x00003d00

5486 ERROR_DEPLOYMENT_BLOCKED_BY_POLICY = 0x00003d01

5487 ERROR_PACKAGES_IN_USE = 0x00003d02

5488 ERROR_RECOVERY_FILE_CORRUPT = 0x00003d03

5489 ERROR_INVALID_STAGED_SIGNATURE = 0x00003d04

5490 ERROR_DELETING_EXISTING_APPLICATIONDATA_STORE_FAILED = 0x00003d05

5491 ERROR_INSTALL_PACKAGE_DOWNGRADE = 0x00003d06

5492 ERROR_SYSTEM_NEEDS_REMEDIATION = 0x00003d07

5493 ERROR_APPX_INTEGRITY_FAILURE_CLR_NGEN = 0x00003d08

5494 ERROR_RESILIENCY_FILE_CORRUPT = 0x00003d09

5495 ERROR_INSTALL_FIREWALL_SERVICE_NOT_RUNNING = 0x00003d0a

5496 APPMODEL_ERROR_NO_PACKAGE = 0x00003d54

5497 APPMODEL_ERROR_PACKAGE_RUNTIME_CORRUPT = 0x00003d55

5498 APPMODEL_ERROR_PACKAGE_IDENTITY_CORRUPT = 0x00003d56

5499 APPMODEL_ERROR_NO_APPLICATION = 0x00003d57

5500 ERROR_STATE_LOAD_STORE_FAILED = 0x00003db8

5501 ERROR_STATE_GET_VERSION_FAILED = 0x00003db9

5502 ERROR_STATE_SET_VERSION_FAILED = 0x00003dba

5503 ERROR_STATE_STRUCTURED_RESET_FAILED = 0x00003dbb

5504 ERROR_STATE_OPEN_CONTAINER_FAILED = 0x00003dbc

5505 ERROR_STATE_CREATE_CONTAINER_FAILED = 0x00003dbd

5506 ERROR_STATE_DELETE_CONTAINER_FAILED = 0x00003dbe

5507 ERROR_STATE_READ_SETTING_FAILED = 0x00003dbf

5508 ERROR_STATE_WRITE_SETTING_FAILED = 0x00003dc0

5509 ERROR_STATE_DELETE_SETTING_FAILED = 0x00003dc1

5510 ERROR_STATE_QUERY_SETTING_FAILED = 0x00003dc2

5511 ERROR_STATE_READ_COMPOSITE_SETTING_FAILED = 0x00003dc3

5512 ERROR_STATE_WRITE_COMPOSITE_SETTING_FAILED = 0x00003dc4

5513 ERROR_STATE_ENUMERATE_CONTAINER_FAILED = 0x00003dc5

5514 ERROR_STATE_ENUMERATE_SETTINGS_FAILED = 0x00003dc6

5515 ERROR_STATE_COMPOSITE_SETTING_VALUE_SIZE_LIMIT_EXCEEDED = 0x00003dc7

5516 ERROR_STATE_SETTING_VALUE_SIZE_LIMIT_EXCEEDED = 0x00003dc8

5517 ERROR_STATE_SETTING_NAME_SIZE_LIMIT_EXCEEDED = 0x00003dc9

5518 ERROR_STATE_CONTAINER_NAME_SIZE_LIMIT_EXCEEDED = 0x00003dca

5519 ERROR_API_UNAVAILABLE = 0x00003de1

5520 STORE_ERROR_UNLICENSED = 0x00003df5

5521 STORE_ERROR_UNLICENSED_USER = 0x00003df6